auctionv1alpha1grpc

package
v1.6.0-20250529173016-... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	AuctionService_GetBidStream_FullMethodName = "/astria.auction.v1alpha1.AuctionService/GetBidStream"
)

Variables

var AuctionService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "astria.auction.v1alpha1.AuctionService",
	HandlerType: (*AuctionServiceServer)(nil),
	Methods:     []grpc.MethodDesc{},
	Streams: []grpc.StreamDesc{
		{
			StreamName:    "GetBidStream",
			Handler:       _AuctionService_GetBidStream_Handler,
			ServerStreams: true,
		},
	},
	Metadata: "astria/auction/v1alpha1/auction_service.proto",
}

AuctionService_ServiceDesc is the grpc.ServiceDesc for AuctionService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterAuctionServiceServer

func RegisterAuctionServiceServer(s grpc.ServiceRegistrar, srv AuctionServiceServer)

Types

type AuctionServiceClient

type AuctionServiceClient interface {
	// An auctioneer will initiate this long running stream to receive bids from the rollup node,
	// until either a timeout or the connection is closed by the client.
	GetBidStream(ctx context.Context, in *v1alpha1.GetBidStreamRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[v1alpha1.GetBidStreamResponse], error)
}

AuctionServiceClient is the client API for AuctionService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewAuctionServiceClient

func NewAuctionServiceClient(cc grpc.ClientConnInterface) AuctionServiceClient

type AuctionServiceServer

type AuctionServiceServer interface {
	// An auctioneer will initiate this long running stream to receive bids from the rollup node,
	// until either a timeout or the connection is closed by the client.
	GetBidStream(*v1alpha1.GetBidStreamRequest, grpc.ServerStreamingServer[v1alpha1.GetBidStreamResponse]) error
}

AuctionServiceServer is the server API for AuctionService service. All implementations should embed UnimplementedAuctionServiceServer for forward compatibility.

type AuctionService_GetBidStreamClient

type AuctionService_GetBidStreamClient = grpc.ServerStreamingClient[v1alpha1.GetBidStreamResponse]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type AuctionService_GetBidStreamServer

type AuctionService_GetBidStreamServer = grpc.ServerStreamingServer[v1alpha1.GetBidStreamResponse]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type UnimplementedAuctionServiceServer

type UnimplementedAuctionServiceServer struct{}

UnimplementedAuctionServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedAuctionServiceServer) GetBidStream

type UnsafeAuctionServiceServer

type UnsafeAuctionServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeAuctionServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to AuctionServiceServer will result in compilation errors.

Source Files

  • auction_service_grpc.pb.go

Jump to