executionv1grpc

package
v1.6.0-20250529173016-... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	ExecutionService_GetGenesisInfo_FullMethodName        = "/astria.execution.v1.ExecutionService/GetGenesisInfo"
	ExecutionService_GetBlock_FullMethodName              = "/astria.execution.v1.ExecutionService/GetBlock"
	ExecutionService_BatchGetBlocks_FullMethodName        = "/astria.execution.v1.ExecutionService/BatchGetBlocks"
	ExecutionService_ExecuteBlock_FullMethodName          = "/astria.execution.v1.ExecutionService/ExecuteBlock"
	ExecutionService_GetCommitmentState_FullMethodName    = "/astria.execution.v1.ExecutionService/GetCommitmentState"
	ExecutionService_UpdateCommitmentState_FullMethodName = "/astria.execution.v1.ExecutionService/UpdateCommitmentState"
)

Variables

var ExecutionService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "astria.execution.v1.ExecutionService",
	HandlerType: (*ExecutionServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetGenesisInfo",
			Handler:    _ExecutionService_GetGenesisInfo_Handler,
		},
		{
			MethodName: "GetBlock",
			Handler:    _ExecutionService_GetBlock_Handler,
		},
		{
			MethodName: "BatchGetBlocks",
			Handler:    _ExecutionService_BatchGetBlocks_Handler,
		},
		{
			MethodName: "ExecuteBlock",
			Handler:    _ExecutionService_ExecuteBlock_Handler,
		},
		{
			MethodName: "GetCommitmentState",
			Handler:    _ExecutionService_GetCommitmentState_Handler,
		},
		{
			MethodName: "UpdateCommitmentState",
			Handler:    _ExecutionService_UpdateCommitmentState_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "astria/execution/v1/execution.proto",
}

ExecutionService_ServiceDesc is the grpc.ServiceDesc for ExecutionService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterExecutionServiceServer

func RegisterExecutionServiceServer(s grpc.ServiceRegistrar, srv ExecutionServiceServer)

Types

type ExecutionServiceClient

type ExecutionServiceClient interface {
	// GetGenesisInfo returns the necessary genesis information for rollup chain.
	GetGenesisInfo(ctx context.Context, in *v1.GetGenesisInfoRequest, opts ...grpc.CallOption) (*v1.GenesisInfo, error)
	// GetBlock will return a block given an identifier.
	GetBlock(ctx context.Context, in *v1.GetBlockRequest, opts ...grpc.CallOption) (*v1.Block, error)
	// BatchGetBlocks will return an array of Blocks given an array of block
	// identifiers.
	BatchGetBlocks(ctx context.Context, in *v1.BatchGetBlocksRequest, opts ...grpc.CallOption) (*v1.BatchGetBlocksResponse, error)
	// ExecuteBlock is called to deterministically derive a rollup block from
	// filtered sequencer block information.
	ExecuteBlock(ctx context.Context, in *v1.ExecuteBlockRequest, opts ...grpc.CallOption) (*v1.Block, error)
	// GetCommitmentState fetches the current CommitmentState of the chain.
	GetCommitmentState(ctx context.Context, in *v1.GetCommitmentStateRequest, opts ...grpc.CallOption) (*v1.CommitmentState, error)
	// UpdateCommitmentState replaces the whole CommitmentState with a new
	// CommitmentState.
	UpdateCommitmentState(ctx context.Context, in *v1.UpdateCommitmentStateRequest, opts ...grpc.CallOption) (*v1.CommitmentState, error)
}

ExecutionServiceClient is the client API for ExecutionService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

ExecutionService is used to drive deterministic production of blocks.

The service can be implemented by any blockchain which wants to utilize the Astria Shared Sequencer, and will have block production driven via the Astria "Conductor".

func NewExecutionServiceClient

func NewExecutionServiceClient(cc grpc.ClientConnInterface) ExecutionServiceClient

type ExecutionServiceServer

type ExecutionServiceServer interface {
	// GetGenesisInfo returns the necessary genesis information for rollup chain.
	GetGenesisInfo(context.Context, *v1.GetGenesisInfoRequest) (*v1.GenesisInfo, error)
	// GetBlock will return a block given an identifier.
	GetBlock(context.Context, *v1.GetBlockRequest) (*v1.Block, error)
	// BatchGetBlocks will return an array of Blocks given an array of block
	// identifiers.
	BatchGetBlocks(context.Context, *v1.BatchGetBlocksRequest) (*v1.BatchGetBlocksResponse, error)
	// ExecuteBlock is called to deterministically derive a rollup block from
	// filtered sequencer block information.
	ExecuteBlock(context.Context, *v1.ExecuteBlockRequest) (*v1.Block, error)
	// GetCommitmentState fetches the current CommitmentState of the chain.
	GetCommitmentState(context.Context, *v1.GetCommitmentStateRequest) (*v1.CommitmentState, error)
	// UpdateCommitmentState replaces the whole CommitmentState with a new
	// CommitmentState.
	UpdateCommitmentState(context.Context, *v1.UpdateCommitmentStateRequest) (*v1.CommitmentState, error)
}

ExecutionServiceServer is the server API for ExecutionService service. All implementations should embed UnimplementedExecutionServiceServer for forward compatibility.

ExecutionService is used to drive deterministic production of blocks.

The service can be implemented by any blockchain which wants to utilize the Astria Shared Sequencer, and will have block production driven via the Astria "Conductor".

type UnimplementedExecutionServiceServer

type UnimplementedExecutionServiceServer struct{}

UnimplementedExecutionServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedExecutionServiceServer) BatchGetBlocks

func (UnimplementedExecutionServiceServer) ExecuteBlock

func (UnimplementedExecutionServiceServer) GetBlock

func (UnimplementedExecutionServiceServer) GetCommitmentState

func (UnimplementedExecutionServiceServer) GetGenesisInfo

func (UnimplementedExecutionServiceServer) UpdateCommitmentState

type UnsafeExecutionServiceServer

type UnsafeExecutionServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeExecutionServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ExecutionServiceServer will result in compilation errors.

Source Files

  • execution_grpc.pb.go

Jump to