Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterExecutionServiceServer(s grpc.ServiceRegistrar, srv ExecutionServiceServer)
- type ExecutionServiceClient
- type ExecutionServiceServer
- type UnimplementedExecutionServiceServer
- func (UnimplementedExecutionServiceServer) DoBlock(context.Context, *v1alpha1.DoBlockRequest) (*v1alpha1.DoBlockResponse, error)
- func (UnimplementedExecutionServiceServer) FinalizeBlock(context.Context, *v1alpha1.FinalizeBlockRequest) (*v1alpha1.FinalizeBlockResponse, error)
- func (UnimplementedExecutionServiceServer) InitState(context.Context, *v1alpha1.InitStateRequest) (*v1alpha1.InitStateResponse, error)
- type UnsafeExecutionServiceServer
Constants ¶
const ( ExecutionService_InitState_FullMethodName = "/astria.execution.v1alpha1.ExecutionService/InitState" ExecutionService_DoBlock_FullMethodName = "/astria.execution.v1alpha1.ExecutionService/DoBlock" ExecutionService_FinalizeBlock_FullMethodName = "/astria.execution.v1alpha1.ExecutionService/FinalizeBlock" )
Variables ¶
var ExecutionService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "astria.execution.v1alpha1.ExecutionService", HandlerType: (*ExecutionServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "InitState", Handler: _ExecutionService_InitState_Handler, }, { MethodName: "DoBlock", Handler: _ExecutionService_DoBlock_Handler, }, { MethodName: "FinalizeBlock", Handler: _ExecutionService_FinalizeBlock_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "astria/execution/v1alpha1/execution.proto", }
ExecutionService_ServiceDesc is the grpc.ServiceDesc for ExecutionService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterExecutionServiceServer ¶
func RegisterExecutionServiceServer(s grpc.ServiceRegistrar, srv ExecutionServiceServer)
Types ¶
type ExecutionServiceClient ¶
type ExecutionServiceClient interface {
InitState(ctx context.Context, in *v1alpha1.InitStateRequest, opts ...grpc.CallOption) (*v1alpha1.InitStateResponse, error)
DoBlock(ctx context.Context, in *v1alpha1.DoBlockRequest, opts ...grpc.CallOption) (*v1alpha1.DoBlockResponse, error)
FinalizeBlock(ctx context.Context, in *v1alpha1.FinalizeBlockRequest, opts ...grpc.CallOption) (*v1alpha1.FinalizeBlockResponse, error)
}
ExecutionServiceClient is the client API for ExecutionService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewExecutionServiceClient ¶
func NewExecutionServiceClient(cc grpc.ClientConnInterface) ExecutionServiceClient
type ExecutionServiceServer ¶
type ExecutionServiceServer interface {
InitState(context.Context, *v1alpha1.InitStateRequest) (*v1alpha1.InitStateResponse, error)
DoBlock(context.Context, *v1alpha1.DoBlockRequest) (*v1alpha1.DoBlockResponse, error)
FinalizeBlock(context.Context, *v1alpha1.FinalizeBlockRequest) (*v1alpha1.FinalizeBlockResponse, error)
}
ExecutionServiceServer is the server API for ExecutionService service. All implementations should embed UnimplementedExecutionServiceServer for forward compatibility.
type UnimplementedExecutionServiceServer ¶
type UnimplementedExecutionServiceServer struct{}
UnimplementedExecutionServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedExecutionServiceServer) DoBlock ¶
func (UnimplementedExecutionServiceServer) DoBlock(context.Context, *v1alpha1.DoBlockRequest) (*v1alpha1.DoBlockResponse, error)
func (UnimplementedExecutionServiceServer) FinalizeBlock ¶
func (UnimplementedExecutionServiceServer) FinalizeBlock(context.Context, *v1alpha1.FinalizeBlockRequest) (*v1alpha1.FinalizeBlockResponse, error)
func (UnimplementedExecutionServiceServer) InitState ¶
func (UnimplementedExecutionServiceServer) InitState(context.Context, *v1alpha1.InitStateRequest) (*v1alpha1.InitStateResponse, error)
type UnsafeExecutionServiceServer ¶
type UnsafeExecutionServiceServer interface {
// contains filtered or unexported methods
}
UnsafeExecutionServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ExecutionServiceServer will result in compilation errors.
Source Files
¶
- execution_grpc.pb.go