executionv2grpc

package
v1.6.1-20250529173016-... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	ExecutionService_CreateExecutionSession_FullMethodName   = "/astria.execution.v2.ExecutionService/CreateExecutionSession"
	ExecutionService_GetExecutedBlockMetadata_FullMethodName = "/astria.execution.v2.ExecutionService/GetExecutedBlockMetadata"
	ExecutionService_ExecuteBlock_FullMethodName             = "/astria.execution.v2.ExecutionService/ExecuteBlock"
	ExecutionService_UpdateCommitmentState_FullMethodName    = "/astria.execution.v2.ExecutionService/UpdateCommitmentState"
)

Variables

var ExecutionService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "astria.execution.v2.ExecutionService",
	HandlerType: (*ExecutionServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "CreateExecutionSession",
			Handler:    _ExecutionService_CreateExecutionSession_Handler,
		},
		{
			MethodName: "GetExecutedBlockMetadata",
			Handler:    _ExecutionService_GetExecutedBlockMetadata_Handler,
		},
		{
			MethodName: "ExecuteBlock",
			Handler:    _ExecutionService_ExecuteBlock_Handler,
		},
		{
			MethodName: "UpdateCommitmentState",
			Handler:    _ExecutionService_UpdateCommitmentState_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "astria/execution/v2/execution_service.proto",
}

ExecutionService_ServiceDesc is the grpc.ServiceDesc for ExecutionService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterExecutionServiceServer

func RegisterExecutionServiceServer(s grpc.ServiceRegistrar, srv ExecutionServiceServer)

Types

type ExecutionServiceClient

type ExecutionServiceClient interface {
	// CreateExecutionSession returns the necessary information for mapping sequencer block
	// height to rollup block number.
	CreateExecutionSession(ctx context.Context, in *v2.CreateExecutionSessionRequest, opts ...grpc.CallOption) (*v2.ExecutionSession, error)
	// GetExecutedBlockMetadata will return a block given an identifier.
	GetExecutedBlockMetadata(ctx context.Context, in *v2.GetExecutedBlockMetadataRequest, opts ...grpc.CallOption) (*v2.ExecutedBlockMetadata, error)
	// ExecuteBlock is called to deterministically derive a rollup block from
	// filtered sequencer block information.
	ExecuteBlock(ctx context.Context, in *v2.ExecuteBlockRequest, opts ...grpc.CallOption) (*v2.ExecuteBlockResponse, error)
	// UpdateCommitmentState replaces the whole CommitmentState with a new
	// CommitmentState.
	UpdateCommitmentState(ctx context.Context, in *v2.UpdateCommitmentStateRequest, opts ...grpc.CallOption) (*v2.CommitmentState, error)
}

ExecutionServiceClient is the client API for ExecutionService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

ExecutionService is used to drive deterministic production of blocks.

The service can be implemented by any blockchain which wants to utilize the Astria Shared Sequencer, and will have block production driven via the Astria "Conductor".

func NewExecutionServiceClient

func NewExecutionServiceClient(cc grpc.ClientConnInterface) ExecutionServiceClient

type ExecutionServiceServer

type ExecutionServiceServer interface {
	// CreateExecutionSession returns the necessary information for mapping sequencer block
	// height to rollup block number.
	CreateExecutionSession(context.Context, *v2.CreateExecutionSessionRequest) (*v2.ExecutionSession, error)
	// GetExecutedBlockMetadata will return a block given an identifier.
	GetExecutedBlockMetadata(context.Context, *v2.GetExecutedBlockMetadataRequest) (*v2.ExecutedBlockMetadata, error)
	// ExecuteBlock is called to deterministically derive a rollup block from
	// filtered sequencer block information.
	ExecuteBlock(context.Context, *v2.ExecuteBlockRequest) (*v2.ExecuteBlockResponse, error)
	// UpdateCommitmentState replaces the whole CommitmentState with a new
	// CommitmentState.
	UpdateCommitmentState(context.Context, *v2.UpdateCommitmentStateRequest) (*v2.CommitmentState, error)
}

ExecutionServiceServer is the server API for ExecutionService service. All implementations should embed UnimplementedExecutionServiceServer for forward compatibility.

ExecutionService is used to drive deterministic production of blocks.

The service can be implemented by any blockchain which wants to utilize the Astria Shared Sequencer, and will have block production driven via the Astria "Conductor".

type UnimplementedExecutionServiceServer

type UnimplementedExecutionServiceServer struct{}

UnimplementedExecutionServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedExecutionServiceServer) CreateExecutionSession

func (UnimplementedExecutionServiceServer) ExecuteBlock

func (UnimplementedExecutionServiceServer) GetExecutedBlockMetadata

func (UnimplementedExecutionServiceServer) UpdateCommitmentState

type UnsafeExecutionServiceServer

type UnsafeExecutionServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeExecutionServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ExecutionServiceServer will result in compilation errors.

Source Files

  • execution_service_grpc.pb.go

Jump to