executionv1

package
v1.36.11-2025052917301... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: MIT Imports: 7 Imported by: 1

Documentation

Index

Constants

const BlockIdentifier_BlockHash_case case_BlockIdentifier_Identifier = 2
const BlockIdentifier_BlockNumber_case case_BlockIdentifier_Identifier = 1
const BlockIdentifier_Identifier_not_set_case case_BlockIdentifier_Identifier = 0

Variables

var File_astria_execution_v1_execution_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type BatchGetBlocksRequest

type BatchGetBlocksRequest struct {
	Identifiers []*BlockIdentifier `protobuf:"bytes,1,rep,name=identifiers,proto3" json:"identifiers,omitempty"`
	// contains filtered or unexported fields
}

Used in BatchGetBlocks, will find all or none based on the list of identifiers.

func (*BatchGetBlocksRequest) GetIdentifiers

func (x *BatchGetBlocksRequest) GetIdentifiers() []*BlockIdentifier

func (*BatchGetBlocksRequest) ProtoMessage

func (*BatchGetBlocksRequest) ProtoMessage()

func (*BatchGetBlocksRequest) ProtoReflect

func (x *BatchGetBlocksRequest) ProtoReflect() protoreflect.Message

func (*BatchGetBlocksRequest) Reset

func (x *BatchGetBlocksRequest) Reset()

func (*BatchGetBlocksRequest) SetIdentifiers

func (x *BatchGetBlocksRequest) SetIdentifiers(v []*BlockIdentifier)

func (*BatchGetBlocksRequest) String

func (x *BatchGetBlocksRequest) String() string

type BatchGetBlocksRequest_builder

type BatchGetBlocksRequest_builder struct {
	Identifiers []*BlockIdentifier
	// contains filtered or unexported fields
}

func (BatchGetBlocksRequest_builder) Build

type BatchGetBlocksResponse

type BatchGetBlocksResponse struct {
	Blocks []*Block `protobuf:"bytes,1,rep,name=blocks,proto3" json:"blocks,omitempty"`
	// contains filtered or unexported fields
}

The list of blocks in response to BatchGetBlocks.

func (*BatchGetBlocksResponse) GetBlocks

func (x *BatchGetBlocksResponse) GetBlocks() []*Block

func (*BatchGetBlocksResponse) ProtoMessage

func (*BatchGetBlocksResponse) ProtoMessage()

func (*BatchGetBlocksResponse) ProtoReflect

func (x *BatchGetBlocksResponse) ProtoReflect() protoreflect.Message

func (*BatchGetBlocksResponse) Reset

func (x *BatchGetBlocksResponse) Reset()

func (*BatchGetBlocksResponse) SetBlocks

func (x *BatchGetBlocksResponse) SetBlocks(v []*Block)

func (*BatchGetBlocksResponse) String

func (x *BatchGetBlocksResponse) String() string

type BatchGetBlocksResponse_builder

type BatchGetBlocksResponse_builder struct {
	Blocks []*Block
	// contains filtered or unexported fields
}

func (BatchGetBlocksResponse_builder) Build

type Block

type Block struct {

	// The block number
	Number uint32 `protobuf:"varint,1,opt,name=number,proto3" json:"number,omitempty"`
	// The hash of the block
	Hash []byte `protobuf:"bytes,2,opt,name=hash,proto3" json:"hash,omitempty"`
	// The hash from the parent block
	ParentBlockHash []byte `protobuf:"bytes,3,opt,name=parent_block_hash,json=parentBlockHash,proto3" json:"parent_block_hash,omitempty"`
	// Timestamp on the block, standardized to google protobuf standard.
	Timestamp *timestamppb.Timestamp `protobuf:"bytes,4,opt,name=timestamp,proto3" json:"timestamp,omitempty"`
	// The hash of the sequencer block from which this block was derived.
	//
	// (Optional) This field will only be utilized if the execution node stores
	// this data in blocks during `ExecuteBlock`.
	SequencerBlockHash []byte `protobuf:"bytes,5,opt,name=sequencer_block_hash,json=sequencerBlockHash,proto3" json:"sequencer_block_hash,omitempty"`
	// contains filtered or unexported fields
}

The set of information which deterministic driver of block production must know about a given rollup Block

func (*Block) ClearTimestamp

func (x *Block) ClearTimestamp()

func (*Block) GetHash

func (x *Block) GetHash() []byte

func (*Block) GetNumber

func (x *Block) GetNumber() uint32

func (*Block) GetParentBlockHash

func (x *Block) GetParentBlockHash() []byte

func (*Block) GetSequencerBlockHash

func (x *Block) GetSequencerBlockHash() []byte

func (*Block) GetTimestamp

func (x *Block) GetTimestamp() *timestamppb.Timestamp

func (*Block) HasTimestamp

func (x *Block) HasTimestamp() bool

func (*Block) ProtoMessage

func (*Block) ProtoMessage()

func (*Block) ProtoReflect

func (x *Block) ProtoReflect() protoreflect.Message

func (*Block) Reset

func (x *Block) Reset()

func (*Block) SetHash

func (x *Block) SetHash(v []byte)

func (*Block) SetNumber

func (x *Block) SetNumber(v uint32)

func (*Block) SetParentBlockHash

func (x *Block) SetParentBlockHash(v []byte)

func (*Block) SetSequencerBlockHash

func (x *Block) SetSequencerBlockHash(v []byte)

func (*Block) SetTimestamp

func (x *Block) SetTimestamp(v *timestamppb.Timestamp)

func (*Block) String

func (x *Block) String() string

type BlockIdentifier

type BlockIdentifier struct {

	// Types that are valid to be assigned to Identifier:
	//
	//	*BlockIdentifier_BlockNumber
	//	*BlockIdentifier_BlockHash
	Identifier isBlockIdentifier_Identifier `protobuf_oneof:"identifier"`
	// contains filtered or unexported fields
}

Fields which are indexed for finding blocks on a blockchain.

func (*BlockIdentifier) ClearBlockHash

func (x *BlockIdentifier) ClearBlockHash()

func (*BlockIdentifier) ClearBlockNumber

func (x *BlockIdentifier) ClearBlockNumber()

func (*BlockIdentifier) ClearIdentifier

func (x *BlockIdentifier) ClearIdentifier()

func (*BlockIdentifier) GetBlockHash

func (x *BlockIdentifier) GetBlockHash() []byte

func (*BlockIdentifier) GetBlockNumber

func (x *BlockIdentifier) GetBlockNumber() uint32

func (*BlockIdentifier) GetIdentifier

func (x *BlockIdentifier) GetIdentifier() isBlockIdentifier_Identifier

func (*BlockIdentifier) HasBlockHash

func (x *BlockIdentifier) HasBlockHash() bool

func (*BlockIdentifier) HasBlockNumber

func (x *BlockIdentifier) HasBlockNumber() bool

func (*BlockIdentifier) HasIdentifier

func (x *BlockIdentifier) HasIdentifier() bool

func (*BlockIdentifier) ProtoMessage

func (*BlockIdentifier) ProtoMessage()

func (*BlockIdentifier) ProtoReflect

func (x *BlockIdentifier) ProtoReflect() protoreflect.Message

func (*BlockIdentifier) Reset

func (x *BlockIdentifier) Reset()

func (*BlockIdentifier) SetBlockHash

func (x *BlockIdentifier) SetBlockHash(v []byte)

func (*BlockIdentifier) SetBlockNumber

func (x *BlockIdentifier) SetBlockNumber(v uint32)

func (*BlockIdentifier) String

func (x *BlockIdentifier) String() string

func (*BlockIdentifier) WhichIdentifier

func (x *BlockIdentifier) WhichIdentifier() case_BlockIdentifier_Identifier

type BlockIdentifier_BlockHash

type BlockIdentifier_BlockHash struct {
	BlockHash []byte `protobuf:"bytes,2,opt,name=block_hash,json=blockHash,proto3,oneof"`
}

type BlockIdentifier_BlockNumber

type BlockIdentifier_BlockNumber struct {
	BlockNumber uint32 `protobuf:"varint,1,opt,name=block_number,json=blockNumber,proto3,oneof"`
}

type BlockIdentifier_builder

type BlockIdentifier_builder struct {

	// Fields of oneof Identifier:
	BlockNumber *uint32
	BlockHash   []byte
	// contains filtered or unexported fields
}

func (BlockIdentifier_builder) Build

type Block_builder

type Block_builder struct {

	// The block number
	Number uint32
	// The hash of the block
	Hash []byte
	// The hash from the parent block
	ParentBlockHash []byte
	// Timestamp on the block, standardized to google protobuf standard.
	Timestamp *timestamppb.Timestamp
	// The hash of the sequencer block from which this block was derived.
	//
	// (Optional) This field will only be utilized if the execution node stores
	// this data in blocks during `ExecuteBlock`.
	SequencerBlockHash []byte
	// contains filtered or unexported fields
}

func (Block_builder) Build

func (b0 Block_builder) Build() *Block

type CommitmentState

type CommitmentState struct {

	// Soft commitment is the rollup block matching latest sequencer block.
	Soft *Block `protobuf:"bytes,1,opt,name=soft,proto3" json:"soft,omitempty"`
	// Firm commitment is achieved when data has been seen in DA.
	Firm *Block `protobuf:"bytes,2,opt,name=firm,proto3" json:"firm,omitempty"`
	// The lowest block number of celestia chain to be searched for rollup blocks given current state
	BaseCelestiaHeight uint64 `protobuf:"varint,3,opt,name=base_celestia_height,json=baseCelestiaHeight,proto3" json:"base_celestia_height,omitempty"`
	// contains filtered or unexported fields
}

The CommitmentState holds the block at each stage of sequencer commitment level

A Valid CommitmentState:

  • Block numbers are such that soft >= firm.
  • No blocks ever decrease in block number.
  • The chain defined by soft is the head of the canonical chain the firm block must belong to.

func (*CommitmentState) ClearFirm

func (x *CommitmentState) ClearFirm()

func (*CommitmentState) ClearSoft

func (x *CommitmentState) ClearSoft()

func (*CommitmentState) GetBaseCelestiaHeight

func (x *CommitmentState) GetBaseCelestiaHeight() uint64

func (*CommitmentState) GetFirm

func (x *CommitmentState) GetFirm() *Block

func (*CommitmentState) GetSoft

func (x *CommitmentState) GetSoft() *Block

func (*CommitmentState) HasFirm

func (x *CommitmentState) HasFirm() bool

func (*CommitmentState) HasSoft

func (x *CommitmentState) HasSoft() bool

func (*CommitmentState) ProtoMessage

func (*CommitmentState) ProtoMessage()

func (*CommitmentState) ProtoReflect

func (x *CommitmentState) ProtoReflect() protoreflect.Message

func (*CommitmentState) Reset

func (x *CommitmentState) Reset()

func (*CommitmentState) SetBaseCelestiaHeight

func (x *CommitmentState) SetBaseCelestiaHeight(v uint64)

func (*CommitmentState) SetFirm

func (x *CommitmentState) SetFirm(v *Block)

func (*CommitmentState) SetSoft

func (x *CommitmentState) SetSoft(v *Block)

func (*CommitmentState) String

func (x *CommitmentState) String() string

type CommitmentState_builder

type CommitmentState_builder struct {

	// Soft commitment is the rollup block matching latest sequencer block.
	Soft *Block
	// Firm commitment is achieved when data has been seen in DA.
	Firm *Block
	// The lowest block number of celestia chain to be searched for rollup blocks given current state
	BaseCelestiaHeight uint64
	// contains filtered or unexported fields
}

func (CommitmentState_builder) Build

type ExecuteBlockRequest

type ExecuteBlockRequest struct {

	// The hash of previous block, which new block will be created on top of.
	PrevBlockHash []byte `protobuf:"bytes,1,opt,name=prev_block_hash,json=prevBlockHash,proto3" json:"prev_block_hash,omitempty"`
	// List of transactions to include in the new block.
	Transactions []*v11.RollupData `protobuf:"bytes,2,rep,name=transactions,proto3" json:"transactions,omitempty"`
	// Timestamp to be used for new block.
	Timestamp *timestamppb.Timestamp `protobuf:"bytes,3,opt,name=timestamp,proto3" json:"timestamp,omitempty"`
	// The hash of the sequencer block from which the transactions and timestamp
	// are derived.
	//
	// Utilizing this field is optional for the execution node.
	SequencerBlockHash []byte `protobuf:"bytes,4,opt,name=sequencer_block_hash,json=sequencerBlockHash,proto3" json:"sequencer_block_hash,omitempty"`
	// contains filtered or unexported fields
}

ExecuteBlockRequest contains all the information needed to create a new rollup block.

This information comes from previous rollup blocks, as well as from sequencer blocks.

func (*ExecuteBlockRequest) ClearTimestamp

func (x *ExecuteBlockRequest) ClearTimestamp()

func (*ExecuteBlockRequest) GetPrevBlockHash

func (x *ExecuteBlockRequest) GetPrevBlockHash() []byte

func (*ExecuteBlockRequest) GetSequencerBlockHash

func (x *ExecuteBlockRequest) GetSequencerBlockHash() []byte

func (*ExecuteBlockRequest) GetTimestamp

func (x *ExecuteBlockRequest) GetTimestamp() *timestamppb.Timestamp

func (*ExecuteBlockRequest) GetTransactions

func (x *ExecuteBlockRequest) GetTransactions() []*v11.RollupData

func (*ExecuteBlockRequest) HasTimestamp

func (x *ExecuteBlockRequest) HasTimestamp() bool

func (*ExecuteBlockRequest) ProtoMessage

func (*ExecuteBlockRequest) ProtoMessage()

func (*ExecuteBlockRequest) ProtoReflect

func (x *ExecuteBlockRequest) ProtoReflect() protoreflect.Message

func (*ExecuteBlockRequest) Reset

func (x *ExecuteBlockRequest) Reset()

func (*ExecuteBlockRequest) SetPrevBlockHash

func (x *ExecuteBlockRequest) SetPrevBlockHash(v []byte)

func (*ExecuteBlockRequest) SetSequencerBlockHash

func (x *ExecuteBlockRequest) SetSequencerBlockHash(v []byte)

func (*ExecuteBlockRequest) SetTimestamp

func (x *ExecuteBlockRequest) SetTimestamp(v *timestamppb.Timestamp)

func (*ExecuteBlockRequest) SetTransactions

func (x *ExecuteBlockRequest) SetTransactions(v []*v11.RollupData)

func (*ExecuteBlockRequest) String

func (x *ExecuteBlockRequest) String() string

type ExecuteBlockRequest_builder

type ExecuteBlockRequest_builder struct {

	// The hash of previous block, which new block will be created on top of.
	PrevBlockHash []byte
	// List of transactions to include in the new block.
	Transactions []*v11.RollupData
	// Timestamp to be used for new block.
	Timestamp *timestamppb.Timestamp
	// The hash of the sequencer block from which the transactions and timestamp
	// are derived.
	//
	// Utilizing this field is optional for the execution node.
	SequencerBlockHash []byte
	// contains filtered or unexported fields
}

func (ExecuteBlockRequest_builder) Build

type GenesisInfo

type GenesisInfo struct {

	// The rollup_id is the unique identifier for the rollup chain.
	RollupId *v1.RollupId `protobuf:"bytes,1,opt,name=rollup_id,json=rollupId,proto3" json:"rollup_id,omitempty"`
	// The first block height of sequencer chain to use for rollup transactions.
	SequencerGenesisBlockHeight uint32 `` /* 147-byte string literal not displayed */
	// The allowed variance in celestia for sequencer blocks to have been posted.
	CelestiaBlockVariance uint64 `` /* 127-byte string literal not displayed */
	// contains filtered or unexported fields
}

GenesisInfo contains the information needed to start a rollup chain.

This information is used to determine which sequencer & celestia data to use from the Astria & Celestia networks.

func (*GenesisInfo) ClearRollupId

func (x *GenesisInfo) ClearRollupId()

func (*GenesisInfo) GetCelestiaBlockVariance

func (x *GenesisInfo) GetCelestiaBlockVariance() uint64

func (*GenesisInfo) GetRollupId

func (x *GenesisInfo) GetRollupId() *v1.RollupId

func (*GenesisInfo) GetSequencerGenesisBlockHeight

func (x *GenesisInfo) GetSequencerGenesisBlockHeight() uint32

func (*GenesisInfo) HasRollupId

func (x *GenesisInfo) HasRollupId() bool

func (*GenesisInfo) ProtoMessage

func (*GenesisInfo) ProtoMessage()

func (*GenesisInfo) ProtoReflect

func (x *GenesisInfo) ProtoReflect() protoreflect.Message

func (*GenesisInfo) Reset

func (x *GenesisInfo) Reset()

func (*GenesisInfo) SetCelestiaBlockVariance

func (x *GenesisInfo) SetCelestiaBlockVariance(v uint64)

func (*GenesisInfo) SetRollupId

func (x *GenesisInfo) SetRollupId(v *v1.RollupId)

func (*GenesisInfo) SetSequencerGenesisBlockHeight

func (x *GenesisInfo) SetSequencerGenesisBlockHeight(v uint32)

func (*GenesisInfo) String

func (x *GenesisInfo) String() string

type GenesisInfo_builder

type GenesisInfo_builder struct {

	// The rollup_id is the unique identifier for the rollup chain.
	RollupId *v1.RollupId
	// The first block height of sequencer chain to use for rollup transactions.
	SequencerGenesisBlockHeight uint32
	// The allowed variance in celestia for sequencer blocks to have been posted.
	CelestiaBlockVariance uint64
	// contains filtered or unexported fields
}

func (GenesisInfo_builder) Build

func (b0 GenesisInfo_builder) Build() *GenesisInfo

type GetBlockRequest

type GetBlockRequest struct {
	Identifier *BlockIdentifier `protobuf:"bytes,1,opt,name=identifier,proto3" json:"identifier,omitempty"`
	// contains filtered or unexported fields
}

Used in GetBlock to find a single block.

func (*GetBlockRequest) ClearIdentifier

func (x *GetBlockRequest) ClearIdentifier()

func (*GetBlockRequest) GetIdentifier

func (x *GetBlockRequest) GetIdentifier() *BlockIdentifier

func (*GetBlockRequest) HasIdentifier

func (x *GetBlockRequest) HasIdentifier() bool

func (*GetBlockRequest) ProtoMessage

func (*GetBlockRequest) ProtoMessage()

func (*GetBlockRequest) ProtoReflect

func (x *GetBlockRequest) ProtoReflect() protoreflect.Message

func (*GetBlockRequest) Reset

func (x *GetBlockRequest) Reset()

func (*GetBlockRequest) SetIdentifier

func (x *GetBlockRequest) SetIdentifier(v *BlockIdentifier)

func (*GetBlockRequest) String

func (x *GetBlockRequest) String() string

type GetBlockRequest_builder

type GetBlockRequest_builder struct {
	Identifier *BlockIdentifier
	// contains filtered or unexported fields
}

func (GetBlockRequest_builder) Build

type GetCommitmentStateRequest

type GetCommitmentStateRequest struct {
	// contains filtered or unexported fields
}

There is only one CommitmentState object, so the request is empty.

func (*GetCommitmentStateRequest) ProtoMessage

func (*GetCommitmentStateRequest) ProtoMessage()

func (*GetCommitmentStateRequest) ProtoReflect

func (*GetCommitmentStateRequest) Reset

func (x *GetCommitmentStateRequest) Reset()

func (*GetCommitmentStateRequest) String

func (x *GetCommitmentStateRequest) String() string

type GetCommitmentStateRequest_builder

type GetCommitmentStateRequest_builder struct {
	// contains filtered or unexported fields
}

func (GetCommitmentStateRequest_builder) Build

type GetGenesisInfoRequest

type GetGenesisInfoRequest struct {
	// contains filtered or unexported fields
}

func (*GetGenesisInfoRequest) ProtoMessage

func (*GetGenesisInfoRequest) ProtoMessage()

func (*GetGenesisInfoRequest) ProtoReflect

func (x *GetGenesisInfoRequest) ProtoReflect() protoreflect.Message

func (*GetGenesisInfoRequest) Reset

func (x *GetGenesisInfoRequest) Reset()

func (*GetGenesisInfoRequest) String

func (x *GetGenesisInfoRequest) String() string

type GetGenesisInfoRequest_builder

type GetGenesisInfoRequest_builder struct {
	// contains filtered or unexported fields
}

func (GetGenesisInfoRequest_builder) Build

type UpdateCommitmentStateRequest

type UpdateCommitmentStateRequest struct {
	CommitmentState *CommitmentState `protobuf:"bytes,1,opt,name=commitment_state,json=commitmentState,proto3" json:"commitment_state,omitempty"`
	// contains filtered or unexported fields
}

The CommitmentState to set, must include complete state.

func (*UpdateCommitmentStateRequest) ClearCommitmentState

func (x *UpdateCommitmentStateRequest) ClearCommitmentState()

func (*UpdateCommitmentStateRequest) GetCommitmentState

func (x *UpdateCommitmentStateRequest) GetCommitmentState() *CommitmentState

func (*UpdateCommitmentStateRequest) HasCommitmentState

func (x *UpdateCommitmentStateRequest) HasCommitmentState() bool

func (*UpdateCommitmentStateRequest) ProtoMessage

func (*UpdateCommitmentStateRequest) ProtoMessage()

func (*UpdateCommitmentStateRequest) ProtoReflect

func (*UpdateCommitmentStateRequest) Reset

func (x *UpdateCommitmentStateRequest) Reset()

func (*UpdateCommitmentStateRequest) SetCommitmentState

func (x *UpdateCommitmentStateRequest) SetCommitmentState(v *CommitmentState)

func (*UpdateCommitmentStateRequest) String

type UpdateCommitmentStateRequest_builder

type UpdateCommitmentStateRequest_builder struct {
	CommitmentState *CommitmentState
	// contains filtered or unexported fields
}

func (UpdateCommitmentStateRequest_builder) Build

Source Files

  • execution.pb.go

Jump to