executionv2

package
v1.36.11-2025052917301... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: MIT Imports: 7 Imported by: 1

Documentation

Index

Constants

const ExecutedBlockIdentifier_Hash_case case_ExecutedBlockIdentifier_Identifier = 2
const ExecutedBlockIdentifier_Identifier_not_set_case case_ExecutedBlockIdentifier_Identifier = 0
const ExecutedBlockIdentifier_Number_case case_ExecutedBlockIdentifier_Identifier = 1

Variables

var File_astria_execution_v2_commitment_state_proto protoreflect.FileDescriptor
var File_astria_execution_v2_create_execution_session_request_proto protoreflect.FileDescriptor
var File_astria_execution_v2_execute_block_request_proto protoreflect.FileDescriptor
var File_astria_execution_v2_execute_block_response_proto protoreflect.FileDescriptor
var File_astria_execution_v2_executed_block_identifier_proto protoreflect.FileDescriptor
var File_astria_execution_v2_executed_block_metadata_proto protoreflect.FileDescriptor
var File_astria_execution_v2_execution_service_proto protoreflect.FileDescriptor
var File_astria_execution_v2_execution_session_parameters_proto protoreflect.FileDescriptor
var File_astria_execution_v2_execution_session_proto protoreflect.FileDescriptor
var File_astria_execution_v2_get_executed_block_metadata_request_proto protoreflect.FileDescriptor
var File_astria_execution_v2_update_commitment_state_request_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type CommitmentState

type CommitmentState struct {

	// Soft committed block metadata derived directly from an Astria sequencer block.
	SoftExecutedBlockMetadata *ExecutedBlockMetadata `` /* 140-byte string literal not displayed */
	// Firm committed block metadata derived from a Sequencer block that has been
	// written to the data availability layer (Celestia).
	FirmExecutedBlockMetadata *ExecutedBlockMetadata `` /* 140-byte string literal not displayed */
	// The lowest Celestia height that will be searched for the next firm block.
	// This information is stored as part of `CommitmentState` so that it will be
	// routinely updated as new firm blocks are received, and so that the execution
	// client will not need to search from Celestia genesis.
	LowestCelestiaSearchHeight uint64 `` /* 144-byte string literal not displayed */
	// contains filtered or unexported fields
}

The CommitmentState holds the block at each stage of sequencer commitment level

A Valid CommitmentState:

  • Block numbers are such that soft >= firm.
  • No blocks ever decrease in block number.
  • The chain defined by soft is the head of the canonical chain the firm block must belong to.

func (*CommitmentState) ClearFirmExecutedBlockMetadata

func (x *CommitmentState) ClearFirmExecutedBlockMetadata()

func (*CommitmentState) ClearSoftExecutedBlockMetadata

func (x *CommitmentState) ClearSoftExecutedBlockMetadata()

func (*CommitmentState) GetFirmExecutedBlockMetadata

func (x *CommitmentState) GetFirmExecutedBlockMetadata() *ExecutedBlockMetadata

func (*CommitmentState) GetLowestCelestiaSearchHeight

func (x *CommitmentState) GetLowestCelestiaSearchHeight() uint64

func (*CommitmentState) GetSoftExecutedBlockMetadata

func (x *CommitmentState) GetSoftExecutedBlockMetadata() *ExecutedBlockMetadata

func (*CommitmentState) HasFirmExecutedBlockMetadata

func (x *CommitmentState) HasFirmExecutedBlockMetadata() bool

func (*CommitmentState) HasSoftExecutedBlockMetadata

func (x *CommitmentState) HasSoftExecutedBlockMetadata() bool

func (*CommitmentState) ProtoMessage

func (*CommitmentState) ProtoMessage()

func (*CommitmentState) ProtoReflect

func (x *CommitmentState) ProtoReflect() protoreflect.Message

func (*CommitmentState) Reset

func (x *CommitmentState) Reset()

func (*CommitmentState) SetFirmExecutedBlockMetadata

func (x *CommitmentState) SetFirmExecutedBlockMetadata(v *ExecutedBlockMetadata)

func (*CommitmentState) SetLowestCelestiaSearchHeight

func (x *CommitmentState) SetLowestCelestiaSearchHeight(v uint64)

func (*CommitmentState) SetSoftExecutedBlockMetadata

func (x *CommitmentState) SetSoftExecutedBlockMetadata(v *ExecutedBlockMetadata)

func (*CommitmentState) String

func (x *CommitmentState) String() string

type CommitmentState_builder

type CommitmentState_builder struct {

	// Soft committed block metadata derived directly from an Astria sequencer block.
	SoftExecutedBlockMetadata *ExecutedBlockMetadata
	// Firm committed block metadata derived from a Sequencer block that has been
	// written to the data availability layer (Celestia).
	FirmExecutedBlockMetadata *ExecutedBlockMetadata
	// The lowest Celestia height that will be searched for the next firm block.
	// This information is stored as part of `CommitmentState` so that it will be
	// routinely updated as new firm blocks are received, and so that the execution
	// client will not need to search from Celestia genesis.
	LowestCelestiaSearchHeight uint64
	// contains filtered or unexported fields
}

func (CommitmentState_builder) Build

type CreateExecutionSessionRequest

type CreateExecutionSessionRequest struct {
	// contains filtered or unexported fields
}

CreateExecutionSessionRequest is used to create a new execution session on the rollup.

func (*CreateExecutionSessionRequest) ProtoMessage

func (*CreateExecutionSessionRequest) ProtoMessage()

func (*CreateExecutionSessionRequest) ProtoReflect

func (*CreateExecutionSessionRequest) Reset

func (x *CreateExecutionSessionRequest) Reset()

func (*CreateExecutionSessionRequest) String

type CreateExecutionSessionRequest_builder

type CreateExecutionSessionRequest_builder struct {
	// contains filtered or unexported fields
}

func (CreateExecutionSessionRequest_builder) Build

type ExecuteBlockRequest

type ExecuteBlockRequest struct {

	// The session within which the block is intended to be executed.
	SessionId string `protobuf:"bytes,1,opt,name=session_id,json=sessionId,proto3" json:"session_id,omitempty"`
	// The hash of previous block, which this new block will be created on top of,
	// formatted in the execution node's preferred encoding.
	ParentHash string `protobuf:"bytes,2,opt,name=parent_hash,json=parentHash,proto3" json:"parent_hash,omitempty"`
	// List of transactions to include in the new block.
	Transactions []*v1.RollupData `protobuf:"bytes,3,rep,name=transactions,proto3" json:"transactions,omitempty"`
	// Timestamp to be used for new block.
	Timestamp *timestamppb.Timestamp `protobuf:"bytes,4,opt,name=timestamp,proto3" json:"timestamp,omitempty"`
	// The hash of the sequencer block from which the transactions and timestamp
	// are derived.
	//
	// Must be a 32 byte base16 encoded string. It may be prefixed with `0x`.
	//
	// Utilizing this field is optional for the execution node.
	SequencerBlockHash string `protobuf:"bytes,5,opt,name=sequencer_block_hash,json=sequencerBlockHash,proto3" json:"sequencer_block_hash,omitempty"`
	// contains filtered or unexported fields
}

ExecuteBlockRequest contains all the information needed to create a new rollup block.

This information comes from previous rollup blocks, as well as from sequencer blocks.

func (*ExecuteBlockRequest) ClearTimestamp

func (x *ExecuteBlockRequest) ClearTimestamp()

func (*ExecuteBlockRequest) GetParentHash

func (x *ExecuteBlockRequest) GetParentHash() string

func (*ExecuteBlockRequest) GetSequencerBlockHash

func (x *ExecuteBlockRequest) GetSequencerBlockHash() string

func (*ExecuteBlockRequest) GetSessionId

func (x *ExecuteBlockRequest) GetSessionId() string

func (*ExecuteBlockRequest) GetTimestamp

func (x *ExecuteBlockRequest) GetTimestamp() *timestamppb.Timestamp

func (*ExecuteBlockRequest) GetTransactions

func (x *ExecuteBlockRequest) GetTransactions() []*v1.RollupData

func (*ExecuteBlockRequest) HasTimestamp

func (x *ExecuteBlockRequest) HasTimestamp() bool

func (*ExecuteBlockRequest) ProtoMessage

func (*ExecuteBlockRequest) ProtoMessage()

func (*ExecuteBlockRequest) ProtoReflect

func (x *ExecuteBlockRequest) ProtoReflect() protoreflect.Message

func (*ExecuteBlockRequest) Reset

func (x *ExecuteBlockRequest) Reset()

func (*ExecuteBlockRequest) SetParentHash

func (x *ExecuteBlockRequest) SetParentHash(v string)

func (*ExecuteBlockRequest) SetSequencerBlockHash

func (x *ExecuteBlockRequest) SetSequencerBlockHash(v string)

func (*ExecuteBlockRequest) SetSessionId

func (x *ExecuteBlockRequest) SetSessionId(v string)

func (*ExecuteBlockRequest) SetTimestamp

func (x *ExecuteBlockRequest) SetTimestamp(v *timestamppb.Timestamp)

func (*ExecuteBlockRequest) SetTransactions

func (x *ExecuteBlockRequest) SetTransactions(v []*v1.RollupData)

func (*ExecuteBlockRequest) String

func (x *ExecuteBlockRequest) String() string

type ExecuteBlockRequest_builder

type ExecuteBlockRequest_builder struct {

	// The session within which the block is intended to be executed.
	SessionId string
	// The hash of previous block, which this new block will be created on top of,
	// formatted in the execution node's preferred encoding.
	ParentHash string
	// List of transactions to include in the new block.
	Transactions []*v1.RollupData
	// Timestamp to be used for new block.
	Timestamp *timestamppb.Timestamp
	// The hash of the sequencer block from which the transactions and timestamp
	// are derived.
	//
	// Must be a 32 byte base16 encoded string. It may be prefixed with `0x`.
	//
	// Utilizing this field is optional for the execution node.
	SequencerBlockHash string
	// contains filtered or unexported fields
}

func (ExecuteBlockRequest_builder) Build

type ExecuteBlockResponse

type ExecuteBlockResponse struct {
	ExecutedBlockMetadata *ExecutedBlockMetadata `` /* 126-byte string literal not displayed */
	// contains filtered or unexported fields
}

ExecuteBlockResponse is the response type for the ExecuteBlock RPC. It contains the metadata of the block which was executed against the rollup.

func (*ExecuteBlockResponse) ClearExecutedBlockMetadata

func (x *ExecuteBlockResponse) ClearExecutedBlockMetadata()

func (*ExecuteBlockResponse) GetExecutedBlockMetadata

func (x *ExecuteBlockResponse) GetExecutedBlockMetadata() *ExecutedBlockMetadata

func (*ExecuteBlockResponse) HasExecutedBlockMetadata

func (x *ExecuteBlockResponse) HasExecutedBlockMetadata() bool

func (*ExecuteBlockResponse) ProtoMessage

func (*ExecuteBlockResponse) ProtoMessage()

func (*ExecuteBlockResponse) ProtoReflect

func (x *ExecuteBlockResponse) ProtoReflect() protoreflect.Message

func (*ExecuteBlockResponse) Reset

func (x *ExecuteBlockResponse) Reset()

func (*ExecuteBlockResponse) SetExecutedBlockMetadata

func (x *ExecuteBlockResponse) SetExecutedBlockMetadata(v *ExecutedBlockMetadata)

func (*ExecuteBlockResponse) String

func (x *ExecuteBlockResponse) String() string

type ExecuteBlockResponse_builder

type ExecuteBlockResponse_builder struct {
	ExecutedBlockMetadata *ExecutedBlockMetadata
	// contains filtered or unexported fields
}

func (ExecuteBlockResponse_builder) Build

type ExecutedBlockIdentifier

type ExecutedBlockIdentifier struct {

	// Types that are valid to be assigned to Identifier:
	//
	//	*ExecutedBlockIdentifier_Number
	//	*ExecutedBlockIdentifier_Hash
	Identifier isExecutedBlockIdentifier_Identifier `protobuf_oneof:"identifier"`
	// contains filtered or unexported fields
}

Identifiers to select an executed block by.

func (*ExecutedBlockIdentifier) ClearHash

func (x *ExecutedBlockIdentifier) ClearHash()

func (*ExecutedBlockIdentifier) ClearIdentifier

func (x *ExecutedBlockIdentifier) ClearIdentifier()

func (*ExecutedBlockIdentifier) ClearNumber

func (x *ExecutedBlockIdentifier) ClearNumber()

func (*ExecutedBlockIdentifier) GetHash

func (x *ExecutedBlockIdentifier) GetHash() string

func (*ExecutedBlockIdentifier) GetIdentifier

func (x *ExecutedBlockIdentifier) GetIdentifier() isExecutedBlockIdentifier_Identifier

func (*ExecutedBlockIdentifier) GetNumber

func (x *ExecutedBlockIdentifier) GetNumber() uint64

func (*ExecutedBlockIdentifier) HasHash

func (x *ExecutedBlockIdentifier) HasHash() bool

func (*ExecutedBlockIdentifier) HasIdentifier

func (x *ExecutedBlockIdentifier) HasIdentifier() bool

func (*ExecutedBlockIdentifier) HasNumber

func (x *ExecutedBlockIdentifier) HasNumber() bool

func (*ExecutedBlockIdentifier) ProtoMessage

func (*ExecutedBlockIdentifier) ProtoMessage()

func (*ExecutedBlockIdentifier) ProtoReflect

func (x *ExecutedBlockIdentifier) ProtoReflect() protoreflect.Message

func (*ExecutedBlockIdentifier) Reset

func (x *ExecutedBlockIdentifier) Reset()

func (*ExecutedBlockIdentifier) SetHash

func (x *ExecutedBlockIdentifier) SetHash(v string)

func (*ExecutedBlockIdentifier) SetNumber

func (x *ExecutedBlockIdentifier) SetNumber(v uint64)

func (*ExecutedBlockIdentifier) String

func (x *ExecutedBlockIdentifier) String() string

func (*ExecutedBlockIdentifier) WhichIdentifier

func (x *ExecutedBlockIdentifier) WhichIdentifier() case_ExecutedBlockIdentifier_Identifier

type ExecutedBlockIdentifier_Hash

type ExecutedBlockIdentifier_Hash struct {
	// Identifier by block hash, corresponding to `ExecutedBlockMetadata.hash`.
	Hash string `protobuf:"bytes,2,opt,name=hash,proto3,oneof"`
}

type ExecutedBlockIdentifier_Number

type ExecutedBlockIdentifier_Number struct {
	// Identifier by block number, corresponding to `ExecutedBlockMetadata.number`.
	Number uint64 `protobuf:"varint,1,opt,name=number,proto3,oneof"`
}

type ExecutedBlockIdentifier_builder

type ExecutedBlockIdentifier_builder struct {

	// Fields of oneof Identifier:
	// Identifier by block number, corresponding to `ExecutedBlockMetadata.number`.
	Number *uint64
	// Identifier by block hash, corresponding to `ExecutedBlockMetadata.hash`.
	Hash *string
	// contains filtered or unexported fields
}

func (ExecutedBlockIdentifier_builder) Build

type ExecutedBlockMetadata

type ExecutedBlockMetadata struct {

	// The block number
	Number uint64 `protobuf:"varint,1,opt,name=number,proto3" json:"number,omitempty"`
	// The hash of the block, formatted in the execution node's preferred encoding.
	Hash string `protobuf:"bytes,2,opt,name=hash,proto3" json:"hash,omitempty"`
	// The hash of this block's parent block, formatted in the execution node's preferred
	// encoding.
	ParentHash string `protobuf:"bytes,3,opt,name=parent_hash,json=parentHash,proto3" json:"parent_hash,omitempty"`
	// Timestamp of the block, taken from the sequencer block that this rollup block
	// was constructed from.
	Timestamp *timestamppb.Timestamp `protobuf:"bytes,4,opt,name=timestamp,proto3" json:"timestamp,omitempty"`
	// The hash of the sequencer block from which this block was derived.
	//
	// Must be 32 byte base16 encoded string. It may be prefixed with `0x`.
	//
	// (Optional) This field will only be utilized if the execution node stores
	// this data in blocks during `ExecuteBlock`.
	SequencerBlockHash string `protobuf:"bytes,5,opt,name=sequencer_block_hash,json=sequencerBlockHash,proto3" json:"sequencer_block_hash,omitempty"`
	// contains filtered or unexported fields
}

The set of information which deterministic driver of block production must know about a given rollup Block

func (*ExecutedBlockMetadata) ClearTimestamp

func (x *ExecutedBlockMetadata) ClearTimestamp()

func (*ExecutedBlockMetadata) GetHash

func (x *ExecutedBlockMetadata) GetHash() string

func (*ExecutedBlockMetadata) GetNumber

func (x *ExecutedBlockMetadata) GetNumber() uint64

func (*ExecutedBlockMetadata) GetParentHash

func (x *ExecutedBlockMetadata) GetParentHash() string

func (*ExecutedBlockMetadata) GetSequencerBlockHash

func (x *ExecutedBlockMetadata) GetSequencerBlockHash() string

func (*ExecutedBlockMetadata) GetTimestamp

func (x *ExecutedBlockMetadata) GetTimestamp() *timestamppb.Timestamp

func (*ExecutedBlockMetadata) HasTimestamp

func (x *ExecutedBlockMetadata) HasTimestamp() bool

func (*ExecutedBlockMetadata) ProtoMessage

func (*ExecutedBlockMetadata) ProtoMessage()

func (*ExecutedBlockMetadata) ProtoReflect

func (x *ExecutedBlockMetadata) ProtoReflect() protoreflect.Message

func (*ExecutedBlockMetadata) Reset

func (x *ExecutedBlockMetadata) Reset()

func (*ExecutedBlockMetadata) SetHash

func (x *ExecutedBlockMetadata) SetHash(v string)

func (*ExecutedBlockMetadata) SetNumber

func (x *ExecutedBlockMetadata) SetNumber(v uint64)

func (*ExecutedBlockMetadata) SetParentHash

func (x *ExecutedBlockMetadata) SetParentHash(v string)

func (*ExecutedBlockMetadata) SetSequencerBlockHash

func (x *ExecutedBlockMetadata) SetSequencerBlockHash(v string)

func (*ExecutedBlockMetadata) SetTimestamp

func (x *ExecutedBlockMetadata) SetTimestamp(v *timestamppb.Timestamp)

func (*ExecutedBlockMetadata) String

func (x *ExecutedBlockMetadata) String() string

type ExecutedBlockMetadata_builder

type ExecutedBlockMetadata_builder struct {

	// The block number
	Number uint64
	// The hash of the block, formatted in the execution node's preferred encoding.
	Hash string
	// The hash of this block's parent block, formatted in the execution node's preferred
	// encoding.
	ParentHash string
	// Timestamp of the block, taken from the sequencer block that this rollup block
	// was constructed from.
	Timestamp *timestamppb.Timestamp
	// The hash of the sequencer block from which this block was derived.
	//
	// Must be 32 byte base16 encoded string. It may be prefixed with `0x`.
	//
	// (Optional) This field will only be utilized if the execution node stores
	// this data in blocks during `ExecuteBlock`.
	SequencerBlockHash string
	// contains filtered or unexported fields
}

func (ExecutedBlockMetadata_builder) Build

type ExecutionSession

type ExecutionSession struct {

	// An ID for the session.
	SessionId string `protobuf:"bytes,1,opt,name=session_id,json=sessionId,proto3" json:"session_id,omitempty"`
	// The configuration for the execution session.
	ExecutionSessionParameters *ExecutionSessionParameters `` /* 141-byte string literal not displayed */
	// The commitment state for executing client to start from.
	CommitmentState *CommitmentState `protobuf:"bytes,3,opt,name=commitment_state,json=commitmentState,proto3" json:"commitment_state,omitempty"`
	// contains filtered or unexported fields
}

ExecutionSession contains the information needed to drive the full execution of a rollup chain in the rollup.

The execution session is only valid for the execution config params with which it was created. Once all blocks within the session have been executed, the execution client must request a new session. The session_id is used to to track which session is being used.

func (*ExecutionSession) ClearCommitmentState

func (x *ExecutionSession) ClearCommitmentState()

func (*ExecutionSession) ClearExecutionSessionParameters

func (x *ExecutionSession) ClearExecutionSessionParameters()

func (*ExecutionSession) GetCommitmentState

func (x *ExecutionSession) GetCommitmentState() *CommitmentState

func (*ExecutionSession) GetExecutionSessionParameters

func (x *ExecutionSession) GetExecutionSessionParameters() *ExecutionSessionParameters

func (*ExecutionSession) GetSessionId

func (x *ExecutionSession) GetSessionId() string

func (*ExecutionSession) HasCommitmentState

func (x *ExecutionSession) HasCommitmentState() bool

func (*ExecutionSession) HasExecutionSessionParameters

func (x *ExecutionSession) HasExecutionSessionParameters() bool

func (*ExecutionSession) ProtoMessage

func (*ExecutionSession) ProtoMessage()

func (*ExecutionSession) ProtoReflect

func (x *ExecutionSession) ProtoReflect() protoreflect.Message

func (*ExecutionSession) Reset

func (x *ExecutionSession) Reset()

func (*ExecutionSession) SetCommitmentState

func (x *ExecutionSession) SetCommitmentState(v *CommitmentState)

func (*ExecutionSession) SetExecutionSessionParameters

func (x *ExecutionSession) SetExecutionSessionParameters(v *ExecutionSessionParameters)

func (*ExecutionSession) SetSessionId

func (x *ExecutionSession) SetSessionId(v string)

func (*ExecutionSession) String

func (x *ExecutionSession) String() string

type ExecutionSessionParameters

type ExecutionSessionParameters struct {

	// The rollup_id is the unique identifier for the rollup chain.
	RollupId *v1.RollupId `protobuf:"bytes,1,opt,name=rollup_id,json=rollupId,proto3" json:"rollup_id,omitempty"`
	// The first rollup block number to be executed. This is mapped to `sequencer_first_block_height`.
	// The minimum first block number is 1, since 0 represents the genesis block.
	// Implementors should reject a value of 0.
	//
	// Servers implementing this API should reject execution of blocks below this
	// value with an OUT_OF_RANGE error code.
	RollupStartBlockNumber uint64 `` /* 132-byte string literal not displayed */
	// The final rollup block number to execute as part of a session.
	//
	// If not set or set to 0, the execution session does not have an upper bound.
	//
	// Servers implementing this API should reject execution of blocks past this
	// value with an OUT_OF_RANGE error code.
	RollupEndBlockNumber uint64 `` /* 126-byte string literal not displayed */
	// The ID of the Astria Sequencer network to retrieve Sequencer blocks from.
	// Conductor implementations should verify that the Sequencer network they are
	// connected to have this chain ID (if fetching soft Sequencer blocks), and verify
	// that the Sequencer metadata blobs retrieved from Celestia contain this chain
	// ID (if extracting firm Sequencer blocks from Celestia blobs).
	SequencerChainId string `protobuf:"bytes,4,opt,name=sequencer_chain_id,json=sequencerChainId,proto3" json:"sequencer_chain_id,omitempty"`
	// The first block height on the sequencer chain to use for rollup transactions.
	// This is mapped to `rollup_start_block_number`.
	SequencerStartBlockHeight uint64 `` /* 141-byte string literal not displayed */
	// The ID of the Celestia network to retrieve blobs from.
	// Conductor implementations should verify that the Celestia network they are
	// connected to have this chain ID (if extracting firm Sequencer blocks from
	// Celestia blobs).
	CelestiaChainId string `protobuf:"bytes,6,opt,name=celestia_chain_id,json=celestiaChainId,proto3" json:"celestia_chain_id,omitempty"`
	// The maximum number of Celestia blocks which can be read above
	// `CommitmentState.lowest_celestia_search_height` in search of the next firm
	// block.
	//
	// Cannot be set to 0 if Conductor is configured to use firm commitments. If
	// Conductor is in soft-only mode, this value is ignored.
	CelestiaSearchHeightMaxLookAhead uint64 `` /* 166-byte string literal not displayed */
	// contains filtered or unexported fields
}

ExecutionSessionParameters contains the information needed to map sequencer block height to rollup block number for driving execution.

This information is used to determine which Astria sequencer and Celestia data to use from the Astria & Celestia networks, as well as define the bounds of block numbers to execute in the given session.

func (*ExecutionSessionParameters) ClearRollupId

func (x *ExecutionSessionParameters) ClearRollupId()

func (*ExecutionSessionParameters) GetCelestiaChainId

func (x *ExecutionSessionParameters) GetCelestiaChainId() string

func (*ExecutionSessionParameters) GetCelestiaSearchHeightMaxLookAhead

func (x *ExecutionSessionParameters) GetCelestiaSearchHeightMaxLookAhead() uint64

func (*ExecutionSessionParameters) GetRollupEndBlockNumber

func (x *ExecutionSessionParameters) GetRollupEndBlockNumber() uint64

func (*ExecutionSessionParameters) GetRollupId

func (x *ExecutionSessionParameters) GetRollupId() *v1.RollupId

func (*ExecutionSessionParameters) GetRollupStartBlockNumber

func (x *ExecutionSessionParameters) GetRollupStartBlockNumber() uint64

func (*ExecutionSessionParameters) GetSequencerChainId

func (x *ExecutionSessionParameters) GetSequencerChainId() string

func (*ExecutionSessionParameters) GetSequencerStartBlockHeight

func (x *ExecutionSessionParameters) GetSequencerStartBlockHeight() uint64

func (*ExecutionSessionParameters) HasRollupId

func (x *ExecutionSessionParameters) HasRollupId() bool

func (*ExecutionSessionParameters) ProtoMessage

func (*ExecutionSessionParameters) ProtoMessage()

func (*ExecutionSessionParameters) ProtoReflect

func (*ExecutionSessionParameters) Reset

func (x *ExecutionSessionParameters) Reset()

func (*ExecutionSessionParameters) SetCelestiaChainId

func (x *ExecutionSessionParameters) SetCelestiaChainId(v string)

func (*ExecutionSessionParameters) SetCelestiaSearchHeightMaxLookAhead

func (x *ExecutionSessionParameters) SetCelestiaSearchHeightMaxLookAhead(v uint64)

func (*ExecutionSessionParameters) SetRollupEndBlockNumber

func (x *ExecutionSessionParameters) SetRollupEndBlockNumber(v uint64)

func (*ExecutionSessionParameters) SetRollupId

func (x *ExecutionSessionParameters) SetRollupId(v *v1.RollupId)

func (*ExecutionSessionParameters) SetRollupStartBlockNumber

func (x *ExecutionSessionParameters) SetRollupStartBlockNumber(v uint64)

func (*ExecutionSessionParameters) SetSequencerChainId

func (x *ExecutionSessionParameters) SetSequencerChainId(v string)

func (*ExecutionSessionParameters) SetSequencerStartBlockHeight

func (x *ExecutionSessionParameters) SetSequencerStartBlockHeight(v uint64)

func (*ExecutionSessionParameters) String

func (x *ExecutionSessionParameters) String() string

type ExecutionSessionParameters_builder

type ExecutionSessionParameters_builder struct {

	// The rollup_id is the unique identifier for the rollup chain.
	RollupId *v1.RollupId
	// The first rollup block number to be executed. This is mapped to `sequencer_first_block_height`.
	// The minimum first block number is 1, since 0 represents the genesis block.
	// Implementors should reject a value of 0.
	//
	// Servers implementing this API should reject execution of blocks below this
	// value with an OUT_OF_RANGE error code.
	RollupStartBlockNumber uint64
	// The final rollup block number to execute as part of a session.
	//
	// If not set or set to 0, the execution session does not have an upper bound.
	//
	// Servers implementing this API should reject execution of blocks past this
	// value with an OUT_OF_RANGE error code.
	RollupEndBlockNumber uint64
	// The ID of the Astria Sequencer network to retrieve Sequencer blocks from.
	// Conductor implementations should verify that the Sequencer network they are
	// connected to have this chain ID (if fetching soft Sequencer blocks), and verify
	// that the Sequencer metadata blobs retrieved from Celestia contain this chain
	// ID (if extracting firm Sequencer blocks from Celestia blobs).
	SequencerChainId string
	// The first block height on the sequencer chain to use for rollup transactions.
	// This is mapped to `rollup_start_block_number`.
	SequencerStartBlockHeight uint64
	// The ID of the Celestia network to retrieve blobs from.
	// Conductor implementations should verify that the Celestia network they are
	// connected to have this chain ID (if extracting firm Sequencer blocks from
	// Celestia blobs).
	CelestiaChainId string
	// The maximum number of Celestia blocks which can be read above
	// `CommitmentState.lowest_celestia_search_height` in search of the next firm
	// block.
	//
	// Cannot be set to 0 if Conductor is configured to use firm commitments. If
	// Conductor is in soft-only mode, this value is ignored.
	CelestiaSearchHeightMaxLookAhead uint64
	// contains filtered or unexported fields
}

func (ExecutionSessionParameters_builder) Build

type ExecutionSession_builder

type ExecutionSession_builder struct {

	// An ID for the session.
	SessionId string
	// The configuration for the execution session.
	ExecutionSessionParameters *ExecutionSessionParameters
	// The commitment state for executing client to start from.
	CommitmentState *CommitmentState
	// contains filtered or unexported fields
}

func (ExecutionSession_builder) Build

type GetExecutedBlockMetadataRequest

type GetExecutedBlockMetadataRequest struct {
	Identifier *ExecutedBlockIdentifier `protobuf:"bytes,1,opt,name=identifier,proto3" json:"identifier,omitempty"`
	// contains filtered or unexported fields
}

Used in GetExecutedBlockMetadata to find a single block.

func (*GetExecutedBlockMetadataRequest) ClearIdentifier

func (x *GetExecutedBlockMetadataRequest) ClearIdentifier()

func (*GetExecutedBlockMetadataRequest) GetIdentifier

func (*GetExecutedBlockMetadataRequest) HasIdentifier

func (x *GetExecutedBlockMetadataRequest) HasIdentifier() bool

func (*GetExecutedBlockMetadataRequest) ProtoMessage

func (*GetExecutedBlockMetadataRequest) ProtoMessage()

func (*GetExecutedBlockMetadataRequest) ProtoReflect

func (*GetExecutedBlockMetadataRequest) Reset

func (*GetExecutedBlockMetadataRequest) SetIdentifier

func (*GetExecutedBlockMetadataRequest) String

type GetExecutedBlockMetadataRequest_builder

type GetExecutedBlockMetadataRequest_builder struct {
	Identifier *ExecutedBlockIdentifier
	// contains filtered or unexported fields
}

func (GetExecutedBlockMetadataRequest_builder) Build

type UpdateCommitmentStateRequest

type UpdateCommitmentStateRequest struct {

	// The session which the commitment state is being updated within.
	SessionId string `protobuf:"bytes,1,opt,name=session_id,json=sessionId,proto3" json:"session_id,omitempty"`
	// The new commitment state to set.
	CommitmentState *CommitmentState `protobuf:"bytes,2,opt,name=commitment_state,json=commitmentState,proto3" json:"commitment_state,omitempty"`
	// contains filtered or unexported fields
}

The CommitmentState to set, must include complete state.

func (*UpdateCommitmentStateRequest) ClearCommitmentState

func (x *UpdateCommitmentStateRequest) ClearCommitmentState()

func (*UpdateCommitmentStateRequest) GetCommitmentState

func (x *UpdateCommitmentStateRequest) GetCommitmentState() *CommitmentState

func (*UpdateCommitmentStateRequest) GetSessionId

func (x *UpdateCommitmentStateRequest) GetSessionId() string

func (*UpdateCommitmentStateRequest) HasCommitmentState

func (x *UpdateCommitmentStateRequest) HasCommitmentState() bool

func (*UpdateCommitmentStateRequest) ProtoMessage

func (*UpdateCommitmentStateRequest) ProtoMessage()

func (*UpdateCommitmentStateRequest) ProtoReflect

func (*UpdateCommitmentStateRequest) Reset

func (x *UpdateCommitmentStateRequest) Reset()

func (*UpdateCommitmentStateRequest) SetCommitmentState

func (x *UpdateCommitmentStateRequest) SetCommitmentState(v *CommitmentState)

func (*UpdateCommitmentStateRequest) SetSessionId

func (x *UpdateCommitmentStateRequest) SetSessionId(v string)

func (*UpdateCommitmentStateRequest) String

type UpdateCommitmentStateRequest_builder

type UpdateCommitmentStateRequest_builder struct {

	// The session which the commitment state is being updated within.
	SessionId string
	// The new commitment state to set.
	CommitmentState *CommitmentState
	// contains filtered or unexported fields
}

func (UpdateCommitmentStateRequest_builder) Build

Source Files

  • commitment_state.pb.go
  • create_execution_session_request.pb.go
  • execute_block_request.pb.go
  • execute_block_response.pb.go
  • executed_block_identifier.pb.go
  • executed_block_metadata.pb.go
  • execution_service.pb.go
  • execution_session.pb.go
  • execution_session_parameters.pb.go
  • get_executed_block_metadata_request.pb.go
  • update_commitment_state_request.pb.go

Jump to