optimistic_executionv1alpha1

package
v1.36.11-2025052917301... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: MIT Imports: 7 Imported by: 1

Documentation

Index

Constants

This section is empty.

Variables

var File_astria_optimistic_execution_v1alpha1_base_block_proto protoreflect.FileDescriptor
var File_astria_optimistic_execution_v1alpha1_execute_optimistic_block_stream_request_proto protoreflect.FileDescriptor
var File_astria_optimistic_execution_v1alpha1_execute_optimistic_block_stream_response_proto protoreflect.FileDescriptor
var File_astria_optimistic_execution_v1alpha1_optimistic_execution_service_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type BaseBlock

type BaseBlock struct {

	// This is the block hash for the proposed block.
	SequencerBlockHash []byte `protobuf:"bytes,1,opt,name=sequencer_block_hash,json=sequencerBlockHash,proto3" json:"sequencer_block_hash,omitempty"`
	// List of transactions to include in the new block.
	Transactions []*v1.RollupData `protobuf:"bytes,2,rep,name=transactions,proto3" json:"transactions,omitempty"`
	// Timestamp to be used for new block.
	Timestamp *timestamppb.Timestamp `protobuf:"bytes,3,opt,name=timestamp,proto3" json:"timestamp,omitempty"`
	// contains filtered or unexported fields
}

The "BaseBlock" is the information needed to simulate bundles on top of a Sequencer block which may not have been committed yet.

func (*BaseBlock) ClearTimestamp

func (x *BaseBlock) ClearTimestamp()

func (*BaseBlock) GetSequencerBlockHash

func (x *BaseBlock) GetSequencerBlockHash() []byte

func (*BaseBlock) GetTimestamp

func (x *BaseBlock) GetTimestamp() *timestamppb.Timestamp

func (*BaseBlock) GetTransactions

func (x *BaseBlock) GetTransactions() []*v1.RollupData

func (*BaseBlock) HasTimestamp

func (x *BaseBlock) HasTimestamp() bool

func (*BaseBlock) ProtoMessage

func (*BaseBlock) ProtoMessage()

func (*BaseBlock) ProtoReflect

func (x *BaseBlock) ProtoReflect() protoreflect.Message

func (*BaseBlock) Reset

func (x *BaseBlock) Reset()

func (*BaseBlock) SetSequencerBlockHash

func (x *BaseBlock) SetSequencerBlockHash(v []byte)

func (*BaseBlock) SetTimestamp

func (x *BaseBlock) SetTimestamp(v *timestamppb.Timestamp)

func (*BaseBlock) SetTransactions

func (x *BaseBlock) SetTransactions(v []*v1.RollupData)

func (*BaseBlock) String

func (x *BaseBlock) String() string

type BaseBlock_builder

type BaseBlock_builder struct {

	// This is the block hash for the proposed block.
	SequencerBlockHash []byte
	// List of transactions to include in the new block.
	Transactions []*v1.RollupData
	// Timestamp to be used for new block.
	Timestamp *timestamppb.Timestamp
	// contains filtered or unexported fields
}

func (BaseBlock_builder) Build

func (b0 BaseBlock_builder) Build() *BaseBlock

type ExecuteOptimisticBlockStreamRequest

type ExecuteOptimisticBlockStreamRequest struct {
	BaseBlock *BaseBlock `protobuf:"bytes,1,opt,name=base_block,json=baseBlock,proto3" json:"base_block,omitempty"`
	// contains filtered or unexported fields
}

func (*ExecuteOptimisticBlockStreamRequest) ClearBaseBlock

func (x *ExecuteOptimisticBlockStreamRequest) ClearBaseBlock()

func (*ExecuteOptimisticBlockStreamRequest) GetBaseBlock

func (*ExecuteOptimisticBlockStreamRequest) HasBaseBlock

func (x *ExecuteOptimisticBlockStreamRequest) HasBaseBlock() bool

func (*ExecuteOptimisticBlockStreamRequest) ProtoMessage

func (*ExecuteOptimisticBlockStreamRequest) ProtoMessage()

func (*ExecuteOptimisticBlockStreamRequest) ProtoReflect

func (*ExecuteOptimisticBlockStreamRequest) Reset

func (*ExecuteOptimisticBlockStreamRequest) SetBaseBlock

func (x *ExecuteOptimisticBlockStreamRequest) SetBaseBlock(v *BaseBlock)

func (*ExecuteOptimisticBlockStreamRequest) String

type ExecuteOptimisticBlockStreamRequest_builder

type ExecuteOptimisticBlockStreamRequest_builder struct {
	BaseBlock *BaseBlock
	// contains filtered or unexported fields
}

func (ExecuteOptimisticBlockStreamRequest_builder) Build

type ExecuteOptimisticBlockStreamResponse

type ExecuteOptimisticBlockStreamResponse struct {

	// Metadata identifying the block resulting from executing a block. Includes number, hash,
	// parent hash and timestamp.
	Block *v2.ExecutedBlockMetadata `protobuf:"bytes,1,opt,name=block,proto3" json:"block,omitempty"`
	// The base_sequencer_block_hash is the hash from the base sequencer block this block
	// is based on. This is used to associate an optimistic execution result with the hash
	// received once a sequencer block is committed.
	BaseSequencerBlockHash []byte `` /* 131-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*ExecuteOptimisticBlockStreamResponse) ClearBlock

func (x *ExecuteOptimisticBlockStreamResponse) ClearBlock()

func (*ExecuteOptimisticBlockStreamResponse) GetBaseSequencerBlockHash

func (x *ExecuteOptimisticBlockStreamResponse) GetBaseSequencerBlockHash() []byte

func (*ExecuteOptimisticBlockStreamResponse) GetBlock

func (*ExecuteOptimisticBlockStreamResponse) HasBlock

func (*ExecuteOptimisticBlockStreamResponse) ProtoMessage

func (*ExecuteOptimisticBlockStreamResponse) ProtoMessage()

func (*ExecuteOptimisticBlockStreamResponse) ProtoReflect

func (*ExecuteOptimisticBlockStreamResponse) Reset

func (*ExecuteOptimisticBlockStreamResponse) SetBaseSequencerBlockHash

func (x *ExecuteOptimisticBlockStreamResponse) SetBaseSequencerBlockHash(v []byte)

func (*ExecuteOptimisticBlockStreamResponse) SetBlock

func (*ExecuteOptimisticBlockStreamResponse) String

type ExecuteOptimisticBlockStreamResponse_builder

type ExecuteOptimisticBlockStreamResponse_builder struct {

	// Metadata identifying the block resulting from executing a block. Includes number, hash,
	// parent hash and timestamp.
	Block *v2.ExecutedBlockMetadata
	// The base_sequencer_block_hash is the hash from the base sequencer block this block
	// is based on. This is used to associate an optimistic execution result with the hash
	// received once a sequencer block is committed.
	BaseSequencerBlockHash []byte
	// contains filtered or unexported fields
}

func (ExecuteOptimisticBlockStreamResponse_builder) Build

Source Files

  • base_block.pb.go
  • execute_optimistic_block_stream_request.pb.go
  • execute_optimistic_block_stream_response.pb.go
  • optimistic_execution_service.pb.go

Jump to