primitivev1

package
v1.36.10-2025041015315... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: MIT Imports: 4 Imported by: 20

Documentation

Index

Constants

This section is empty.

Variables

var File_astria_primitive_v1_types_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type Address

type Address struct {

	// A bech32m encoded string. The data are the first 20 bytes of a sha256-hashed ed25519
	// public key. Implementors must not accept both the `bytes` and `bech32m` being set.
	Bech32M string `protobuf:"bytes,2,opt,name=bech32m,proto3" json:"bech32m,omitempty"`
	// contains filtered or unexported fields
}

An Astria `Address`.

Astria addresses are bech32m encoded strings, with the data part being the first 20 entries of a sha256-hashed ed25519 public key.

func (*Address) GetBech32M

func (x *Address) GetBech32M() string

func (*Address) ProtoMessage

func (*Address) ProtoMessage()

func (*Address) ProtoReflect

func (x *Address) ProtoReflect() protoreflect.Message

func (*Address) Reset

func (x *Address) Reset()

func (*Address) SetBech32M

func (x *Address) SetBech32M(v string)

func (*Address) String

func (x *Address) String() string

type Address_builder

type Address_builder struct {

	// A bech32m encoded string. The data are the first 20 bytes of a sha256-hashed ed25519
	// public key. Implementors must not accept both the `bytes` and `bech32m` being set.
	Bech32M string
	// contains filtered or unexported fields
}

func (Address_builder) Build

func (b0 Address_builder) Build() *Address

type Denom

type Denom struct {
	Id        []byte `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	BaseDenom string `protobuf:"bytes,2,opt,name=base_denom,json=baseDenom,proto3" json:"base_denom,omitempty"`
	// contains filtered or unexported fields
}

/ Represents a denomination of some asset used within the sequencer. / The `id` is used to identify the asset and for balance accounting.

func (*Denom) GetBaseDenom

func (x *Denom) GetBaseDenom() string

func (*Denom) GetId

func (x *Denom) GetId() []byte

func (*Denom) ProtoMessage

func (*Denom) ProtoMessage()

func (*Denom) ProtoReflect

func (x *Denom) ProtoReflect() protoreflect.Message

func (*Denom) Reset

func (x *Denom) Reset()

func (*Denom) SetBaseDenom

func (x *Denom) SetBaseDenom(v string)

func (*Denom) SetId

func (x *Denom) SetId(v []byte)

func (*Denom) String

func (x *Denom) String() string

type Denom_builder

type Denom_builder struct {
	Id        []byte
	BaseDenom string
	// contains filtered or unexported fields
}

func (Denom_builder) Build

func (b0 Denom_builder) Build() *Denom

type Int128

type Int128 struct {
	Lo uint64 `protobuf:"varint,1,opt,name=lo,proto3" json:"lo,omitempty"`
	Hi uint64 `protobuf:"varint,2,opt,name=hi,proto3" json:"hi,omitempty"`
	// contains filtered or unexported fields
}

A 128 bit signed integer encoded in protobuf.

Protobuf does not support integers larger than 64 bits, so this message encodes a i128 by splitting it into its upper 64 and lower 64 bits, each encoded as a uint64.

A native i128 x can then be constructed by casting both integers to i128, left shifting hi by 64 positions and adding lo:

x = (hi as i128) << 64 + (lo as i128)

func (*Int128) GetHi

func (x *Int128) GetHi() uint64

func (*Int128) GetLo

func (x *Int128) GetLo() uint64

func (*Int128) ProtoMessage

func (*Int128) ProtoMessage()

func (*Int128) ProtoReflect

func (x *Int128) ProtoReflect() protoreflect.Message

func (*Int128) Reset

func (x *Int128) Reset()

func (*Int128) SetHi

func (x *Int128) SetHi(v uint64)

func (*Int128) SetLo

func (x *Int128) SetLo(v uint64)

func (*Int128) String

func (x *Int128) String() string

type Int128_builder

type Int128_builder struct {
	Lo uint64
	Hi uint64
	// contains filtered or unexported fields
}

func (Int128_builder) Build

func (b0 Int128_builder) Build() *Int128

type Proof

type Proof struct {

	// A sequence of 32 byte hashes used to reconstruct a Merkle Tree Hash.
	AuditPath []byte `protobuf:"bytes,1,opt,name=audit_path,json=auditPath,proto3" json:"audit_path,omitempty"`
	// The index of the leaf this proof applies to.
	LeafIndex uint64 `protobuf:"varint,2,opt,name=leaf_index,json=leafIndex,proto3" json:"leaf_index,omitempty"`
	// The total size of the tree this proof was derived from.
	TreeSize uint64 `protobuf:"varint,3,opt,name=tree_size,json=treeSize,proto3" json:"tree_size,omitempty"`
	// contains filtered or unexported fields
}

A proof for a tree of the given size containing the audit path from a leaf to the root.

func (*Proof) GetAuditPath

func (x *Proof) GetAuditPath() []byte

func (*Proof) GetLeafIndex

func (x *Proof) GetLeafIndex() uint64

func (*Proof) GetTreeSize

func (x *Proof) GetTreeSize() uint64

func (*Proof) ProtoMessage

func (*Proof) ProtoMessage()

func (*Proof) ProtoReflect

func (x *Proof) ProtoReflect() protoreflect.Message

func (*Proof) Reset

func (x *Proof) Reset()

func (*Proof) SetAuditPath

func (x *Proof) SetAuditPath(v []byte)

func (*Proof) SetLeafIndex

func (x *Proof) SetLeafIndex(v uint64)

func (*Proof) SetTreeSize

func (x *Proof) SetTreeSize(v uint64)

func (*Proof) String

func (x *Proof) String() string

type Proof_builder

type Proof_builder struct {

	// A sequence of 32 byte hashes used to reconstruct a Merkle Tree Hash.
	AuditPath []byte
	// The index of the leaf this proof applies to.
	LeafIndex uint64
	// The total size of the tree this proof was derived from.
	TreeSize uint64
	// contains filtered or unexported fields
}

func (Proof_builder) Build

func (b0 Proof_builder) Build() *Proof

type RollupId

type RollupId struct {
	Inner []byte `protobuf:"bytes,1,opt,name=inner,proto3" json:"inner,omitempty"`
	// contains filtered or unexported fields
}

A `RollupId` is a unique identifier for a rollup chain. It must be 32 bytes long. It can be derived from a string using a sha256 hash.

func (*RollupId) GetInner

func (x *RollupId) GetInner() []byte

func (*RollupId) ProtoMessage

func (*RollupId) ProtoMessage()

func (*RollupId) ProtoReflect

func (x *RollupId) ProtoReflect() protoreflect.Message

func (*RollupId) Reset

func (x *RollupId) Reset()

func (*RollupId) SetInner

func (x *RollupId) SetInner(v []byte)

func (*RollupId) String

func (x *RollupId) String() string

type RollupId_builder

type RollupId_builder struct {
	Inner []byte
	// contains filtered or unexported fields
}

func (RollupId_builder) Build

func (b0 RollupId_builder) Build() *RollupId

type TransactionId

type TransactionId struct {

	// The hash of the transaction which the ID represents.
	// It must be a lower hex-encoded 32-byte hash.
	Inner string `protobuf:"bytes,1,opt,name=inner,proto3" json:"inner,omitempty"`
	// contains filtered or unexported fields
}

A `TransactionId` is a unique identifier for a transaction. It contains the hash of the transaction, to be included in rollup deposit events for source tracking.

func (*TransactionId) GetInner

func (x *TransactionId) GetInner() string

func (*TransactionId) ProtoMessage

func (*TransactionId) ProtoMessage()

func (*TransactionId) ProtoReflect

func (x *TransactionId) ProtoReflect() protoreflect.Message

func (*TransactionId) Reset

func (x *TransactionId) Reset()

func (*TransactionId) SetInner

func (x *TransactionId) SetInner(v string)

func (*TransactionId) String

func (x *TransactionId) String() string

type TransactionId_builder

type TransactionId_builder struct {

	// The hash of the transaction which the ID represents.
	// It must be a lower hex-encoded 32-byte hash.
	Inner string
	// contains filtered or unexported fields
}

func (TransactionId_builder) Build

type Uint128

type Uint128 struct {
	Lo uint64 `protobuf:"varint,1,opt,name=lo,proto3" json:"lo,omitempty"`
	Hi uint64 `protobuf:"varint,2,opt,name=hi,proto3" json:"hi,omitempty"`
	// contains filtered or unexported fields
}

A 128 bit unsigned integer encoded in protobuf.

Protobuf does not support integers larger than 64 bits, so this message encodes a u128 by splitting it into its upper 64 and lower 64 bits, each encoded as a uint64.

A native u128 x can then be constructed by casting both integers to u128, left shifting hi by 64 positions and adding lo:

x = (hi as u128) << 64 + (lo as u128)

func (*Uint128) GetHi

func (x *Uint128) GetHi() uint64

func (*Uint128) GetLo

func (x *Uint128) GetLo() uint64

func (*Uint128) ProtoMessage

func (*Uint128) ProtoMessage()

func (*Uint128) ProtoReflect

func (x *Uint128) ProtoReflect() protoreflect.Message

func (*Uint128) Reset

func (x *Uint128) Reset()

func (*Uint128) SetHi

func (x *Uint128) SetHi(v uint64)

func (*Uint128) SetLo

func (x *Uint128) SetLo(v uint64)

func (*Uint128) String

func (x *Uint128) String() string

type Uint128_builder

type Uint128_builder struct {
	Lo uint64
	Hi uint64
	// contains filtered or unexported fields
}

func (Uint128_builder) Build

func (b0 Uint128_builder) Build() *Uint128

Source Files

  • types.pb.go

Jump to