Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterSequencerServiceServer(s grpc.ServiceRegistrar, srv SequencerServiceServer)
- type SequencerServiceClient
- type SequencerServiceServer
- type UnimplementedSequencerServiceServer
- func (UnimplementedSequencerServiceServer) GetFilteredSequencerBlock(context.Context, *v1alpha1.GetFilteredSequencerBlockRequest) (*v1alpha1.FilteredSequencerBlock, error)
- func (UnimplementedSequencerServiceServer) GetPendingNonce(context.Context, *v1alpha1.GetPendingNonceRequest) (*v1alpha1.GetPendingNonceResponse, error)
- func (UnimplementedSequencerServiceServer) GetSequencerBlock(context.Context, *v1alpha1.GetSequencerBlockRequest) (*v1alpha1.SequencerBlock, error)
- type UnsafeSequencerServiceServer
Constants ¶
const ( SequencerService_GetSequencerBlock_FullMethodName = "/astria.sequencerblock.v1alpha1.SequencerService/GetSequencerBlock" SequencerService_GetFilteredSequencerBlock_FullMethodName = "/astria.sequencerblock.v1alpha1.SequencerService/GetFilteredSequencerBlock" SequencerService_GetPendingNonce_FullMethodName = "/astria.sequencerblock.v1alpha1.SequencerService/GetPendingNonce" )
Variables ¶
var SequencerService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "astria.sequencerblock.v1alpha1.SequencerService", HandlerType: (*SequencerServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "GetSequencerBlock", Handler: _SequencerService_GetSequencerBlock_Handler, }, { MethodName: "GetFilteredSequencerBlock", Handler: _SequencerService_GetFilteredSequencerBlock_Handler, }, { MethodName: "GetPendingNonce", Handler: _SequencerService_GetPendingNonce_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "astria/sequencerblock/v1alpha1/service.proto", }
SequencerService_ServiceDesc is the grpc.ServiceDesc for SequencerService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterSequencerServiceServer ¶
func RegisterSequencerServiceServer(s grpc.ServiceRegistrar, srv SequencerServiceServer)
Types ¶
type SequencerServiceClient ¶
type SequencerServiceClient interface {
// Given a block height, returns the sequencer block at that height.
GetSequencerBlock(ctx context.Context, in *v1alpha1.GetSequencerBlockRequest, opts ...grpc.CallOption) (*v1alpha1.SequencerBlock, error)
// Given a block height and set of rollup ids, returns a SequencerBlock which
// is filtered to contain only the transactions that are relevant to the given rollup.
GetFilteredSequencerBlock(ctx context.Context, in *v1alpha1.GetFilteredSequencerBlockRequest, opts ...grpc.CallOption) (*v1alpha1.FilteredSequencerBlock, error)
// Returns the pending nonce for the given account.
GetPendingNonce(ctx context.Context, in *v1alpha1.GetPendingNonceRequest, opts ...grpc.CallOption) (*v1alpha1.GetPendingNonceResponse, error)
}
SequencerServiceClient is the client API for SequencerService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewSequencerServiceClient ¶
func NewSequencerServiceClient(cc grpc.ClientConnInterface) SequencerServiceClient
type SequencerServiceServer ¶
type SequencerServiceServer interface {
// Given a block height, returns the sequencer block at that height.
GetSequencerBlock(context.Context, *v1alpha1.GetSequencerBlockRequest) (*v1alpha1.SequencerBlock, error)
// Given a block height and set of rollup ids, returns a SequencerBlock which
// is filtered to contain only the transactions that are relevant to the given rollup.
GetFilteredSequencerBlock(context.Context, *v1alpha1.GetFilteredSequencerBlockRequest) (*v1alpha1.FilteredSequencerBlock, error)
// Returns the pending nonce for the given account.
GetPendingNonce(context.Context, *v1alpha1.GetPendingNonceRequest) (*v1alpha1.GetPendingNonceResponse, error)
}
SequencerServiceServer is the server API for SequencerService service. All implementations should embed UnimplementedSequencerServiceServer for forward compatibility.
type UnimplementedSequencerServiceServer ¶
type UnimplementedSequencerServiceServer struct{}
UnimplementedSequencerServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedSequencerServiceServer) GetFilteredSequencerBlock ¶
func (UnimplementedSequencerServiceServer) GetFilteredSequencerBlock(context.Context, *v1alpha1.GetFilteredSequencerBlockRequest) (*v1alpha1.FilteredSequencerBlock, error)
func (UnimplementedSequencerServiceServer) GetPendingNonce ¶
func (UnimplementedSequencerServiceServer) GetPendingNonce(context.Context, *v1alpha1.GetPendingNonceRequest) (*v1alpha1.GetPendingNonceResponse, error)
func (UnimplementedSequencerServiceServer) GetSequencerBlock ¶
func (UnimplementedSequencerServiceServer) GetSequencerBlock(context.Context, *v1alpha1.GetSequencerBlockRequest) (*v1alpha1.SequencerBlock, error)
type UnsafeSequencerServiceServer ¶
type UnsafeSequencerServiceServer interface {
// contains filtered or unexported methods
}
UnsafeSequencerServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to SequencerServiceServer will result in compilation errors.
Source Files
¶
- service_grpc.pb.go