splendorapisv1connect

package
v1.19.1-20250101084028... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	// SplendorServiceRegisterUserProcedure is the fully-qualified name of the SplendorService's
	// RegisterUser RPC.
	SplendorServiceRegisterUserProcedure = "/atypicaldev.splendorapis.v1.SplendorService/RegisterUser"
	// SplendorServiceLoginProcedure is the fully-qualified name of the SplendorService's Login RPC.
	SplendorServiceLoginProcedure = "/atypicaldev.splendorapis.v1.SplendorService/Login"
	// SplendorServiceCreateTableProcedure is the fully-qualified name of the SplendorService's
	// CreateTable RPC.
	SplendorServiceCreateTableProcedure = "/atypicaldev.splendorapis.v1.SplendorService/CreateTable"
	// SplendorServiceJoinTableProcedure is the fully-qualified name of the SplendorService's JoinTable
	// RPC.
	SplendorServiceJoinTableProcedure = "/atypicaldev.splendorapis.v1.SplendorService/JoinTable"
	// SplendorServiceLeaveTableProcedure is the fully-qualified name of the SplendorService's
	// LeaveTable RPC.
	SplendorServiceLeaveTableProcedure = "/atypicaldev.splendorapis.v1.SplendorService/LeaveTable"
	// SplendorServiceStartGameProcedure is the fully-qualified name of the SplendorService's StartGame
	// RPC.
	SplendorServiceStartGameProcedure = "/atypicaldev.splendorapis.v1.SplendorService/StartGame"
	// SplendorServiceListTablesProcedure is the fully-qualified name of the SplendorService's
	// ListTables RPC.
	SplendorServiceListTablesProcedure = "/atypicaldev.splendorapis.v1.SplendorService/ListTables"
)

These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.

Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.

const (
	// SplendorServiceName is the fully-qualified name of the SplendorService service.
	SplendorServiceName = "atypicaldev.splendorapis.v1.SplendorService"
)

Variables

This section is empty.

Functions

func NewSplendorServiceHandler

func NewSplendorServiceHandler(svc SplendorServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)

NewSplendorServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.

By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.

Types

type SplendorServiceClient

SplendorServiceClient is a client for the atypicaldev.splendorapis.v1.SplendorService service.

func NewSplendorServiceClient

func NewSplendorServiceClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) SplendorServiceClient

NewSplendorServiceClient constructs a client for the atypicaldev.splendorapis.v1.SplendorService service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.

The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).

type UnimplementedSplendorServiceHandler

type UnimplementedSplendorServiceHandler struct{}

UnimplementedSplendorServiceHandler returns CodeUnimplemented from all methods.

func (UnimplementedSplendorServiceHandler) CreateTable

func (UnimplementedSplendorServiceHandler) JoinTable

func (UnimplementedSplendorServiceHandler) LeaveTable

func (UnimplementedSplendorServiceHandler) ListTables

func (UnimplementedSplendorServiceHandler) Login

func (UnimplementedSplendorServiceHandler) RegisterUser

func (UnimplementedSplendorServiceHandler) StartGame

Source Files

  • service.connect.go

Jump to