v0

package
v1.36.11-2026020415081... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 8 Imported by: 2

Documentation

Index

Constants

const PermissionSetChange_ChildMember_case case_PermissionSetChange_Child = 5
const PermissionSetChange_ChildSet_case case_PermissionSetChange_Child = 4
const PermissionSetChange_Child_not_set_case case_PermissionSetChange_Child = 0
const WatchPermissionSetsResponse_BreakingSchemaChange_case case_WatchPermissionSetsResponse_Response = 4
const WatchPermissionSetsResponse_Change_case case_WatchPermissionSetsResponse_Response = 1
const WatchPermissionSetsResponse_CompletedRevision_case case_WatchPermissionSetsResponse_Response = 2
const WatchPermissionSetsResponse_LookupPermissionSetsRequired_case case_WatchPermissionSetsResponse_Response = 3
const WatchPermissionSetsResponse_Response_not_set_case case_WatchPermissionSetsResponse_Response = 0
const WatchPermissionsResponse_Change_case case_WatchPermissionsResponse_Response = 1
const WatchPermissionsResponse_CompletedRevision_case case_WatchPermissionsResponse_Response = 2
const WatchPermissionsResponse_Response_not_set_case case_WatchPermissionsResponse_Response = 0

Variables

var (
	PermissionChange_Permissionship_name = map[int32]string{
		0: "PERMISSIONSHIP_UNSPECIFIED",
		1: "PERMISSIONSHIP_NO_PERMISSION",
		2: "PERMISSIONSHIP_HAS_PERMISSION",
		3: "PERMISSIONSHIP_CONDITIONAL_PERMISSION",
	}
	PermissionChange_Permissionship_value = map[string]int32{
		"PERMISSIONSHIP_UNSPECIFIED":            0,
		"PERMISSIONSHIP_NO_PERMISSION":          1,
		"PERMISSIONSHIP_HAS_PERMISSION":         2,
		"PERMISSIONSHIP_CONDITIONAL_PERMISSION": 3,
	}
)

Enum value maps for PermissionChange_Permissionship.

var (
	PermissionSetChange_SetOperation_name = map[int32]string{
		0: "SET_OPERATION_UNSPECIFIED",
		1: "SET_OPERATION_ADDED",
		2: "SET_OPERATION_REMOVED",
	}
	PermissionSetChange_SetOperation_value = map[string]int32{
		"SET_OPERATION_UNSPECIFIED": 0,
		"SET_OPERATION_ADDED":       1,
		"SET_OPERATION_REMOVED":     2,
	}
)

Enum value maps for PermissionSetChange_SetOperation.

var File_authzed_api_materialize_v0_relationships_proto protoreflect.FileDescriptor
var File_authzed_api_materialize_v0_watchpermissions_proto protoreflect.FileDescriptor
var File_authzed_api_materialize_v0_watchpermissionsets_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type BreakingSchemaChange

type BreakingSchemaChange struct {

	// change_at is the revision at which a breaking schema event has happened.
	ChangeAt *v1.ZedToken `protobuf:"bytes,1,opt,name=change_at,json=changeAt,proto3" json:"change_at,omitempty"`
	// contains filtered or unexported fields
}

BreakingSchemaChange is used to signal a breaking schema change has happened, and that the consumer should expect delays in the ingestion of new changes, because the permission set snapshot needs to be rebuilt from scratch. Once the snapshot is ready, the consumer will receive a LookupPermissionSetsRequired event.

func (*BreakingSchemaChange) ClearChangeAt

func (x *BreakingSchemaChange) ClearChangeAt()

func (*BreakingSchemaChange) GetChangeAt

func (x *BreakingSchemaChange) GetChangeAt() *v1.ZedToken

func (*BreakingSchemaChange) HasChangeAt

func (x *BreakingSchemaChange) HasChangeAt() bool

func (*BreakingSchemaChange) ProtoMessage

func (*BreakingSchemaChange) ProtoMessage()

func (*BreakingSchemaChange) ProtoReflect

func (x *BreakingSchemaChange) ProtoReflect() protoreflect.Message

func (*BreakingSchemaChange) Reset

func (x *BreakingSchemaChange) Reset()

func (*BreakingSchemaChange) SetChangeAt

func (x *BreakingSchemaChange) SetChangeAt(v *v1.ZedToken)

func (*BreakingSchemaChange) String

func (x *BreakingSchemaChange) String() string

type BreakingSchemaChange_builder

type BreakingSchemaChange_builder struct {

	// change_at is the revision at which a breaking schema event has happened.
	ChangeAt *v1.ZedToken
	// contains filtered or unexported fields
}

func (BreakingSchemaChange_builder) Build

type Cursor

type Cursor struct {

	// limit is the number of permission sets to stream over a single LookupPermissionSets call that was requested.
	Limit uint32 `protobuf:"varint,1,opt,name=limit,proto3" json:"limit,omitempty"`
	// token is the snapshot revision at which the cursor was computed.
	Token *v1.ZedToken `protobuf:"bytes,4,opt,name=token,proto3" json:"token,omitempty"`
	// starting_index is an offset of the permission set represented by this cursor
	StartingIndex uint32 `protobuf:"varint,5,opt,name=starting_index,json=startingIndex,proto3" json:"starting_index,omitempty"`
	// completed_members is a boolean flag that indicates that the cursor has reached the end of the permission sets
	CompletedMembers bool `protobuf:"varint,6,opt,name=completed_members,json=completedMembers,proto3" json:"completed_members,omitempty"`
	// starting_key is a string cursor used by some backends to resume the stream from a specific point.
	StartingKey string `protobuf:"bytes,7,opt,name=starting_key,json=startingKey,proto3" json:"starting_key,omitempty"`
	// cursor is a string-encoded internal materialize cursor.
	Cursor string `protobuf:"bytes,8,opt,name=cursor,proto3" json:"cursor,omitempty"`
	// contains filtered or unexported fields
}

func (*Cursor) ClearToken

func (x *Cursor) ClearToken()

func (*Cursor) GetCompletedMembers

func (x *Cursor) GetCompletedMembers() bool

func (*Cursor) GetCursor

func (x *Cursor) GetCursor() string

func (*Cursor) GetLimit

func (x *Cursor) GetLimit() uint32

func (*Cursor) GetStartingIndex

func (x *Cursor) GetStartingIndex() uint32

func (*Cursor) GetStartingKey

func (x *Cursor) GetStartingKey() string

func (*Cursor) GetToken

func (x *Cursor) GetToken() *v1.ZedToken

func (*Cursor) HasToken

func (x *Cursor) HasToken() bool

func (*Cursor) ProtoMessage

func (*Cursor) ProtoMessage()

func (*Cursor) ProtoReflect

func (x *Cursor) ProtoReflect() protoreflect.Message

func (*Cursor) Reset

func (x *Cursor) Reset()

func (*Cursor) SetCompletedMembers

func (x *Cursor) SetCompletedMembers(v bool)

func (*Cursor) SetCursor

func (x *Cursor) SetCursor(v string)

func (*Cursor) SetLimit

func (x *Cursor) SetLimit(v uint32)

func (*Cursor) SetStartingIndex

func (x *Cursor) SetStartingIndex(v uint32)

func (*Cursor) SetStartingKey

func (x *Cursor) SetStartingKey(v string)

func (*Cursor) SetToken

func (x *Cursor) SetToken(v *v1.ZedToken)

func (*Cursor) String

func (x *Cursor) String() string

type Cursor_builder

type Cursor_builder struct {

	// limit is the number of permission sets to stream over a single LookupPermissionSets call that was requested.
	Limit uint32
	// token is the snapshot revision at which the cursor was computed.
	Token *v1.ZedToken
	// starting_index is an offset of the permission set represented by this cursor
	StartingIndex uint32
	// completed_members is a boolean flag that indicates that the cursor has reached the end of the permission sets
	CompletedMembers bool
	// starting_key is a string cursor used by some backends to resume the stream from a specific point.
	StartingKey string
	// cursor is a string-encoded internal materialize cursor.
	Cursor string
	// contains filtered or unexported fields
}

func (Cursor_builder) Build

func (b0 Cursor_builder) Build() *Cursor

type DownloadPermissionSetsRequest

type DownloadPermissionSetsRequest struct {

	// optional_at_revision is a specific revision to download; for now this will
	// just validate that it matches the backing store if provided.
	OptionalAtRevision *v1.ZedToken `protobuf:"bytes,1,opt,name=optional_at_revision,json=optionalAtRevision,proto3" json:"optional_at_revision,omitempty"`
	// contains filtered or unexported fields
}

func (*DownloadPermissionSetsRequest) ClearOptionalAtRevision

func (x *DownloadPermissionSetsRequest) ClearOptionalAtRevision()

func (*DownloadPermissionSetsRequest) GetOptionalAtRevision

func (x *DownloadPermissionSetsRequest) GetOptionalAtRevision() *v1.ZedToken

func (*DownloadPermissionSetsRequest) HasOptionalAtRevision

func (x *DownloadPermissionSetsRequest) HasOptionalAtRevision() bool

func (*DownloadPermissionSetsRequest) ProtoMessage

func (*DownloadPermissionSetsRequest) ProtoMessage()

func (*DownloadPermissionSetsRequest) ProtoReflect

func (*DownloadPermissionSetsRequest) Reset

func (x *DownloadPermissionSetsRequest) Reset()

func (*DownloadPermissionSetsRequest) SetOptionalAtRevision

func (x *DownloadPermissionSetsRequest) SetOptionalAtRevision(v *v1.ZedToken)

func (*DownloadPermissionSetsRequest) String

type DownloadPermissionSetsRequest_builder

type DownloadPermissionSetsRequest_builder struct {

	// optional_at_revision is a specific revision to download; for now this will
	// just validate that it matches the backing store if provided.
	OptionalAtRevision *v1.ZedToken
	// contains filtered or unexported fields
}

func (DownloadPermissionSetsRequest_builder) Build

type DownloadPermissionSetsResponse

type DownloadPermissionSetsResponse struct {

	// files contains the list of downloadable files with their URLs
	Files []*File `protobuf:"bytes,1,rep,name=files,proto3" json:"files,omitempty"`
	// timestamp represents the time associated with the returned data revision.
	Timestamp *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=timestamp,proto3" json:"timestamp,omitempty"`
	// contains filtered or unexported fields
}

func (*DownloadPermissionSetsResponse) ClearTimestamp

func (x *DownloadPermissionSetsResponse) ClearTimestamp()

func (*DownloadPermissionSetsResponse) GetFiles

func (x *DownloadPermissionSetsResponse) GetFiles() []*File

func (*DownloadPermissionSetsResponse) GetTimestamp

func (*DownloadPermissionSetsResponse) HasTimestamp

func (x *DownloadPermissionSetsResponse) HasTimestamp() bool

func (*DownloadPermissionSetsResponse) ProtoMessage

func (*DownloadPermissionSetsResponse) ProtoMessage()

func (*DownloadPermissionSetsResponse) ProtoReflect

func (*DownloadPermissionSetsResponse) Reset

func (x *DownloadPermissionSetsResponse) Reset()

func (*DownloadPermissionSetsResponse) SetFiles

func (x *DownloadPermissionSetsResponse) SetFiles(v []*File)

func (*DownloadPermissionSetsResponse) SetTimestamp

func (*DownloadPermissionSetsResponse) String

type DownloadPermissionSetsResponse_builder

type DownloadPermissionSetsResponse_builder struct {

	// files contains the list of downloadable files with their URLs
	Files []*File
	// timestamp represents the time associated with the returned data revision.
	Timestamp *timestamppb.Timestamp
	// contains filtered or unexported fields
}

func (DownloadPermissionSetsResponse_builder) Build

type ExperimentalCountRelationshipsByFilterRequest

type ExperimentalCountRelationshipsByFilterRequest struct {

	// relationship_filter specifies the filter to apply when counting relationships.
	RelationshipFilter *v1.RelationshipFilter `protobuf:"bytes,1,opt,name=relationship_filter,json=relationshipFilter,proto3" json:"relationship_filter,omitempty"`
	// contains filtered or unexported fields
}

func (*ExperimentalCountRelationshipsByFilterRequest) ClearRelationshipFilter

func (x *ExperimentalCountRelationshipsByFilterRequest) ClearRelationshipFilter()

func (*ExperimentalCountRelationshipsByFilterRequest) GetRelationshipFilter

func (*ExperimentalCountRelationshipsByFilterRequest) HasRelationshipFilter

func (x *ExperimentalCountRelationshipsByFilterRequest) HasRelationshipFilter() bool

func (*ExperimentalCountRelationshipsByFilterRequest) ProtoMessage

func (*ExperimentalCountRelationshipsByFilterRequest) ProtoReflect

func (*ExperimentalCountRelationshipsByFilterRequest) Reset

func (*ExperimentalCountRelationshipsByFilterRequest) SetRelationshipFilter

func (*ExperimentalCountRelationshipsByFilterRequest) String

type ExperimentalCountRelationshipsByFilterRequest_builder

type ExperimentalCountRelationshipsByFilterRequest_builder struct {

	// relationship_filter specifies the filter to apply when counting relationships.
	RelationshipFilter *v1.RelationshipFilter
	// contains filtered or unexported fields
}

func (ExperimentalCountRelationshipsByFilterRequest_builder) Build

type ExperimentalCountRelationshipsByFilterResponse

type ExperimentalCountRelationshipsByFilterResponse struct {

	// relationship_count is the count of relationships that match the filter.
	RelationshipCount uint64 `protobuf:"varint,1,opt,name=relationship_count,json=relationshipCount,proto3" json:"relationship_count,omitempty"`
	// read_at is the ZedToken at which the relationship count applies.
	ReadAt *v1.ZedToken `protobuf:"bytes,2,opt,name=read_at,json=readAt,proto3" json:"read_at,omitempty"`
	// contains filtered or unexported fields
}

func (*ExperimentalCountRelationshipsByFilterResponse) ClearReadAt

func (*ExperimentalCountRelationshipsByFilterResponse) GetReadAt

func (*ExperimentalCountRelationshipsByFilterResponse) GetRelationshipCount

func (x *ExperimentalCountRelationshipsByFilterResponse) GetRelationshipCount() uint64

func (*ExperimentalCountRelationshipsByFilterResponse) HasReadAt

func (*ExperimentalCountRelationshipsByFilterResponse) ProtoMessage

func (*ExperimentalCountRelationshipsByFilterResponse) ProtoReflect

func (*ExperimentalCountRelationshipsByFilterResponse) Reset

func (*ExperimentalCountRelationshipsByFilterResponse) SetReadAt

func (*ExperimentalCountRelationshipsByFilterResponse) SetRelationshipCount

func (x *ExperimentalCountRelationshipsByFilterResponse) SetRelationshipCount(v uint64)

func (*ExperimentalCountRelationshipsByFilterResponse) String

type ExperimentalCountRelationshipsByFilterResponse_builder

type ExperimentalCountRelationshipsByFilterResponse_builder struct {

	// relationship_count is the count of relationships that match the filter.
	RelationshipCount uint64
	// read_at is the ZedToken at which the relationship count applies.
	ReadAt *v1.ZedToken
	// contains filtered or unexported fields
}

func (ExperimentalCountRelationshipsByFilterResponse_builder) Build

type File

type File struct {

	// name is the filename of the downloadable file
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// url is the download URL for the file (typically a signed S3 URL)
	Url string `protobuf:"bytes,2,opt,name=url,proto3" json:"url,omitempty"`
	// contains filtered or unexported fields
}

func (*File) GetName

func (x *File) GetName() string

func (*File) GetUrl

func (x *File) GetUrl() string

func (*File) ProtoMessage

func (*File) ProtoMessage()

func (*File) ProtoReflect

func (x *File) ProtoReflect() protoreflect.Message

func (*File) Reset

func (x *File) Reset()

func (*File) SetName

func (x *File) SetName(v string)

func (*File) SetUrl

func (x *File) SetUrl(v string)

func (*File) String

func (x *File) String() string

type File_builder

type File_builder struct {

	// name is the filename of the downloadable file
	Name string
	// url is the download URL for the file (typically a signed S3 URL)
	Url string
	// contains filtered or unexported fields
}

func (File_builder) Build

func (b0 File_builder) Build() *File

type LookupPermissionSetsRequest

type LookupPermissionSetsRequest struct {

	// limit is the number of permission sets to stream over a single LookupPermissionSets. Once the limit is reached,
	// the server will close the stream. If more permission sets are available, the consume should open a new stream
	// providing optional_starting_after_cursor, using the cursor from the last response.
	Limit uint32 `protobuf:"varint,1,opt,name=limit,proto3" json:"limit,omitempty"`
	// optional_at_revision specifies the client is requesting to lookup PermissionSets at a specific revision. It's
	// optional, and if not provided, PermissionSets will be looked up at the current revision. The cursor always
	// takes precedence in defining the revision when present.
	OptionalAtRevision *v1.ZedToken `protobuf:"bytes,2,opt,name=optional_at_revision,json=optionalAtRevision,proto3" json:"optional_at_revision,omitempty"`
	// optional_starting_after_cursor is used to specify the offset to start streaming permission sets from.
	OptionalStartingAfterCursor *Cursor `` /* 146-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*LookupPermissionSetsRequest) ClearOptionalAtRevision

func (x *LookupPermissionSetsRequest) ClearOptionalAtRevision()

func (*LookupPermissionSetsRequest) ClearOptionalStartingAfterCursor

func (x *LookupPermissionSetsRequest) ClearOptionalStartingAfterCursor()

func (*LookupPermissionSetsRequest) GetLimit

func (x *LookupPermissionSetsRequest) GetLimit() uint32

func (*LookupPermissionSetsRequest) GetOptionalAtRevision

func (x *LookupPermissionSetsRequest) GetOptionalAtRevision() *v1.ZedToken

func (*LookupPermissionSetsRequest) GetOptionalStartingAfterCursor

func (x *LookupPermissionSetsRequest) GetOptionalStartingAfterCursor() *Cursor

func (*LookupPermissionSetsRequest) HasOptionalAtRevision

func (x *LookupPermissionSetsRequest) HasOptionalAtRevision() bool

func (*LookupPermissionSetsRequest) HasOptionalStartingAfterCursor

func (x *LookupPermissionSetsRequest) HasOptionalStartingAfterCursor() bool

func (*LookupPermissionSetsRequest) ProtoMessage

func (*LookupPermissionSetsRequest) ProtoMessage()

func (*LookupPermissionSetsRequest) ProtoReflect

func (*LookupPermissionSetsRequest) Reset

func (x *LookupPermissionSetsRequest) Reset()

func (*LookupPermissionSetsRequest) SetLimit

func (x *LookupPermissionSetsRequest) SetLimit(v uint32)

func (*LookupPermissionSetsRequest) SetOptionalAtRevision

func (x *LookupPermissionSetsRequest) SetOptionalAtRevision(v *v1.ZedToken)

func (*LookupPermissionSetsRequest) SetOptionalStartingAfterCursor

func (x *LookupPermissionSetsRequest) SetOptionalStartingAfterCursor(v *Cursor)

func (*LookupPermissionSetsRequest) String

func (x *LookupPermissionSetsRequest) String() string

type LookupPermissionSetsRequest_builder

type LookupPermissionSetsRequest_builder struct {

	// limit is the number of permission sets to stream over a single LookupPermissionSets. Once the limit is reached,
	// the server will close the stream. If more permission sets are available, the consume should open a new stream
	// providing optional_starting_after_cursor, using the cursor from the last response.
	Limit uint32
	// optional_at_revision specifies the client is requesting to lookup PermissionSets at a specific revision. It's
	// optional, and if not provided, PermissionSets will be looked up at the current revision. The cursor always
	// takes precedence in defining the revision when present.
	OptionalAtRevision *v1.ZedToken
	// optional_starting_after_cursor is used to specify the offset to start streaming permission sets from.
	OptionalStartingAfterCursor *Cursor
	// contains filtered or unexported fields
}

func (LookupPermissionSetsRequest_builder) Build

type LookupPermissionSetsRequired

type LookupPermissionSetsRequired struct {

	// required_lookup_at is the snapshot revision at which the permission set needs to be rebuilt to.
	RequiredLookupAt *v1.ZedToken `protobuf:"bytes,1,opt,name=required_lookup_at,json=requiredLookupAt,proto3" json:"required_lookup_at,omitempty"`
	// contains filtered or unexported fields
}

LookupPermissionSetsRequired is a signal that the consumer should perform a LookupPermissionSets call because the permission set snapshot needs to be rebuilt from scratch. This typically happens when the origin SpiceDB cluster has seen its schema changed, see BreakingSchemaChange event.

func (*LookupPermissionSetsRequired) ClearRequiredLookupAt

func (x *LookupPermissionSetsRequired) ClearRequiredLookupAt()

func (*LookupPermissionSetsRequired) GetRequiredLookupAt

func (x *LookupPermissionSetsRequired) GetRequiredLookupAt() *v1.ZedToken

func (*LookupPermissionSetsRequired) HasRequiredLookupAt

func (x *LookupPermissionSetsRequired) HasRequiredLookupAt() bool

func (*LookupPermissionSetsRequired) ProtoMessage

func (*LookupPermissionSetsRequired) ProtoMessage()

func (*LookupPermissionSetsRequired) ProtoReflect

func (*LookupPermissionSetsRequired) Reset

func (x *LookupPermissionSetsRequired) Reset()

func (*LookupPermissionSetsRequired) SetRequiredLookupAt

func (x *LookupPermissionSetsRequired) SetRequiredLookupAt(v *v1.ZedToken)

func (*LookupPermissionSetsRequired) String

type LookupPermissionSetsRequired_builder

type LookupPermissionSetsRequired_builder struct {

	// required_lookup_at is the snapshot revision at which the permission set needs to be rebuilt to.
	RequiredLookupAt *v1.ZedToken
	// contains filtered or unexported fields
}

func (LookupPermissionSetsRequired_builder) Build

type LookupPermissionSetsResponse

type LookupPermissionSetsResponse struct {

	// change represents the permission set delta necessary to transition an uninitialized target system to
	// a specific snapshot revision. In practice it's not different from the WatchPermissionSetsResponse.change, except
	// all changes will be of time SET_OPERATION_ADDED because it's assumed there is no known previous state.
	//
	// Applying the deltas to a previously initialized target system would yield incorrect results.
	Change *PermissionSetChange `protobuf:"bytes,1,opt,name=change,proto3" json:"change,omitempty"`
	// cursor points to a specific permission set in a revision.
	// The consumer should keep track of the cursor in order to resume streaming in the event of consumer restarts. This
	// is particularly important in backfill scenarios that may take hours or event days to complete.
	Cursor *Cursor `protobuf:"bytes,2,opt,name=cursor,proto3" json:"cursor,omitempty"`
	// contains filtered or unexported fields
}

func (*LookupPermissionSetsResponse) ClearChange

func (x *LookupPermissionSetsResponse) ClearChange()

func (*LookupPermissionSetsResponse) ClearCursor

func (x *LookupPermissionSetsResponse) ClearCursor()

func (*LookupPermissionSetsResponse) GetChange

func (*LookupPermissionSetsResponse) GetCursor

func (x *LookupPermissionSetsResponse) GetCursor() *Cursor

func (*LookupPermissionSetsResponse) HasChange

func (x *LookupPermissionSetsResponse) HasChange() bool

func (*LookupPermissionSetsResponse) HasCursor

func (x *LookupPermissionSetsResponse) HasCursor() bool

func (*LookupPermissionSetsResponse) ProtoMessage

func (*LookupPermissionSetsResponse) ProtoMessage()

func (*LookupPermissionSetsResponse) ProtoReflect

func (*LookupPermissionSetsResponse) Reset

func (x *LookupPermissionSetsResponse) Reset()

func (*LookupPermissionSetsResponse) SetChange

func (*LookupPermissionSetsResponse) SetCursor

func (x *LookupPermissionSetsResponse) SetCursor(v *Cursor)

func (*LookupPermissionSetsResponse) String

type LookupPermissionSetsResponse_builder

type LookupPermissionSetsResponse_builder struct {

	// change represents the permission set delta necessary to transition an uninitialized target system to
	// a specific snapshot revision. In practice it's not different from the WatchPermissionSetsResponse.change, except
	// all changes will be of time SET_OPERATION_ADDED because it's assumed there is no known previous state.
	//
	// Applying the deltas to a previously initialized target system would yield incorrect results.
	Change *PermissionSetChange
	// cursor points to a specific permission set in a revision.
	// The consumer should keep track of the cursor in order to resume streaming in the event of consumer restarts. This
	// is particularly important in backfill scenarios that may take hours or event days to complete.
	Cursor *Cursor
	// contains filtered or unexported fields
}

func (LookupPermissionSetsResponse_builder) Build

type MemberReference

type MemberReference struct {

	// object_type is the type of object of a permission set member
	ObjectType string `protobuf:"bytes,1,opt,name=object_type,json=objectType,proto3" json:"object_type,omitempty"`
	// object_id is the ID of a permission set member
	ObjectId string `protobuf:"bytes,2,opt,name=object_id,json=objectId,proto3" json:"object_id,omitempty"`
	// optional_permission_or_relation is the permission or relation referenced by this permission set member
	OptionalPermissionOrRelation string `` /* 149-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*MemberReference) GetObjectId

func (x *MemberReference) GetObjectId() string

func (*MemberReference) GetObjectType

func (x *MemberReference) GetObjectType() string

func (*MemberReference) GetOptionalPermissionOrRelation

func (x *MemberReference) GetOptionalPermissionOrRelation() string

func (*MemberReference) ProtoMessage

func (*MemberReference) ProtoMessage()

func (*MemberReference) ProtoReflect

func (x *MemberReference) ProtoReflect() protoreflect.Message

func (*MemberReference) Reset

func (x *MemberReference) Reset()

func (*MemberReference) SetObjectId

func (x *MemberReference) SetObjectId(v string)

func (*MemberReference) SetObjectType

func (x *MemberReference) SetObjectType(v string)

func (*MemberReference) SetOptionalPermissionOrRelation

func (x *MemberReference) SetOptionalPermissionOrRelation(v string)

func (*MemberReference) String

func (x *MemberReference) String() string

type MemberReference_builder

type MemberReference_builder struct {

	// object_type is the type of object of a permission set member
	ObjectType string
	// object_id is the ID of a permission set member
	ObjectId string
	// optional_permission_or_relation is the permission or relation referenced by this permission set member
	OptionalPermissionOrRelation string
	// contains filtered or unexported fields
}

func (MemberReference_builder) Build

type PermissionChange

type PermissionChange struct {

	// revision represents the revision at which the change occurred.
	Revision *v1.ZedToken `protobuf:"bytes,1,opt,name=revision,proto3" json:"revision,omitempty"`
	// resource is the resource that the permission change is related to.
	Resource *v1.ObjectReference `protobuf:"bytes,2,opt,name=resource,proto3" json:"resource,omitempty"`
	// permission is the permission that has changed.
	Permission string `protobuf:"bytes,3,opt,name=permission,proto3" json:"permission,omitempty"`
	// subject is the subject that the permission change is related to.
	Subject *v1.SubjectReference `protobuf:"bytes,4,opt,name=subject,proto3" json:"subject,omitempty"`
	// permissionship is the new permissionship of the subject over the resource after the change.
	Permissionship PermissionChange_Permissionship `` /* 146-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*PermissionChange) ClearResource

func (x *PermissionChange) ClearResource()

func (*PermissionChange) ClearRevision

func (x *PermissionChange) ClearRevision()

func (*PermissionChange) ClearSubject

func (x *PermissionChange) ClearSubject()

func (*PermissionChange) GetPermission

func (x *PermissionChange) GetPermission() string

func (*PermissionChange) GetPermissionship

func (x *PermissionChange) GetPermissionship() PermissionChange_Permissionship

func (*PermissionChange) GetResource

func (x *PermissionChange) GetResource() *v1.ObjectReference

func (*PermissionChange) GetRevision

func (x *PermissionChange) GetRevision() *v1.ZedToken

func (*PermissionChange) GetSubject

func (x *PermissionChange) GetSubject() *v1.SubjectReference

func (*PermissionChange) HasResource

func (x *PermissionChange) HasResource() bool

func (*PermissionChange) HasRevision

func (x *PermissionChange) HasRevision() bool

func (*PermissionChange) HasSubject

func (x *PermissionChange) HasSubject() bool

func (*PermissionChange) ProtoMessage

func (*PermissionChange) ProtoMessage()

func (*PermissionChange) ProtoReflect

func (x *PermissionChange) ProtoReflect() protoreflect.Message

func (*PermissionChange) Reset

func (x *PermissionChange) Reset()

func (*PermissionChange) SetPermission

func (x *PermissionChange) SetPermission(v string)

func (*PermissionChange) SetPermissionship

func (x *PermissionChange) SetPermissionship(v PermissionChange_Permissionship)

func (*PermissionChange) SetResource

func (x *PermissionChange) SetResource(v *v1.ObjectReference)

func (*PermissionChange) SetRevision

func (x *PermissionChange) SetRevision(v *v1.ZedToken)

func (*PermissionChange) SetSubject

func (x *PermissionChange) SetSubject(v *v1.SubjectReference)

func (*PermissionChange) String

func (x *PermissionChange) String() string

type PermissionChange_Permissionship

type PermissionChange_Permissionship int32
const (
	PermissionChange_PERMISSIONSHIP_UNSPECIFIED            PermissionChange_Permissionship = 0
	PermissionChange_PERMISSIONSHIP_NO_PERMISSION          PermissionChange_Permissionship = 1
	PermissionChange_PERMISSIONSHIP_HAS_PERMISSION         PermissionChange_Permissionship = 2
	PermissionChange_PERMISSIONSHIP_CONDITIONAL_PERMISSION PermissionChange_Permissionship = 3
)

func (PermissionChange_Permissionship) Descriptor

func (PermissionChange_Permissionship) Enum

func (PermissionChange_Permissionship) Number

func (PermissionChange_Permissionship) String

func (PermissionChange_Permissionship) Type

type PermissionChange_builder

type PermissionChange_builder struct {

	// revision represents the revision at which the change occurred.
	Revision *v1.ZedToken
	// resource is the resource that the permission change is related to.
	Resource *v1.ObjectReference
	// permission is the permission that has changed.
	Permission string
	// subject is the subject that the permission change is related to.
	Subject *v1.SubjectReference
	// permissionship is the new permissionship of the subject over the resource after the change.
	Permissionship PermissionChange_Permissionship
	// contains filtered or unexported fields
}

func (PermissionChange_builder) Build

type PermissionSetChange

type PermissionSetChange struct {

	// revision represents the revision at which the permission set change occurred.
	AtRevision *v1.ZedToken `protobuf:"bytes,1,opt,name=at_revision,json=atRevision,proto3" json:"at_revision,omitempty"`
	// operation represents the type of set operation that took place as part of the change
	Operation PermissionSetChange_SetOperation `` /* 137-byte string literal not displayed */
	// parent_set represents the permission set parent of either another set or a member
	ParentSet *SetReference `protobuf:"bytes,3,opt,name=parent_set,json=parentSet,proto3" json:"parent_set,omitempty"`
	// Types that are valid to be assigned to Child:
	//
	//	*PermissionSetChange_ChildSet
	//	*PermissionSetChange_ChildMember
	Child isPermissionSetChange_Child `protobuf_oneof:"child"`
	// contains filtered or unexported fields
}

func (*PermissionSetChange) ClearAtRevision

func (x *PermissionSetChange) ClearAtRevision()

func (*PermissionSetChange) ClearChild

func (x *PermissionSetChange) ClearChild()

func (*PermissionSetChange) ClearChildMember

func (x *PermissionSetChange) ClearChildMember()

func (*PermissionSetChange) ClearChildSet

func (x *PermissionSetChange) ClearChildSet()

func (*PermissionSetChange) ClearParentSet

func (x *PermissionSetChange) ClearParentSet()

func (*PermissionSetChange) GetAtRevision

func (x *PermissionSetChange) GetAtRevision() *v1.ZedToken

func (*PermissionSetChange) GetChild

func (x *PermissionSetChange) GetChild() isPermissionSetChange_Child

func (*PermissionSetChange) GetChildMember

func (x *PermissionSetChange) GetChildMember() *MemberReference

func (*PermissionSetChange) GetChildSet

func (x *PermissionSetChange) GetChildSet() *SetReference

func (*PermissionSetChange) GetOperation

func (*PermissionSetChange) GetParentSet

func (x *PermissionSetChange) GetParentSet() *SetReference

func (*PermissionSetChange) HasAtRevision

func (x *PermissionSetChange) HasAtRevision() bool

func (*PermissionSetChange) HasChild

func (x *PermissionSetChange) HasChild() bool

func (*PermissionSetChange) HasChildMember

func (x *PermissionSetChange) HasChildMember() bool

func (*PermissionSetChange) HasChildSet

func (x *PermissionSetChange) HasChildSet() bool

func (*PermissionSetChange) HasParentSet

func (x *PermissionSetChange) HasParentSet() bool

func (*PermissionSetChange) ProtoMessage

func (*PermissionSetChange) ProtoMessage()

func (*PermissionSetChange) ProtoReflect

func (x *PermissionSetChange) ProtoReflect() protoreflect.Message

func (*PermissionSetChange) Reset

func (x *PermissionSetChange) Reset()

func (*PermissionSetChange) SetAtRevision

func (x *PermissionSetChange) SetAtRevision(v *v1.ZedToken)

func (*PermissionSetChange) SetChildMember

func (x *PermissionSetChange) SetChildMember(v *MemberReference)

func (*PermissionSetChange) SetChildSet

func (x *PermissionSetChange) SetChildSet(v *SetReference)

func (*PermissionSetChange) SetOperation

func (*PermissionSetChange) SetParentSet

func (x *PermissionSetChange) SetParentSet(v *SetReference)

func (*PermissionSetChange) String

func (x *PermissionSetChange) String() string

func (*PermissionSetChange) WhichChild

func (x *PermissionSetChange) WhichChild() case_PermissionSetChange_Child

type PermissionSetChange_ChildMember

type PermissionSetChange_ChildMember struct {
	// child_member represents the scenario where an specific object is considered member of the parent set
	ChildMember *MemberReference `protobuf:"bytes,5,opt,name=child_member,json=childMember,proto3,oneof"`
}

type PermissionSetChange_ChildSet

type PermissionSetChange_ChildSet struct {
	// child_set represents the scenario where another set is considered member of the parent set
	ChildSet *SetReference `protobuf:"bytes,4,opt,name=child_set,json=childSet,proto3,oneof"`
}

type PermissionSetChange_SetOperation

type PermissionSetChange_SetOperation int32
const (
	PermissionSetChange_SET_OPERATION_UNSPECIFIED PermissionSetChange_SetOperation = 0
	PermissionSetChange_SET_OPERATION_ADDED       PermissionSetChange_SetOperation = 1
	PermissionSetChange_SET_OPERATION_REMOVED     PermissionSetChange_SetOperation = 2
)

func (PermissionSetChange_SetOperation) Descriptor

func (PermissionSetChange_SetOperation) Enum

func (PermissionSetChange_SetOperation) Number

func (PermissionSetChange_SetOperation) String

func (PermissionSetChange_SetOperation) Type

type PermissionSetChange_builder

type PermissionSetChange_builder struct {

	// revision represents the revision at which the permission set change occurred.
	AtRevision *v1.ZedToken
	// operation represents the type of set operation that took place as part of the change
	Operation PermissionSetChange_SetOperation
	// parent_set represents the permission set parent of either another set or a member
	ParentSet *SetReference
	// Fields of oneof Child:
	// child_set represents the scenario where another set is considered member of the parent set
	ChildSet *SetReference
	// child_member represents the scenario where an specific object is considered member of the parent set
	ChildMember *MemberReference
	// contains filtered or unexported fields
}

func (PermissionSetChange_builder) Build

type SetReference

type SetReference struct {

	// object_type is the type of object in a permission set
	ObjectType string `protobuf:"bytes,1,opt,name=object_type,json=objectType,proto3" json:"object_type,omitempty"`
	// object_id is the ID of a permission set
	ObjectId string `protobuf:"bytes,2,opt,name=object_id,json=objectId,proto3" json:"object_id,omitempty"`
	// permission_or_relation is the permission or relation referenced by this permission set
	PermissionOrRelation string `protobuf:"bytes,3,opt,name=permission_or_relation,json=permissionOrRelation,proto3" json:"permission_or_relation,omitempty"`
	// contains filtered or unexported fields
}

func (*SetReference) GetObjectId

func (x *SetReference) GetObjectId() string

func (*SetReference) GetObjectType

func (x *SetReference) GetObjectType() string

func (*SetReference) GetPermissionOrRelation

func (x *SetReference) GetPermissionOrRelation() string

func (*SetReference) ProtoMessage

func (*SetReference) ProtoMessage()

func (*SetReference) ProtoReflect

func (x *SetReference) ProtoReflect() protoreflect.Message

func (*SetReference) Reset

func (x *SetReference) Reset()

func (*SetReference) SetObjectId

func (x *SetReference) SetObjectId(v string)

func (*SetReference) SetObjectType

func (x *SetReference) SetObjectType(v string)

func (*SetReference) SetPermissionOrRelation

func (x *SetReference) SetPermissionOrRelation(v string)

func (*SetReference) String

func (x *SetReference) String() string

type SetReference_builder

type SetReference_builder struct {

	// object_type is the type of object in a permission set
	ObjectType string
	// object_id is the ID of a permission set
	ObjectId string
	// permission_or_relation is the permission or relation referenced by this permission set
	PermissionOrRelation string
	// contains filtered or unexported fields
}

func (SetReference_builder) Build

func (b0 SetReference_builder) Build() *SetReference

type WatchPermissionSetsRequest

type WatchPermissionSetsRequest struct {

	// optional_starting_after is used to specify the SpiceDB revision to start watching from.
	// If not specified, the watch will start from the current SpiceDB revision time of the request ("head revision").
	OptionalStartingAfter *v1.ZedToken `` /* 126-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*WatchPermissionSetsRequest) ClearOptionalStartingAfter

func (x *WatchPermissionSetsRequest) ClearOptionalStartingAfter()

func (*WatchPermissionSetsRequest) GetOptionalStartingAfter

func (x *WatchPermissionSetsRequest) GetOptionalStartingAfter() *v1.ZedToken

func (*WatchPermissionSetsRequest) HasOptionalStartingAfter

func (x *WatchPermissionSetsRequest) HasOptionalStartingAfter() bool

func (*WatchPermissionSetsRequest) ProtoMessage

func (*WatchPermissionSetsRequest) ProtoMessage()

func (*WatchPermissionSetsRequest) ProtoReflect

func (*WatchPermissionSetsRequest) Reset

func (x *WatchPermissionSetsRequest) Reset()

func (*WatchPermissionSetsRequest) SetOptionalStartingAfter

func (x *WatchPermissionSetsRequest) SetOptionalStartingAfter(v *v1.ZedToken)

func (*WatchPermissionSetsRequest) String

func (x *WatchPermissionSetsRequest) String() string

type WatchPermissionSetsRequest_builder

type WatchPermissionSetsRequest_builder struct {

	// optional_starting_after is used to specify the SpiceDB revision to start watching from.
	// If not specified, the watch will start from the current SpiceDB revision time of the request ("head revision").
	OptionalStartingAfter *v1.ZedToken
	// contains filtered or unexported fields
}

func (WatchPermissionSetsRequest_builder) Build

type WatchPermissionSetsResponse

type WatchPermissionSetsResponse struct {

	// Types that are valid to be assigned to Response:
	//
	//	*WatchPermissionSetsResponse_Change
	//	*WatchPermissionSetsResponse_CompletedRevision
	//	*WatchPermissionSetsResponse_LookupPermissionSetsRequired
	//	*WatchPermissionSetsResponse_BreakingSchemaChange
	Response isWatchPermissionSetsResponse_Response `protobuf_oneof:"response"`
	// contains filtered or unexported fields
}

func (*WatchPermissionSetsResponse) ClearBreakingSchemaChange

func (x *WatchPermissionSetsResponse) ClearBreakingSchemaChange()

func (*WatchPermissionSetsResponse) ClearChange

func (x *WatchPermissionSetsResponse) ClearChange()

func (*WatchPermissionSetsResponse) ClearCompletedRevision

func (x *WatchPermissionSetsResponse) ClearCompletedRevision()

func (*WatchPermissionSetsResponse) ClearLookupPermissionSetsRequired

func (x *WatchPermissionSetsResponse) ClearLookupPermissionSetsRequired()

func (*WatchPermissionSetsResponse) ClearResponse

func (x *WatchPermissionSetsResponse) ClearResponse()

func (*WatchPermissionSetsResponse) GetBreakingSchemaChange

func (x *WatchPermissionSetsResponse) GetBreakingSchemaChange() *BreakingSchemaChange

func (*WatchPermissionSetsResponse) GetChange

func (*WatchPermissionSetsResponse) GetCompletedRevision

func (x *WatchPermissionSetsResponse) GetCompletedRevision() *v1.ZedToken

func (*WatchPermissionSetsResponse) GetLookupPermissionSetsRequired

func (x *WatchPermissionSetsResponse) GetLookupPermissionSetsRequired() *LookupPermissionSetsRequired

func (*WatchPermissionSetsResponse) GetResponse

func (x *WatchPermissionSetsResponse) GetResponse() isWatchPermissionSetsResponse_Response

func (*WatchPermissionSetsResponse) HasBreakingSchemaChange

func (x *WatchPermissionSetsResponse) HasBreakingSchemaChange() bool

func (*WatchPermissionSetsResponse) HasChange

func (x *WatchPermissionSetsResponse) HasChange() bool

func (*WatchPermissionSetsResponse) HasCompletedRevision

func (x *WatchPermissionSetsResponse) HasCompletedRevision() bool

func (*WatchPermissionSetsResponse) HasLookupPermissionSetsRequired

func (x *WatchPermissionSetsResponse) HasLookupPermissionSetsRequired() bool

func (*WatchPermissionSetsResponse) HasResponse

func (x *WatchPermissionSetsResponse) HasResponse() bool

func (*WatchPermissionSetsResponse) ProtoMessage

func (*WatchPermissionSetsResponse) ProtoMessage()

func (*WatchPermissionSetsResponse) ProtoReflect

func (*WatchPermissionSetsResponse) Reset

func (x *WatchPermissionSetsResponse) Reset()

func (*WatchPermissionSetsResponse) SetBreakingSchemaChange

func (x *WatchPermissionSetsResponse) SetBreakingSchemaChange(v *BreakingSchemaChange)

func (*WatchPermissionSetsResponse) SetChange

func (*WatchPermissionSetsResponse) SetCompletedRevision

func (x *WatchPermissionSetsResponse) SetCompletedRevision(v *v1.ZedToken)

func (*WatchPermissionSetsResponse) SetLookupPermissionSetsRequired

func (x *WatchPermissionSetsResponse) SetLookupPermissionSetsRequired(v *LookupPermissionSetsRequired)

func (*WatchPermissionSetsResponse) String

func (x *WatchPermissionSetsResponse) String() string

func (*WatchPermissionSetsResponse) WhichResponse

func (x *WatchPermissionSetsResponse) WhichResponse() case_WatchPermissionSetsResponse_Response

type WatchPermissionSetsResponse_BreakingSchemaChange

type WatchPermissionSetsResponse_BreakingSchemaChange struct {
	// breaking_schema_change is a signal that a breaking schema change has been written to the origin SpiceDB cluster,
	// and that the consumer should expect delays in the ingestion of new changes,
	// because the permission set snapshot needs to be rebuilt from scratch. Once the snapshot is ready, the consumer
	// will receive a LookupPermissionSetsRequired event.
	BreakingSchemaChange *BreakingSchemaChange `protobuf:"bytes,4,opt,name=breaking_schema_change,json=breakingSchemaChange,proto3,oneof"`
}

type WatchPermissionSetsResponse_Change

type WatchPermissionSetsResponse_Change struct {
	// change is the permission set delta that has occurred as result of a mutation in origin SpiceDB.
	// The consumer should apply this change to the current state of the permission sets in their target system.
	// Once an event arrives with completed_revision instead, the consumer shall consider the set of
	// changes originating from that revision completed.
	//
	// The consumer should keep track of the revision in order to resume streaming in the event of consumer restarts.
	Change *PermissionSetChange `protobuf:"bytes,1,opt,name=change,proto3,oneof"`
}

type WatchPermissionSetsResponse_CompletedRevision

type WatchPermissionSetsResponse_CompletedRevision struct {
	// completed_revision is the revision token that indicates the completion of a set of changes. It may also be
	// received without accompanying set of changes, indicating that a mutation in the origin SpiceDB cluster did
	// not yield any effective changes in the permission sets
	CompletedRevision *v1.ZedToken `protobuf:"bytes,2,opt,name=completed_revision,json=completedRevision,proto3,oneof"`
}

type WatchPermissionSetsResponse_LookupPermissionSetsRequired

type WatchPermissionSetsResponse_LookupPermissionSetsRequired struct {
	// lookup_permission_sets_required is a signal that the consumer should perform a LookupPermissionSets call because
	// the permission set snapshot needs to be rebuilt from scratch. This typically happens when the origin SpiceDB
	// cluster has seen its schema changed.
	LookupPermissionSetsRequired *LookupPermissionSetsRequired `protobuf:"bytes,3,opt,name=lookup_permission_sets_required,json=lookupPermissionSetsRequired,proto3,oneof"`
}

type WatchPermissionSetsResponse_builder

type WatchPermissionSetsResponse_builder struct {

	// Fields of oneof Response:
	// change is the permission set delta that has occurred as result of a mutation in origin SpiceDB.
	// The consumer should apply this change to the current state of the permission sets in their target system.
	// Once an event arrives with completed_revision instead, the consumer shall consider the set of
	// changes originating from that revision completed.
	//
	// The consumer should keep track of the revision in order to resume streaming in the event of consumer restarts.
	Change *PermissionSetChange
	// completed_revision is the revision token that indicates the completion of a set of changes. It may also be
	// received without accompanying set of changes, indicating that a mutation in the origin SpiceDB cluster did
	// not yield any effective changes in the permission sets
	CompletedRevision *v1.ZedToken
	// lookup_permission_sets_required is a signal that the consumer should perform a LookupPermissionSets call because
	// the permission set snapshot needs to be rebuilt from scratch. This typically happens when the origin SpiceDB
	// cluster has seen its schema changed.
	LookupPermissionSetsRequired *LookupPermissionSetsRequired
	// breaking_schema_change is a signal that a breaking schema change has been written to the origin SpiceDB cluster,
	// and that the consumer should expect delays in the ingestion of new changes,
	// because the permission set snapshot needs to be rebuilt from scratch. Once the snapshot is ready, the consumer
	// will receive a LookupPermissionSetsRequired event.
	BreakingSchemaChange *BreakingSchemaChange
	// contains filtered or unexported fields
}

func (WatchPermissionSetsResponse_builder) Build

type WatchPermissionsRequest

type WatchPermissionsRequest struct {

	// permissions is a list of permissions to watch for changes. At least one permission must be specified, and it must
	// be a subset or equal to the permissions that were enabled for the service.
	Permissions []*WatchedPermission `protobuf:"bytes,1,rep,name=permissions,proto3" json:"permissions,omitempty"`
	// optional_starting_after is the revision token to start watching from. If not provided, the stream
	// will start from the current revision at the moment of the request.
	OptionalStartingAfter *v1.ZedToken `` /* 126-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*WatchPermissionsRequest) ClearOptionalStartingAfter

func (x *WatchPermissionsRequest) ClearOptionalStartingAfter()

func (*WatchPermissionsRequest) GetOptionalStartingAfter

func (x *WatchPermissionsRequest) GetOptionalStartingAfter() *v1.ZedToken

func (*WatchPermissionsRequest) GetPermissions

func (x *WatchPermissionsRequest) GetPermissions() []*WatchedPermission

func (*WatchPermissionsRequest) HasOptionalStartingAfter

func (x *WatchPermissionsRequest) HasOptionalStartingAfter() bool

func (*WatchPermissionsRequest) ProtoMessage

func (*WatchPermissionsRequest) ProtoMessage()

func (*WatchPermissionsRequest) ProtoReflect

func (x *WatchPermissionsRequest) ProtoReflect() protoreflect.Message

func (*WatchPermissionsRequest) Reset

func (x *WatchPermissionsRequest) Reset()

func (*WatchPermissionsRequest) SetOptionalStartingAfter

func (x *WatchPermissionsRequest) SetOptionalStartingAfter(v *v1.ZedToken)

func (*WatchPermissionsRequest) SetPermissions

func (x *WatchPermissionsRequest) SetPermissions(v []*WatchedPermission)

func (*WatchPermissionsRequest) String

func (x *WatchPermissionsRequest) String() string

type WatchPermissionsRequest_builder

type WatchPermissionsRequest_builder struct {

	// permissions is a list of permissions to watch for changes. At least one permission must be specified, and it must
	// be a subset or equal to the permissions that were enabled for the service.
	Permissions []*WatchedPermission
	// optional_starting_after is the revision token to start watching from. If not provided, the stream
	// will start from the current revision at the moment of the request.
	OptionalStartingAfter *v1.ZedToken
	// contains filtered or unexported fields
}

func (WatchPermissionsRequest_builder) Build

type WatchPermissionsResponse

type WatchPermissionsResponse struct {

	// Types that are valid to be assigned to Response:
	//
	//	*WatchPermissionsResponse_Change
	//	*WatchPermissionsResponse_CompletedRevision
	Response isWatchPermissionsResponse_Response `protobuf_oneof:"response"`
	// contains filtered or unexported fields
}

func (*WatchPermissionsResponse) ClearChange

func (x *WatchPermissionsResponse) ClearChange()

func (*WatchPermissionsResponse) ClearCompletedRevision

func (x *WatchPermissionsResponse) ClearCompletedRevision()

func (*WatchPermissionsResponse) ClearResponse

func (x *WatchPermissionsResponse) ClearResponse()

func (*WatchPermissionsResponse) GetChange

func (*WatchPermissionsResponse) GetCompletedRevision

func (x *WatchPermissionsResponse) GetCompletedRevision() *v1.ZedToken

func (*WatchPermissionsResponse) GetResponse

func (x *WatchPermissionsResponse) GetResponse() isWatchPermissionsResponse_Response

func (*WatchPermissionsResponse) HasChange

func (x *WatchPermissionsResponse) HasChange() bool

func (*WatchPermissionsResponse) HasCompletedRevision

func (x *WatchPermissionsResponse) HasCompletedRevision() bool

func (*WatchPermissionsResponse) HasResponse

func (x *WatchPermissionsResponse) HasResponse() bool

func (*WatchPermissionsResponse) ProtoMessage

func (*WatchPermissionsResponse) ProtoMessage()

func (*WatchPermissionsResponse) ProtoReflect

func (x *WatchPermissionsResponse) ProtoReflect() protoreflect.Message

func (*WatchPermissionsResponse) Reset

func (x *WatchPermissionsResponse) Reset()

func (*WatchPermissionsResponse) SetChange

func (x *WatchPermissionsResponse) SetChange(v *PermissionChange)

func (*WatchPermissionsResponse) SetCompletedRevision

func (x *WatchPermissionsResponse) SetCompletedRevision(v *v1.ZedToken)

func (*WatchPermissionsResponse) String

func (x *WatchPermissionsResponse) String() string

func (*WatchPermissionsResponse) WhichResponse

func (x *WatchPermissionsResponse) WhichResponse() case_WatchPermissionsResponse_Response

type WatchPermissionsResponse_Change

type WatchPermissionsResponse_Change struct {
	// change is the computed permission delta that has occurred as result of a mutation in origin SpiceDB.
	// The consumer should apply this change to the current state of the computed permissions in their target system.
	// Once an event arrives with completed_revision instead, the consumer shall consider there are not more changes
	// originating from that revision.
	//
	// The consumer should keep track of the revision in order to resume streaming in the event of consumer restarts.
	Change *PermissionChange `protobuf:"bytes,1,opt,name=change,proto3,oneof"`
}

type WatchPermissionsResponse_CompletedRevision

type WatchPermissionsResponse_CompletedRevision struct {
	// completed_revision is the revision token that indicates all changes originating from a revision have been
	// streamed and thus the revision should be considered completed. It may also be
	// received without accompanying set of changes, indicating that a mutation in the origin SpiceDB cluster did
	// not yield any effective changes in the computed permissions
	CompletedRevision *v1.ZedToken `protobuf:"bytes,2,opt,name=completed_revision,json=completedRevision,proto3,oneof"`
}

type WatchPermissionsResponse_builder

type WatchPermissionsResponse_builder struct {

	// Fields of oneof Response:
	// change is the computed permission delta that has occurred as result of a mutation in origin SpiceDB.
	// The consumer should apply this change to the current state of the computed permissions in their target system.
	// Once an event arrives with completed_revision instead, the consumer shall consider there are not more changes
	// originating from that revision.
	//
	// The consumer should keep track of the revision in order to resume streaming in the event of consumer restarts.
	Change *PermissionChange
	// completed_revision is the revision token that indicates all changes originating from a revision have been
	// streamed and thus the revision should be considered completed. It may also be
	// received without accompanying set of changes, indicating that a mutation in the origin SpiceDB cluster did
	// not yield any effective changes in the computed permissions
	CompletedRevision *v1.ZedToken
	// contains filtered or unexported fields
}

func (WatchPermissionsResponse_builder) Build

type WatchedPermission

type WatchedPermission struct {

	// resource_type is the type of the resource to watch for changes.
	ResourceType string `protobuf:"bytes,1,opt,name=resource_type,json=resourceType,proto3" json:"resource_type,omitempty"`
	// permission is the permission to watch for changes.
	Permission string `protobuf:"bytes,2,opt,name=permission,proto3" json:"permission,omitempty"`
	// subject_type is the type of the subject to watch for changes.
	SubjectType string `protobuf:"bytes,3,opt,name=subject_type,json=subjectType,proto3" json:"subject_type,omitempty"`
	// optional_subject_relation is the relation on the subject to watch for changes.
	OptionalSubjectRelation string `` /* 132-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*WatchedPermission) GetOptionalSubjectRelation

func (x *WatchedPermission) GetOptionalSubjectRelation() string

func (*WatchedPermission) GetPermission

func (x *WatchedPermission) GetPermission() string

func (*WatchedPermission) GetResourceType

func (x *WatchedPermission) GetResourceType() string

func (*WatchedPermission) GetSubjectType

func (x *WatchedPermission) GetSubjectType() string

func (*WatchedPermission) ProtoMessage

func (*WatchedPermission) ProtoMessage()

func (*WatchedPermission) ProtoReflect

func (x *WatchedPermission) ProtoReflect() protoreflect.Message

func (*WatchedPermission) Reset

func (x *WatchedPermission) Reset()

func (*WatchedPermission) SetOptionalSubjectRelation

func (x *WatchedPermission) SetOptionalSubjectRelation(v string)

func (*WatchedPermission) SetPermission

func (x *WatchedPermission) SetPermission(v string)

func (*WatchedPermission) SetResourceType

func (x *WatchedPermission) SetResourceType(v string)

func (*WatchedPermission) SetSubjectType

func (x *WatchedPermission) SetSubjectType(v string)

func (*WatchedPermission) String

func (x *WatchedPermission) String() string

type WatchedPermission_builder

type WatchedPermission_builder struct {

	// resource_type is the type of the resource to watch for changes.
	ResourceType string
	// permission is the permission to watch for changes.
	Permission string
	// subject_type is the type of the subject to watch for changes.
	SubjectType string
	// optional_subject_relation is the relation on the subject to watch for changes.
	OptionalSubjectRelation string
	// contains filtered or unexported fields
}

func (WatchedPermission_builder) Build

Source Files

  • relationships.pb.go
  • watchpermissions.pb.go
  • watchpermissionsets.pb.go

Jump to