logstreamv1

package
v1.36.12-2023060203054... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 4 Imported by: 2

Documentation

Index

Constants

This section is empty.

Variables

var File_build_bazel_remote_logstream_v1_remote_logstream_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type CreateLogStreamRequest

type CreateLogStreamRequest struct {

	// Required. The parent resource of the created LogStream.
	// The list of valid types of parent resources of LogStreams is up to the
	// implementing server.
	// Example: projects/123
	Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
	// contains filtered or unexported fields
}

Contains all information necessary to create a new LogStream resource.

func (*CreateLogStreamRequest) GetParent

func (x *CreateLogStreamRequest) GetParent() string

func (*CreateLogStreamRequest) ProtoMessage

func (*CreateLogStreamRequest) ProtoMessage()

func (*CreateLogStreamRequest) ProtoReflect

func (x *CreateLogStreamRequest) ProtoReflect() protoreflect.Message

func (*CreateLogStreamRequest) Reset

func (x *CreateLogStreamRequest) Reset()

func (*CreateLogStreamRequest) SetParent

func (x *CreateLogStreamRequest) SetParent(v string)

func (*CreateLogStreamRequest) String

func (x *CreateLogStreamRequest) String() string

type CreateLogStreamRequest_builder

type CreateLogStreamRequest_builder struct {

	// Required. The parent resource of the created LogStream.
	// The list of valid types of parent resources of LogStreams is up to the
	// implementing server.
	// Example: projects/123
	Parent string
	// contains filtered or unexported fields
}

func (CreateLogStreamRequest_builder) Build

type LogStream

type LogStream struct {

	// Structured name of the resource in the format:
	//
	//	{parent=**}/logstreams/{logstream_id}
	//	Example: projects/123/logstreams/456-def
	//
	// Attempting to call the Byte Stream API's `Write` RPC with a LogStream's
	//
	//	`name` as the value for `ByteStream.Write.resource_name` is an error.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Resource name to pass to `ByteStream.Write` in the format:
	//
	//	{parent=**}/logstreams/{logstream_id}/{write_token}
	//	Example: projects/123/logstreams/456-def/789-ghi
	//
	// Attempting to call the Byte Stream API's `Read` RPC with a LogStream's
	//
	//	`write_resource_name` as the value for `ByteStream.Write.resource_name`
	//	is an error.
	//
	// `write_resource_name` is separate from `name` to ensure that only the
	// intended writers can write to a given LogStream. Writers must address write
	// operations to the `write_resource_name`, not the `name`, and must have
	// permission to write LogStreams. `write_resource_name` embeds a secret token
	// and should be protected accordingly; a mishandled `write_resource_name` can
	// result in unintended writers corrupting the LogStream. Therefore, the field
	// should be excluded from calls to any calls which retrieve LogStream
	// metadata (i.e.: `GetLogStream`).
	//
	// Bytes written to this resource must to be readable when `ByteStream.Read`
	// is called with the `name` resource.
	// Reading a write_resource_name must return an INVALID_ARGUMENT error.
	WriteResourceName string `protobuf:"bytes,2,opt,name=write_resource_name,json=writeResourceName,proto3" json:"write_resource_name,omitempty"`
	// contains filtered or unexported fields
}

A handle to a log (an ordered sequence of bytes).

func (*LogStream) GetName

func (x *LogStream) GetName() string

func (*LogStream) GetWriteResourceName

func (x *LogStream) GetWriteResourceName() string

func (*LogStream) ProtoMessage

func (*LogStream) ProtoMessage()

func (*LogStream) ProtoReflect

func (x *LogStream) ProtoReflect() protoreflect.Message

func (*LogStream) Reset

func (x *LogStream) Reset()

func (*LogStream) SetName

func (x *LogStream) SetName(v string)

func (*LogStream) SetWriteResourceName

func (x *LogStream) SetWriteResourceName(v string)

func (*LogStream) String

func (x *LogStream) String() string

type LogStream_builder

type LogStream_builder struct {

	// Structured name of the resource in the format:
	//
	//	{parent=**}/logstreams/{logstream_id}
	//	Example: projects/123/logstreams/456-def
	//
	// Attempting to call the Byte Stream API's `Write` RPC with a LogStream's
	//
	//	`name` as the value for `ByteStream.Write.resource_name` is an error.
	Name string
	// Resource name to pass to `ByteStream.Write` in the format:
	//
	//	{parent=**}/logstreams/{logstream_id}/{write_token}
	//	Example: projects/123/logstreams/456-def/789-ghi
	//
	// Attempting to call the Byte Stream API's `Read` RPC with a LogStream's
	//
	//	`write_resource_name` as the value for `ByteStream.Write.resource_name`
	//	is an error.
	//
	// `write_resource_name` is separate from `name` to ensure that only the
	// intended writers can write to a given LogStream. Writers must address write
	// operations to the `write_resource_name`, not the `name`, and must have
	// permission to write LogStreams. `write_resource_name` embeds a secret token
	// and should be protected accordingly; a mishandled `write_resource_name` can
	// result in unintended writers corrupting the LogStream. Therefore, the field
	// should be excluded from calls to any calls which retrieve LogStream
	// metadata (i.e.: `GetLogStream`).
	//
	// Bytes written to this resource must to be readable when `ByteStream.Read`
	// is called with the `name` resource.
	// Reading a write_resource_name must return an INVALID_ARGUMENT error.
	WriteResourceName string
	// contains filtered or unexported fields
}

func (LogStream_builder) Build

func (b0 LogStream_builder) Build() *LogStream

Source Files

  • remote_logstream.pb.go

Jump to