metadatav1

package
v1.36.11-2026071102571... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: ISC Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	// optional metadata.v1.AuthzPolicy authz = 50000;
	E_Authz = &file_metadata_v1_metadata_proto_extTypes[0]
)

Extension fields to descriptorpb.MethodOptions.

var File_metadata_v1_metadata_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type AuthzPolicy

type AuthzPolicy struct {

	// allow_unauthenticated is a boolean that indicates whether the method can be
	// called without any authentication.
	AllowUnauthenticated bool `protobuf:"varint,1,opt,name=allow_unauthenticated,json=allowUnauthenticated,proto3" json:"allow_unauthenticated,omitempty"`
	// internal_only is a boolean that indicates whether the method can only be
	// called by internal clients and is not intended to be used by public clients.
	InternalOnly bool `protobuf:"varint,2,opt,name=internal_only,json=internalOnly,proto3" json:"internal_only,omitempty"`
	// contains filtered or unexported fields
}

AuthzPolicy is a message that can be attached to a method in a proto file.

func (*AuthzPolicy) GetAllowUnauthenticated

func (x *AuthzPolicy) GetAllowUnauthenticated() bool

func (*AuthzPolicy) GetInternalOnly

func (x *AuthzPolicy) GetInternalOnly() bool

func (*AuthzPolicy) ProtoMessage

func (*AuthzPolicy) ProtoMessage()

func (*AuthzPolicy) ProtoReflect

func (x *AuthzPolicy) ProtoReflect() protoreflect.Message

func (*AuthzPolicy) Reset

func (x *AuthzPolicy) Reset()

func (*AuthzPolicy) SetAllowUnauthenticated

func (x *AuthzPolicy) SetAllowUnauthenticated(v bool)

func (*AuthzPolicy) SetInternalOnly

func (x *AuthzPolicy) SetInternalOnly(v bool)

func (*AuthzPolicy) String

func (x *AuthzPolicy) String() string

type AuthzPolicy_builder

type AuthzPolicy_builder struct {

	// allow_unauthenticated is a boolean that indicates whether the method can be
	// called without any authentication.
	AllowUnauthenticated bool
	// internal_only is a boolean that indicates whether the method can only be
	// called by internal clients and is not intended to be used by public clients.
	InternalOnly bool
	// contains filtered or unexported fields
}

func (AuthzPolicy_builder) Build

func (b0 AuthzPolicy_builder) Build() *AuthzPolicy

Source Files

  • metadata.pb.go

Jump to