Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterCedanaGPUServer(s grpc.ServiceRegistrar, srv CedanaGPUServer)
- type CedanaGPUClient
- type CedanaGPUServer
- type UnimplementedCedanaGPUServer
- func (UnimplementedCedanaGPUServer) Checkpoint(context.Context, *cedanagpu.CheckpointRequest) (*cedanagpu.CheckpointResponse, error)
- func (UnimplementedCedanaGPUServer) HealthCheck(context.Context, *cedanagpu.HealthCheckRequest) (*cedanagpu.HealthCheckResponse, error)
- func (UnimplementedCedanaGPUServer) Restore(context.Context, *cedanagpu.RestoreRequest) (*cedanagpu.RestoreResponse, error)
- func (UnimplementedCedanaGPUServer) StartupPoll(context.Context, *cedanagpu.StartupPollRequest) (*cedanagpu.StartupPollResponse, error)
- type UnsafeCedanaGPUServer
Constants ¶
const ( CedanaGPU_Checkpoint_FullMethodName = "/cedanagpu.CedanaGPU/Checkpoint" CedanaGPU_Restore_FullMethodName = "/cedanagpu.CedanaGPU/Restore" CedanaGPU_StartupPoll_FullMethodName = "/cedanagpu.CedanaGPU/StartupPoll" CedanaGPU_HealthCheck_FullMethodName = "/cedanagpu.CedanaGPU/HealthCheck" )
Variables ¶
var CedanaGPU_ServiceDesc = grpc.ServiceDesc{ ServiceName: "cedanagpu.CedanaGPU", HandlerType: (*CedanaGPUServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "Checkpoint", Handler: _CedanaGPU_Checkpoint_Handler, }, { MethodName: "Restore", Handler: _CedanaGPU_Restore_Handler, }, { MethodName: "StartupPoll", Handler: _CedanaGPU_StartupPoll_Handler, }, { MethodName: "HealthCheck", Handler: _CedanaGPU_HealthCheck_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "cedanagpu/gpu.proto", }
CedanaGPU_ServiceDesc is the grpc.ServiceDesc for CedanaGPU service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterCedanaGPUServer ¶
func RegisterCedanaGPUServer(s grpc.ServiceRegistrar, srv CedanaGPUServer)
Types ¶
type CedanaGPUClient ¶
type CedanaGPUClient interface {
Checkpoint(ctx context.Context, in *cedanagpu.CheckpointRequest, opts ...grpc.CallOption) (*cedanagpu.CheckpointResponse, error)
Restore(ctx context.Context, in *cedanagpu.RestoreRequest, opts ...grpc.CallOption) (*cedanagpu.RestoreResponse, error)
StartupPoll(ctx context.Context, in *cedanagpu.StartupPollRequest, opts ...grpc.CallOption) (*cedanagpu.StartupPollResponse, error)
HealthCheck(ctx context.Context, in *cedanagpu.HealthCheckRequest, opts ...grpc.CallOption) (*cedanagpu.HealthCheckResponse, error)
}
CedanaGPUClient is the client API for CedanaGPU service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewCedanaGPUClient ¶
func NewCedanaGPUClient(cc grpc.ClientConnInterface) CedanaGPUClient
type CedanaGPUServer ¶
type CedanaGPUServer interface {
Checkpoint(context.Context, *cedanagpu.CheckpointRequest) (*cedanagpu.CheckpointResponse, error)
Restore(context.Context, *cedanagpu.RestoreRequest) (*cedanagpu.RestoreResponse, error)
StartupPoll(context.Context, *cedanagpu.StartupPollRequest) (*cedanagpu.StartupPollResponse, error)
HealthCheck(context.Context, *cedanagpu.HealthCheckRequest) (*cedanagpu.HealthCheckResponse, error)
}
CedanaGPUServer is the server API for CedanaGPU service. All implementations should embed UnimplementedCedanaGPUServer for forward compatibility.
type UnimplementedCedanaGPUServer ¶
type UnimplementedCedanaGPUServer struct{}
UnimplementedCedanaGPUServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedCedanaGPUServer) Checkpoint ¶
func (UnimplementedCedanaGPUServer) Checkpoint(context.Context, *cedanagpu.CheckpointRequest) (*cedanagpu.CheckpointResponse, error)
func (UnimplementedCedanaGPUServer) HealthCheck ¶
func (UnimplementedCedanaGPUServer) HealthCheck(context.Context, *cedanagpu.HealthCheckRequest) (*cedanagpu.HealthCheckResponse, error)
func (UnimplementedCedanaGPUServer) Restore ¶
func (UnimplementedCedanaGPUServer) Restore(context.Context, *cedanagpu.RestoreRequest) (*cedanagpu.RestoreResponse, error)
func (UnimplementedCedanaGPUServer) StartupPoll ¶
func (UnimplementedCedanaGPUServer) StartupPoll(context.Context, *cedanagpu.StartupPollRequest) (*cedanagpu.StartupPollResponse, error)
type UnsafeCedanaGPUServer ¶
type UnsafeCedanaGPUServer interface {
// contains filtered or unexported methods
}
UnsafeCedanaGPUServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to CedanaGPUServer will result in compilation errors.
Source Files
¶
- gpu_grpc.pb.go