_gogrpc

package
v1.5.1-20250203234117-... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: AGPL-3.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	TaskService_JobDump_FullMethodName                 = "/cedana.services.task.TaskService/JobDump"
	TaskService_JobRestore_FullMethodName              = "/cedana.services.task.TaskService/JobRestore"
	TaskService_JobRestoreAttach_FullMethodName        = "/cedana.services.task.TaskService/JobRestoreAttach"
	TaskService_JobQuery_FullMethodName                = "/cedana.services.task.TaskService/JobQuery"
	TaskService_Start_FullMethodName                   = "/cedana.services.task.TaskService/Start"
	TaskService_StartAttach_FullMethodName             = "/cedana.services.task.TaskService/StartAttach"
	TaskService_Dump_FullMethodName                    = "/cedana.services.task.TaskService/Dump"
	TaskService_Restore_FullMethodName                 = "/cedana.services.task.TaskService/Restore"
	TaskService_RestoreAttach_FullMethodName           = "/cedana.services.task.TaskService/RestoreAttach"
	TaskService_Manage_FullMethodName                  = "/cedana.services.task.TaskService/Manage"
	TaskService_ContainerdDump_FullMethodName          = "/cedana.services.task.TaskService/ContainerdDump"
	TaskService_ContainerdRestore_FullMethodName       = "/cedana.services.task.TaskService/ContainerdRestore"
	TaskService_ContainerdQuery_FullMethodName         = "/cedana.services.task.TaskService/ContainerdQuery"
	TaskService_ContainerdRootfsDump_FullMethodName    = "/cedana.services.task.TaskService/ContainerdRootfsDump"
	TaskService_ContainerdRootfsRestore_FullMethodName = "/cedana.services.task.TaskService/ContainerdRootfsRestore"
	TaskService_RuncDump_FullMethodName                = "/cedana.services.task.TaskService/RuncDump"
	TaskService_RuncRestore_FullMethodName             = "/cedana.services.task.TaskService/RuncRestore"
	TaskService_RuncQuery_FullMethodName               = "/cedana.services.task.TaskService/RuncQuery"
	TaskService_RuncGetPausePid_FullMethodName         = "/cedana.services.task.TaskService/RuncGetPausePid"
	TaskService_RuncManage_FullMethodName              = "/cedana.services.task.TaskService/RuncManage"
	TaskService_CRIORootfsDump_FullMethodName          = "/cedana.services.task.TaskService/CRIORootfsDump"
	TaskService_CRIOImagePush_FullMethodName           = "/cedana.services.task.TaskService/CRIOImagePush"
	TaskService_LogStreaming_FullMethodName            = "/cedana.services.task.TaskService/LogStreaming"
	TaskService_ProcessStateStreaming_FullMethodName   = "/cedana.services.task.TaskService/ProcessStateStreaming"
	TaskService_DetailedHealthCheck_FullMethodName     = "/cedana.services.task.TaskService/DetailedHealthCheck"
	TaskService_KataDump_FullMethodName                = "/cedana.services.task.TaskService/KataDump"
	TaskService_KataRestore_FullMethodName             = "/cedana.services.task.TaskService/KataRestore"
	TaskService_HostKataDump_FullMethodName            = "/cedana.services.task.TaskService/HostKataDump"
	TaskService_HostKataRestore_FullMethodName         = "/cedana.services.task.TaskService/HostKataRestore"
	TaskService_CreateUnixSocket_FullMethodName        = "/cedana.services.task.TaskService/CreateUnixSocket"
	TaskService_GetConfig_FullMethodName               = "/cedana.services.task.TaskService/GetConfig"
	TaskService_QueueCheckpoint_FullMethodName         = "/cedana.services.task.TaskService/QueueCheckpoint"
	TaskService_QueueRestore_FullMethodName            = "/cedana.services.task.TaskService/QueueRestore"
	TaskService_JobStatus_FullMethodName               = "/cedana.services.task.TaskService/JobStatus"
	TaskService_GetContainerInfo_FullMethodName        = "/cedana.services.task.TaskService/GetContainerInfo"
)

Variables

var TaskService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "cedana.services.task.TaskService",
	HandlerType: (*TaskServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "JobDump",
			Handler:    _TaskService_JobDump_Handler,
		},
		{
			MethodName: "JobRestore",
			Handler:    _TaskService_JobRestore_Handler,
		},
		{
			MethodName: "JobQuery",
			Handler:    _TaskService_JobQuery_Handler,
		},
		{
			MethodName: "Start",
			Handler:    _TaskService_Start_Handler,
		},
		{
			MethodName: "Dump",
			Handler:    _TaskService_Dump_Handler,
		},
		{
			MethodName: "Restore",
			Handler:    _TaskService_Restore_Handler,
		},
		{
			MethodName: "Manage",
			Handler:    _TaskService_Manage_Handler,
		},
		{
			MethodName: "ContainerdDump",
			Handler:    _TaskService_ContainerdDump_Handler,
		},
		{
			MethodName: "ContainerdRestore",
			Handler:    _TaskService_ContainerdRestore_Handler,
		},
		{
			MethodName: "ContainerdQuery",
			Handler:    _TaskService_ContainerdQuery_Handler,
		},
		{
			MethodName: "ContainerdRootfsDump",
			Handler:    _TaskService_ContainerdRootfsDump_Handler,
		},
		{
			MethodName: "ContainerdRootfsRestore",
			Handler:    _TaskService_ContainerdRootfsRestore_Handler,
		},
		{
			MethodName: "RuncDump",
			Handler:    _TaskService_RuncDump_Handler,
		},
		{
			MethodName: "RuncRestore",
			Handler:    _TaskService_RuncRestore_Handler,
		},
		{
			MethodName: "RuncQuery",
			Handler:    _TaskService_RuncQuery_Handler,
		},
		{
			MethodName: "RuncGetPausePid",
			Handler:    _TaskService_RuncGetPausePid_Handler,
		},
		{
			MethodName: "RuncManage",
			Handler:    _TaskService_RuncManage_Handler,
		},
		{
			MethodName: "CRIORootfsDump",
			Handler:    _TaskService_CRIORootfsDump_Handler,
		},
		{
			MethodName: "CRIOImagePush",
			Handler:    _TaskService_CRIOImagePush_Handler,
		},
		{
			MethodName: "DetailedHealthCheck",
			Handler:    _TaskService_DetailedHealthCheck_Handler,
		},
		{
			MethodName: "KataDump",
			Handler:    _TaskService_KataDump_Handler,
		},
		{
			MethodName: "KataRestore",
			Handler:    _TaskService_KataRestore_Handler,
		},
		{
			MethodName: "HostKataDump",
			Handler:    _TaskService_HostKataDump_Handler,
		},
		{
			MethodName: "HostKataRestore",
			Handler:    _TaskService_HostKataRestore_Handler,
		},
		{
			MethodName: "CreateUnixSocket",
			Handler:    _TaskService_CreateUnixSocket_Handler,
		},
		{
			MethodName: "GetConfig",
			Handler:    _TaskService_GetConfig_Handler,
		},
		{
			MethodName: "QueueCheckpoint",
			Handler:    _TaskService_QueueCheckpoint_Handler,
		},
		{
			MethodName: "QueueRestore",
			Handler:    _TaskService_QueueRestore_Handler,
		},
		{
			MethodName: "JobStatus",
			Handler:    _TaskService_JobStatus_Handler,
		},
		{
			MethodName: "GetContainerInfo",
			Handler:    _TaskService_GetContainerInfo_Handler,
		},
	},
	Streams: []grpc.StreamDesc{
		{
			StreamName:    "JobRestoreAttach",
			Handler:       _TaskService_JobRestoreAttach_Handler,
			ServerStreams: true,
			ClientStreams: true,
		},
		{
			StreamName:    "StartAttach",
			Handler:       _TaskService_StartAttach_Handler,
			ServerStreams: true,
			ClientStreams: true,
		},
		{
			StreamName:    "RestoreAttach",
			Handler:       _TaskService_RestoreAttach_Handler,
			ServerStreams: true,
			ClientStreams: true,
		},
		{
			StreamName:    "LogStreaming",
			Handler:       _TaskService_LogStreaming_Handler,
			ServerStreams: true,
			ClientStreams: true,
		},
		{
			StreamName:    "ProcessStateStreaming",
			Handler:       _TaskService_ProcessStateStreaming_Handler,
			ServerStreams: true,
		},
	},
	Metadata: "task.proto",
}

TaskService_ServiceDesc is the grpc.ServiceDesc for TaskService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterTaskServiceServer

func RegisterTaskServiceServer(s grpc.ServiceRegistrar, srv TaskServiceServer)

Types

type TaskServiceClient

type TaskServiceClient interface {
	// Managed Job
	JobDump(ctx context.Context, in *_go.JobDumpArgs, opts ...grpc.CallOption) (*_go.JobDumpResp, error)
	JobRestore(ctx context.Context, in *_go.JobRestoreArgs, opts ...grpc.CallOption) (*_go.JobRestoreResp, error)
	JobRestoreAttach(ctx context.Context, opts ...grpc.CallOption) (grpc.BidiStreamingClient[_go.AttachArgs, _go.AttachResp], error)
	JobQuery(ctx context.Context, in *_go.JobQueryArgs, opts ...grpc.CallOption) (*_go.JobQueryResp, error)
	// Process
	Start(ctx context.Context, in *_go.StartArgs, opts ...grpc.CallOption) (*_go.StartResp, error)
	StartAttach(ctx context.Context, opts ...grpc.CallOption) (grpc.BidiStreamingClient[_go.AttachArgs, _go.AttachResp], error)
	Dump(ctx context.Context, in *_go.DumpArgs, opts ...grpc.CallOption) (*_go.DumpResp, error)
	Restore(ctx context.Context, in *_go.RestoreArgs, opts ...grpc.CallOption) (*_go.RestoreResp, error)
	RestoreAttach(ctx context.Context, opts ...grpc.CallOption) (grpc.BidiStreamingClient[_go.AttachArgs, _go.AttachResp], error)
	Manage(ctx context.Context, in *_go.ManageArgs, opts ...grpc.CallOption) (*_go.ManageResp, error)
	// Containerd
	ContainerdDump(ctx context.Context, in *_go.ContainerdDumpArgs, opts ...grpc.CallOption) (*_go.ContainerdDumpResp, error)
	ContainerdRestore(ctx context.Context, in *_go.ContainerdRestoreArgs, opts ...grpc.CallOption) (*_go.ContainerdRestoreResp, error)
	ContainerdQuery(ctx context.Context, in *_go.ContainerdQueryArgs, opts ...grpc.CallOption) (*_go.ContainerdQueryResp, error)
	ContainerdRootfsDump(ctx context.Context, in *_go.ContainerdRootfsDumpArgs, opts ...grpc.CallOption) (*_go.ContainerdRootfsDumpResp, error)
	ContainerdRootfsRestore(ctx context.Context, in *_go.ContainerdRootfsRestoreArgs, opts ...grpc.CallOption) (*_go.ContainerdRootfsRestoreResp, error)
	// Runc
	RuncDump(ctx context.Context, in *_go.RuncDumpArgs, opts ...grpc.CallOption) (*_go.RuncDumpResp, error)
	RuncRestore(ctx context.Context, in *_go.RuncRestoreArgs, opts ...grpc.CallOption) (*_go.RuncRestoreResp, error)
	RuncQuery(ctx context.Context, in *_go.RuncQueryArgs, opts ...grpc.CallOption) (*_go.RuncQueryResp, error)
	RuncGetPausePid(ctx context.Context, in *_go.RuncGetPausePidArgs, opts ...grpc.CallOption) (*_go.RuncGetPausePidResp, error)
	RuncManage(ctx context.Context, in *_go.RuncManageArgs, opts ...grpc.CallOption) (*_go.RuncManageResp, error)
	// CRIO
	CRIORootfsDump(ctx context.Context, in *_go.CRIORootfsDumpArgs, opts ...grpc.CallOption) (*_go.CRIORootfsDumpResp, error)
	CRIOImagePush(ctx context.Context, in *_go.CRIOImagePushArgs, opts ...grpc.CallOption) (*_go.CRIOImagePushResp, error)
	// Streaming
	LogStreaming(ctx context.Context, opts ...grpc.CallOption) (grpc.BidiStreamingClient[_go.LogStreamingResp, _go.LogStreamingArgs], error)
	ProcessStateStreaming(ctx context.Context, in *_go.ProcessStateStreamingArgs, opts ...grpc.CallOption) (grpc.ServerStreamingClient[_go.ProcessState], error)
	// Health
	DetailedHealthCheck(ctx context.Context, in *_go.DetailedHealthCheckRequest, opts ...grpc.CallOption) (*_go.DetailedHealthCheckResponse, error)
	// Kata
	KataDump(ctx context.Context, in *_go.DumpArgs, opts ...grpc.CallOption) (*_go.DumpResp, error)
	KataRestore(ctx context.Context, in *_go.RestoreArgs, opts ...grpc.CallOption) (*_go.RestoreResp, error)
	HostKataDump(ctx context.Context, in *_go.HostDumpKataArgs, opts ...grpc.CallOption) (*_go.HostDumpKataResp, error)
	HostKataRestore(ctx context.Context, in *_go.HostRestoreKataArgs, opts ...grpc.CallOption) (*_go.HostRestoreKataResp, error)
	CreateUnixSocket(ctx context.Context, in *_go.Empty, opts ...grpc.CallOption) (*_go.SocketResp, error)
	// Config
	GetConfig(ctx context.Context, in *_go.GetConfigRequest, opts ...grpc.CallOption) (*_go.GetConfigResponse, error)
	// JobQueue
	QueueCheckpoint(ctx context.Context, in *_go.QueueJobCheckpointRequest, opts ...grpc.CallOption) (*wrapperspb.BoolValue, error)
	QueueRestore(ctx context.Context, in *_go.QueueJobRestoreRequest, opts ...grpc.CallOption) (*wrapperspb.BoolValue, error)
	JobStatus(ctx context.Context, in *_go.QueueJobID, opts ...grpc.CallOption) (*_go.QueueJobStatus, error)
	// ASR
	GetContainerInfo(ctx context.Context, in *_go.ContainerInfoRequest, opts ...grpc.CallOption) (*_go.ContainersInfo, error)
}

TaskServiceClient is the client API for TaskService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewTaskServiceClient

func NewTaskServiceClient(cc grpc.ClientConnInterface) TaskServiceClient

type TaskServiceServer

type TaskServiceServer interface {
	// Managed Job
	JobDump(context.Context, *_go.JobDumpArgs) (*_go.JobDumpResp, error)
	JobRestore(context.Context, *_go.JobRestoreArgs) (*_go.JobRestoreResp, error)
	JobRestoreAttach(grpc.BidiStreamingServer[_go.AttachArgs, _go.AttachResp]) error
	JobQuery(context.Context, *_go.JobQueryArgs) (*_go.JobQueryResp, error)
	// Process
	Start(context.Context, *_go.StartArgs) (*_go.StartResp, error)
	StartAttach(grpc.BidiStreamingServer[_go.AttachArgs, _go.AttachResp]) error
	Dump(context.Context, *_go.DumpArgs) (*_go.DumpResp, error)
	Restore(context.Context, *_go.RestoreArgs) (*_go.RestoreResp, error)
	RestoreAttach(grpc.BidiStreamingServer[_go.AttachArgs, _go.AttachResp]) error
	Manage(context.Context, *_go.ManageArgs) (*_go.ManageResp, error)
	// Containerd
	ContainerdDump(context.Context, *_go.ContainerdDumpArgs) (*_go.ContainerdDumpResp, error)
	ContainerdRestore(context.Context, *_go.ContainerdRestoreArgs) (*_go.ContainerdRestoreResp, error)
	ContainerdQuery(context.Context, *_go.ContainerdQueryArgs) (*_go.ContainerdQueryResp, error)
	ContainerdRootfsDump(context.Context, *_go.ContainerdRootfsDumpArgs) (*_go.ContainerdRootfsDumpResp, error)
	ContainerdRootfsRestore(context.Context, *_go.ContainerdRootfsRestoreArgs) (*_go.ContainerdRootfsRestoreResp, error)
	// Runc
	RuncDump(context.Context, *_go.RuncDumpArgs) (*_go.RuncDumpResp, error)
	RuncRestore(context.Context, *_go.RuncRestoreArgs) (*_go.RuncRestoreResp, error)
	RuncQuery(context.Context, *_go.RuncQueryArgs) (*_go.RuncQueryResp, error)
	RuncGetPausePid(context.Context, *_go.RuncGetPausePidArgs) (*_go.RuncGetPausePidResp, error)
	RuncManage(context.Context, *_go.RuncManageArgs) (*_go.RuncManageResp, error)
	// CRIO
	CRIORootfsDump(context.Context, *_go.CRIORootfsDumpArgs) (*_go.CRIORootfsDumpResp, error)
	CRIOImagePush(context.Context, *_go.CRIOImagePushArgs) (*_go.CRIOImagePushResp, error)
	// Streaming
	LogStreaming(grpc.BidiStreamingServer[_go.LogStreamingResp, _go.LogStreamingArgs]) error
	ProcessStateStreaming(*_go.ProcessStateStreamingArgs, grpc.ServerStreamingServer[_go.ProcessState]) error
	// Health
	DetailedHealthCheck(context.Context, *_go.DetailedHealthCheckRequest) (*_go.DetailedHealthCheckResponse, error)
	// Kata
	KataDump(context.Context, *_go.DumpArgs) (*_go.DumpResp, error)
	KataRestore(context.Context, *_go.RestoreArgs) (*_go.RestoreResp, error)
	HostKataDump(context.Context, *_go.HostDumpKataArgs) (*_go.HostDumpKataResp, error)
	HostKataRestore(context.Context, *_go.HostRestoreKataArgs) (*_go.HostRestoreKataResp, error)
	CreateUnixSocket(context.Context, *_go.Empty) (*_go.SocketResp, error)
	// Config
	GetConfig(context.Context, *_go.GetConfigRequest) (*_go.GetConfigResponse, error)
	// JobQueue
	QueueCheckpoint(context.Context, *_go.QueueJobCheckpointRequest) (*wrapperspb.BoolValue, error)
	QueueRestore(context.Context, *_go.QueueJobRestoreRequest) (*wrapperspb.BoolValue, error)
	JobStatus(context.Context, *_go.QueueJobID) (*_go.QueueJobStatus, error)
	// ASR
	GetContainerInfo(context.Context, *_go.ContainerInfoRequest) (*_go.ContainersInfo, error)
}

TaskServiceServer is the server API for TaskService service. All implementations should embed UnimplementedTaskServiceServer for forward compatibility.

type TaskService_JobRestoreAttachClient

type TaskService_JobRestoreAttachClient = grpc.BidiStreamingClient[_go.AttachArgs, _go.AttachResp]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type TaskService_JobRestoreAttachServer

type TaskService_JobRestoreAttachServer = grpc.BidiStreamingServer[_go.AttachArgs, _go.AttachResp]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type TaskService_LogStreamingClient

type TaskService_LogStreamingClient = grpc.BidiStreamingClient[_go.LogStreamingResp, _go.LogStreamingArgs]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type TaskService_LogStreamingServer

type TaskService_LogStreamingServer = grpc.BidiStreamingServer[_go.LogStreamingResp, _go.LogStreamingArgs]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type TaskService_ProcessStateStreamingClient

type TaskService_ProcessStateStreamingClient = grpc.ServerStreamingClient[_go.ProcessState]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type TaskService_ProcessStateStreamingServer

type TaskService_ProcessStateStreamingServer = grpc.ServerStreamingServer[_go.ProcessState]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type TaskService_RestoreAttachClient

type TaskService_RestoreAttachClient = grpc.BidiStreamingClient[_go.AttachArgs, _go.AttachResp]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type TaskService_RestoreAttachServer

type TaskService_RestoreAttachServer = grpc.BidiStreamingServer[_go.AttachArgs, _go.AttachResp]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type TaskService_StartAttachClient

type TaskService_StartAttachClient = grpc.BidiStreamingClient[_go.AttachArgs, _go.AttachResp]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type TaskService_StartAttachServer

type TaskService_StartAttachServer = grpc.BidiStreamingServer[_go.AttachArgs, _go.AttachResp]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type UnimplementedTaskServiceServer

type UnimplementedTaskServiceServer struct{}

UnimplementedTaskServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedTaskServiceServer) CRIOImagePush

func (UnimplementedTaskServiceServer) CRIORootfsDump

func (UnimplementedTaskServiceServer) ContainerdDump

func (UnimplementedTaskServiceServer) ContainerdQuery

func (UnimplementedTaskServiceServer) ContainerdRestore

func (UnimplementedTaskServiceServer) ContainerdRootfsDump

func (UnimplementedTaskServiceServer) ContainerdRootfsRestore

func (UnimplementedTaskServiceServer) CreateUnixSocket

func (UnimplementedTaskServiceServer) DetailedHealthCheck

func (UnimplementedTaskServiceServer) Dump

func (UnimplementedTaskServiceServer) GetConfig

func (UnimplementedTaskServiceServer) GetContainerInfo

func (UnimplementedTaskServiceServer) HostKataDump

func (UnimplementedTaskServiceServer) HostKataRestore

func (UnimplementedTaskServiceServer) JobDump

func (UnimplementedTaskServiceServer) JobQuery

func (UnimplementedTaskServiceServer) JobRestore

func (UnimplementedTaskServiceServer) JobRestoreAttach

func (UnimplementedTaskServiceServer) JobStatus

func (UnimplementedTaskServiceServer) KataDump

func (UnimplementedTaskServiceServer) KataRestore

func (UnimplementedTaskServiceServer) LogStreaming

func (UnimplementedTaskServiceServer) Manage

func (UnimplementedTaskServiceServer) ProcessStateStreaming

func (UnimplementedTaskServiceServer) QueueCheckpoint

func (UnimplementedTaskServiceServer) QueueRestore

func (UnimplementedTaskServiceServer) Restore

func (UnimplementedTaskServiceServer) RestoreAttach

func (UnimplementedTaskServiceServer) RuncDump

func (UnimplementedTaskServiceServer) RuncGetPausePid

func (UnimplementedTaskServiceServer) RuncManage

func (UnimplementedTaskServiceServer) RuncQuery

func (UnimplementedTaskServiceServer) RuncRestore

func (UnimplementedTaskServiceServer) Start

func (UnimplementedTaskServiceServer) StartAttach

type UnsafeTaskServiceServer

type UnsafeTaskServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeTaskServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to TaskServiceServer will result in compilation errors.

Source Files

  • task_grpc.pb.go

Jump to