Documentation
¶
Index ¶
Constants ¶
const (
AuditService_ListAuditedEvents_FullMethodName = "/buf.alpha.audit.v1alpha1.AuditService/ListAuditedEvents"
)
Variables ¶
var AuditService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "buf.alpha.audit.v1alpha1.AuditService", HandlerType: (*AuditServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "ListAuditedEvents", Handler: _AuditService_ListAuditedEvents_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "buf/alpha/audit/v1alpha1/service.proto", }
AuditService_ServiceDesc is the grpc.ServiceDesc for AuditService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterAuditServiceServer ¶
func RegisterAuditServiceServer(s grpc.ServiceRegistrar, srv AuditServiceServer)
Types ¶
type AuditServiceClient ¶
type AuditServiceClient interface {
// ListAuditedEvents lists audited events recorded in the BSR instance.
ListAuditedEvents(ctx context.Context, in *v1alpha1.ListAuditedEventsRequest, opts ...grpc.CallOption) (*v1alpha1.ListAuditedEventsResponse, error)
}
AuditServiceClient is the client API for AuditService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
AuditService is the Audit service.
func NewAuditServiceClient ¶
func NewAuditServiceClient(cc grpc.ClientConnInterface) AuditServiceClient
type AuditServiceServer ¶
type AuditServiceServer interface {
// ListAuditedEvents lists audited events recorded in the BSR instance.
ListAuditedEvents(context.Context, *v1alpha1.ListAuditedEventsRequest) (*v1alpha1.ListAuditedEventsResponse, error)
}
AuditServiceServer is the server API for AuditService service. All implementations should embed UnimplementedAuditServiceServer for forward compatibility.
AuditService is the Audit service.
type UnimplementedAuditServiceServer ¶
type UnimplementedAuditServiceServer struct{}
UnimplementedAuditServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedAuditServiceServer) ListAuditedEvents ¶
func (UnimplementedAuditServiceServer) ListAuditedEvents(context.Context, *v1alpha1.ListAuditedEventsRequest) (*v1alpha1.ListAuditedEventsResponse, error)
type UnsafeAuditServiceServer ¶
type UnsafeAuditServiceServer interface {
// contains filtered or unexported methods
}
UnsafeAuditServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to AuditServiceServer will result in compilation errors.
Source Files
¶
- service_grpc.pb.go