Documentation
¶
Index ¶
Constants ¶
const (
EventService_Event_FullMethodName = "/buf.alpha.webhook.v1alpha1.EventService/Event"
)
Variables ¶
var EventService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "buf.alpha.webhook.v1alpha1.EventService", HandlerType: (*EventServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "Event", Handler: _EventService_Event_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "buf/alpha/webhook/v1alpha1/event.proto", }
EventService_ServiceDesc is the grpc.ServiceDesc for EventService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterEventServiceServer ¶
func RegisterEventServiceServer(s grpc.ServiceRegistrar, srv EventServiceServer)
Types ¶
type EventServiceClient ¶
type EventServiceClient interface {
// Event is the rpc which receives webhook events.
Event(ctx context.Context, in *v1alpha1.EventRequest, opts ...grpc.CallOption) (*v1alpha1.EventResponse, error)
}
EventServiceClient is the client API for EventService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
EventService is the service which receives webhook events from Buf.
func NewEventServiceClient ¶
func NewEventServiceClient(cc grpc.ClientConnInterface) EventServiceClient
type EventServiceServer ¶
type EventServiceServer interface {
// Event is the rpc which receives webhook events.
Event(context.Context, *v1alpha1.EventRequest) (*v1alpha1.EventResponse, error)
}
EventServiceServer is the server API for EventService service. All implementations should embed UnimplementedEventServiceServer for forward compatibility.
EventService is the service which receives webhook events from Buf.
type UnimplementedEventServiceServer ¶
type UnimplementedEventServiceServer struct{}
UnimplementedEventServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedEventServiceServer) Event ¶
func (UnimplementedEventServiceServer) Event(context.Context, *v1alpha1.EventRequest) (*v1alpha1.EventResponse, error)
type UnsafeEventServiceServer ¶
type UnsafeEventServiceServer interface {
// contains filtered or unexported methods
}
UnsafeEventServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to EventServiceServer will result in compilation errors.
Source Files
¶
- event_grpc.pb.go