Documentation
¶
Index ¶
- Variables
- type Image
- type ImageFile
- func (x *ImageFile) ClearBufExtension()
- func (x *ImageFile) ClearEdition()
- func (x *ImageFile) ClearName()
- func (x *ImageFile) ClearOptions()
- func (x *ImageFile) ClearPackage()
- func (x *ImageFile) ClearSourceCodeInfo()
- func (x *ImageFile) ClearSyntax()
- func (x *ImageFile) GetBufExtension() *ImageFileExtension
- func (x *ImageFile) GetDependency() []string
- func (x *ImageFile) GetEdition() descriptorpb.Edition
- func (x *ImageFile) GetEnumType() []*descriptorpb.EnumDescriptorProto
- func (x *ImageFile) GetExtension() []*descriptorpb.FieldDescriptorProto
- func (x *ImageFile) GetMessageType() []*descriptorpb.DescriptorProto
- func (x *ImageFile) GetName() string
- func (x *ImageFile) GetOptions() *descriptorpb.FileOptions
- func (x *ImageFile) GetPackage() string
- func (x *ImageFile) GetPublicDependency() []int32
- func (x *ImageFile) GetService() []*descriptorpb.ServiceDescriptorProto
- func (x *ImageFile) GetSourceCodeInfo() *descriptorpb.SourceCodeInfo
- func (x *ImageFile) GetSyntax() string
- func (x *ImageFile) GetWeakDependency() []int32
- func (x *ImageFile) HasBufExtension() bool
- func (x *ImageFile) HasEdition() bool
- func (x *ImageFile) HasName() bool
- func (x *ImageFile) HasOptions() bool
- func (x *ImageFile) HasPackage() bool
- func (x *ImageFile) HasSourceCodeInfo() bool
- func (x *ImageFile) HasSyntax() bool
- func (*ImageFile) ProtoMessage()
- func (x *ImageFile) ProtoReflect() protoreflect.Message
- func (x *ImageFile) Reset()
- func (x *ImageFile) SetBufExtension(v *ImageFileExtension)
- func (x *ImageFile) SetDependency(v []string)
- func (x *ImageFile) SetEdition(v descriptorpb.Edition)
- func (x *ImageFile) SetEnumType(v []*descriptorpb.EnumDescriptorProto)
- func (x *ImageFile) SetExtension(v []*descriptorpb.FieldDescriptorProto)
- func (x *ImageFile) SetMessageType(v []*descriptorpb.DescriptorProto)
- func (x *ImageFile) SetName(v string)
- func (x *ImageFile) SetOptions(v *descriptorpb.FileOptions)
- func (x *ImageFile) SetPackage(v string)
- func (x *ImageFile) SetPublicDependency(v []int32)
- func (x *ImageFile) SetService(v []*descriptorpb.ServiceDescriptorProto)
- func (x *ImageFile) SetSourceCodeInfo(v *descriptorpb.SourceCodeInfo)
- func (x *ImageFile) SetSyntax(v string)
- func (x *ImageFile) SetWeakDependency(v []int32)
- func (x *ImageFile) String() string
- type ImageFileExtension
- func (x *ImageFileExtension) ClearIsImport()
- func (x *ImageFileExtension) ClearIsSyntaxUnspecified()
- func (x *ImageFileExtension) ClearModuleInfo()
- func (x *ImageFileExtension) GetIsImport() bool
- func (x *ImageFileExtension) GetIsSyntaxUnspecified() bool
- func (x *ImageFileExtension) GetModuleInfo() *ModuleInfo
- func (x *ImageFileExtension) GetUnusedDependency() []int32
- func (x *ImageFileExtension) HasIsImport() bool
- func (x *ImageFileExtension) HasIsSyntaxUnspecified() bool
- func (x *ImageFileExtension) HasModuleInfo() bool
- func (*ImageFileExtension) ProtoMessage()
- func (x *ImageFileExtension) ProtoReflect() protoreflect.Message
- func (x *ImageFileExtension) Reset()
- func (x *ImageFileExtension) SetIsImport(v bool)
- func (x *ImageFileExtension) SetIsSyntaxUnspecified(v bool)
- func (x *ImageFileExtension) SetModuleInfo(v *ModuleInfo)
- func (x *ImageFileExtension) SetUnusedDependency(v []int32)
- func (x *ImageFileExtension) String() string
- type ImageFileExtension_builder
- type ImageFile_builder
- type Image_builder
- type ModuleInfo
- func (x *ModuleInfo) ClearCommit()
- func (x *ModuleInfo) ClearName()
- func (x *ModuleInfo) GetCommit() string
- func (x *ModuleInfo) GetName() *ModuleName
- func (x *ModuleInfo) HasCommit() bool
- func (x *ModuleInfo) HasName() bool
- func (*ModuleInfo) ProtoMessage()
- func (x *ModuleInfo) ProtoReflect() protoreflect.Message
- func (x *ModuleInfo) Reset()
- func (x *ModuleInfo) SetCommit(v string)
- func (x *ModuleInfo) SetName(v *ModuleName)
- func (x *ModuleInfo) String() string
- type ModuleInfo_builder
- type ModuleName
- func (x *ModuleName) ClearOwner()
- func (x *ModuleName) ClearRemote()
- func (x *ModuleName) ClearRepository()
- func (x *ModuleName) GetOwner() string
- func (x *ModuleName) GetRemote() string
- func (x *ModuleName) GetRepository() string
- func (x *ModuleName) HasOwner() bool
- func (x *ModuleName) HasRemote() bool
- func (x *ModuleName) HasRepository() bool
- func (*ModuleName) ProtoMessage()
- func (x *ModuleName) ProtoReflect() protoreflect.Message
- func (x *ModuleName) Reset()
- func (x *ModuleName) SetOwner(v string)
- func (x *ModuleName) SetRemote(v string)
- func (x *ModuleName) SetRepository(v string)
- func (x *ModuleName) String() string
- type ModuleName_builder
Constants ¶
This section is empty.
Variables ¶
var File_buf_alpha_image_v1_image_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Image ¶
type Image struct {
File []*ImageFile `protobuf:"bytes,1,rep,name=file" json:"file,omitempty"`
// contains filtered or unexported fields
}
Image is an ext FileDescriptorSet.
See https://github.com/protocolbuffers/protobuf/blob/master/src/google/protobuf/descriptor.proto
func (*Image) ProtoReflect ¶
func (x *Image) ProtoReflect() protoreflect.Message
type ImageFile ¶
type ImageFile struct {
Name *string `protobuf:"bytes,1,opt,name=name" json:"name,omitempty"`
Package *string `protobuf:"bytes,2,opt,name=package" json:"package,omitempty"`
Dependency []string `protobuf:"bytes,3,rep,name=dependency" json:"dependency,omitempty"`
PublicDependency []int32 `protobuf:"varint,10,rep,name=public_dependency,json=publicDependency" json:"public_dependency,omitempty"`
WeakDependency []int32 `protobuf:"varint,11,rep,name=weak_dependency,json=weakDependency" json:"weak_dependency,omitempty"`
MessageType []*descriptorpb.DescriptorProto `protobuf:"bytes,4,rep,name=message_type,json=messageType" json:"message_type,omitempty"`
EnumType []*descriptorpb.EnumDescriptorProto `protobuf:"bytes,5,rep,name=enum_type,json=enumType" json:"enum_type,omitempty"`
Service []*descriptorpb.ServiceDescriptorProto `protobuf:"bytes,6,rep,name=service" json:"service,omitempty"`
Extension []*descriptorpb.FieldDescriptorProto `protobuf:"bytes,7,rep,name=extension" json:"extension,omitempty"`
Options *descriptorpb.FileOptions `protobuf:"bytes,8,opt,name=options" json:"options,omitempty"`
SourceCodeInfo *descriptorpb.SourceCodeInfo `protobuf:"bytes,9,opt,name=source_code_info,json=sourceCodeInfo" json:"source_code_info,omitempty"`
Syntax *string `protobuf:"bytes,12,opt,name=syntax" json:"syntax,omitempty"`
Edition *descriptorpb.Edition `protobuf:"varint,14,opt,name=edition,enum=google.protobuf.Edition" json:"edition,omitempty"`
// buf_extension contains buf-specific extensions to FileDescriptorProtos.
//
// The prefixed name and high tag value is used to all but guarantee there
// will never be any conflict with Google's FileDescriptorProto definition.
// The definition of a FileDescriptorProto has not changed in years, so
// we're not too worried about a conflict here.
BufExtension *ImageFileExtension `protobuf:"bytes,8042,opt,name=buf_extension,json=bufExtension" json:"buf_extension,omitempty"`
// contains filtered or unexported fields
}
ImageFile is an extended FileDescriptorProto.
Since FileDescriptorProto does not have extensions, we copy the fields from FileDescriptorProto, and then add our own extensions via the buf_extension field. This is compatible with a FileDescriptorProto.
See https://github.com/protocolbuffers/protobuf/blob/master/src/google/protobuf/descriptor.proto
func (*ImageFile) GetBufExtension ¶
func (x *ImageFile) GetBufExtension() *ImageFileExtension
func (*ImageFile) GetEdition ¶
func (x *ImageFile) GetEdition() descriptorpb.Edition
func (*ImageFile) GetEnumType ¶
func (x *ImageFile) GetEnumType() []*descriptorpb.EnumDescriptorProto
func (*ImageFile) GetExtension ¶
func (x *ImageFile) GetExtension() []*descriptorpb.FieldDescriptorProto
func (*ImageFile) GetMessageType ¶
func (x *ImageFile) GetMessageType() []*descriptorpb.DescriptorProto
func (*ImageFile) GetOptions ¶
func (x *ImageFile) GetOptions() *descriptorpb.FileOptions
func (*ImageFile) GetService ¶
func (x *ImageFile) GetService() []*descriptorpb.ServiceDescriptorProto
func (*ImageFile) GetSourceCodeInfo ¶
func (x *ImageFile) GetSourceCodeInfo() *descriptorpb.SourceCodeInfo
func (*ImageFile) ProtoReflect ¶
func (x *ImageFile) ProtoReflect() protoreflect.Message
func (*ImageFile) SetBufExtension ¶
func (x *ImageFile) SetBufExtension(v *ImageFileExtension)
func (*ImageFile) SetEdition ¶
func (x *ImageFile) SetEdition(v descriptorpb.Edition)
func (*ImageFile) SetEnumType ¶
func (x *ImageFile) SetEnumType(v []*descriptorpb.EnumDescriptorProto)
func (*ImageFile) SetExtension ¶
func (x *ImageFile) SetExtension(v []*descriptorpb.FieldDescriptorProto)
func (*ImageFile) SetMessageType ¶
func (x *ImageFile) SetMessageType(v []*descriptorpb.DescriptorProto)
func (*ImageFile) SetOptions ¶
func (x *ImageFile) SetOptions(v *descriptorpb.FileOptions)
func (*ImageFile) SetService ¶
func (x *ImageFile) SetService(v []*descriptorpb.ServiceDescriptorProto)
func (*ImageFile) SetSourceCodeInfo ¶
func (x *ImageFile) SetSourceCodeInfo(v *descriptorpb.SourceCodeInfo)
type ImageFileExtension ¶
type ImageFileExtension struct {
// is_import denotes whether this file is considered an "import".
//
// An import is a file which was not derived from the local source files.
// There are two cases where this could be true:
//
// 1. A Well-Known Type included from the compiler.
// 2. A file that was included from a Buf module dependency.
//
// We use "import" as this matches with the protoc concept of
// --include_imports, however import is a bit of an overloaded term.
//
// This will always be set.
IsImport *bool `protobuf:"varint,1,opt,name=is_import,json=isImport" json:"is_import,omitempty"`
// ModuleInfo contains information about the Buf module this file belongs to.
//
// This field is optional and will not be set if the module is not known.
ModuleInfo *ModuleInfo `protobuf:"bytes,2,opt,name=module_info,json=moduleInfo" json:"module_info,omitempty"`
// is_syntax_unspecified denotes whether the file did not have a syntax
// explicitly specified.
//
// Per the FileDescriptorProto spec, it would be fine in this case to just
// leave the syntax field unset to denote this and to set the syntax field
// to "proto2" if it is specified. However, protoc does not set the syntax
// field if it was "proto2", and plugins may (incorrectly) depend on this.
// We also want to maintain consistency with protoc as much as possible.
// So instead, we have this field which will denote whether syntax was not
// specified.
//
// This will always be set.
IsSyntaxUnspecified *bool `protobuf:"varint,3,opt,name=is_syntax_unspecified,json=isSyntaxUnspecified" json:"is_syntax_unspecified,omitempty"`
// unused_dependency are the indexes within the dependency field on
// FileDescriptorProto for those dependencies that are not used.
//
// This matches the shape of the public_dependency and weak_dependency
// fields.
UnusedDependency []int32 `protobuf:"varint,4,rep,name=unused_dependency,json=unusedDependency" json:"unused_dependency,omitempty"`
// contains filtered or unexported fields
}
ImageFileExtension contains extensions to ImageFiles.
The fields are not included directly on the ImageFile so that we can both detect if extensions exist, which signifies this was created by buf and not by protoc, and so that we can add fields in a freeform manner without worrying about conflicts with FileDescriptorProto.
func (*ImageFileExtension) ClearIsImport ¶
func (x *ImageFileExtension) ClearIsImport()
func (*ImageFileExtension) ClearIsSyntaxUnspecified ¶
func (x *ImageFileExtension) ClearIsSyntaxUnspecified()
func (*ImageFileExtension) ClearModuleInfo ¶
func (x *ImageFileExtension) ClearModuleInfo()
func (*ImageFileExtension) GetIsImport ¶
func (x *ImageFileExtension) GetIsImport() bool
func (*ImageFileExtension) GetIsSyntaxUnspecified ¶
func (x *ImageFileExtension) GetIsSyntaxUnspecified() bool
func (*ImageFileExtension) GetModuleInfo ¶
func (x *ImageFileExtension) GetModuleInfo() *ModuleInfo
func (*ImageFileExtension) GetUnusedDependency ¶
func (x *ImageFileExtension) GetUnusedDependency() []int32
func (*ImageFileExtension) HasIsImport ¶
func (x *ImageFileExtension) HasIsImport() bool
func (*ImageFileExtension) HasIsSyntaxUnspecified ¶
func (x *ImageFileExtension) HasIsSyntaxUnspecified() bool
func (*ImageFileExtension) HasModuleInfo ¶
func (x *ImageFileExtension) HasModuleInfo() bool
func (*ImageFileExtension) ProtoMessage ¶
func (*ImageFileExtension) ProtoMessage()
func (*ImageFileExtension) ProtoReflect ¶
func (x *ImageFileExtension) ProtoReflect() protoreflect.Message
func (*ImageFileExtension) Reset ¶
func (x *ImageFileExtension) Reset()
func (*ImageFileExtension) SetIsImport ¶
func (x *ImageFileExtension) SetIsImport(v bool)
func (*ImageFileExtension) SetIsSyntaxUnspecified ¶
func (x *ImageFileExtension) SetIsSyntaxUnspecified(v bool)
func (*ImageFileExtension) SetModuleInfo ¶
func (x *ImageFileExtension) SetModuleInfo(v *ModuleInfo)
func (*ImageFileExtension) SetUnusedDependency ¶
func (x *ImageFileExtension) SetUnusedDependency(v []int32)
func (*ImageFileExtension) String ¶
func (x *ImageFileExtension) String() string
type ImageFileExtension_builder ¶
type ImageFileExtension_builder struct {
// is_import denotes whether this file is considered an "import".
//
// An import is a file which was not derived from the local source files.
// There are two cases where this could be true:
//
// 1. A Well-Known Type included from the compiler.
// 2. A file that was included from a Buf module dependency.
//
// We use "import" as this matches with the protoc concept of
// --include_imports, however import is a bit of an overloaded term.
//
// This will always be set.
IsImport *bool
// ModuleInfo contains information about the Buf module this file belongs to.
//
// This field is optional and will not be set if the module is not known.
ModuleInfo *ModuleInfo
// is_syntax_unspecified denotes whether the file did not have a syntax
// explicitly specified.
//
// Per the FileDescriptorProto spec, it would be fine in this case to just
// leave the syntax field unset to denote this and to set the syntax field
// to "proto2" if it is specified. However, protoc does not set the syntax
// field if it was "proto2", and plugins may (incorrectly) depend on this.
// We also want to maintain consistency with protoc as much as possible.
// So instead, we have this field which will denote whether syntax was not
// specified.
//
// This will always be set.
IsSyntaxUnspecified *bool
// unused_dependency are the indexes within the dependency field on
// FileDescriptorProto for those dependencies that are not used.
//
// This matches the shape of the public_dependency and weak_dependency
// fields.
UnusedDependency []int32
// contains filtered or unexported fields
}
func (ImageFileExtension_builder) Build ¶
func (b0 ImageFileExtension_builder) Build() *ImageFileExtension
type ImageFile_builder ¶
type ImageFile_builder struct {
Name *string
Package *string
Dependency []string
PublicDependency []int32
WeakDependency []int32
MessageType []*descriptorpb.DescriptorProto
EnumType []*descriptorpb.EnumDescriptorProto
Service []*descriptorpb.ServiceDescriptorProto
Extension []*descriptorpb.FieldDescriptorProto
Options *descriptorpb.FileOptions
SourceCodeInfo *descriptorpb.SourceCodeInfo
Syntax *string
Edition *descriptorpb.Edition
// buf_extension contains buf-specific extensions to FileDescriptorProtos.
//
// The prefixed name and high tag value is used to all but guarantee there
// will never be any conflict with Google's FileDescriptorProto definition.
// The definition of a FileDescriptorProto has not changed in years, so
// we're not too worried about a conflict here.
BufExtension *ImageFileExtension
// contains filtered or unexported fields
}
func (ImageFile_builder) Build ¶
func (b0 ImageFile_builder) Build() *ImageFile
type Image_builder ¶
type Image_builder struct {
File []*ImageFile
// contains filtered or unexported fields
}
func (Image_builder) Build ¶
func (b0 Image_builder) Build() *Image
type ModuleInfo ¶
type ModuleInfo struct {
// name is the name of the Buf module.
//
// This will always be set.
Name *ModuleName `protobuf:"bytes,1,opt,name=name" json:"name,omitempty"`
// commit is the repository commit.
//
// This field is optional and will not be set if the commit is not known.
Commit *string `protobuf:"bytes,2,opt,name=commit" json:"commit,omitempty"`
// contains filtered or unexported fields
}
ModuleInfo contains information about a Buf module that an ImageFile belongs to.
func (*ModuleInfo) ClearCommit ¶
func (x *ModuleInfo) ClearCommit()
func (*ModuleInfo) ClearName ¶
func (x *ModuleInfo) ClearName()
func (*ModuleInfo) GetCommit ¶
func (x *ModuleInfo) GetCommit() string
func (*ModuleInfo) GetName ¶
func (x *ModuleInfo) GetName() *ModuleName
func (*ModuleInfo) HasCommit ¶
func (x *ModuleInfo) HasCommit() bool
func (*ModuleInfo) HasName ¶
func (x *ModuleInfo) HasName() bool
func (*ModuleInfo) ProtoMessage ¶
func (*ModuleInfo) ProtoMessage()
func (*ModuleInfo) ProtoReflect ¶
func (x *ModuleInfo) ProtoReflect() protoreflect.Message
func (*ModuleInfo) Reset ¶
func (x *ModuleInfo) Reset()
func (*ModuleInfo) SetCommit ¶
func (x *ModuleInfo) SetCommit(v string)
func (*ModuleInfo) SetName ¶
func (x *ModuleInfo) SetName(v *ModuleName)
func (*ModuleInfo) String ¶
func (x *ModuleInfo) String() string
type ModuleInfo_builder ¶
type ModuleInfo_builder struct {
// name is the name of the Buf module.
//
// This will always be set.
Name *ModuleName
// commit is the repository commit.
//
// This field is optional and will not be set if the commit is not known.
Commit *string
// contains filtered or unexported fields
}
func (ModuleInfo_builder) Build ¶
func (b0 ModuleInfo_builder) Build() *ModuleInfo
type ModuleName ¶
type ModuleName struct {
Remote *string `protobuf:"bytes,1,opt,name=remote" json:"remote,omitempty"`
Owner *string `protobuf:"bytes,2,opt,name=owner" json:"owner,omitempty"`
Repository *string `protobuf:"bytes,3,opt,name=repository" json:"repository,omitempty"`
// contains filtered or unexported fields
}
ModuleName is a module name.
All fields will always be set.
func (*ModuleName) ClearOwner ¶
func (x *ModuleName) ClearOwner()
func (*ModuleName) ClearRemote ¶
func (x *ModuleName) ClearRemote()
func (*ModuleName) ClearRepository ¶
func (x *ModuleName) ClearRepository()
func (*ModuleName) GetOwner ¶
func (x *ModuleName) GetOwner() string
func (*ModuleName) GetRemote ¶
func (x *ModuleName) GetRemote() string
func (*ModuleName) GetRepository ¶
func (x *ModuleName) GetRepository() string
func (*ModuleName) HasOwner ¶
func (x *ModuleName) HasOwner() bool
func (*ModuleName) HasRemote ¶
func (x *ModuleName) HasRemote() bool
func (*ModuleName) HasRepository ¶
func (x *ModuleName) HasRepository() bool
func (*ModuleName) ProtoMessage ¶
func (*ModuleName) ProtoMessage()
func (*ModuleName) ProtoReflect ¶
func (x *ModuleName) ProtoReflect() protoreflect.Message
func (*ModuleName) Reset ¶
func (x *ModuleName) Reset()
func (*ModuleName) SetOwner ¶
func (x *ModuleName) SetOwner(v string)
func (*ModuleName) SetRemote ¶
func (x *ModuleName) SetRemote(v string)
func (*ModuleName) SetRepository ¶
func (x *ModuleName) SetRepository(v string)
func (*ModuleName) String ¶
func (x *ModuleName) String() string
type ModuleName_builder ¶
type ModuleName_builder struct {
Remote *string
Owner *string
Repository *string
// contains filtered or unexported fields
}
func (ModuleName_builder) Build ¶
func (b0 ModuleName_builder) Build() *ModuleName
Source Files
¶
- image.pb.go