Documentation
¶
Index ¶
- Variables
- type Blob
- func (x *Blob) ClearDigest()
- func (x *Blob) GetContent() []byte
- func (x *Blob) GetDigest() *Digest
- func (x *Blob) HasDigest() bool
- func (*Blob) ProtoMessage()
- func (x *Blob) ProtoReflect() protoreflect.Message
- func (x *Blob) Reset()
- func (x *Blob) SetContent(v []byte)
- func (x *Blob) SetDigest(v *Digest)
- func (x *Blob) String() string
- type Blob_builder
- type Digest
- func (x *Digest) GetDigest() []byte
- func (x *Digest) GetDigestType() DigestType
- func (*Digest) ProtoMessage()
- func (x *Digest) ProtoReflect() protoreflect.Message
- func (x *Digest) Reset()
- func (x *Digest) SetDigest(v []byte)
- func (x *Digest) SetDigestType(v DigestType)
- func (x *Digest) String() string
- type DigestType
- type Digest_builder
- type Module
- func (x *Module) ClearBreakingConfig()
- func (x *Module) ClearLintConfig()
- func (x *Module) GetBreakingConfig() *v1.Config
- func (x *Module) GetDependencies() []*ModulePin
- func (x *Module) GetDocumentation() string
- func (x *Module) GetDocumentationPath() string
- func (x *Module) GetFiles() []*ModuleFile
- func (x *Module) GetLicense() string
- func (x *Module) GetLintConfig() *v11.Config
- func (x *Module) HasBreakingConfig() bool
- func (x *Module) HasLintConfig() bool
- func (*Module) ProtoMessage()
- func (x *Module) ProtoReflect() protoreflect.Message
- func (x *Module) Reset()
- func (x *Module) SetBreakingConfig(v *v1.Config)
- func (x *Module) SetDependencies(v []*ModulePin)
- func (x *Module) SetDocumentation(v string)
- func (x *Module) SetDocumentationPath(v string)
- func (x *Module) SetFiles(v []*ModuleFile)
- func (x *Module) SetLicense(v string)
- func (x *Module) SetLintConfig(v *v11.Config)
- func (x *Module) String() string
- type ModuleFile
- func (x *ModuleFile) GetContent() []byte
- func (x *ModuleFile) GetPath() string
- func (*ModuleFile) ProtoMessage()
- func (x *ModuleFile) ProtoReflect() protoreflect.Message
- func (x *ModuleFile) Reset()
- func (x *ModuleFile) SetContent(v []byte)
- func (x *ModuleFile) SetPath(v string)
- func (x *ModuleFile) String() string
- type ModuleFile_builder
- type ModulePin
- func (x *ModulePin) GetCommit() string
- func (x *ModulePin) GetManifestDigest() string
- func (x *ModulePin) GetOwner() string
- func (x *ModulePin) GetRemote() string
- func (x *ModulePin) GetRepository() string
- func (*ModulePin) ProtoMessage()
- func (x *ModulePin) ProtoReflect() protoreflect.Message
- func (x *ModulePin) Reset()
- func (x *ModulePin) SetCommit(v string)
- func (x *ModulePin) SetManifestDigest(v string)
- func (x *ModulePin) SetOwner(v string)
- func (x *ModulePin) SetRemote(v string)
- func (x *ModulePin) SetRepository(v string)
- func (x *ModulePin) String() string
- type ModulePin_builder
- type ModuleReference
- func (x *ModuleReference) GetOwner() string
- func (x *ModuleReference) GetReference() string
- func (x *ModuleReference) GetRemote() string
- func (x *ModuleReference) GetRepository() string
- func (*ModuleReference) ProtoMessage()
- func (x *ModuleReference) ProtoReflect() protoreflect.Message
- func (x *ModuleReference) Reset()
- func (x *ModuleReference) SetOwner(v string)
- func (x *ModuleReference) SetReference(v string)
- func (x *ModuleReference) SetRemote(v string)
- func (x *ModuleReference) SetRepository(v string)
- func (x *ModuleReference) String() string
- type ModuleReference_builder
- type Module_builder
Constants ¶
This section is empty.
Variables ¶
var ( DigestType_name = map[int32]string{ 0: "DIGEST_TYPE_UNSPECIFIED", 1: "DIGEST_TYPE_SHAKE256", } DigestType_value = map[string]int32{ "DIGEST_TYPE_UNSPECIFIED": 0, "DIGEST_TYPE_SHAKE256": 1, } )
Enum value maps for DigestType.
var File_buf_alpha_module_v1alpha1_module_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Blob ¶
type Blob struct {
// Digest of the content.
Digest *Digest `protobuf:"bytes,1,opt,name=digest,proto3" json:"digest,omitempty"`
// Content of the blob.
Content []byte `protobuf:"bytes,2,opt,name=content,proto3" json:"content,omitempty"`
// contains filtered or unexported fields
}
Blob represents some module content with an associated digest.
func (*Blob) ProtoReflect ¶
func (x *Blob) ProtoReflect() protoreflect.Message
type Blob_builder ¶
type Blob_builder struct {
// Digest of the content.
Digest *Digest
// Content of the blob.
Content []byte
// contains filtered or unexported fields
}
func (Blob_builder) Build ¶
func (b0 Blob_builder) Build() *Blob
type Digest ¶
type Digest struct {
// digest_type describes the hash algorithm. e.g. "SHAKE256"
DigestType DigestType `` /* 134-byte string literal not displayed */
// digest is the hash's output without encoding.
Digest []byte `protobuf:"bytes,2,opt,name=digest,proto3" json:"digest,omitempty"`
// contains filtered or unexported fields
}
Digest represents a hash function's value.
func (*Digest) GetDigestType ¶
func (x *Digest) GetDigestType() DigestType
func (*Digest) ProtoReflect ¶
func (x *Digest) ProtoReflect() protoreflect.Message
func (*Digest) SetDigestType ¶
func (x *Digest) SetDigestType(v DigestType)
type DigestType ¶
type DigestType int32
const ( DigestType_DIGEST_TYPE_UNSPECIFIED DigestType = 0 DigestType_DIGEST_TYPE_SHAKE256 DigestType = 1 )
func (DigestType) Descriptor ¶
func (DigestType) Descriptor() protoreflect.EnumDescriptor
func (DigestType) Enum ¶
func (x DigestType) Enum() *DigestType
func (DigestType) Number ¶
func (x DigestType) Number() protoreflect.EnumNumber
func (DigestType) String ¶
func (x DigestType) String() string
func (DigestType) Type ¶
func (DigestType) Type() protoreflect.EnumType
type Digest_builder ¶
type Digest_builder struct {
// digest_type describes the hash algorithm. e.g. "SHAKE256"
DigestType DigestType
// digest is the hash's output without encoding.
Digest []byte
// contains filtered or unexported fields
}
func (Digest_builder) Build ¶
func (b0 Digest_builder) Build() *Digest
type Module ¶
type Module struct {
// files are the files that make up the set.
//
// Sorted by path.
// Path must be unique.
// Only the target files. No imports.
//
// Maximum total size of all content: 32MB.
Files []*ModuleFile `protobuf:"bytes,1,rep,name=files,proto3" json:"files,omitempty"`
// dependencies are the dependencies.
Dependencies []*ModulePin `protobuf:"bytes,2,rep,name=dependencies,proto3" json:"dependencies,omitempty"`
// documentation is the string representation of the contents of the file at documentation_path.
//
// string is used to enforce UTF-8 encoding or 7-bit ASCII text.
Documentation string `protobuf:"bytes,3,opt,name=documentation,proto3" json:"documentation,omitempty"`
// breaking_config is the breaking change detection configuration set for the module.
BreakingConfig *v1.Config `protobuf:"bytes,4,opt,name=breaking_config,json=breakingConfig,proto3" json:"breaking_config,omitempty"`
// lint_config is the lint configuration set for the module.
LintConfig *v11.Config `protobuf:"bytes,5,opt,name=lint_config,json=lintConfig,proto3" json:"lint_config,omitempty"`
// license is the string representation of the contents of the `LICENSE` file.
//
// string is used to enforce UTF-8 encoding or 7-bit ASCII text.
License string `protobuf:"bytes,6,opt,name=license,proto3" json:"license,omitempty"`
// documentation_path is the path of the file which contains the module documentation.
//
// either `buf.md`, `README.md` or `README.markdown`.
// if empty, assumes buf.md.
DocumentationPath string `protobuf:"bytes,7,opt,name=documentation_path,json=documentationPath,proto3" json:"documentation_path,omitempty"`
// contains filtered or unexported fields
}
Module is a module.
func (*Module) GetFiles ¶
func (x *Module) GetFiles() []*ModuleFile
func (*Module) ProtoReflect ¶
func (x *Module) ProtoReflect() protoreflect.Message
func (*Module) SetFiles ¶
func (x *Module) SetFiles(v []*ModuleFile)
type ModuleFile ¶
type ModuleFile struct {
// path is the relative path of the file.
// Path can only use '/' as the separator character, and includes no ".." components.
Path string `protobuf:"bytes,1,opt,name=path,proto3" json:"path,omitempty"`
// content is the content of the file.
Content []byte `protobuf:"bytes,2,opt,name=content,proto3" json:"content,omitempty"`
// contains filtered or unexported fields
}
ModuleFile is a file within a FileSet.
func (*ModuleFile) GetContent ¶
func (x *ModuleFile) GetContent() []byte
func (*ModuleFile) GetPath ¶
func (x *ModuleFile) GetPath() string
func (*ModuleFile) ProtoMessage ¶
func (*ModuleFile) ProtoMessage()
func (*ModuleFile) ProtoReflect ¶
func (x *ModuleFile) ProtoReflect() protoreflect.Message
func (*ModuleFile) Reset ¶
func (x *ModuleFile) Reset()
func (*ModuleFile) SetContent ¶
func (x *ModuleFile) SetContent(v []byte)
func (*ModuleFile) SetPath ¶
func (x *ModuleFile) SetPath(v string)
func (*ModuleFile) String ¶
func (x *ModuleFile) String() string
type ModuleFile_builder ¶
type ModuleFile_builder struct {
// path is the relative path of the file.
// Path can only use '/' as the separator character, and includes no ".." components.
Path string
// content is the content of the file.
Content []byte
// contains filtered or unexported fields
}
func (ModuleFile_builder) Build ¶
func (b0 ModuleFile_builder) Build() *ModuleFile
type ModulePin ¶
type ModulePin struct {
Remote string `protobuf:"bytes,1,opt,name=remote,proto3" json:"remote,omitempty"`
Owner string `protobuf:"bytes,2,opt,name=owner,proto3" json:"owner,omitempty"`
Repository string `protobuf:"bytes,3,opt,name=repository,proto3" json:"repository,omitempty"`
Commit string `protobuf:"bytes,5,opt,name=commit,proto3" json:"commit,omitempty"`
// Module's manifest digest. Replacement for previous b1/b3 digests.
// This is in the format '<digest_type>:<digest>`, where '<digest_type>' is the lowercase digest name ('shake256'),
// and '<digest>' is the lowercase hex-encoded digest.
// This value is persisted directly to the buf.lock file (https://buf.build/docs/configuration/v1/buf-lock) as the 'digest' key.
ManifestDigest string `protobuf:"bytes,8,opt,name=manifest_digest,json=manifestDigest,proto3" json:"manifest_digest,omitempty"`
// contains filtered or unexported fields
}
ModulePin is a module pin.
func (*ModulePin) ProtoReflect ¶
func (x *ModulePin) ProtoReflect() protoreflect.Message
type ModulePin_builder ¶
type ModulePin_builder struct {
Remote string
Owner string
Repository string
Commit string
// Module's manifest digest. Replacement for previous b1/b3 digests.
// This is in the format '<digest_type>:<digest>`, where '<digest_type>' is the lowercase digest name ('shake256'),
// and '<digest>' is the lowercase hex-encoded digest.
// This value is persisted directly to the buf.lock file (https://buf.build/docs/configuration/v1/buf-lock) as the 'digest' key.
ManifestDigest string
// contains filtered or unexported fields
}
func (ModulePin_builder) Build ¶
func (b0 ModulePin_builder) Build() *ModulePin
type ModuleReference ¶
type ModuleReference struct {
Remote string `protobuf:"bytes,1,opt,name=remote,proto3" json:"remote,omitempty"`
Owner string `protobuf:"bytes,2,opt,name=owner,proto3" json:"owner,omitempty"`
Repository string `protobuf:"bytes,3,opt,name=repository,proto3" json:"repository,omitempty"`
// either tag, or commit
Reference string `protobuf:"bytes,4,opt,name=reference,proto3" json:"reference,omitempty"`
// contains filtered or unexported fields
}
ModuleReference is a module reference.
func (*ModuleReference) GetOwner ¶
func (x *ModuleReference) GetOwner() string
func (*ModuleReference) GetReference ¶
func (x *ModuleReference) GetReference() string
func (*ModuleReference) GetRemote ¶
func (x *ModuleReference) GetRemote() string
func (*ModuleReference) GetRepository ¶
func (x *ModuleReference) GetRepository() string
func (*ModuleReference) ProtoMessage ¶
func (*ModuleReference) ProtoMessage()
func (*ModuleReference) ProtoReflect ¶
func (x *ModuleReference) ProtoReflect() protoreflect.Message
func (*ModuleReference) Reset ¶
func (x *ModuleReference) Reset()
func (*ModuleReference) SetOwner ¶
func (x *ModuleReference) SetOwner(v string)
func (*ModuleReference) SetReference ¶
func (x *ModuleReference) SetReference(v string)
func (*ModuleReference) SetRemote ¶
func (x *ModuleReference) SetRemote(v string)
func (*ModuleReference) SetRepository ¶
func (x *ModuleReference) SetRepository(v string)
func (*ModuleReference) String ¶
func (x *ModuleReference) String() string
type ModuleReference_builder ¶
type ModuleReference_builder struct {
Remote string
Owner string
Repository string
// either tag, or commit
Reference string
// contains filtered or unexported fields
}
func (ModuleReference_builder) Build ¶
func (b0 ModuleReference_builder) Build() *ModuleReference
type Module_builder ¶
type Module_builder struct {
// files are the files that make up the set.
//
// Sorted by path.
// Path must be unique.
// Only the target files. No imports.
//
// Maximum total size of all content: 32MB.
Files []*ModuleFile
// dependencies are the dependencies.
Dependencies []*ModulePin
// documentation is the string representation of the contents of the file at documentation_path.
//
// string is used to enforce UTF-8 encoding or 7-bit ASCII text.
Documentation string
// breaking_config is the breaking change detection configuration set for the module.
BreakingConfig *v1.Config
// lint_config is the lint configuration set for the module.
LintConfig *v11.Config
// license is the string representation of the contents of the `LICENSE` file.
//
// string is used to enforce UTF-8 encoding or 7-bit ASCII text.
License string
// documentation_path is the path of the file which contains the module documentation.
//
// either `buf.md`, `README.md` or `README.markdown`.
// if empty, assumes buf.md.
DocumentationPath string
// contains filtered or unexported fields
}
func (Module_builder) Build ¶
func (b0 Module_builder) Build() *Module
Source Files
¶
- module.pb.go
Click to show internal directories.
Click to hide internal directories.