planetv1connect

package
v1.10.0-20240801130531... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 6 Imported by: 1

Documentation

Index

Constants

const (
	// PlanetServiceGetPlanetsProcedure is the fully-qualified name of the PlanetService's GetPlanets
	// RPC.
	PlanetServiceGetPlanetsProcedure = "/buf.knit.demo.swapi.planet.v1.PlanetService/GetPlanets"
	// PlanetServiceListPlanetsProcedure is the fully-qualified name of the PlanetService's ListPlanets
	// RPC.
	PlanetServiceListPlanetsProcedure = "/buf.knit.demo.swapi.planet.v1.PlanetService/ListPlanets"
)

These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.

Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.

const (
	// PlanetServiceName is the fully-qualified name of the PlanetService service.
	PlanetServiceName = "buf.knit.demo.swapi.planet.v1.PlanetService"
)

Variables

This section is empty.

Functions

func NewPlanetServiceHandler

func NewPlanetServiceHandler(svc PlanetServiceHandler, opts ...connect_go.HandlerOption) (string, http.Handler)

NewPlanetServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.

By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.

Types

type PlanetServiceClient

PlanetServiceClient is a client for the buf.knit.demo.swapi.planet.v1.PlanetService service.

func NewPlanetServiceClient

func NewPlanetServiceClient(httpClient connect_go.HTTPClient, baseURL string, opts ...connect_go.ClientOption) PlanetServiceClient

NewPlanetServiceClient constructs a client for the buf.knit.demo.swapi.planet.v1.PlanetService service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.

The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).

type PlanetServiceHandler

PlanetServiceHandler is an implementation of the buf.knit.demo.swapi.planet.v1.PlanetService service.

type UnimplementedPlanetServiceHandler

type UnimplementedPlanetServiceHandler struct{}

UnimplementedPlanetServiceHandler returns CodeUnimplemented from all methods.

func (UnimplementedPlanetServiceHandler) GetPlanets

func (UnimplementedPlanetServiceHandler) ListPlanets

Source Files

  • planet.connect.go

Jump to