Documentation
¶
Index ¶
- Constants
- func NewVehicleServiceHandler(svc VehicleServiceHandler, opts ...connect_go.HandlerOption) (string, http.Handler)
- type UnimplementedVehicleServiceHandler
- func (UnimplementedVehicleServiceHandler) GetVehicles(context.Context, *connect_go.Request[v1.GetVehiclesRequest]) (*connect_go.Response[v1.GetVehiclesResponse], error)
- func (UnimplementedVehicleServiceHandler) ListVehicles(context.Context, *connect_go.Request[v1.ListVehiclesRequest]) (*connect_go.Response[v1.ListVehiclesResponse], error)
- type VehicleServiceClient
- type VehicleServiceHandler
Constants ¶
const ( // VehicleServiceGetVehiclesProcedure is the fully-qualified name of the VehicleService's // GetVehicles RPC. VehicleServiceGetVehiclesProcedure = "/buf.knit.demo.swapi.vehicle.v1.VehicleService/GetVehicles" // VehicleServiceListVehiclesProcedure is the fully-qualified name of the VehicleService's // ListVehicles RPC. VehicleServiceListVehiclesProcedure = "/buf.knit.demo.swapi.vehicle.v1.VehicleService/ListVehicles" )
These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.
Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.
const (
// VehicleServiceName is the fully-qualified name of the VehicleService service.
VehicleServiceName = "buf.knit.demo.swapi.vehicle.v1.VehicleService"
)
Variables ¶
This section is empty.
Functions ¶
func NewVehicleServiceHandler ¶
func NewVehicleServiceHandler(svc VehicleServiceHandler, opts ...connect_go.HandlerOption) (string, http.Handler)
NewVehicleServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.
By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.
Types ¶
type UnimplementedVehicleServiceHandler ¶
type UnimplementedVehicleServiceHandler struct{}
UnimplementedVehicleServiceHandler returns CodeUnimplemented from all methods.
func (UnimplementedVehicleServiceHandler) GetVehicles ¶
func (UnimplementedVehicleServiceHandler) GetVehicles(context.Context, *connect_go.Request[v1.GetVehiclesRequest]) (*connect_go.Response[v1.GetVehiclesResponse], error)
func (UnimplementedVehicleServiceHandler) ListVehicles ¶
func (UnimplementedVehicleServiceHandler) ListVehicles(context.Context, *connect_go.Request[v1.ListVehiclesRequest]) (*connect_go.Response[v1.ListVehiclesResponse], error)
type VehicleServiceClient ¶
type VehicleServiceClient interface {
GetVehicles(context.Context, *connect_go.Request[v1.GetVehiclesRequest]) (*connect_go.Response[v1.GetVehiclesResponse], error)
ListVehicles(context.Context, *connect_go.Request[v1.ListVehiclesRequest]) (*connect_go.Response[v1.ListVehiclesResponse], error)
}
VehicleServiceClient is a client for the buf.knit.demo.swapi.vehicle.v1.VehicleService service.
func NewVehicleServiceClient ¶
func NewVehicleServiceClient(httpClient connect_go.HTTPClient, baseURL string, opts ...connect_go.ClientOption) VehicleServiceClient
NewVehicleServiceClient constructs a client for the buf.knit.demo.swapi.vehicle.v1.VehicleService service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.
The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).
type VehicleServiceHandler ¶
type VehicleServiceHandler interface {
GetVehicles(context.Context, *connect_go.Request[v1.GetVehiclesRequest]) (*connect_go.Response[v1.GetVehiclesResponse], error)
ListVehicles(context.Context, *connect_go.Request[v1.ListVehiclesRequest]) (*connect_go.Response[v1.ListVehiclesResponse], error)
}
VehicleServiceHandler is an implementation of the buf.knit.demo.swapi.vehicle.v1.VehicleService service.
Source Files
¶
- vehicle.connect.go