personv1connect

package
v1.19.1-20240801130531... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 6 Imported by: 1

Documentation

Index

Constants

const (
	// PersonServiceGetPeopleProcedure is the fully-qualified name of the PersonService's GetPeople RPC.
	PersonServiceGetPeopleProcedure = "/buf.knit.demo.swapi.person.v1.PersonService/GetPeople"
	// PersonServiceListPeopleProcedure is the fully-qualified name of the PersonService's ListPeople
	// RPC.
	PersonServiceListPeopleProcedure = "/buf.knit.demo.swapi.person.v1.PersonService/ListPeople"
)

These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.

Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.

const (
	// PersonServiceName is the fully-qualified name of the PersonService service.
	PersonServiceName = "buf.knit.demo.swapi.person.v1.PersonService"
)

Variables

This section is empty.

Functions

func NewPersonServiceHandler

func NewPersonServiceHandler(svc PersonServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)

NewPersonServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.

By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.

Types

type PersonServiceClient

PersonServiceClient is a client for the buf.knit.demo.swapi.person.v1.PersonService service.

func NewPersonServiceClient

func NewPersonServiceClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) PersonServiceClient

NewPersonServiceClient constructs a client for the buf.knit.demo.swapi.person.v1.PersonService service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.

The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).

type PersonServiceHandler

PersonServiceHandler is an implementation of the buf.knit.demo.swapi.person.v1.PersonService service.

type UnimplementedPersonServiceHandler

type UnimplementedPersonServiceHandler struct{}

UnimplementedPersonServiceHandler returns CodeUnimplemented from all methods.

func (UnimplementedPersonServiceHandler) GetPeople

func (UnimplementedPersonServiceHandler) ListPeople

Source Files

  • person.connect.go

Jump to