relationsv1connect

package
v1.19.1-20240801130531... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 6 Imported by: 1

Documentation

Index

Constants

const (
	// FilmResolverServiceName is the fully-qualified name of the FilmResolverService service.
	FilmResolverServiceName = "buf.knit.demo.swapi.relations.v1.FilmResolverService"
	// PersonResolverServiceName is the fully-qualified name of the PersonResolverService service.
	PersonResolverServiceName = "buf.knit.demo.swapi.relations.v1.PersonResolverService"
	// PlanetResolverServiceName is the fully-qualified name of the PlanetResolverService service.
	PlanetResolverServiceName = "buf.knit.demo.swapi.relations.v1.PlanetResolverService"
	// SpeciesResolverServiceName is the fully-qualified name of the SpeciesResolverService service.
	SpeciesResolverServiceName = "buf.knit.demo.swapi.relations.v1.SpeciesResolverService"
	// StarshipResolverServiceName is the fully-qualified name of the StarshipResolverService service.
	StarshipResolverServiceName = "buf.knit.demo.swapi.relations.v1.StarshipResolverService"
	// VehicleResolverServiceName is the fully-qualified name of the VehicleResolverService service.
	VehicleResolverServiceName = "buf.knit.demo.swapi.relations.v1.VehicleResolverService"
)
const (
	// FilmResolverServiceGetPersonFilmsProcedure is the fully-qualified name of the
	// FilmResolverService's GetPersonFilms RPC.
	FilmResolverServiceGetPersonFilmsProcedure = "/buf.knit.demo.swapi.relations.v1.FilmResolverService/GetPersonFilms"
	// FilmResolverServiceGetSpeciesFilmsProcedure is the fully-qualified name of the
	// FilmResolverService's GetSpeciesFilms RPC.
	FilmResolverServiceGetSpeciesFilmsProcedure = "/buf.knit.demo.swapi.relations.v1.FilmResolverService/GetSpeciesFilms"
	// FilmResolverServiceGetPlanetFilmsProcedure is the fully-qualified name of the
	// FilmResolverService's GetPlanetFilms RPC.
	FilmResolverServiceGetPlanetFilmsProcedure = "/buf.knit.demo.swapi.relations.v1.FilmResolverService/GetPlanetFilms"
	// FilmResolverServiceGetStarshipFilmsProcedure is the fully-qualified name of the
	// FilmResolverService's GetStarshipFilms RPC.
	FilmResolverServiceGetStarshipFilmsProcedure = "/buf.knit.demo.swapi.relations.v1.FilmResolverService/GetStarshipFilms"
	// FilmResolverServiceGetVehicleFilmsProcedure is the fully-qualified name of the
	// FilmResolverService's GetVehicleFilms RPC.
	FilmResolverServiceGetVehicleFilmsProcedure = "/buf.knit.demo.swapi.relations.v1.FilmResolverService/GetVehicleFilms"
	// PersonResolverServiceGetFilmCharactersProcedure is the fully-qualified name of the
	// PersonResolverService's GetFilmCharacters RPC.
	PersonResolverServiceGetFilmCharactersProcedure = "/buf.knit.demo.swapi.relations.v1.PersonResolverService/GetFilmCharacters"
	// PersonResolverServiceGetSpeciesCharactersProcedure is the fully-qualified name of the
	// PersonResolverService's GetSpeciesCharacters RPC.
	PersonResolverServiceGetSpeciesCharactersProcedure = "/buf.knit.demo.swapi.relations.v1.PersonResolverService/GetSpeciesCharacters"
	// PersonResolverServiceGetPlanetResidentsProcedure is the fully-qualified name of the
	// PersonResolverService's GetPlanetResidents RPC.
	PersonResolverServiceGetPlanetResidentsProcedure = "/buf.knit.demo.swapi.relations.v1.PersonResolverService/GetPlanetResidents"
	// PersonResolverServiceGetStarshipPilotsProcedure is the fully-qualified name of the
	// PersonResolverService's GetStarshipPilots RPC.
	PersonResolverServiceGetStarshipPilotsProcedure = "/buf.knit.demo.swapi.relations.v1.PersonResolverService/GetStarshipPilots"
	// PersonResolverServiceGetVehiclePilotsProcedure is the fully-qualified name of the
	// PersonResolverService's GetVehiclePilots RPC.
	PersonResolverServiceGetVehiclePilotsProcedure = "/buf.knit.demo.swapi.relations.v1.PersonResolverService/GetVehiclePilots"
	// PlanetResolverServiceGetFilmPlanetsProcedure is the fully-qualified name of the
	// PlanetResolverService's GetFilmPlanets RPC.
	PlanetResolverServiceGetFilmPlanetsProcedure = "/buf.knit.demo.swapi.relations.v1.PlanetResolverService/GetFilmPlanets"
	// PlanetResolverServiceGetPersonHomeworldProcedure is the fully-qualified name of the
	// PlanetResolverService's GetPersonHomeworld RPC.
	PlanetResolverServiceGetPersonHomeworldProcedure = "/buf.knit.demo.swapi.relations.v1.PlanetResolverService/GetPersonHomeworld"
	// PlanetResolverServiceGetSpeciesHomeworldProcedure is the fully-qualified name of the
	// PlanetResolverService's GetSpeciesHomeworld RPC.
	PlanetResolverServiceGetSpeciesHomeworldProcedure = "/buf.knit.demo.swapi.relations.v1.PlanetResolverService/GetSpeciesHomeworld"
	// SpeciesResolverServiceGetFilmSpeciesProcedure is the fully-qualified name of the
	// SpeciesResolverService's GetFilmSpecies RPC.
	SpeciesResolverServiceGetFilmSpeciesProcedure = "/buf.knit.demo.swapi.relations.v1.SpeciesResolverService/GetFilmSpecies"
	// SpeciesResolverServiceGetPersonSpeciesProcedure is the fully-qualified name of the
	// SpeciesResolverService's GetPersonSpecies RPC.
	SpeciesResolverServiceGetPersonSpeciesProcedure = "/buf.knit.demo.swapi.relations.v1.SpeciesResolverService/GetPersonSpecies"
	// StarshipResolverServiceGetFilmStarshipsProcedure is the fully-qualified name of the
	// StarshipResolverService's GetFilmStarships RPC.
	StarshipResolverServiceGetFilmStarshipsProcedure = "/buf.knit.demo.swapi.relations.v1.StarshipResolverService/GetFilmStarships"
	// StarshipResolverServiceGetPersonStarshipsProcedure is the fully-qualified name of the
	// StarshipResolverService's GetPersonStarships RPC.
	StarshipResolverServiceGetPersonStarshipsProcedure = "/buf.knit.demo.swapi.relations.v1.StarshipResolverService/GetPersonStarships"
	// VehicleResolverServiceGetFilmVehiclesProcedure is the fully-qualified name of the
	// VehicleResolverService's GetFilmVehicles RPC.
	VehicleResolverServiceGetFilmVehiclesProcedure = "/buf.knit.demo.swapi.relations.v1.VehicleResolverService/GetFilmVehicles"
	// VehicleResolverServiceGetPersonVehiclesProcedure is the fully-qualified name of the
	// VehicleResolverService's GetPersonVehicles RPC.
	VehicleResolverServiceGetPersonVehiclesProcedure = "/buf.knit.demo.swapi.relations.v1.VehicleResolverService/GetPersonVehicles"
)

These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.

Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.

Variables

This section is empty.

Functions

func NewFilmResolverServiceHandler

func NewFilmResolverServiceHandler(svc FilmResolverServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)

NewFilmResolverServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.

By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.

func NewPersonResolverServiceHandler

func NewPersonResolverServiceHandler(svc PersonResolverServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)

NewPersonResolverServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.

By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.

func NewPlanetResolverServiceHandler

func NewPlanetResolverServiceHandler(svc PlanetResolverServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)

NewPlanetResolverServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.

By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.

func NewSpeciesResolverServiceHandler

func NewSpeciesResolverServiceHandler(svc SpeciesResolverServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)

NewSpeciesResolverServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.

By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.

func NewStarshipResolverServiceHandler

func NewStarshipResolverServiceHandler(svc StarshipResolverServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)

NewStarshipResolverServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.

By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.

func NewVehicleResolverServiceHandler

func NewVehicleResolverServiceHandler(svc VehicleResolverServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)

NewVehicleResolverServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.

By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.

Types

type FilmResolverServiceClient

FilmResolverServiceClient is a client for the buf.knit.demo.swapi.relations.v1.FilmResolverService service.

func NewFilmResolverServiceClient

func NewFilmResolverServiceClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) FilmResolverServiceClient

NewFilmResolverServiceClient constructs a client for the buf.knit.demo.swapi.relations.v1.FilmResolverService service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.

The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).

type FilmResolverServiceHandler

FilmResolverServiceHandler is an implementation of the buf.knit.demo.swapi.relations.v1.FilmResolverService service.

type PersonResolverServiceClient

PersonResolverServiceClient is a client for the buf.knit.demo.swapi.relations.v1.PersonResolverService service.

func NewPersonResolverServiceClient

func NewPersonResolverServiceClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) PersonResolverServiceClient

NewPersonResolverServiceClient constructs a client for the buf.knit.demo.swapi.relations.v1.PersonResolverService service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.

The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).

type PersonResolverServiceHandler

PersonResolverServiceHandler is an implementation of the buf.knit.demo.swapi.relations.v1.PersonResolverService service.

type PlanetResolverServiceClient

PlanetResolverServiceClient is a client for the buf.knit.demo.swapi.relations.v1.PlanetResolverService service.

func NewPlanetResolverServiceClient

func NewPlanetResolverServiceClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) PlanetResolverServiceClient

NewPlanetResolverServiceClient constructs a client for the buf.knit.demo.swapi.relations.v1.PlanetResolverService service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.

The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).

type PlanetResolverServiceHandler

PlanetResolverServiceHandler is an implementation of the buf.knit.demo.swapi.relations.v1.PlanetResolverService service.

type SpeciesResolverServiceClient

SpeciesResolverServiceClient is a client for the buf.knit.demo.swapi.relations.v1.SpeciesResolverService service.

func NewSpeciesResolverServiceClient

func NewSpeciesResolverServiceClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) SpeciesResolverServiceClient

NewSpeciesResolverServiceClient constructs a client for the buf.knit.demo.swapi.relations.v1.SpeciesResolverService service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.

The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).

type SpeciesResolverServiceHandler

SpeciesResolverServiceHandler is an implementation of the buf.knit.demo.swapi.relations.v1.SpeciesResolverService service.

type StarshipResolverServiceClient

StarshipResolverServiceClient is a client for the buf.knit.demo.swapi.relations.v1.StarshipResolverService service.

func NewStarshipResolverServiceClient

func NewStarshipResolverServiceClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) StarshipResolverServiceClient

NewStarshipResolverServiceClient constructs a client for the buf.knit.demo.swapi.relations.v1.StarshipResolverService service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.

The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).

type StarshipResolverServiceHandler

StarshipResolverServiceHandler is an implementation of the buf.knit.demo.swapi.relations.v1.StarshipResolverService service.

type UnimplementedFilmResolverServiceHandler

type UnimplementedFilmResolverServiceHandler struct{}

UnimplementedFilmResolverServiceHandler returns CodeUnimplemented from all methods.

func (UnimplementedFilmResolverServiceHandler) GetPersonFilms

func (UnimplementedFilmResolverServiceHandler) GetPlanetFilms

func (UnimplementedFilmResolverServiceHandler) GetSpeciesFilms

func (UnimplementedFilmResolverServiceHandler) GetStarshipFilms

func (UnimplementedFilmResolverServiceHandler) GetVehicleFilms

type UnimplementedPersonResolverServiceHandler

type UnimplementedPersonResolverServiceHandler struct{}

UnimplementedPersonResolverServiceHandler returns CodeUnimplemented from all methods.

func (UnimplementedPersonResolverServiceHandler) GetFilmCharacters

func (UnimplementedPersonResolverServiceHandler) GetPlanetResidents

func (UnimplementedPersonResolverServiceHandler) GetSpeciesCharacters

func (UnimplementedPersonResolverServiceHandler) GetStarshipPilots

func (UnimplementedPersonResolverServiceHandler) GetVehiclePilots

type UnimplementedPlanetResolverServiceHandler

type UnimplementedPlanetResolverServiceHandler struct{}

UnimplementedPlanetResolverServiceHandler returns CodeUnimplemented from all methods.

func (UnimplementedPlanetResolverServiceHandler) GetFilmPlanets

func (UnimplementedPlanetResolverServiceHandler) GetPersonHomeworld

func (UnimplementedPlanetResolverServiceHandler) GetSpeciesHomeworld

type UnimplementedSpeciesResolverServiceHandler

type UnimplementedSpeciesResolverServiceHandler struct{}

UnimplementedSpeciesResolverServiceHandler returns CodeUnimplemented from all methods.

func (UnimplementedSpeciesResolverServiceHandler) GetFilmSpecies

func (UnimplementedSpeciesResolverServiceHandler) GetPersonSpecies

type UnimplementedStarshipResolverServiceHandler

type UnimplementedStarshipResolverServiceHandler struct{}

UnimplementedStarshipResolverServiceHandler returns CodeUnimplemented from all methods.

func (UnimplementedStarshipResolverServiceHandler) GetFilmStarships

func (UnimplementedStarshipResolverServiceHandler) GetPersonStarships

type UnimplementedVehicleResolverServiceHandler

type UnimplementedVehicleResolverServiceHandler struct{}

UnimplementedVehicleResolverServiceHandler returns CodeUnimplemented from all methods.

func (UnimplementedVehicleResolverServiceHandler) GetFilmVehicles

func (UnimplementedVehicleResolverServiceHandler) GetPersonVehicles

type VehicleResolverServiceClient

VehicleResolverServiceClient is a client for the buf.knit.demo.swapi.relations.v1.VehicleResolverService service.

func NewVehicleResolverServiceClient

func NewVehicleResolverServiceClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) VehicleResolverServiceClient

NewVehicleResolverServiceClient constructs a client for the buf.knit.demo.swapi.relations.v1.VehicleResolverService service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.

The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).

type VehicleResolverServiceHandler

VehicleResolverServiceHandler is an implementation of the buf.knit.demo.swapi.relations.v1.VehicleResolverService service.

Source Files

  • relations.connect.go

Jump to