planetv1

package
v1.36.11-2024080113053... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 5 Imported by: 2

Documentation

Index

Constants

This section is empty.

Variables

var File_buf_knit_demo_swapi_planet_v1_planet_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type GetPlanetsRequest

type GetPlanetsRequest struct {
	Ids []string `protobuf:"bytes,1,rep,name=ids,proto3" json:"ids,omitempty"`
	// contains filtered or unexported fields
}

func (*GetPlanetsRequest) GetIds

func (x *GetPlanetsRequest) GetIds() []string

func (*GetPlanetsRequest) ProtoMessage

func (*GetPlanetsRequest) ProtoMessage()

func (*GetPlanetsRequest) ProtoReflect

func (x *GetPlanetsRequest) ProtoReflect() protoreflect.Message

func (*GetPlanetsRequest) Reset

func (x *GetPlanetsRequest) Reset()

func (*GetPlanetsRequest) SetIds

func (x *GetPlanetsRequest) SetIds(v []string)

func (*GetPlanetsRequest) String

func (x *GetPlanetsRequest) String() string

type GetPlanetsRequest_builder

type GetPlanetsRequest_builder struct {
	Ids []string
	// contains filtered or unexported fields
}

func (GetPlanetsRequest_builder) Build

type GetPlanetsResponse

type GetPlanetsResponse struct {
	Planets []*Planet `protobuf:"bytes,1,rep,name=planets,proto3" json:"planets,omitempty"`
	// contains filtered or unexported fields
}

func (*GetPlanetsResponse) GetPlanets

func (x *GetPlanetsResponse) GetPlanets() []*Planet

func (*GetPlanetsResponse) ProtoMessage

func (*GetPlanetsResponse) ProtoMessage()

func (*GetPlanetsResponse) ProtoReflect

func (x *GetPlanetsResponse) ProtoReflect() protoreflect.Message

func (*GetPlanetsResponse) Reset

func (x *GetPlanetsResponse) Reset()

func (*GetPlanetsResponse) SetPlanets

func (x *GetPlanetsResponse) SetPlanets(v []*Planet)

func (*GetPlanetsResponse) String

func (x *GetPlanetsResponse) String() string

type GetPlanetsResponse_builder

type GetPlanetsResponse_builder struct {
	Planets []*Planet
	// contains filtered or unexported fields
}

func (GetPlanetsResponse_builder) Build

type ListPlanetsRequest

type ListPlanetsRequest struct {

	// The maximum number of items to return.
	PageSize uint32 `protobuf:"varint,2,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
	// The next_page_token value returned from a previous List request, if any.
	PageToken string `protobuf:"bytes,3,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
	// contains filtered or unexported fields
}

func (*ListPlanetsRequest) GetPageSize

func (x *ListPlanetsRequest) GetPageSize() uint32

func (*ListPlanetsRequest) GetPageToken

func (x *ListPlanetsRequest) GetPageToken() string

func (*ListPlanetsRequest) ProtoMessage

func (*ListPlanetsRequest) ProtoMessage()

func (*ListPlanetsRequest) ProtoReflect

func (x *ListPlanetsRequest) ProtoReflect() protoreflect.Message

func (*ListPlanetsRequest) Reset

func (x *ListPlanetsRequest) Reset()

func (*ListPlanetsRequest) SetPageSize

func (x *ListPlanetsRequest) SetPageSize(v uint32)

func (*ListPlanetsRequest) SetPageToken

func (x *ListPlanetsRequest) SetPageToken(v string)

func (*ListPlanetsRequest) String

func (x *ListPlanetsRequest) String() string

type ListPlanetsRequest_builder

type ListPlanetsRequest_builder struct {

	// The maximum number of items to return.
	PageSize uint32
	// The next_page_token value returned from a previous List request, if any.
	PageToken string
	// contains filtered or unexported fields
}

func (ListPlanetsRequest_builder) Build

type ListPlanetsResponse

type ListPlanetsResponse struct {

	// Planets that satisfy the request criteria.
	// Max number of items is limited by page_size in the request.
	Planets []*Planet `protobuf:"bytes,1,rep,name=planets,proto3" json:"planets,omitempty"`
	// Token to retrieve the next page of results, or empty if there are no more results in the list.
	NextPageToken string `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
	// contains filtered or unexported fields
}

func (*ListPlanetsResponse) GetNextPageToken

func (x *ListPlanetsResponse) GetNextPageToken() string

func (*ListPlanetsResponse) GetPlanets

func (x *ListPlanetsResponse) GetPlanets() []*Planet

func (*ListPlanetsResponse) ProtoMessage

func (*ListPlanetsResponse) ProtoMessage()

func (*ListPlanetsResponse) ProtoReflect

func (x *ListPlanetsResponse) ProtoReflect() protoreflect.Message

func (*ListPlanetsResponse) Reset

func (x *ListPlanetsResponse) Reset()

func (*ListPlanetsResponse) SetNextPageToken

func (x *ListPlanetsResponse) SetNextPageToken(v string)

func (*ListPlanetsResponse) SetPlanets

func (x *ListPlanetsResponse) SetPlanets(v []*Planet)

func (*ListPlanetsResponse) String

func (x *ListPlanetsResponse) String() string

type ListPlanetsResponse_builder

type ListPlanetsResponse_builder struct {

	// Planets that satisfy the request criteria.
	// Max number of items is limited by page_size in the request.
	Planets []*Planet
	// Token to retrieve the next page of results, or empty if there are no more results in the list.
	NextPageToken string
	// contains filtered or unexported fields
}

func (ListPlanetsResponse_builder) Build

type Planet

type Planet struct {
	Id             string                 `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	Climates       []string               `protobuf:"bytes,2,rep,name=climates,proto3" json:"climates,omitempty"`
	Diameter       int32                  `protobuf:"varint,3,opt,name=diameter,proto3" json:"diameter,omitempty"`
	Gravity        string                 `protobuf:"bytes,4,opt,name=gravity,proto3" json:"gravity,omitempty"`
	Name           string                 `protobuf:"bytes,5,opt,name=name,proto3" json:"name,omitempty"`
	OrbitalPeriod  int32                  `protobuf:"varint,6,opt,name=orbital_period,json=orbitalPeriod,proto3" json:"orbital_period,omitempty"`
	Population     float64                `protobuf:"fixed64,7,opt,name=population,proto3" json:"population,omitempty"`
	RotationPeriod int32                  `protobuf:"varint,8,opt,name=rotation_period,json=rotationPeriod,proto3" json:"rotation_period,omitempty"`
	SurfaceWater   float64                `protobuf:"fixed64,9,opt,name=surface_water,json=surfaceWater,proto3" json:"surface_water,omitempty"`
	Terrains       []string               `protobuf:"bytes,10,rep,name=terrains,proto3" json:"terrains,omitempty"`
	ResidentIds    []string               `protobuf:"bytes,11,rep,name=resident_ids,json=residentIds,proto3" json:"resident_ids,omitempty"`
	FilmIds        []string               `protobuf:"bytes,12,rep,name=film_ids,json=filmIds,proto3" json:"film_ids,omitempty"`
	Created        *timestamppb.Timestamp `protobuf:"bytes,13,opt,name=created,proto3" json:"created,omitempty"`
	Edited         *timestamppb.Timestamp `protobuf:"bytes,14,opt,name=edited,proto3" json:"edited,omitempty"`
	// contains filtered or unexported fields
}

func (*Planet) ClearCreated

func (x *Planet) ClearCreated()

func (*Planet) ClearEdited

func (x *Planet) ClearEdited()

func (*Planet) GetClimates

func (x *Planet) GetClimates() []string

func (*Planet) GetCreated

func (x *Planet) GetCreated() *timestamppb.Timestamp

func (*Planet) GetDiameter

func (x *Planet) GetDiameter() int32

func (*Planet) GetEdited

func (x *Planet) GetEdited() *timestamppb.Timestamp

func (*Planet) GetFilmIds

func (x *Planet) GetFilmIds() []string

func (*Planet) GetGravity

func (x *Planet) GetGravity() string

func (*Planet) GetId

func (x *Planet) GetId() string

func (*Planet) GetName

func (x *Planet) GetName() string

func (*Planet) GetOrbitalPeriod

func (x *Planet) GetOrbitalPeriod() int32

func (*Planet) GetPopulation

func (x *Planet) GetPopulation() float64

func (*Planet) GetResidentIds

func (x *Planet) GetResidentIds() []string

func (*Planet) GetRotationPeriod

func (x *Planet) GetRotationPeriod() int32

func (*Planet) GetSurfaceWater

func (x *Planet) GetSurfaceWater() float64

func (*Planet) GetTerrains

func (x *Planet) GetTerrains() []string

func (*Planet) HasCreated

func (x *Planet) HasCreated() bool

func (*Planet) HasEdited

func (x *Planet) HasEdited() bool

func (*Planet) ProtoMessage

func (*Planet) ProtoMessage()

func (*Planet) ProtoReflect

func (x *Planet) ProtoReflect() protoreflect.Message

func (*Planet) Reset

func (x *Planet) Reset()

func (*Planet) SetClimates

func (x *Planet) SetClimates(v []string)

func (*Planet) SetCreated

func (x *Planet) SetCreated(v *timestamppb.Timestamp)

func (*Planet) SetDiameter

func (x *Planet) SetDiameter(v int32)

func (*Planet) SetEdited

func (x *Planet) SetEdited(v *timestamppb.Timestamp)

func (*Planet) SetFilmIds

func (x *Planet) SetFilmIds(v []string)

func (*Planet) SetGravity

func (x *Planet) SetGravity(v string)

func (*Planet) SetId

func (x *Planet) SetId(v string)

func (*Planet) SetName

func (x *Planet) SetName(v string)

func (*Planet) SetOrbitalPeriod

func (x *Planet) SetOrbitalPeriod(v int32)

func (*Planet) SetPopulation

func (x *Planet) SetPopulation(v float64)

func (*Planet) SetResidentIds

func (x *Planet) SetResidentIds(v []string)

func (*Planet) SetRotationPeriod

func (x *Planet) SetRotationPeriod(v int32)

func (*Planet) SetSurfaceWater

func (x *Planet) SetSurfaceWater(v float64)

func (*Planet) SetTerrains

func (x *Planet) SetTerrains(v []string)

func (*Planet) String

func (x *Planet) String() string

type Planet_builder

type Planet_builder struct {
	Id             string
	Climates       []string
	Diameter       int32
	Gravity        string
	Name           string
	OrbitalPeriod  int32
	Population     float64
	RotationPeriod int32
	SurfaceWater   float64
	Terrains       []string
	ResidentIds    []string
	FilmIds        []string
	Created        *timestamppb.Timestamp
	Edited         *timestamppb.Timestamp
	// contains filtered or unexported fields
}

func (Planet_builder) Build

func (b0 Planet_builder) Build() *Planet

Source Files

  • planet.pb.go

Jump to