speciesv1

package
v1.36.12-2024080113053... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 3, 2026 License: Apache-2.0 Imports: 5 Imported by: 2

Documentation

Index

Constants

This section is empty.

Variables

var File_buf_knit_demo_swapi_species_v1_species_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type GetSpeciesRequest

type GetSpeciesRequest struct {
	Ids []string `protobuf:"bytes,1,rep,name=ids,proto3" json:"ids,omitempty"`
	// contains filtered or unexported fields
}

func (*GetSpeciesRequest) GetIds

func (x *GetSpeciesRequest) GetIds() []string

func (*GetSpeciesRequest) ProtoMessage

func (*GetSpeciesRequest) ProtoMessage()

func (*GetSpeciesRequest) ProtoReflect

func (x *GetSpeciesRequest) ProtoReflect() protoreflect.Message

func (*GetSpeciesRequest) Reset

func (x *GetSpeciesRequest) Reset()

func (*GetSpeciesRequest) SetIds

func (x *GetSpeciesRequest) SetIds(v []string)

func (*GetSpeciesRequest) String

func (x *GetSpeciesRequest) String() string

type GetSpeciesRequest_builder

type GetSpeciesRequest_builder struct {
	Ids []string
	// contains filtered or unexported fields
}

func (GetSpeciesRequest_builder) Build

type GetSpeciesResponse

type GetSpeciesResponse struct {
	Species []*Species `protobuf:"bytes,1,rep,name=species,proto3" json:"species,omitempty"`
	// contains filtered or unexported fields
}

func (*GetSpeciesResponse) GetSpecies

func (x *GetSpeciesResponse) GetSpecies() []*Species

func (*GetSpeciesResponse) ProtoMessage

func (*GetSpeciesResponse) ProtoMessage()

func (*GetSpeciesResponse) ProtoReflect

func (x *GetSpeciesResponse) ProtoReflect() protoreflect.Message

func (*GetSpeciesResponse) Reset

func (x *GetSpeciesResponse) Reset()

func (*GetSpeciesResponse) SetSpecies

func (x *GetSpeciesResponse) SetSpecies(v []*Species)

func (*GetSpeciesResponse) String

func (x *GetSpeciesResponse) String() string

type GetSpeciesResponse_builder

type GetSpeciesResponse_builder struct {
	Species []*Species
	// contains filtered or unexported fields
}

func (GetSpeciesResponse_builder) Build

type ListSpeciesRequest

type ListSpeciesRequest struct {

	// The maximum number of items to return.
	PageSize uint32 `protobuf:"varint,2,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
	// The next_page_token value returned from a previous List request, if any.
	PageToken string `protobuf:"bytes,3,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
	// contains filtered or unexported fields
}

func (*ListSpeciesRequest) GetPageSize

func (x *ListSpeciesRequest) GetPageSize() uint32

func (*ListSpeciesRequest) GetPageToken

func (x *ListSpeciesRequest) GetPageToken() string

func (*ListSpeciesRequest) ProtoMessage

func (*ListSpeciesRequest) ProtoMessage()

func (*ListSpeciesRequest) ProtoReflect

func (x *ListSpeciesRequest) ProtoReflect() protoreflect.Message

func (*ListSpeciesRequest) Reset

func (x *ListSpeciesRequest) Reset()

func (*ListSpeciesRequest) SetPageSize

func (x *ListSpeciesRequest) SetPageSize(v uint32)

func (*ListSpeciesRequest) SetPageToken

func (x *ListSpeciesRequest) SetPageToken(v string)

func (*ListSpeciesRequest) String

func (x *ListSpeciesRequest) String() string

type ListSpeciesRequest_builder

type ListSpeciesRequest_builder struct {

	// The maximum number of items to return.
	PageSize uint32
	// The next_page_token value returned from a previous List request, if any.
	PageToken string
	// contains filtered or unexported fields
}

func (ListSpeciesRequest_builder) Build

type ListSpeciesResponse

type ListSpeciesResponse struct {

	// Species that satisfy the request criteria.
	// Max number of items is limited by page_size in the request.
	Species []*Species `protobuf:"bytes,1,rep,name=species,proto3" json:"species,omitempty"`
	// Token to retrieve the next page of results, or empty if there are no more results in the list.
	NextPageToken string `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
	// contains filtered or unexported fields
}

func (*ListSpeciesResponse) GetNextPageToken

func (x *ListSpeciesResponse) GetNextPageToken() string

func (*ListSpeciesResponse) GetSpecies

func (x *ListSpeciesResponse) GetSpecies() []*Species

func (*ListSpeciesResponse) ProtoMessage

func (*ListSpeciesResponse) ProtoMessage()

func (*ListSpeciesResponse) ProtoReflect

func (x *ListSpeciesResponse) ProtoReflect() protoreflect.Message

func (*ListSpeciesResponse) Reset

func (x *ListSpeciesResponse) Reset()

func (*ListSpeciesResponse) SetNextPageToken

func (x *ListSpeciesResponse) SetNextPageToken(v string)

func (*ListSpeciesResponse) SetSpecies

func (x *ListSpeciesResponse) SetSpecies(v []*Species)

func (*ListSpeciesResponse) String

func (x *ListSpeciesResponse) String() string

type ListSpeciesResponse_builder

type ListSpeciesResponse_builder struct {

	// Species that satisfy the request criteria.
	// Max number of items is limited by page_size in the request.
	Species []*Species
	// Token to retrieve the next page of results, or empty if there are no more results in the list.
	NextPageToken string
	// contains filtered or unexported fields
}

func (ListSpeciesResponse_builder) Build

type Species

type Species struct {
	Id              string                 `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	AverageHeight   float64                `protobuf:"fixed64,2,opt,name=average_height,json=averageHeight,proto3" json:"average_height,omitempty"`
	AverageLifespan int64                  `protobuf:"varint,3,opt,name=average_lifespan,json=averageLifespan,proto3" json:"average_lifespan,omitempty"`
	Classification  string                 `protobuf:"bytes,4,opt,name=classification,proto3" json:"classification,omitempty"`
	Designation     string                 `protobuf:"bytes,5,opt,name=designation,proto3" json:"designation,omitempty"`
	EyeColors       []string               `protobuf:"bytes,6,rep,name=eye_colors,json=eyeColors,proto3" json:"eye_colors,omitempty"`
	HairColors      []string               `protobuf:"bytes,7,rep,name=hair_colors,json=hairColors,proto3" json:"hair_colors,omitempty"`
	Language        string                 `protobuf:"bytes,8,opt,name=language,proto3" json:"language,omitempty"`
	Name            string                 `protobuf:"bytes,9,opt,name=name,proto3" json:"name,omitempty"`
	SkinColors      []string               `protobuf:"bytes,10,rep,name=skin_colors,json=skinColors,proto3" json:"skin_colors,omitempty"`
	HomeworldId     string                 `protobuf:"bytes,11,opt,name=homeworld_id,json=homeworldId,proto3" json:"homeworld_id,omitempty"`
	PeopleIds       []string               `protobuf:"bytes,12,rep,name=people_ids,json=peopleIds,proto3" json:"people_ids,omitempty"`
	FilmIds         []string               `protobuf:"bytes,13,rep,name=film_ids,json=filmIds,proto3" json:"film_ids,omitempty"`
	Created         *timestamppb.Timestamp `protobuf:"bytes,14,opt,name=created,proto3" json:"created,omitempty"`
	Edited          *timestamppb.Timestamp `protobuf:"bytes,15,opt,name=edited,proto3" json:"edited,omitempty"`
	// contains filtered or unexported fields
}

func (*Species) ClearCreated

func (x *Species) ClearCreated()

func (*Species) ClearEdited

func (x *Species) ClearEdited()

func (*Species) GetAverageHeight

func (x *Species) GetAverageHeight() float64

func (*Species) GetAverageLifespan

func (x *Species) GetAverageLifespan() int64

func (*Species) GetClassification

func (x *Species) GetClassification() string

func (*Species) GetCreated

func (x *Species) GetCreated() *timestamppb.Timestamp

func (*Species) GetDesignation

func (x *Species) GetDesignation() string

func (*Species) GetEdited

func (x *Species) GetEdited() *timestamppb.Timestamp

func (*Species) GetEyeColors

func (x *Species) GetEyeColors() []string

func (*Species) GetFilmIds

func (x *Species) GetFilmIds() []string

func (*Species) GetHairColors

func (x *Species) GetHairColors() []string

func (*Species) GetHomeworldId

func (x *Species) GetHomeworldId() string

func (*Species) GetId

func (x *Species) GetId() string

func (*Species) GetLanguage

func (x *Species) GetLanguage() string

func (*Species) GetName

func (x *Species) GetName() string

func (*Species) GetPeopleIds

func (x *Species) GetPeopleIds() []string

func (*Species) GetSkinColors

func (x *Species) GetSkinColors() []string

func (*Species) HasCreated

func (x *Species) HasCreated() bool

func (*Species) HasEdited

func (x *Species) HasEdited() bool

func (*Species) ProtoMessage

func (*Species) ProtoMessage()

func (*Species) ProtoReflect

func (x *Species) ProtoReflect() protoreflect.Message

func (*Species) Reset

func (x *Species) Reset()

func (*Species) SetAverageHeight

func (x *Species) SetAverageHeight(v float64)

func (*Species) SetAverageLifespan

func (x *Species) SetAverageLifespan(v int64)

func (*Species) SetClassification

func (x *Species) SetClassification(v string)

func (*Species) SetCreated

func (x *Species) SetCreated(v *timestamppb.Timestamp)

func (*Species) SetDesignation

func (x *Species) SetDesignation(v string)

func (*Species) SetEdited

func (x *Species) SetEdited(v *timestamppb.Timestamp)

func (*Species) SetEyeColors

func (x *Species) SetEyeColors(v []string)

func (*Species) SetFilmIds

func (x *Species) SetFilmIds(v []string)

func (*Species) SetHairColors

func (x *Species) SetHairColors(v []string)

func (*Species) SetHomeworldId

func (x *Species) SetHomeworldId(v string)

func (*Species) SetId

func (x *Species) SetId(v string)

func (*Species) SetLanguage

func (x *Species) SetLanguage(v string)

func (*Species) SetName

func (x *Species) SetName(v string)

func (*Species) SetPeopleIds

func (x *Species) SetPeopleIds(v []string)

func (*Species) SetSkinColors

func (x *Species) SetSkinColors(v []string)

func (*Species) String

func (x *Species) String() string

type Species_builder

type Species_builder struct {
	Id              string
	AverageHeight   float64
	AverageLifespan int64
	Classification  string
	Designation     string
	EyeColors       []string
	HairColors      []string
	Language        string
	Name            string
	SkinColors      []string
	HomeworldId     string
	PeopleIds       []string
	FilmIds         []string
	Created         *timestamppb.Timestamp
	Edited          *timestamppb.Timestamp
	// contains filtered or unexported fields
}

func (Species_builder) Build

func (b0 Species_builder) Build() *Species

Source Files

  • species.pb.go

Jump to