reflectv1beta1grpc

package
v1.6.1-20240117202343-... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	FileDescriptorSetService_GetFileDescriptorSet_FullMethodName = "/buf.reflect.v1beta1.FileDescriptorSetService/GetFileDescriptorSet"
)

Variables

var FileDescriptorSetService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "buf.reflect.v1beta1.FileDescriptorSetService",
	HandlerType: (*FileDescriptorSetServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetFileDescriptorSet",
			Handler:    _FileDescriptorSetService_GetFileDescriptorSet_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "buf/reflect/v1beta1/file_descriptor_set.proto",
}

FileDescriptorSetService_ServiceDesc is the grpc.ServiceDesc for FileDescriptorSetService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterFileDescriptorSetServiceServer

func RegisterFileDescriptorSetServiceServer(s grpc.ServiceRegistrar, srv FileDescriptorSetServiceServer)

Types

type FileDescriptorSetServiceClient

type FileDescriptorSetServiceClient interface {
	// GetFileDescriptorSet returns a set of file descriptors that can be used to build
	// dynamic representations of a schema and/or service interfaces. This can also be
	// used for server reflection.
	GetFileDescriptorSet(ctx context.Context, in *v1beta1.GetFileDescriptorSetRequest, opts ...grpc.CallOption) (*v1beta1.GetFileDescriptorSetResponse, error)
}

FileDescriptorSetServiceClient is the client API for FileDescriptorSetService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

FileDescriptorSetService is implemented by a schema registry. It allows clients to download Protobuf schemas. The schema is returned in the form of a FileDescriptorSet, which is also the same form produced by the `protoc` reference compiler (and is compatible with the format produced by `buf`).

Protobuf runtimes that support descriptors and dynamic messages provide APIs for taking these FileDescriptorSet proto messages and turning those into a usable dynamic schema, allowing clients to interpret and manipulate messages of arbitrary types, including interpreting the Protobuf binary format.

func NewFileDescriptorSetServiceClient

func NewFileDescriptorSetServiceClient(cc grpc.ClientConnInterface) FileDescriptorSetServiceClient

type FileDescriptorSetServiceServer

type FileDescriptorSetServiceServer interface {
	// GetFileDescriptorSet returns a set of file descriptors that can be used to build
	// dynamic representations of a schema and/or service interfaces. This can also be
	// used for server reflection.
	GetFileDescriptorSet(context.Context, *v1beta1.GetFileDescriptorSetRequest) (*v1beta1.GetFileDescriptorSetResponse, error)
}

FileDescriptorSetServiceServer is the server API for FileDescriptorSetService service. All implementations should embed UnimplementedFileDescriptorSetServiceServer for forward compatibility.

FileDescriptorSetService is implemented by a schema registry. It allows clients to download Protobuf schemas. The schema is returned in the form of a FileDescriptorSet, which is also the same form produced by the `protoc` reference compiler (and is compatible with the format produced by `buf`).

Protobuf runtimes that support descriptors and dynamic messages provide APIs for taking these FileDescriptorSet proto messages and turning those into a usable dynamic schema, allowing clients to interpret and manipulate messages of arbitrary types, including interpreting the Protobuf binary format.

type UnimplementedFileDescriptorSetServiceServer

type UnimplementedFileDescriptorSetServiceServer struct{}

UnimplementedFileDescriptorSetServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedFileDescriptorSetServiceServer) GetFileDescriptorSet

type UnsafeFileDescriptorSetServiceServer

type UnsafeFileDescriptorSetServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeFileDescriptorSetServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to FileDescriptorSetServiceServer will result in compilation errors.

Source Files

  • file_descriptor_set_grpc.pb.go

Jump to