Documentation
¶
Index ¶
- Variables
- type GetFileDescriptorSetRequest
- func (x *GetFileDescriptorSetRequest) GetModule() string
- func (x *GetFileDescriptorSetRequest) GetSymbols() []string
- func (x *GetFileDescriptorSetRequest) GetVersion() string
- func (*GetFileDescriptorSetRequest) ProtoMessage()
- func (x *GetFileDescriptorSetRequest) ProtoReflect() protoreflect.Message
- func (x *GetFileDescriptorSetRequest) Reset()
- func (x *GetFileDescriptorSetRequest) SetModule(v string)
- func (x *GetFileDescriptorSetRequest) SetSymbols(v []string)
- func (x *GetFileDescriptorSetRequest) SetVersion(v string)
- func (x *GetFileDescriptorSetRequest) String() string
- type GetFileDescriptorSetRequest_builder
- type GetFileDescriptorSetResponse
- func (x *GetFileDescriptorSetResponse) ClearFileDescriptorSet()
- func (x *GetFileDescriptorSetResponse) GetFileDescriptorSet() *descriptorpb.FileDescriptorSet
- func (x *GetFileDescriptorSetResponse) GetVersion() string
- func (x *GetFileDescriptorSetResponse) HasFileDescriptorSet() bool
- func (*GetFileDescriptorSetResponse) ProtoMessage()
- func (x *GetFileDescriptorSetResponse) ProtoReflect() protoreflect.Message
- func (x *GetFileDescriptorSetResponse) Reset()
- func (x *GetFileDescriptorSetResponse) SetFileDescriptorSet(v *descriptorpb.FileDescriptorSet)
- func (x *GetFileDescriptorSetResponse) SetVersion(v string)
- func (x *GetFileDescriptorSetResponse) String() string
- type GetFileDescriptorSetResponse_builder
Constants ¶
This section is empty.
Variables ¶
var File_buf_reflect_v1beta1_file_descriptor_set_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type GetFileDescriptorSetRequest ¶
type GetFileDescriptorSetRequest struct {
// The name of the module that contains the schema of interest.
//
// Some servers may host multiple modules and thus require this field. Others may host a
// single module and not support this field. The format of the module name depends on the
// server implementation.
//
// For Buf Schema Registries, the module name is required. An "Invalid Argument" error
// will occur if it is missing. Buf Schema Registries require the module name to be in
// the following format (note that the domain name of the registry must be included):
//
// buf.build/acme/weather
//
// If the given module is not known to the server, a "Not Found" error is returned. If
// a module name is given but not supported by this server or if the module name is in
// an incorrect format, an "Invalid Argument" error is returned.
Module string `protobuf:"bytes,1,opt,name=module,proto3" json:"module,omitempty"`
// The version of the module to use.
//
// Some servers may not support multiple versions and thus not support this field. If
// the field is supported by the server but not provided by the client, the server will
// respond with the latest version of the requested module and indicate the version in
// the response. The format of the module version depends on the server implementation.
//
// For Buf Schema Registries, this field can be a commit. But it can also be a tag, a
// draft name, or "main" (which is the same as omitting it, since it will also resolve
// to the latest version).
//
// If specified but the requested module has no such version, a "Not Found" error is
// returned.
Version string `protobuf:"bytes,2,opt,name=version,proto3" json:"version,omitempty"`
// Zero or more symbol names. The names may refer to packages, messages, enums,
// services, methods, or extensions. All names must be fully-qualified but should
// NOT start with a period. If any name is invalid, the request will fail with an
// "Invalid Argument" error. If any name is unresolvable/not present in the
// requested module, the request will fail with a "Failed Precondition" error.
//
// If no names are provided, the full schema for the module is returned.
// Otherwise, the resulting schema contains only the named elements and all of
// their dependencies. This is enough information for the caller to construct
// a dynamic message for any requested message types or to dynamically invoke
// an RPC for any requested methods or services. If a package is named, that is
// equivalent to specifying the names of all messages, enums, extensions, and
// services defined in that package.
Symbols []string `protobuf:"bytes,3,rep,name=symbols,proto3" json:"symbols,omitempty"`
// contains filtered or unexported fields
}
func (*GetFileDescriptorSetRequest) GetModule ¶
func (x *GetFileDescriptorSetRequest) GetModule() string
func (*GetFileDescriptorSetRequest) GetSymbols ¶
func (x *GetFileDescriptorSetRequest) GetSymbols() []string
func (*GetFileDescriptorSetRequest) GetVersion ¶
func (x *GetFileDescriptorSetRequest) GetVersion() string
func (*GetFileDescriptorSetRequest) ProtoMessage ¶
func (*GetFileDescriptorSetRequest) ProtoMessage()
func (*GetFileDescriptorSetRequest) ProtoReflect ¶
func (x *GetFileDescriptorSetRequest) ProtoReflect() protoreflect.Message
func (*GetFileDescriptorSetRequest) Reset ¶
func (x *GetFileDescriptorSetRequest) Reset()
func (*GetFileDescriptorSetRequest) SetModule ¶
func (x *GetFileDescriptorSetRequest) SetModule(v string)
func (*GetFileDescriptorSetRequest) SetSymbols ¶
func (x *GetFileDescriptorSetRequest) SetSymbols(v []string)
func (*GetFileDescriptorSetRequest) SetVersion ¶
func (x *GetFileDescriptorSetRequest) SetVersion(v string)
func (*GetFileDescriptorSetRequest) String ¶
func (x *GetFileDescriptorSetRequest) String() string
type GetFileDescriptorSetRequest_builder ¶
type GetFileDescriptorSetRequest_builder struct {
// The name of the module that contains the schema of interest.
//
// Some servers may host multiple modules and thus require this field. Others may host a
// single module and not support this field. The format of the module name depends on the
// server implementation.
//
// For Buf Schema Registries, the module name is required. An "Invalid Argument" error
// will occur if it is missing. Buf Schema Registries require the module name to be in
// the following format (note that the domain name of the registry must be included):
//
// buf.build/acme/weather
//
// If the given module is not known to the server, a "Not Found" error is returned. If
// a module name is given but not supported by this server or if the module name is in
// an incorrect format, an "Invalid Argument" error is returned.
Module string
// The version of the module to use.
//
// Some servers may not support multiple versions and thus not support this field. If
// the field is supported by the server but not provided by the client, the server will
// respond with the latest version of the requested module and indicate the version in
// the response. The format of the module version depends on the server implementation.
//
// For Buf Schema Registries, this field can be a commit. But it can also be a tag, a
// draft name, or "main" (which is the same as omitting it, since it will also resolve
// to the latest version).
//
// If specified but the requested module has no such version, a "Not Found" error is
// returned.
Version string
// Zero or more symbol names. The names may refer to packages, messages, enums,
// services, methods, or extensions. All names must be fully-qualified but should
// NOT start with a period. If any name is invalid, the request will fail with an
// "Invalid Argument" error. If any name is unresolvable/not present in the
// requested module, the request will fail with a "Failed Precondition" error.
//
// If no names are provided, the full schema for the module is returned.
// Otherwise, the resulting schema contains only the named elements and all of
// their dependencies. This is enough information for the caller to construct
// a dynamic message for any requested message types or to dynamically invoke
// an RPC for any requested methods or services. If a package is named, that is
// equivalent to specifying the names of all messages, enums, extensions, and
// services defined in that package.
Symbols []string
// contains filtered or unexported fields
}
func (GetFileDescriptorSetRequest_builder) Build ¶
func (b0 GetFileDescriptorSetRequest_builder) Build() *GetFileDescriptorSetRequest
type GetFileDescriptorSetResponse ¶
type GetFileDescriptorSetResponse struct {
// The schema, which is a set of file descriptors that include the requested symbols
// and their dependencies.
//
// The returned file descriptors will be topologically sorted.
FileDescriptorSet *descriptorpb.FileDescriptorSet `protobuf:"bytes,1,opt,name=file_descriptor_set,json=fileDescriptorSet,proto3" json:"file_descriptor_set,omitempty"`
// The version of the returned schema. May not be set, such as if the server does not
// support multiple versions of schemas. May be different from the requested version,
// such as if the requested version was a name or tag that is resolved to another form.
//
// For Buf Schema Registries, if the requested version is a tag, draft name, or "main",
// the returned version will be the corresponding commit.
Version string `protobuf:"bytes,2,opt,name=version,proto3" json:"version,omitempty"`
// contains filtered or unexported fields
}
func (*GetFileDescriptorSetResponse) ClearFileDescriptorSet ¶
func (x *GetFileDescriptorSetResponse) ClearFileDescriptorSet()
func (*GetFileDescriptorSetResponse) GetFileDescriptorSet ¶
func (x *GetFileDescriptorSetResponse) GetFileDescriptorSet() *descriptorpb.FileDescriptorSet
func (*GetFileDescriptorSetResponse) GetVersion ¶
func (x *GetFileDescriptorSetResponse) GetVersion() string
func (*GetFileDescriptorSetResponse) HasFileDescriptorSet ¶
func (x *GetFileDescriptorSetResponse) HasFileDescriptorSet() bool
func (*GetFileDescriptorSetResponse) ProtoMessage ¶
func (*GetFileDescriptorSetResponse) ProtoMessage()
func (*GetFileDescriptorSetResponse) ProtoReflect ¶
func (x *GetFileDescriptorSetResponse) ProtoReflect() protoreflect.Message
func (*GetFileDescriptorSetResponse) Reset ¶
func (x *GetFileDescriptorSetResponse) Reset()
func (*GetFileDescriptorSetResponse) SetFileDescriptorSet ¶
func (x *GetFileDescriptorSetResponse) SetFileDescriptorSet(v *descriptorpb.FileDescriptorSet)
func (*GetFileDescriptorSetResponse) SetVersion ¶
func (x *GetFileDescriptorSetResponse) SetVersion(v string)
func (*GetFileDescriptorSetResponse) String ¶
func (x *GetFileDescriptorSetResponse) String() string
type GetFileDescriptorSetResponse_builder ¶
type GetFileDescriptorSetResponse_builder struct {
// The schema, which is a set of file descriptors that include the requested symbols
// and their dependencies.
//
// The returned file descriptors will be topologically sorted.
FileDescriptorSet *descriptorpb.FileDescriptorSet
// The version of the returned schema. May not be set, such as if the server does not
// support multiple versions of schemas. May be different from the requested version,
// such as if the requested version was a name or tag that is resolved to another form.
//
// For Buf Schema Registries, if the requested version is a tag, draft name, or "main",
// the returned version will be the corresponding commit.
Version string
// contains filtered or unexported fields
}
func (GetFileDescriptorSetResponse_builder) Build ¶
func (b0 GetFileDescriptorSetResponse_builder) Build() *GetFileDescriptorSetResponse
Source Files
¶
- file_descriptor_set.pb.go
Click to show internal directories.
Click to hide internal directories.