Documentation
¶
Index ¶
- Constants
- func NewCommitServiceHandler(svc CommitServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
- func NewDownloadServiceHandler(svc DownloadServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
- func NewLabelServiceHandler(svc LabelServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
- func NewPolicyServiceHandler(svc PolicyServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
- func NewResourceServiceHandler(svc ResourceServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
- func NewUploadServiceHandler(svc UploadServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
- type CommitServiceClient
- type CommitServiceHandler
- type DownloadServiceClient
- type DownloadServiceHandler
- type LabelServiceClient
- type LabelServiceHandler
- type PolicyServiceClient
- type PolicyServiceHandler
- type ResourceServiceClient
- type ResourceServiceHandler
- type UnimplementedCommitServiceHandler
- func (UnimplementedCommitServiceHandler) GetCommits(context.Context, *connect.Request[v1beta1.GetCommitsRequest]) (*connect.Response[v1beta1.GetCommitsResponse], error)
- func (UnimplementedCommitServiceHandler) ListCommits(context.Context, *connect.Request[v1beta1.ListCommitsRequest]) (*connect.Response[v1beta1.ListCommitsResponse], error)
- type UnimplementedDownloadServiceHandler
- type UnimplementedLabelServiceHandler
- func (UnimplementedLabelServiceHandler) ArchiveLabels(context.Context, *connect.Request[v1beta1.ArchiveLabelsRequest]) (*connect.Response[v1beta1.ArchiveLabelsResponse], error)
- func (UnimplementedLabelServiceHandler) CreateOrUpdateLabels(context.Context, *connect.Request[v1beta1.CreateOrUpdateLabelsRequest]) (*connect.Response[v1beta1.CreateOrUpdateLabelsResponse], error)
- func (UnimplementedLabelServiceHandler) GetLabels(context.Context, *connect.Request[v1beta1.GetLabelsRequest]) (*connect.Response[v1beta1.GetLabelsResponse], error)
- func (UnimplementedLabelServiceHandler) ListLabelHistory(context.Context, *connect.Request[v1beta1.ListLabelHistoryRequest]) (*connect.Response[v1beta1.ListLabelHistoryResponse], error)
- func (UnimplementedLabelServiceHandler) ListLabels(context.Context, *connect.Request[v1beta1.ListLabelsRequest]) (*connect.Response[v1beta1.ListLabelsResponse], error)
- func (UnimplementedLabelServiceHandler) UnarchiveLabels(context.Context, *connect.Request[v1beta1.UnarchiveLabelsRequest]) (*connect.Response[v1beta1.UnarchiveLabelsResponse], error)
- type UnimplementedPolicyServiceHandler
- func (UnimplementedPolicyServiceHandler) CreatePolicies(context.Context, *connect.Request[v1beta1.CreatePoliciesRequest]) (*connect.Response[v1beta1.CreatePoliciesResponse], error)
- func (UnimplementedPolicyServiceHandler) DeletePolicies(context.Context, *connect.Request[v1beta1.DeletePoliciesRequest]) (*connect.Response[v1beta1.DeletePoliciesResponse], error)
- func (UnimplementedPolicyServiceHandler) GetPolicies(context.Context, *connect.Request[v1beta1.GetPoliciesRequest]) (*connect.Response[v1beta1.GetPoliciesResponse], error)
- func (UnimplementedPolicyServiceHandler) ListPolicies(context.Context, *connect.Request[v1beta1.ListPoliciesRequest]) (*connect.Response[v1beta1.ListPoliciesResponse], error)
- func (UnimplementedPolicyServiceHandler) UpdatePolicies(context.Context, *connect.Request[v1beta1.UpdatePoliciesRequest]) (*connect.Response[v1beta1.UpdatePoliciesResponse], error)
- type UnimplementedResourceServiceHandler
- type UnimplementedUploadServiceHandler
- type UploadServiceClient
- type UploadServiceHandler
Constants ¶
const ( // CommitServiceGetCommitsProcedure is the fully-qualified name of the CommitService's GetCommits // RPC. CommitServiceGetCommitsProcedure = "/buf.registry.policy.v1beta1.CommitService/GetCommits" // CommitServiceListCommitsProcedure is the fully-qualified name of the CommitService's ListCommits // RPC. CommitServiceListCommitsProcedure = "/buf.registry.policy.v1beta1.CommitService/ListCommits" )
These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.
Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.
const ( // LabelServiceGetLabelsProcedure is the fully-qualified name of the LabelService's GetLabels RPC. LabelServiceGetLabelsProcedure = "/buf.registry.policy.v1beta1.LabelService/GetLabels" // LabelServiceListLabelsProcedure is the fully-qualified name of the LabelService's ListLabels RPC. LabelServiceListLabelsProcedure = "/buf.registry.policy.v1beta1.LabelService/ListLabels" // LabelServiceListLabelHistoryProcedure is the fully-qualified name of the LabelService's // ListLabelHistory RPC. LabelServiceListLabelHistoryProcedure = "/buf.registry.policy.v1beta1.LabelService/ListLabelHistory" // LabelServiceCreateOrUpdateLabelsProcedure is the fully-qualified name of the LabelService's // CreateOrUpdateLabels RPC. LabelServiceCreateOrUpdateLabelsProcedure = "/buf.registry.policy.v1beta1.LabelService/CreateOrUpdateLabels" // LabelServiceArchiveLabelsProcedure is the fully-qualified name of the LabelService's // ArchiveLabels RPC. LabelServiceArchiveLabelsProcedure = "/buf.registry.policy.v1beta1.LabelService/ArchiveLabels" // LabelServiceUnarchiveLabelsProcedure is the fully-qualified name of the LabelService's // UnarchiveLabels RPC. LabelServiceUnarchiveLabelsProcedure = "/buf.registry.policy.v1beta1.LabelService/UnarchiveLabels" )
These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.
Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.
const ( // PolicyServiceGetPoliciesProcedure is the fully-qualified name of the PolicyService's GetPolicies // RPC. PolicyServiceGetPoliciesProcedure = "/buf.registry.policy.v1beta1.PolicyService/GetPolicies" // PolicyServiceListPoliciesProcedure is the fully-qualified name of the PolicyService's // ListPolicies RPC. PolicyServiceListPoliciesProcedure = "/buf.registry.policy.v1beta1.PolicyService/ListPolicies" // PolicyServiceCreatePoliciesProcedure is the fully-qualified name of the PolicyService's // CreatePolicies RPC. PolicyServiceCreatePoliciesProcedure = "/buf.registry.policy.v1beta1.PolicyService/CreatePolicies" // PolicyServiceUpdatePoliciesProcedure is the fully-qualified name of the PolicyService's // UpdatePolicies RPC. PolicyServiceUpdatePoliciesProcedure = "/buf.registry.policy.v1beta1.PolicyService/UpdatePolicies" // PolicyServiceDeletePoliciesProcedure is the fully-qualified name of the PolicyService's // DeletePolicies RPC. PolicyServiceDeletePoliciesProcedure = "/buf.registry.policy.v1beta1.PolicyService/DeletePolicies" )
These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.
Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.
const (
// CommitServiceName is the fully-qualified name of the CommitService service.
CommitServiceName = "buf.registry.policy.v1beta1.CommitService"
)
const ( // DownloadServiceDownloadProcedure is the fully-qualified name of the DownloadService's Download // RPC. DownloadServiceDownloadProcedure = "/buf.registry.policy.v1beta1.DownloadService/Download" )
These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.
Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.
const (
// DownloadServiceName is the fully-qualified name of the DownloadService service.
DownloadServiceName = "buf.registry.policy.v1beta1.DownloadService"
)
const (
// LabelServiceName is the fully-qualified name of the LabelService service.
LabelServiceName = "buf.registry.policy.v1beta1.LabelService"
)
const (
// PolicyServiceName is the fully-qualified name of the PolicyService service.
PolicyServiceName = "buf.registry.policy.v1beta1.PolicyService"
)
const ( // ResourceServiceGetResourcesProcedure is the fully-qualified name of the ResourceService's // GetResources RPC. ResourceServiceGetResourcesProcedure = "/buf.registry.policy.v1beta1.ResourceService/GetResources" )
These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.
Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.
const (
// ResourceServiceName is the fully-qualified name of the ResourceService service.
ResourceServiceName = "buf.registry.policy.v1beta1.ResourceService"
)
const (
// UploadServiceName is the fully-qualified name of the UploadService service.
UploadServiceName = "buf.registry.policy.v1beta1.UploadService"
)
const (
// UploadServiceUploadProcedure is the fully-qualified name of the UploadService's Upload RPC.
UploadServiceUploadProcedure = "/buf.registry.policy.v1beta1.UploadService/Upload"
)
These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.
Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.
Variables ¶
This section is empty.
Functions ¶
func NewCommitServiceHandler ¶
func NewCommitServiceHandler(svc CommitServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
NewCommitServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.
By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.
func NewDownloadServiceHandler ¶
func NewDownloadServiceHandler(svc DownloadServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
NewDownloadServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.
By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.
func NewLabelServiceHandler ¶
func NewLabelServiceHandler(svc LabelServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
NewLabelServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.
By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.
func NewPolicyServiceHandler ¶
func NewPolicyServiceHandler(svc PolicyServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
NewPolicyServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.
By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.
func NewResourceServiceHandler ¶
func NewResourceServiceHandler(svc ResourceServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
NewResourceServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.
By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.
func NewUploadServiceHandler ¶
func NewUploadServiceHandler(svc UploadServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
NewUploadServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.
By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.
Types ¶
type CommitServiceClient ¶
type CommitServiceClient interface {
// Get Commits.
GetCommits(context.Context, *connect.Request[v1beta1.GetCommitsRequest]) (*connect.Response[v1beta1.GetCommitsResponse], error)
// List Commits for a given Policy.
ListCommits(context.Context, *connect.Request[v1beta1.ListCommitsRequest]) (*connect.Response[v1beta1.ListCommitsResponse], error)
}
CommitServiceClient is a client for the buf.registry.policy.v1beta1.CommitService service.
func NewCommitServiceClient ¶
func NewCommitServiceClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) CommitServiceClient
NewCommitServiceClient constructs a client for the buf.registry.policy.v1beta1.CommitService service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.
The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).
type CommitServiceHandler ¶
type CommitServiceHandler interface {
// Get Commits.
GetCommits(context.Context, *connect.Request[v1beta1.GetCommitsRequest]) (*connect.Response[v1beta1.GetCommitsResponse], error)
// List Commits for a given Policy.
ListCommits(context.Context, *connect.Request[v1beta1.ListCommitsRequest]) (*connect.Response[v1beta1.ListCommitsResponse], error)
}
CommitServiceHandler is an implementation of the buf.registry.policy.v1beta1.CommitService service.
type DownloadServiceClient ¶
type DownloadServiceClient interface {
// Download contents for given set of Policies.
//
// Contents are a single YAML file.
Download(context.Context, *connect.Request[v1beta1.DownloadRequest]) (*connect.Response[v1beta1.DownloadResponse], error)
}
DownloadServiceClient is a client for the buf.registry.policy.v1beta1.DownloadService service.
func NewDownloadServiceClient ¶
func NewDownloadServiceClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) DownloadServiceClient
NewDownloadServiceClient constructs a client for the buf.registry.policy.v1beta1.DownloadService service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.
The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).
type DownloadServiceHandler ¶
type DownloadServiceHandler interface {
// Download contents for given set of Policies.
//
// Contents are a single YAML file.
Download(context.Context, *connect.Request[v1beta1.DownloadRequest]) (*connect.Response[v1beta1.DownloadResponse], error)
}
DownloadServiceHandler is an implementation of the buf.registry.policy.v1beta1.DownloadService service.
type LabelServiceClient ¶
type LabelServiceClient interface {
// Get Labels by id or name.
GetLabels(context.Context, *connect.Request[v1beta1.GetLabelsRequest]) (*connect.Response[v1beta1.GetLabelsResponse], error)
// List Labels for a given Policy, Commit or Label.
ListLabels(context.Context, *connect.Request[v1beta1.ListLabelsRequest]) (*connect.Response[v1beta1.ListLabelsResponse], error)
// List the history of a Label.
ListLabelHistory(context.Context, *connect.Request[v1beta1.ListLabelHistoryRequest]) (*connect.Response[v1beta1.ListLabelHistoryResponse], error)
// Create or update Labels on a Policy.
//
// If the Label does not exist, it will be created. If the Label was archived, it will be
// unarchived. If the Label already existed, the Commit in the request has to be newer than the
// Commit that the Label is currently pointing to, otherwise an error is returned.
//
// This operation is atomic. Either all Labels are created/updated or an error is returned.
CreateOrUpdateLabels(context.Context, *connect.Request[v1beta1.CreateOrUpdateLabelsRequest]) (*connect.Response[v1beta1.CreateOrUpdateLabelsResponse], error)
// Archive existing Labels.
//
// This operation is atomic. Either all Labels are archived or an error is returned.
ArchiveLabels(context.Context, *connect.Request[v1beta1.ArchiveLabelsRequest]) (*connect.Response[v1beta1.ArchiveLabelsResponse], error)
// Unarchive existing Labels.
//
// This operation is atomic. Either all Labels are unarchived or an error is returned.
UnarchiveLabels(context.Context, *connect.Request[v1beta1.UnarchiveLabelsRequest]) (*connect.Response[v1beta1.UnarchiveLabelsResponse], error)
}
LabelServiceClient is a client for the buf.registry.policy.v1beta1.LabelService service.
func NewLabelServiceClient ¶
func NewLabelServiceClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) LabelServiceClient
NewLabelServiceClient constructs a client for the buf.registry.policy.v1beta1.LabelService service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.
The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).
type LabelServiceHandler ¶
type LabelServiceHandler interface {
// Get Labels by id or name.
GetLabels(context.Context, *connect.Request[v1beta1.GetLabelsRequest]) (*connect.Response[v1beta1.GetLabelsResponse], error)
// List Labels for a given Policy, Commit or Label.
ListLabels(context.Context, *connect.Request[v1beta1.ListLabelsRequest]) (*connect.Response[v1beta1.ListLabelsResponse], error)
// List the history of a Label.
ListLabelHistory(context.Context, *connect.Request[v1beta1.ListLabelHistoryRequest]) (*connect.Response[v1beta1.ListLabelHistoryResponse], error)
// Create or update Labels on a Policy.
//
// If the Label does not exist, it will be created. If the Label was archived, it will be
// unarchived. If the Label already existed, the Commit in the request has to be newer than the
// Commit that the Label is currently pointing to, otherwise an error is returned.
//
// This operation is atomic. Either all Labels are created/updated or an error is returned.
CreateOrUpdateLabels(context.Context, *connect.Request[v1beta1.CreateOrUpdateLabelsRequest]) (*connect.Response[v1beta1.CreateOrUpdateLabelsResponse], error)
// Archive existing Labels.
//
// This operation is atomic. Either all Labels are archived or an error is returned.
ArchiveLabels(context.Context, *connect.Request[v1beta1.ArchiveLabelsRequest]) (*connect.Response[v1beta1.ArchiveLabelsResponse], error)
// Unarchive existing Labels.
//
// This operation is atomic. Either all Labels are unarchived or an error is returned.
UnarchiveLabels(context.Context, *connect.Request[v1beta1.UnarchiveLabelsRequest]) (*connect.Response[v1beta1.UnarchiveLabelsResponse], error)
}
LabelServiceHandler is an implementation of the buf.registry.policy.v1beta1.LabelService service.
type PolicyServiceClient ¶
type PolicyServiceClient interface {
// Get Policies by id or name.
GetPolicies(context.Context, *connect.Request[v1beta1.GetPoliciesRequest]) (*connect.Response[v1beta1.GetPoliciesResponse], error)
// List Policies, usually for a specific User or Organization.
ListPolicies(context.Context, *connect.Request[v1beta1.ListPoliciesRequest]) (*connect.Response[v1beta1.ListPoliciesResponse], error)
// Create new Policies.
//
// This operation is atomic. Either all Policies are created or an error is returned.
CreatePolicies(context.Context, *connect.Request[v1beta1.CreatePoliciesRequest]) (*connect.Response[v1beta1.CreatePoliciesResponse], error)
// Update exiting Policies.
//
// This operation is atomic. Either all Policies are updated or an error is returned.
UpdatePolicies(context.Context, *connect.Request[v1beta1.UpdatePoliciesRequest]) (*connect.Response[v1beta1.UpdatePoliciesResponse], error)
// Delete existing Policies.
//
// This operation is atomic. Either all Policies are deleted or an error is returned.
DeletePolicies(context.Context, *connect.Request[v1beta1.DeletePoliciesRequest]) (*connect.Response[v1beta1.DeletePoliciesResponse], error)
}
PolicyServiceClient is a client for the buf.registry.policy.v1beta1.PolicyService service.
func NewPolicyServiceClient ¶
func NewPolicyServiceClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) PolicyServiceClient
NewPolicyServiceClient constructs a client for the buf.registry.policy.v1beta1.PolicyService service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.
The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).
type PolicyServiceHandler ¶
type PolicyServiceHandler interface {
// Get Policies by id or name.
GetPolicies(context.Context, *connect.Request[v1beta1.GetPoliciesRequest]) (*connect.Response[v1beta1.GetPoliciesResponse], error)
// List Policies, usually for a specific User or Organization.
ListPolicies(context.Context, *connect.Request[v1beta1.ListPoliciesRequest]) (*connect.Response[v1beta1.ListPoliciesResponse], error)
// Create new Policies.
//
// This operation is atomic. Either all Policies are created or an error is returned.
CreatePolicies(context.Context, *connect.Request[v1beta1.CreatePoliciesRequest]) (*connect.Response[v1beta1.CreatePoliciesResponse], error)
// Update exiting Policies.
//
// This operation is atomic. Either all Policies are updated or an error is returned.
UpdatePolicies(context.Context, *connect.Request[v1beta1.UpdatePoliciesRequest]) (*connect.Response[v1beta1.UpdatePoliciesResponse], error)
// Delete existing Policies.
//
// This operation is atomic. Either all Policies are deleted or an error is returned.
DeletePolicies(context.Context, *connect.Request[v1beta1.DeletePoliciesRequest]) (*connect.Response[v1beta1.DeletePoliciesResponse], error)
}
PolicyServiceHandler is an implementation of the buf.registry.policy.v1beta1.PolicyService service.
type ResourceServiceClient ¶
type ResourceServiceClient interface {
// Get Resources.
GetResources(context.Context, *connect.Request[v1beta1.GetResourcesRequest]) (*connect.Response[v1beta1.GetResourcesResponse], error)
}
ResourceServiceClient is a client for the buf.registry.policy.v1beta1.ResourceService service.
func NewResourceServiceClient ¶
func NewResourceServiceClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) ResourceServiceClient
NewResourceServiceClient constructs a client for the buf.registry.policy.v1beta1.ResourceService service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.
The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).
type ResourceServiceHandler ¶
type ResourceServiceHandler interface {
// Get Resources.
GetResources(context.Context, *connect.Request[v1beta1.GetResourcesRequest]) (*connect.Response[v1beta1.GetResourcesResponse], error)
}
ResourceServiceHandler is an implementation of the buf.registry.policy.v1beta1.ResourceService service.
type UnimplementedCommitServiceHandler ¶
type UnimplementedCommitServiceHandler struct{}
UnimplementedCommitServiceHandler returns CodeUnimplemented from all methods.
func (UnimplementedCommitServiceHandler) GetCommits ¶
func (UnimplementedCommitServiceHandler) GetCommits(context.Context, *connect.Request[v1beta1.GetCommitsRequest]) (*connect.Response[v1beta1.GetCommitsResponse], error)
func (UnimplementedCommitServiceHandler) ListCommits ¶
func (UnimplementedCommitServiceHandler) ListCommits(context.Context, *connect.Request[v1beta1.ListCommitsRequest]) (*connect.Response[v1beta1.ListCommitsResponse], error)
type UnimplementedDownloadServiceHandler ¶
type UnimplementedDownloadServiceHandler struct{}
UnimplementedDownloadServiceHandler returns CodeUnimplemented from all methods.
func (UnimplementedDownloadServiceHandler) Download ¶
func (UnimplementedDownloadServiceHandler) Download(context.Context, *connect.Request[v1beta1.DownloadRequest]) (*connect.Response[v1beta1.DownloadResponse], error)
type UnimplementedLabelServiceHandler ¶
type UnimplementedLabelServiceHandler struct{}
UnimplementedLabelServiceHandler returns CodeUnimplemented from all methods.
func (UnimplementedLabelServiceHandler) ArchiveLabels ¶
func (UnimplementedLabelServiceHandler) ArchiveLabels(context.Context, *connect.Request[v1beta1.ArchiveLabelsRequest]) (*connect.Response[v1beta1.ArchiveLabelsResponse], error)
func (UnimplementedLabelServiceHandler) CreateOrUpdateLabels ¶
func (UnimplementedLabelServiceHandler) CreateOrUpdateLabels(context.Context, *connect.Request[v1beta1.CreateOrUpdateLabelsRequest]) (*connect.Response[v1beta1.CreateOrUpdateLabelsResponse], error)
func (UnimplementedLabelServiceHandler) GetLabels ¶
func (UnimplementedLabelServiceHandler) GetLabels(context.Context, *connect.Request[v1beta1.GetLabelsRequest]) (*connect.Response[v1beta1.GetLabelsResponse], error)
func (UnimplementedLabelServiceHandler) ListLabelHistory ¶
func (UnimplementedLabelServiceHandler) ListLabelHistory(context.Context, *connect.Request[v1beta1.ListLabelHistoryRequest]) (*connect.Response[v1beta1.ListLabelHistoryResponse], error)
func (UnimplementedLabelServiceHandler) ListLabels ¶
func (UnimplementedLabelServiceHandler) ListLabels(context.Context, *connect.Request[v1beta1.ListLabelsRequest]) (*connect.Response[v1beta1.ListLabelsResponse], error)
func (UnimplementedLabelServiceHandler) UnarchiveLabels ¶
func (UnimplementedLabelServiceHandler) UnarchiveLabels(context.Context, *connect.Request[v1beta1.UnarchiveLabelsRequest]) (*connect.Response[v1beta1.UnarchiveLabelsResponse], error)
type UnimplementedPolicyServiceHandler ¶
type UnimplementedPolicyServiceHandler struct{}
UnimplementedPolicyServiceHandler returns CodeUnimplemented from all methods.
func (UnimplementedPolicyServiceHandler) CreatePolicies ¶
func (UnimplementedPolicyServiceHandler) CreatePolicies(context.Context, *connect.Request[v1beta1.CreatePoliciesRequest]) (*connect.Response[v1beta1.CreatePoliciesResponse], error)
func (UnimplementedPolicyServiceHandler) DeletePolicies ¶
func (UnimplementedPolicyServiceHandler) DeletePolicies(context.Context, *connect.Request[v1beta1.DeletePoliciesRequest]) (*connect.Response[v1beta1.DeletePoliciesResponse], error)
func (UnimplementedPolicyServiceHandler) GetPolicies ¶
func (UnimplementedPolicyServiceHandler) GetPolicies(context.Context, *connect.Request[v1beta1.GetPoliciesRequest]) (*connect.Response[v1beta1.GetPoliciesResponse], error)
func (UnimplementedPolicyServiceHandler) ListPolicies ¶
func (UnimplementedPolicyServiceHandler) ListPolicies(context.Context, *connect.Request[v1beta1.ListPoliciesRequest]) (*connect.Response[v1beta1.ListPoliciesResponse], error)
func (UnimplementedPolicyServiceHandler) UpdatePolicies ¶
func (UnimplementedPolicyServiceHandler) UpdatePolicies(context.Context, *connect.Request[v1beta1.UpdatePoliciesRequest]) (*connect.Response[v1beta1.UpdatePoliciesResponse], error)
type UnimplementedResourceServiceHandler ¶
type UnimplementedResourceServiceHandler struct{}
UnimplementedResourceServiceHandler returns CodeUnimplemented from all methods.
func (UnimplementedResourceServiceHandler) GetResources ¶
func (UnimplementedResourceServiceHandler) GetResources(context.Context, *connect.Request[v1beta1.GetResourcesRequest]) (*connect.Response[v1beta1.GetResourcesResponse], error)
type UnimplementedUploadServiceHandler ¶
type UnimplementedUploadServiceHandler struct{}
UnimplementedUploadServiceHandler returns CodeUnimplemented from all methods.
func (UnimplementedUploadServiceHandler) Upload ¶
func (UnimplementedUploadServiceHandler) Upload(context.Context, *connect.Request[v1beta1.UploadRequest]) (*connect.Response[v1beta1.UploadResponse], error)
type UploadServiceClient ¶
type UploadServiceClient interface {
// Upload contents for given set of Policies.
//
// Contents are expected to be a single YAML file.
Upload(context.Context, *connect.Request[v1beta1.UploadRequest]) (*connect.Response[v1beta1.UploadResponse], error)
}
UploadServiceClient is a client for the buf.registry.policy.v1beta1.UploadService service.
func NewUploadServiceClient ¶
func NewUploadServiceClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) UploadServiceClient
NewUploadServiceClient constructs a client for the buf.registry.policy.v1beta1.UploadService service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.
The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).
type UploadServiceHandler ¶
type UploadServiceHandler interface {
// Upload contents for given set of Policies.
//
// Contents are expected to be a single YAML file.
Upload(context.Context, *connect.Request[v1beta1.UploadRequest]) (*connect.Response[v1beta1.UploadResponse], error)
}
UploadServiceHandler is an implementation of the buf.registry.policy.v1beta1.UploadService service.
Source Files
¶
- commit_service.connect.go
- download_service.connect.go
- label_service.connect.go
- policy_service.connect.go
- resource_service.connect.go
- upload_service.connect.go