modulev1grpc

package
v1.6.1-20260126144947-... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	CommitService_GetCommits_FullMethodName  = "/buf.registry.module.v1.CommitService/GetCommits"
	CommitService_ListCommits_FullMethodName = "/buf.registry.module.v1.CommitService/ListCommits"
)
const (
	LabelService_GetLabels_FullMethodName            = "/buf.registry.module.v1.LabelService/GetLabels"
	LabelService_ListLabels_FullMethodName           = "/buf.registry.module.v1.LabelService/ListLabels"
	LabelService_ListLabelHistory_FullMethodName     = "/buf.registry.module.v1.LabelService/ListLabelHistory"
	LabelService_CreateOrUpdateLabels_FullMethodName = "/buf.registry.module.v1.LabelService/CreateOrUpdateLabels"
	LabelService_ArchiveLabels_FullMethodName        = "/buf.registry.module.v1.LabelService/ArchiveLabels"
	LabelService_UnarchiveLabels_FullMethodName      = "/buf.registry.module.v1.LabelService/UnarchiveLabels"
)
const (
	ModuleService_GetModules_FullMethodName    = "/buf.registry.module.v1.ModuleService/GetModules"
	ModuleService_ListModules_FullMethodName   = "/buf.registry.module.v1.ModuleService/ListModules"
	ModuleService_CreateModules_FullMethodName = "/buf.registry.module.v1.ModuleService/CreateModules"
	ModuleService_UpdateModules_FullMethodName = "/buf.registry.module.v1.ModuleService/UpdateModules"
	ModuleService_DeleteModules_FullMethodName = "/buf.registry.module.v1.ModuleService/DeleteModules"
)
const (
	DownloadService_Download_FullMethodName = "/buf.registry.module.v1.DownloadService/Download"
)
const (
	FileDescriptorSetService_GetFileDescriptorSet_FullMethodName = "/buf.registry.module.v1.FileDescriptorSetService/GetFileDescriptorSet"
)
const (
	GraphService_GetGraph_FullMethodName = "/buf.registry.module.v1.GraphService/GetGraph"
)
const (
	ResourceService_GetResources_FullMethodName = "/buf.registry.module.v1.ResourceService/GetResources"
)
const (
	UploadService_Upload_FullMethodName = "/buf.registry.module.v1.UploadService/Upload"
)

Variables

var CommitService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "buf.registry.module.v1.CommitService",
	HandlerType: (*CommitServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetCommits",
			Handler:    _CommitService_GetCommits_Handler,
		},
		{
			MethodName: "ListCommits",
			Handler:    _CommitService_ListCommits_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "buf/registry/module/v1/commit_service.proto",
}

CommitService_ServiceDesc is the grpc.ServiceDesc for CommitService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var DownloadService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "buf.registry.module.v1.DownloadService",
	HandlerType: (*DownloadServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "Download",
			Handler:    _DownloadService_Download_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "buf/registry/module/v1/download_service.proto",
}

DownloadService_ServiceDesc is the grpc.ServiceDesc for DownloadService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var FileDescriptorSetService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "buf.registry.module.v1.FileDescriptorSetService",
	HandlerType: (*FileDescriptorSetServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetFileDescriptorSet",
			Handler:    _FileDescriptorSetService_GetFileDescriptorSet_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "buf/registry/module/v1/file_descriptor_set_service.proto",
}

FileDescriptorSetService_ServiceDesc is the grpc.ServiceDesc for FileDescriptorSetService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var GraphService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "buf.registry.module.v1.GraphService",
	HandlerType: (*GraphServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetGraph",
			Handler:    _GraphService_GetGraph_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "buf/registry/module/v1/graph_service.proto",
}

GraphService_ServiceDesc is the grpc.ServiceDesc for GraphService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var LabelService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "buf.registry.module.v1.LabelService",
	HandlerType: (*LabelServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetLabels",
			Handler:    _LabelService_GetLabels_Handler,
		},
		{
			MethodName: "ListLabels",
			Handler:    _LabelService_ListLabels_Handler,
		},
		{
			MethodName: "ListLabelHistory",
			Handler:    _LabelService_ListLabelHistory_Handler,
		},
		{
			MethodName: "CreateOrUpdateLabels",
			Handler:    _LabelService_CreateOrUpdateLabels_Handler,
		},
		{
			MethodName: "ArchiveLabels",
			Handler:    _LabelService_ArchiveLabels_Handler,
		},
		{
			MethodName: "UnarchiveLabels",
			Handler:    _LabelService_UnarchiveLabels_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "buf/registry/module/v1/label_service.proto",
}

LabelService_ServiceDesc is the grpc.ServiceDesc for LabelService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var ModuleService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "buf.registry.module.v1.ModuleService",
	HandlerType: (*ModuleServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetModules",
			Handler:    _ModuleService_GetModules_Handler,
		},
		{
			MethodName: "ListModules",
			Handler:    _ModuleService_ListModules_Handler,
		},
		{
			MethodName: "CreateModules",
			Handler:    _ModuleService_CreateModules_Handler,
		},
		{
			MethodName: "UpdateModules",
			Handler:    _ModuleService_UpdateModules_Handler,
		},
		{
			MethodName: "DeleteModules",
			Handler:    _ModuleService_DeleteModules_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "buf/registry/module/v1/module_service.proto",
}

ModuleService_ServiceDesc is the grpc.ServiceDesc for ModuleService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var ResourceService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "buf.registry.module.v1.ResourceService",
	HandlerType: (*ResourceServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetResources",
			Handler:    _ResourceService_GetResources_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "buf/registry/module/v1/resource_service.proto",
}

ResourceService_ServiceDesc is the grpc.ServiceDesc for ResourceService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var UploadService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "buf.registry.module.v1.UploadService",
	HandlerType: (*UploadServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "Upload",
			Handler:    _UploadService_Upload_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "buf/registry/module/v1/upload_service.proto",
}

UploadService_ServiceDesc is the grpc.ServiceDesc for UploadService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterCommitServiceServer

func RegisterCommitServiceServer(s grpc.ServiceRegistrar, srv CommitServiceServer)

func RegisterDownloadServiceServer

func RegisterDownloadServiceServer(s grpc.ServiceRegistrar, srv DownloadServiceServer)

func RegisterFileDescriptorSetServiceServer

func RegisterFileDescriptorSetServiceServer(s grpc.ServiceRegistrar, srv FileDescriptorSetServiceServer)

func RegisterGraphServiceServer

func RegisterGraphServiceServer(s grpc.ServiceRegistrar, srv GraphServiceServer)

func RegisterLabelServiceServer

func RegisterLabelServiceServer(s grpc.ServiceRegistrar, srv LabelServiceServer)

func RegisterModuleServiceServer

func RegisterModuleServiceServer(s grpc.ServiceRegistrar, srv ModuleServiceServer)

func RegisterResourceServiceServer

func RegisterResourceServiceServer(s grpc.ServiceRegistrar, srv ResourceServiceServer)

func RegisterUploadServiceServer

func RegisterUploadServiceServer(s grpc.ServiceRegistrar, srv UploadServiceServer)

Types

type CommitServiceClient

type CommitServiceClient interface {
	// Get Commits.
	GetCommits(ctx context.Context, in *v1.GetCommitsRequest, opts ...grpc.CallOption) (*v1.GetCommitsResponse, error)
	// List Commits for a given Module, Label, or Commit.
	ListCommits(ctx context.Context, in *v1.ListCommitsRequest, opts ...grpc.CallOption) (*v1.ListCommitsResponse, error)
}

CommitServiceClient is the client API for CommitService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

Operate on Commits.

func NewCommitServiceClient

func NewCommitServiceClient(cc grpc.ClientConnInterface) CommitServiceClient

type CommitServiceServer

type CommitServiceServer interface {
	// Get Commits.
	GetCommits(context.Context, *v1.GetCommitsRequest) (*v1.GetCommitsResponse, error)
	// List Commits for a given Module, Label, or Commit.
	ListCommits(context.Context, *v1.ListCommitsRequest) (*v1.ListCommitsResponse, error)
}

CommitServiceServer is the server API for CommitService service. All implementations should embed UnimplementedCommitServiceServer for forward compatibility.

Operate on Commits.

type DownloadServiceClient

type DownloadServiceClient interface {
	// Download the contents of multiple Modules, Labels, or Commits.
	//
	// Content consists of the .proto files, license files, and documentation files.
	Download(ctx context.Context, in *v1.DownloadRequest, opts ...grpc.CallOption) (*v1.DownloadResponse, error)
}

DownloadServiceClient is the client API for DownloadService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

Download contents.

func NewDownloadServiceClient

func NewDownloadServiceClient(cc grpc.ClientConnInterface) DownloadServiceClient

type DownloadServiceServer

type DownloadServiceServer interface {
	// Download the contents of multiple Modules, Labels, or Commits.
	//
	// Content consists of the .proto files, license files, and documentation files.
	Download(context.Context, *v1.DownloadRequest) (*v1.DownloadResponse, error)
}

DownloadServiceServer is the server API for DownloadService service. All implementations should embed UnimplementedDownloadServiceServer for forward compatibility.

Download contents.

type FileDescriptorSetServiceClient

type FileDescriptorSetServiceClient interface {
	// Get the compiled FileDescriptorSet for the given Module, Label, or Commit.
	GetFileDescriptorSet(ctx context.Context, in *v1.GetFileDescriptorSetRequest, opts ...grpc.CallOption) (*v1.GetFileDescriptorSetResponse, error)
}

FileDescriptorSetServiceClient is the client API for FileDescriptorSetService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

Provide compiled FileDescriptorSets for Modules, Labels, or Commits.

func NewFileDescriptorSetServiceClient

func NewFileDescriptorSetServiceClient(cc grpc.ClientConnInterface) FileDescriptorSetServiceClient

type FileDescriptorSetServiceServer

type FileDescriptorSetServiceServer interface {
	// Get the compiled FileDescriptorSet for the given Module, Label, or Commit.
	GetFileDescriptorSet(context.Context, *v1.GetFileDescriptorSetRequest) (*v1.GetFileDescriptorSetResponse, error)
}

FileDescriptorSetServiceServer is the server API for FileDescriptorSetService service. All implementations should embed UnimplementedFileDescriptorSetServiceServer for forward compatibility.

Provide compiled FileDescriptorSets for Modules, Labels, or Commits.

type GraphServiceClient

type GraphServiceClient interface {
	// Get a dependency graph that includes the given Commits.
	//
	// Commits will be resolved via the given ResourceRefs, and all Commits will be included in the
	// graph, along with their dependencies.
	//
	// A dependency graph is a directed acyclic graph.
	GetGraph(ctx context.Context, in *v1.GetGraphRequest, opts ...grpc.CallOption) (*v1.GetGraphResponse, error)
}

GraphServiceClient is the client API for GraphService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

Get dependency graphs.

func NewGraphServiceClient

func NewGraphServiceClient(cc grpc.ClientConnInterface) GraphServiceClient

type GraphServiceServer

type GraphServiceServer interface {
	// Get a dependency graph that includes the given Commits.
	//
	// Commits will be resolved via the given ResourceRefs, and all Commits will be included in the
	// graph, along with their dependencies.
	//
	// A dependency graph is a directed acyclic graph.
	GetGraph(context.Context, *v1.GetGraphRequest) (*v1.GetGraphResponse, error)
}

GraphServiceServer is the server API for GraphService service. All implementations should embed UnimplementedGraphServiceServer for forward compatibility.

Get dependency graphs.

type LabelServiceClient

type LabelServiceClient interface {
	// Get Labels by id or name.
	GetLabels(ctx context.Context, in *v1.GetLabelsRequest, opts ...grpc.CallOption) (*v1.GetLabelsResponse, error)
	// List Labels for a given Module, Commit or Label.
	ListLabels(ctx context.Context, in *v1.ListLabelsRequest, opts ...grpc.CallOption) (*v1.ListLabelsResponse, error)
	// List the history of a Label.
	ListLabelHistory(ctx context.Context, in *v1.ListLabelHistoryRequest, opts ...grpc.CallOption) (*v1.ListLabelHistoryResponse, error)
	// Create or update Labels on a Module.
	//
	// If the Label does not exist, it will be created.
	// If the Label was archived, it will be unarchived.
	// If the Label already existed, the Commit in the request has to be newer than the Commit that
	// the Label is currently pointing to, otherwise an error is returned.
	//
	// This operation is atomic. Either all Labels are created/updated or an error is returned.
	CreateOrUpdateLabels(ctx context.Context, in *v1.CreateOrUpdateLabelsRequest, opts ...grpc.CallOption) (*v1.CreateOrUpdateLabelsResponse, error)
	// Archive existing Labels.
	//
	// This operation is atomic. Either all Labels are archived or an error is returned.
	ArchiveLabels(ctx context.Context, in *v1.ArchiveLabelsRequest, opts ...grpc.CallOption) (*v1.ArchiveLabelsResponse, error)
	// Unarchive existing Labels.
	//
	// This operation is atomic. Either all Labels are unarchived or an error is returned.
	UnarchiveLabels(ctx context.Context, in *v1.UnarchiveLabelsRequest, opts ...grpc.CallOption) (*v1.UnarchiveLabelsResponse, error)
}

LabelServiceClient is the client API for LabelService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

Operate on Labels.

func NewLabelServiceClient

func NewLabelServiceClient(cc grpc.ClientConnInterface) LabelServiceClient

type LabelServiceServer

type LabelServiceServer interface {
	// Get Labels by id or name.
	GetLabels(context.Context, *v1.GetLabelsRequest) (*v1.GetLabelsResponse, error)
	// List Labels for a given Module, Commit or Label.
	ListLabels(context.Context, *v1.ListLabelsRequest) (*v1.ListLabelsResponse, error)
	// List the history of a Label.
	ListLabelHistory(context.Context, *v1.ListLabelHistoryRequest) (*v1.ListLabelHistoryResponse, error)
	// Create or update Labels on a Module.
	//
	// If the Label does not exist, it will be created.
	// If the Label was archived, it will be unarchived.
	// If the Label already existed, the Commit in the request has to be newer than the Commit that
	// the Label is currently pointing to, otherwise an error is returned.
	//
	// This operation is atomic. Either all Labels are created/updated or an error is returned.
	CreateOrUpdateLabels(context.Context, *v1.CreateOrUpdateLabelsRequest) (*v1.CreateOrUpdateLabelsResponse, error)
	// Archive existing Labels.
	//
	// This operation is atomic. Either all Labels are archived or an error is returned.
	ArchiveLabels(context.Context, *v1.ArchiveLabelsRequest) (*v1.ArchiveLabelsResponse, error)
	// Unarchive existing Labels.
	//
	// This operation is atomic. Either all Labels are unarchived or an error is returned.
	UnarchiveLabels(context.Context, *v1.UnarchiveLabelsRequest) (*v1.UnarchiveLabelsResponse, error)
}

LabelServiceServer is the server API for LabelService service. All implementations should embed UnimplementedLabelServiceServer for forward compatibility.

Operate on Labels.

type ModuleServiceClient

type ModuleServiceClient interface {
	// Get Modules by id or name.
	GetModules(ctx context.Context, in *v1.GetModulesRequest, opts ...grpc.CallOption) (*v1.GetModulesResponse, error)
	// List Modules, usually for a specific User or Organization.
	ListModules(ctx context.Context, in *v1.ListModulesRequest, opts ...grpc.CallOption) (*v1.ListModulesResponse, error)
	// Create new Modules.
	//
	// New modules are created with a default Label named "main".
	//
	// This operation is atomic. Either all Modules are created or an error is returned.
	CreateModules(ctx context.Context, in *v1.CreateModulesRequest, opts ...grpc.CallOption) (*v1.CreateModulesResponse, error)
	// Update existing Modules.
	//
	// This operation is atomic. Either all Modules are updated or an error is returned.
	UpdateModules(ctx context.Context, in *v1.UpdateModulesRequest, opts ...grpc.CallOption) (*v1.UpdateModulesResponse, error)
	// Delete existing Modules.
	//
	// This operation is atomic. Either all Modules are deleted or an error is returned.
	DeleteModules(ctx context.Context, in *v1.DeleteModulesRequest, opts ...grpc.CallOption) (*v1.DeleteModulesResponse, error)
}

ModuleServiceClient is the client API for ModuleService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

Operate on Modules.

func NewModuleServiceClient

func NewModuleServiceClient(cc grpc.ClientConnInterface) ModuleServiceClient

type ModuleServiceServer

type ModuleServiceServer interface {
	// Get Modules by id or name.
	GetModules(context.Context, *v1.GetModulesRequest) (*v1.GetModulesResponse, error)
	// List Modules, usually for a specific User or Organization.
	ListModules(context.Context, *v1.ListModulesRequest) (*v1.ListModulesResponse, error)
	// Create new Modules.
	//
	// New modules are created with a default Label named "main".
	//
	// This operation is atomic. Either all Modules are created or an error is returned.
	CreateModules(context.Context, *v1.CreateModulesRequest) (*v1.CreateModulesResponse, error)
	// Update existing Modules.
	//
	// This operation is atomic. Either all Modules are updated or an error is returned.
	UpdateModules(context.Context, *v1.UpdateModulesRequest) (*v1.UpdateModulesResponse, error)
	// Delete existing Modules.
	//
	// This operation is atomic. Either all Modules are deleted or an error is returned.
	DeleteModules(context.Context, *v1.DeleteModulesRequest) (*v1.DeleteModulesResponse, error)
}

ModuleServiceServer is the server API for ModuleService service. All implementations should embed UnimplementedModuleServiceServer for forward compatibility.

Operate on Modules.

type ResourceServiceClient

type ResourceServiceClient interface {
	// Get Resources.
	GetResources(ctx context.Context, in *v1.GetResourcesRequest, opts ...grpc.CallOption) (*v1.GetResourcesResponse, error)
}

ResourceServiceClient is the client API for ResourceService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

Operate on Resources.

func NewResourceServiceClient

func NewResourceServiceClient(cc grpc.ClientConnInterface) ResourceServiceClient

type ResourceServiceServer

type ResourceServiceServer interface {
	// Get Resources.
	GetResources(context.Context, *v1.GetResourcesRequest) (*v1.GetResourcesResponse, error)
}

ResourceServiceServer is the server API for ResourceService service. All implementations should embed UnimplementedResourceServiceServer for forward compatibility.

Operate on Resources.

type UnimplementedCommitServiceServer

type UnimplementedCommitServiceServer struct{}

UnimplementedCommitServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedCommitServiceServer) GetCommits

func (UnimplementedCommitServiceServer) ListCommits

type UnimplementedDownloadServiceServer

type UnimplementedDownloadServiceServer struct{}

UnimplementedDownloadServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedDownloadServiceServer) Download

type UnimplementedFileDescriptorSetServiceServer

type UnimplementedFileDescriptorSetServiceServer struct{}

UnimplementedFileDescriptorSetServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedFileDescriptorSetServiceServer) GetFileDescriptorSet

type UnimplementedGraphServiceServer

type UnimplementedGraphServiceServer struct{}

UnimplementedGraphServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedGraphServiceServer) GetGraph

type UnimplementedLabelServiceServer

type UnimplementedLabelServiceServer struct{}

UnimplementedLabelServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedLabelServiceServer) ArchiveLabels

func (UnimplementedLabelServiceServer) CreateOrUpdateLabels

func (UnimplementedLabelServiceServer) GetLabels

func (UnimplementedLabelServiceServer) ListLabelHistory

func (UnimplementedLabelServiceServer) ListLabels

func (UnimplementedLabelServiceServer) UnarchiveLabels

type UnimplementedModuleServiceServer

type UnimplementedModuleServiceServer struct{}

UnimplementedModuleServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedModuleServiceServer) CreateModules

func (UnimplementedModuleServiceServer) DeleteModules

func (UnimplementedModuleServiceServer) GetModules

func (UnimplementedModuleServiceServer) ListModules

func (UnimplementedModuleServiceServer) UpdateModules

type UnimplementedResourceServiceServer

type UnimplementedResourceServiceServer struct{}

UnimplementedResourceServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedResourceServiceServer) GetResources

type UnimplementedUploadServiceServer

type UnimplementedUploadServiceServer struct{}

UnimplementedUploadServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedUploadServiceServer) Upload

type UnsafeCommitServiceServer

type UnsafeCommitServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeCommitServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to CommitServiceServer will result in compilation errors.

type UnsafeDownloadServiceServer

type UnsafeDownloadServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeDownloadServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to DownloadServiceServer will result in compilation errors.

type UnsafeFileDescriptorSetServiceServer

type UnsafeFileDescriptorSetServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeFileDescriptorSetServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to FileDescriptorSetServiceServer will result in compilation errors.

type UnsafeGraphServiceServer

type UnsafeGraphServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeGraphServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to GraphServiceServer will result in compilation errors.

type UnsafeLabelServiceServer

type UnsafeLabelServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeLabelServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to LabelServiceServer will result in compilation errors.

type UnsafeModuleServiceServer

type UnsafeModuleServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeModuleServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ModuleServiceServer will result in compilation errors.

type UnsafeResourceServiceServer

type UnsafeResourceServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeResourceServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ResourceServiceServer will result in compilation errors.

type UnsafeUploadServiceServer

type UnsafeUploadServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeUploadServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to UploadServiceServer will result in compilation errors.

type UploadServiceClient

type UploadServiceClient interface {
	// Upload contents for given set of Modules.
	//
	// Content consists of the Files: .proto files, license files, and documentation files.
	Upload(ctx context.Context, in *v1.UploadRequest, opts ...grpc.CallOption) (*v1.UploadResponse, error)
}

UploadServiceClient is the client API for UploadService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

Upload contents.

func NewUploadServiceClient

func NewUploadServiceClient(cc grpc.ClientConnInterface) UploadServiceClient

type UploadServiceServer

type UploadServiceServer interface {
	// Upload contents for given set of Modules.
	//
	// Content consists of the Files: .proto files, license files, and documentation files.
	Upload(context.Context, *v1.UploadRequest) (*v1.UploadResponse, error)
}

UploadServiceServer is the server API for UploadService service. All implementations should embed UnimplementedUploadServiceServer for forward compatibility.

Upload contents.

Source Files

  • commit_service_grpc.pb.go
  • download_service_grpc.pb.go
  • file_descriptor_set_service_grpc.pb.go
  • graph_service_grpc.pb.go
  • label_service_grpc.pb.go
  • module_service_grpc.pb.go
  • resource_service_grpc.pb.go
  • upload_service_grpc.pb.go

Jump to