_gogrpc

package
v1.5.1-20240910225426-... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: AGPL-3.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	CedanaGPU_Checkpoint_FullMethodName  = "/cedanagpu.CedanaGPU/Checkpoint"
	CedanaGPU_Restore_FullMethodName     = "/cedanagpu.CedanaGPU/Restore"
	CedanaGPU_StartupPoll_FullMethodName = "/cedanagpu.CedanaGPU/StartupPoll"
	CedanaGPU_HealthCheck_FullMethodName = "/cedanagpu.CedanaGPU/HealthCheck"
)
const (
	TaskService_Start_FullMethodName                   = "/cedana.services.task.TaskService/Start"
	TaskService_Dump_FullMethodName                    = "/cedana.services.task.TaskService/Dump"
	TaskService_Restore_FullMethodName                 = "/cedana.services.task.TaskService/Restore"
	TaskService_Query_FullMethodName                   = "/cedana.services.task.TaskService/Query"
	TaskService_ContainerdDump_FullMethodName          = "/cedana.services.task.TaskService/ContainerdDump"
	TaskService_ContainerdRestore_FullMethodName       = "/cedana.services.task.TaskService/ContainerdRestore"
	TaskService_ContainerdQuery_FullMethodName         = "/cedana.services.task.TaskService/ContainerdQuery"
	TaskService_ContainerdRootfsDump_FullMethodName    = "/cedana.services.task.TaskService/ContainerdRootfsDump"
	TaskService_ContainerdRootfsRestore_FullMethodName = "/cedana.services.task.TaskService/ContainerdRootfsRestore"
	TaskService_RuncDump_FullMethodName                = "/cedana.services.task.TaskService/RuncDump"
	TaskService_RuncRestore_FullMethodName             = "/cedana.services.task.TaskService/RuncRestore"
	TaskService_RuncQuery_FullMethodName               = "/cedana.services.task.TaskService/RuncQuery"
	TaskService_RuncGetPausePid_FullMethodName         = "/cedana.services.task.TaskService/RuncGetPausePid"
	TaskService_CRIORootfsDump_FullMethodName          = "/cedana.services.task.TaskService/CRIORootfsDump"
	TaskService_CRIOImagePush_FullMethodName           = "/cedana.services.task.TaskService/CRIOImagePush"
	TaskService_StartAttach_FullMethodName             = "/cedana.services.task.TaskService/StartAttach"
	TaskService_RestoreAttach_FullMethodName           = "/cedana.services.task.TaskService/RestoreAttach"
	TaskService_LogStreaming_FullMethodName            = "/cedana.services.task.TaskService/LogStreaming"
	TaskService_ProcessStateStreaming_FullMethodName   = "/cedana.services.task.TaskService/ProcessStateStreaming"
	TaskService_DetailedHealthCheck_FullMethodName     = "/cedana.services.task.TaskService/DetailedHealthCheck"
	TaskService_KataDump_FullMethodName                = "/cedana.services.task.TaskService/KataDump"
	TaskService_KataRestore_FullMethodName             = "/cedana.services.task.TaskService/KataRestore"
	TaskService_GetConfig_FullMethodName               = "/cedana.services.task.TaskService/GetConfig"
	TaskService_QueueCheckpoint_FullMethodName         = "/cedana.services.task.TaskService/QueueCheckpoint"
	TaskService_QueueRestore_FullMethodName            = "/cedana.services.task.TaskService/QueueRestore"
	TaskService_JobStatus_FullMethodName               = "/cedana.services.task.TaskService/JobStatus"
)

Variables

var CedanaGPU_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "cedanagpu.CedanaGPU",
	HandlerType: (*CedanaGPUServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "Checkpoint",
			Handler:    _CedanaGPU_Checkpoint_Handler,
		},
		{
			MethodName: "Restore",
			Handler:    _CedanaGPU_Restore_Handler,
		},
		{
			MethodName: "StartupPoll",
			Handler:    _CedanaGPU_StartupPoll_Handler,
		},
		{
			MethodName: "HealthCheck",
			Handler:    _CedanaGPU_HealthCheck_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "gpu.proto",
}

CedanaGPU_ServiceDesc is the grpc.ServiceDesc for CedanaGPU service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var TaskService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "cedana.services.task.TaskService",
	HandlerType: (*TaskServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "Start",
			Handler:    _TaskService_Start_Handler,
		},
		{
			MethodName: "Dump",
			Handler:    _TaskService_Dump_Handler,
		},
		{
			MethodName: "Restore",
			Handler:    _TaskService_Restore_Handler,
		},
		{
			MethodName: "Query",
			Handler:    _TaskService_Query_Handler,
		},
		{
			MethodName: "ContainerdDump",
			Handler:    _TaskService_ContainerdDump_Handler,
		},
		{
			MethodName: "ContainerdRestore",
			Handler:    _TaskService_ContainerdRestore_Handler,
		},
		{
			MethodName: "ContainerdQuery",
			Handler:    _TaskService_ContainerdQuery_Handler,
		},
		{
			MethodName: "ContainerdRootfsDump",
			Handler:    _TaskService_ContainerdRootfsDump_Handler,
		},
		{
			MethodName: "ContainerdRootfsRestore",
			Handler:    _TaskService_ContainerdRootfsRestore_Handler,
		},
		{
			MethodName: "RuncDump",
			Handler:    _TaskService_RuncDump_Handler,
		},
		{
			MethodName: "RuncRestore",
			Handler:    _TaskService_RuncRestore_Handler,
		},
		{
			MethodName: "RuncQuery",
			Handler:    _TaskService_RuncQuery_Handler,
		},
		{
			MethodName: "RuncGetPausePid",
			Handler:    _TaskService_RuncGetPausePid_Handler,
		},
		{
			MethodName: "CRIORootfsDump",
			Handler:    _TaskService_CRIORootfsDump_Handler,
		},
		{
			MethodName: "CRIOImagePush",
			Handler:    _TaskService_CRIOImagePush_Handler,
		},
		{
			MethodName: "DetailedHealthCheck",
			Handler:    _TaskService_DetailedHealthCheck_Handler,
		},
		{
			MethodName: "KataDump",
			Handler:    _TaskService_KataDump_Handler,
		},
		{
			MethodName: "KataRestore",
			Handler:    _TaskService_KataRestore_Handler,
		},
		{
			MethodName: "GetConfig",
			Handler:    _TaskService_GetConfig_Handler,
		},
		{
			MethodName: "QueueCheckpoint",
			Handler:    _TaskService_QueueCheckpoint_Handler,
		},
		{
			MethodName: "QueueRestore",
			Handler:    _TaskService_QueueRestore_Handler,
		},
		{
			MethodName: "JobStatus",
			Handler:    _TaskService_JobStatus_Handler,
		},
	},
	Streams: []grpc.StreamDesc{
		{
			StreamName:    "StartAttach",
			Handler:       _TaskService_StartAttach_Handler,
			ServerStreams: true,
			ClientStreams: true,
		},
		{
			StreamName:    "RestoreAttach",
			Handler:       _TaskService_RestoreAttach_Handler,
			ServerStreams: true,
			ClientStreams: true,
		},
		{
			StreamName:    "LogStreaming",
			Handler:       _TaskService_LogStreaming_Handler,
			ServerStreams: true,
			ClientStreams: true,
		},
		{
			StreamName:    "ProcessStateStreaming",
			Handler:       _TaskService_ProcessStateStreaming_Handler,
			ServerStreams: true,
		},
	},
	Metadata: "task.proto",
}

TaskService_ServiceDesc is the grpc.ServiceDesc for TaskService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterCedanaGPUServer

func RegisterCedanaGPUServer(s grpc.ServiceRegistrar, srv CedanaGPUServer)

func RegisterTaskServiceServer

func RegisterTaskServiceServer(s grpc.ServiceRegistrar, srv TaskServiceServer)

Types

type CedanaGPUClient

type CedanaGPUClient interface {
	Checkpoint(ctx context.Context, in *_go.CheckpointRequest, opts ...grpc.CallOption) (*_go.CheckpointResponse, error)
	Restore(ctx context.Context, in *_go.RestoreRequest, opts ...grpc.CallOption) (*_go.RestoreResponse, error)
	StartupPoll(ctx context.Context, in *_go.StartupPollRequest, opts ...grpc.CallOption) (*_go.StartupPollResponse, error)
	HealthCheck(ctx context.Context, in *_go.HealthCheckRequest, opts ...grpc.CallOption) (*_go.HealthCheckResponse, error)
}

CedanaGPUClient is the client API for CedanaGPU service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewCedanaGPUClient

func NewCedanaGPUClient(cc grpc.ClientConnInterface) CedanaGPUClient

type CedanaGPUServer

CedanaGPUServer is the server API for CedanaGPU service. All implementations should embed UnimplementedCedanaGPUServer for forward compatibility.

type TaskServiceClient

type TaskServiceClient interface {
	// Process
	Start(ctx context.Context, in *_go.StartArgs, opts ...grpc.CallOption) (*_go.StartResp, error)
	Dump(ctx context.Context, in *_go.DumpArgs, opts ...grpc.CallOption) (*_go.DumpResp, error)
	Restore(ctx context.Context, in *_go.RestoreArgs, opts ...grpc.CallOption) (*_go.RestoreResp, error)
	Query(ctx context.Context, in *_go.QueryArgs, opts ...grpc.CallOption) (*_go.QueryResp, error)
	// Containerd
	ContainerdDump(ctx context.Context, in *_go.ContainerdDumpArgs, opts ...grpc.CallOption) (*_go.ContainerdDumpResp, error)
	ContainerdRestore(ctx context.Context, in *_go.ContainerdRestoreArgs, opts ...grpc.CallOption) (*_go.ContainerdRestoreResp, error)
	ContainerdQuery(ctx context.Context, in *_go.ContainerdQueryArgs, opts ...grpc.CallOption) (*_go.ContainerdQueryResp, error)
	ContainerdRootfsDump(ctx context.Context, in *_go.ContainerdRootfsDumpArgs, opts ...grpc.CallOption) (*_go.ContainerdRootfsDumpResp, error)
	ContainerdRootfsRestore(ctx context.Context, in *_go.ContainerdRootfsRestoreArgs, opts ...grpc.CallOption) (*_go.ContainerdRootfsRestoreResp, error)
	// Runc
	RuncDump(ctx context.Context, in *_go.RuncDumpArgs, opts ...grpc.CallOption) (*_go.RuncDumpResp, error)
	RuncRestore(ctx context.Context, in *_go.RuncRestoreArgs, opts ...grpc.CallOption) (*_go.RuncRestoreResp, error)
	RuncQuery(ctx context.Context, in *_go.RuncQueryArgs, opts ...grpc.CallOption) (*_go.RuncQueryResp, error)
	RuncGetPausePid(ctx context.Context, in *_go.RuncGetPausePidArgs, opts ...grpc.CallOption) (*_go.RuncGetPausePidResp, error)
	// CRIO
	CRIORootfsDump(ctx context.Context, in *_go.CRIORootfsDumpArgs, opts ...grpc.CallOption) (*_go.CRIORootfsDumpResp, error)
	CRIOImagePush(ctx context.Context, in *_go.CRIOImagePushArgs, opts ...grpc.CallOption) (*_go.CRIOImagePushResp, error)
	// Streaming
	StartAttach(ctx context.Context, opts ...grpc.CallOption) (grpc.BidiStreamingClient[_go.StartAttachArgs, _go.StartAttachResp], error)
	RestoreAttach(ctx context.Context, opts ...grpc.CallOption) (grpc.BidiStreamingClient[_go.RestoreAttachArgs, _go.RestoreAttachResp], error)
	LogStreaming(ctx context.Context, opts ...grpc.CallOption) (grpc.BidiStreamingClient[_go.LogStreamingResp, _go.LogStreamingArgs], error)
	ProcessStateStreaming(ctx context.Context, in *_go.ProcessStateStreamingArgs, opts ...grpc.CallOption) (grpc.ServerStreamingClient[_go.ProcessState], error)
	// Health
	DetailedHealthCheck(ctx context.Context, in *_go.DetailedHealthCheckRequest, opts ...grpc.CallOption) (*_go.DetailedHealthCheckResponse, error)
	// Kata
	KataDump(ctx context.Context, in *_go.DumpArgs, opts ...grpc.CallOption) (*_go.DumpResp, error)
	KataRestore(ctx context.Context, in *_go.RestoreArgs, opts ...grpc.CallOption) (*_go.RestoreResp, error)
	// Config
	GetConfig(ctx context.Context, in *_go.GetConfigRequest, opts ...grpc.CallOption) (*_go.GetConfigResponse, error)
	// JobQueue
	QueueCheckpoint(ctx context.Context, in *_go.QueueJobCheckpointRequest, opts ...grpc.CallOption) (*wrapperspb.BoolValue, error)
	QueueRestore(ctx context.Context, in *_go.QueueJobRestoreRequest, opts ...grpc.CallOption) (*wrapperspb.BoolValue, error)
	JobStatus(ctx context.Context, in *_go.QueueJobID, opts ...grpc.CallOption) (*_go.QueueJobStatus, error)
}

TaskServiceClient is the client API for TaskService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewTaskServiceClient

func NewTaskServiceClient(cc grpc.ClientConnInterface) TaskServiceClient

type TaskServiceServer

type TaskServiceServer interface {
	// Process
	Start(context.Context, *_go.StartArgs) (*_go.StartResp, error)
	Dump(context.Context, *_go.DumpArgs) (*_go.DumpResp, error)
	Restore(context.Context, *_go.RestoreArgs) (*_go.RestoreResp, error)
	Query(context.Context, *_go.QueryArgs) (*_go.QueryResp, error)
	// Containerd
	ContainerdDump(context.Context, *_go.ContainerdDumpArgs) (*_go.ContainerdDumpResp, error)
	ContainerdRestore(context.Context, *_go.ContainerdRestoreArgs) (*_go.ContainerdRestoreResp, error)
	ContainerdQuery(context.Context, *_go.ContainerdQueryArgs) (*_go.ContainerdQueryResp, error)
	ContainerdRootfsDump(context.Context, *_go.ContainerdRootfsDumpArgs) (*_go.ContainerdRootfsDumpResp, error)
	ContainerdRootfsRestore(context.Context, *_go.ContainerdRootfsRestoreArgs) (*_go.ContainerdRootfsRestoreResp, error)
	// Runc
	RuncDump(context.Context, *_go.RuncDumpArgs) (*_go.RuncDumpResp, error)
	RuncRestore(context.Context, *_go.RuncRestoreArgs) (*_go.RuncRestoreResp, error)
	RuncQuery(context.Context, *_go.RuncQueryArgs) (*_go.RuncQueryResp, error)
	RuncGetPausePid(context.Context, *_go.RuncGetPausePidArgs) (*_go.RuncGetPausePidResp, error)
	// CRIO
	CRIORootfsDump(context.Context, *_go.CRIORootfsDumpArgs) (*_go.CRIORootfsDumpResp, error)
	CRIOImagePush(context.Context, *_go.CRIOImagePushArgs) (*_go.CRIOImagePushResp, error)
	// Streaming
	StartAttach(grpc.BidiStreamingServer[_go.StartAttachArgs, _go.StartAttachResp]) error
	RestoreAttach(grpc.BidiStreamingServer[_go.RestoreAttachArgs, _go.RestoreAttachResp]) error
	LogStreaming(grpc.BidiStreamingServer[_go.LogStreamingResp, _go.LogStreamingArgs]) error
	ProcessStateStreaming(*_go.ProcessStateStreamingArgs, grpc.ServerStreamingServer[_go.ProcessState]) error
	// Health
	DetailedHealthCheck(context.Context, *_go.DetailedHealthCheckRequest) (*_go.DetailedHealthCheckResponse, error)
	// Kata
	KataDump(context.Context, *_go.DumpArgs) (*_go.DumpResp, error)
	KataRestore(context.Context, *_go.RestoreArgs) (*_go.RestoreResp, error)
	// Config
	GetConfig(context.Context, *_go.GetConfigRequest) (*_go.GetConfigResponse, error)
	// JobQueue
	QueueCheckpoint(context.Context, *_go.QueueJobCheckpointRequest) (*wrapperspb.BoolValue, error)
	QueueRestore(context.Context, *_go.QueueJobRestoreRequest) (*wrapperspb.BoolValue, error)
	JobStatus(context.Context, *_go.QueueJobID) (*_go.QueueJobStatus, error)
}

TaskServiceServer is the server API for TaskService service. All implementations should embed UnimplementedTaskServiceServer for forward compatibility.

type TaskService_LogStreamingClient

type TaskService_LogStreamingClient = grpc.BidiStreamingClient[_go.LogStreamingResp, _go.LogStreamingArgs]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type TaskService_LogStreamingServer

type TaskService_LogStreamingServer = grpc.BidiStreamingServer[_go.LogStreamingResp, _go.LogStreamingArgs]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type TaskService_ProcessStateStreamingClient

type TaskService_ProcessStateStreamingClient = grpc.ServerStreamingClient[_go.ProcessState]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type TaskService_ProcessStateStreamingServer

type TaskService_ProcessStateStreamingServer = grpc.ServerStreamingServer[_go.ProcessState]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type TaskService_RestoreAttachClient

type TaskService_RestoreAttachClient = grpc.BidiStreamingClient[_go.RestoreAttachArgs, _go.RestoreAttachResp]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type TaskService_RestoreAttachServer

type TaskService_RestoreAttachServer = grpc.BidiStreamingServer[_go.RestoreAttachArgs, _go.RestoreAttachResp]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type TaskService_StartAttachClient

type TaskService_StartAttachClient = grpc.BidiStreamingClient[_go.StartAttachArgs, _go.StartAttachResp]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type TaskService_StartAttachServer

type TaskService_StartAttachServer = grpc.BidiStreamingServer[_go.StartAttachArgs, _go.StartAttachResp]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type UnimplementedCedanaGPUServer

type UnimplementedCedanaGPUServer struct{}

UnimplementedCedanaGPUServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedCedanaGPUServer) Checkpoint

func (UnimplementedCedanaGPUServer) HealthCheck

func (UnimplementedCedanaGPUServer) Restore

func (UnimplementedCedanaGPUServer) StartupPoll

type UnimplementedTaskServiceServer

type UnimplementedTaskServiceServer struct{}

UnimplementedTaskServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedTaskServiceServer) CRIOImagePush

func (UnimplementedTaskServiceServer) CRIORootfsDump

func (UnimplementedTaskServiceServer) ContainerdDump

func (UnimplementedTaskServiceServer) ContainerdQuery

func (UnimplementedTaskServiceServer) ContainerdRestore

func (UnimplementedTaskServiceServer) ContainerdRootfsDump

func (UnimplementedTaskServiceServer) ContainerdRootfsRestore

func (UnimplementedTaskServiceServer) DetailedHealthCheck

func (UnimplementedTaskServiceServer) Dump

func (UnimplementedTaskServiceServer) GetConfig

func (UnimplementedTaskServiceServer) JobStatus

func (UnimplementedTaskServiceServer) KataDump

func (UnimplementedTaskServiceServer) KataRestore

func (UnimplementedTaskServiceServer) LogStreaming

func (UnimplementedTaskServiceServer) ProcessStateStreaming

func (UnimplementedTaskServiceServer) Query

func (UnimplementedTaskServiceServer) QueueCheckpoint

func (UnimplementedTaskServiceServer) QueueRestore

func (UnimplementedTaskServiceServer) Restore

func (UnimplementedTaskServiceServer) RestoreAttach

func (UnimplementedTaskServiceServer) RuncDump

func (UnimplementedTaskServiceServer) RuncGetPausePid

func (UnimplementedTaskServiceServer) RuncQuery

func (UnimplementedTaskServiceServer) RuncRestore

func (UnimplementedTaskServiceServer) Start

func (UnimplementedTaskServiceServer) StartAttach

type UnsafeCedanaGPUServer

type UnsafeCedanaGPUServer interface {
	// contains filtered or unexported methods
}

UnsafeCedanaGPUServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to CedanaGPUServer will result in compilation errors.

type UnsafeTaskServiceServer

type UnsafeTaskServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeTaskServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to TaskServiceServer will result in compilation errors.

Source Files

  • gpu_grpc.pb.go
  • task_grpc.pb.go

Jump to