gpugrpc

package
v1.6.1-20260204162307-... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: AGPL-3.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	Controller_Freeze_FullMethodName      = "/gpu.Controller/Freeze"
	Controller_Unfreeze_FullMethodName    = "/gpu.Controller/Unfreeze"
	Controller_Dump_FullMethodName        = "/gpu.Controller/Dump"
	Controller_Restore_FullMethodName     = "/gpu.Controller/Restore"
	Controller_HealthCheck_FullMethodName = "/gpu.Controller/HealthCheck"
	Controller_Info_FullMethodName        = "/gpu.Controller/Info"
	Controller_Attach_FullMethodName      = "/gpu.Controller/Attach"
)

Variables

var Controller_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "gpu.Controller",
	HandlerType: (*ControllerServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "Freeze",
			Handler:    _Controller_Freeze_Handler,
		},
		{
			MethodName: "Unfreeze",
			Handler:    _Controller_Unfreeze_Handler,
		},
		{
			MethodName: "Dump",
			Handler:    _Controller_Dump_Handler,
		},
		{
			MethodName: "Restore",
			Handler:    _Controller_Restore_Handler,
		},
		{
			MethodName: "HealthCheck",
			Handler:    _Controller_HealthCheck_Handler,
		},
		{
			MethodName: "Info",
			Handler:    _Controller_Info_Handler,
		},
		{
			MethodName: "Attach",
			Handler:    _Controller_Attach_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "gpu/controller.proto",
}

Controller_ServiceDesc is the grpc.ServiceDesc for Controller service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterControllerServer

func RegisterControllerServer(s grpc.ServiceRegistrar, srv ControllerServer)

Types

type ControllerClient

type ControllerClient interface {
	Freeze(ctx context.Context, in *gpu.FreezeReq, opts ...grpc.CallOption) (*gpu.FreezeResp, error)
	Unfreeze(ctx context.Context, in *gpu.UnfreezeReq, opts ...grpc.CallOption) (*gpu.UnfreezeResp, error)
	Dump(ctx context.Context, in *gpu.DumpReq, opts ...grpc.CallOption) (*gpu.DumpResp, error)
	Restore(ctx context.Context, in *gpu.RestoreReq, opts ...grpc.CallOption) (*gpu.RestoreResp, error)
	HealthCheck(ctx context.Context, in *gpu.HealthCheckReq, opts ...grpc.CallOption) (*gpu.HealthCheckResp, error)
	Info(ctx context.Context, in *gpu.InfoReq, opts ...grpc.CallOption) (*gpu.InfoResp, error)
	// Only use if forcefully attaching to a PID, so that the Info RPC will return this PID.
	Attach(ctx context.Context, in *gpu.AttachReq, opts ...grpc.CallOption) (*gpu.AttachResp, error)
}

ControllerClient is the client API for Controller service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewControllerClient

func NewControllerClient(cc grpc.ClientConnInterface) ControllerClient

type ControllerServer

type ControllerServer interface {
	Freeze(context.Context, *gpu.FreezeReq) (*gpu.FreezeResp, error)
	Unfreeze(context.Context, *gpu.UnfreezeReq) (*gpu.UnfreezeResp, error)
	Dump(context.Context, *gpu.DumpReq) (*gpu.DumpResp, error)
	Restore(context.Context, *gpu.RestoreReq) (*gpu.RestoreResp, error)
	HealthCheck(context.Context, *gpu.HealthCheckReq) (*gpu.HealthCheckResp, error)
	Info(context.Context, *gpu.InfoReq) (*gpu.InfoResp, error)
	// Only use if forcefully attaching to a PID, so that the Info RPC will return this PID.
	Attach(context.Context, *gpu.AttachReq) (*gpu.AttachResp, error)
}

ControllerServer is the server API for Controller service. All implementations should embed UnimplementedControllerServer for forward compatibility.

type UnimplementedControllerServer

type UnimplementedControllerServer struct{}

UnimplementedControllerServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedControllerServer) Attach

func (UnimplementedControllerServer) Dump

func (UnimplementedControllerServer) Freeze

func (UnimplementedControllerServer) HealthCheck

func (UnimplementedControllerServer) Info

func (UnimplementedControllerServer) Restore

func (UnimplementedControllerServer) Unfreeze

type UnsafeControllerServer

type UnsafeControllerServer interface {
	// contains filtered or unexported methods
}

UnsafeControllerServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ControllerServer will result in compilation errors.

Source Files

  • controller_grpc.pb.go

Jump to