daemonpluginrpc

package
v0.5.0-20251217045538-... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: AGPL-3.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

const (
	// DaemonDumpPath is the path of the Daemon's Dump RPC.
	DaemonDumpPath = "/daemon.Daemon/Dump"
	// DaemonFreezePath is the path of the Daemon's Freeze RPC.
	DaemonFreezePath = "/daemon.Daemon/Freeze"
	// DaemonUnfreezePath is the path of the Daemon's Unfreeze RPC.
	DaemonUnfreezePath = "/daemon.Daemon/Unfreeze"
	// DaemonRestorePath is the path of the Daemon's Restore RPC.
	DaemonRestorePath = "/daemon.Daemon/Restore"
	// DaemonDumpVMPath is the path of the Daemon's DumpVM RPC.
	DaemonDumpVMPath = "/daemon.Daemon/DumpVM"
	// DaemonRestoreVMPath is the path of the Daemon's RestoreVM RPC.
	DaemonRestoreVMPath = "/daemon.Daemon/RestoreVM"
	// DaemonRunPath is the path of the Daemon's Run RPC.
	DaemonRunPath = "/daemon.Daemon/Run"
	// DaemonManagePath is the path of the Daemon's Manage RPC.
	DaemonManagePath = "/daemon.Daemon/Manage"
	// DaemonGetPath is the path of the Daemon's Get RPC.
	DaemonGetPath = "/daemon.Daemon/Get"
	// DaemonListPath is the path of the Daemon's List RPC.
	DaemonListPath = "/daemon.Daemon/List"
	// DaemonKillPath is the path of the Daemon's Kill RPC.
	DaemonKillPath = "/daemon.Daemon/Kill"
	// DaemonDeletePath is the path of the Daemon's Delete RPC.
	DaemonDeletePath = "/daemon.Daemon/Delete"
	// DaemonGetCheckpointPath is the path of the Daemon's GetCheckpoint RPC.
	DaemonGetCheckpointPath = "/daemon.Daemon/GetCheckpoint"
	// DaemonListCheckpointsPath is the path of the Daemon's ListCheckpoints RPC.
	DaemonListCheckpointsPath = "/daemon.Daemon/ListCheckpoints"
	// DaemonDeleteCheckpointPath is the path of the Daemon's DeleteCheckpoint RPC.
	DaemonDeleteCheckpointPath = "/daemon.Daemon/DeleteCheckpoint"
	// DaemonQueryPath is the path of the Daemon's Query RPC.
	DaemonQueryPath = "/daemon.Daemon/Query"
	// DaemonHealthCheckPath is the path of the Daemon's HealthCheck RPC.
	DaemonHealthCheckPath = "/daemon.Daemon/HealthCheck"
	// DaemonReloadPluginsPath is the path of the Daemon's ReloadPlugins RPC.
	DaemonReloadPluginsPath = "/daemon.Daemon/ReloadPlugins"
	// DaemonCreateUnixSocketPath is the path of the Daemon's CreateUnixSocket RPC.
	DaemonCreateUnixSocketPath = "/daemon.Daemon/CreateUnixSocket"
)

Variables

This section is empty.

Functions

func RegisterDaemonServer

func RegisterDaemonServer(serverRegistrar pluginrpc.ServerRegistrar, daemonServer DaemonServer)

RegisterDaemonServer registers the server for the daemon.Daemon service.

Types

type DaemonClient

type DaemonClient interface {
	// Dump a process/container/job
	Dump(context.Context, *daemon.DumpReq, ...pluginrpc.CallOption) (*daemon.DumpResp, error)
	// Freeze a process/container/job
	Freeze(context.Context, *daemon.DumpReq, ...pluginrpc.CallOption) (*daemon.DumpResp, error)
	// Unfreeze a process/container/job
	Unfreeze(context.Context, *daemon.DumpReq, ...pluginrpc.CallOption) (*daemon.DumpResp, error)
	// Restore a process/container/job
	Restore(context.Context, *daemon.RestoreReq, ...pluginrpc.CallOption) (*daemon.RestoreResp, error)
	// Dump a VM
	DumpVM(context.Context, *daemon.DumpVMReq, ...pluginrpc.CallOption) (*daemon.DumpVMResp, error)
	// Restore a VM
	RestoreVM(context.Context, *daemon.RestoreVMReq, ...pluginrpc.CallOption) (*daemon.RestoreVMResp, error)
	// Run a managed process/container (job)
	Run(context.Context, *daemon.RunReq, ...pluginrpc.CallOption) (*daemon.RunResp, error)
	// Manage a running process/container (job)
	Manage(context.Context, *daemon.RunReq, ...pluginrpc.CallOption) (*daemon.RunResp, error)
	// Get details of a managed process/container (job)
	Get(context.Context, *daemon.GetReq, ...pluginrpc.CallOption) (*daemon.GetResp, error)
	// List all managed processes/containers (jobs)
	List(context.Context, *daemon.ListReq, ...pluginrpc.CallOption) (*daemon.ListResp, error)
	// Kill a managed process/container (job)
	Kill(context.Context, *daemon.KillReq, ...pluginrpc.CallOption) (*daemon.KillResp, error)
	// Delete a managed process/container (job)
	Delete(context.Context, *daemon.DeleteReq, ...pluginrpc.CallOption) (*daemon.DeleteResp, error)
	// Get a specific checkpoint, or the latest checkpoint for a job (if JID is provided)
	GetCheckpoint(context.Context, *daemon.GetCheckpointReq, ...pluginrpc.CallOption) (*daemon.GetCheckpointResp, error)
	// List all checkpoints for a job
	ListCheckpoints(context.Context, *daemon.ListCheckpointsReq, ...pluginrpc.CallOption) (*daemon.ListCheckpointsResp, error)
	// Delete a checkpoint
	DeleteCheckpoint(context.Context, *daemon.DeleteCheckpointReq, ...pluginrpc.CallOption) (*daemon.DeleteCheckpointResp, error)
	// Generic query call
	Query(context.Context, *daemon.QueryReq, ...pluginrpc.CallOption) (*daemon.QueryResp, error)
	// Health check the daemon, and installed plugins
	HealthCheck(context.Context, *daemon.HealthCheckReq, ...pluginrpc.CallOption) (*daemon.HealthCheckResp, error)
	// Reload plugins in the daemon. Call after installing/removing any plugins.
	ReloadPlugins(context.Context, *daemon.Empty, ...pluginrpc.CallOption) (*daemon.Empty, error)
	// Create a unix socket
	CreateUnixSocket(context.Context, *daemon.Empty, ...pluginrpc.CallOption) (*daemon.SocketResp, error)
}

DaemonClient is a client for the daemon.Daemon service.

func NewDaemonClient

func NewDaemonClient(client pluginrpc.Client) (DaemonClient, error)

NewDaemonClient constructs a client for the daemon.Daemon service.

type DaemonHandler

type DaemonHandler interface {
	// Dump a process/container/job
	Dump(context.Context, *daemon.DumpReq) (*daemon.DumpResp, error)
	// Freeze a process/container/job
	Freeze(context.Context, *daemon.DumpReq) (*daemon.DumpResp, error)
	// Unfreeze a process/container/job
	Unfreeze(context.Context, *daemon.DumpReq) (*daemon.DumpResp, error)
	// Restore a process/container/job
	Restore(context.Context, *daemon.RestoreReq) (*daemon.RestoreResp, error)
	// Dump a VM
	DumpVM(context.Context, *daemon.DumpVMReq) (*daemon.DumpVMResp, error)
	// Restore a VM
	RestoreVM(context.Context, *daemon.RestoreVMReq) (*daemon.RestoreVMResp, error)
	// Run a managed process/container (job)
	Run(context.Context, *daemon.RunReq) (*daemon.RunResp, error)
	// Manage a running process/container (job)
	Manage(context.Context, *daemon.RunReq) (*daemon.RunResp, error)
	// Get details of a managed process/container (job)
	Get(context.Context, *daemon.GetReq) (*daemon.GetResp, error)
	// List all managed processes/containers (jobs)
	List(context.Context, *daemon.ListReq) (*daemon.ListResp, error)
	// Kill a managed process/container (job)
	Kill(context.Context, *daemon.KillReq) (*daemon.KillResp, error)
	// Delete a managed process/container (job)
	Delete(context.Context, *daemon.DeleteReq) (*daemon.DeleteResp, error)
	// Get a specific checkpoint, or the latest checkpoint for a job (if JID is provided)
	GetCheckpoint(context.Context, *daemon.GetCheckpointReq) (*daemon.GetCheckpointResp, error)
	// List all checkpoints for a job
	ListCheckpoints(context.Context, *daemon.ListCheckpointsReq) (*daemon.ListCheckpointsResp, error)
	// Delete a checkpoint
	DeleteCheckpoint(context.Context, *daemon.DeleteCheckpointReq) (*daemon.DeleteCheckpointResp, error)
	// Generic query call
	Query(context.Context, *daemon.QueryReq) (*daemon.QueryResp, error)
	// Health check the daemon, and installed plugins
	HealthCheck(context.Context, *daemon.HealthCheckReq) (*daemon.HealthCheckResp, error)
	// Reload plugins in the daemon. Call after installing/removing any plugins.
	ReloadPlugins(context.Context, *daemon.Empty) (*daemon.Empty, error)
	// Create a unix socket
	CreateUnixSocket(context.Context, *daemon.Empty) (*daemon.SocketResp, error)
}

DaemonHandler is an implementation of the daemon.Daemon service.

type DaemonServer

type DaemonServer interface {
	// Dump a process/container/job
	Dump(context.Context, pluginrpc.HandleEnv, ...pluginrpc.HandleOption) error
	// Freeze a process/container/job
	Freeze(context.Context, pluginrpc.HandleEnv, ...pluginrpc.HandleOption) error
	// Unfreeze a process/container/job
	Unfreeze(context.Context, pluginrpc.HandleEnv, ...pluginrpc.HandleOption) error
	// Restore a process/container/job
	Restore(context.Context, pluginrpc.HandleEnv, ...pluginrpc.HandleOption) error
	// Dump a VM
	DumpVM(context.Context, pluginrpc.HandleEnv, ...pluginrpc.HandleOption) error
	// Restore a VM
	RestoreVM(context.Context, pluginrpc.HandleEnv, ...pluginrpc.HandleOption) error
	// Run a managed process/container (job)
	Run(context.Context, pluginrpc.HandleEnv, ...pluginrpc.HandleOption) error
	// Manage a running process/container (job)
	Manage(context.Context, pluginrpc.HandleEnv, ...pluginrpc.HandleOption) error
	// Get details of a managed process/container (job)
	Get(context.Context, pluginrpc.HandleEnv, ...pluginrpc.HandleOption) error
	// List all managed processes/containers (jobs)
	List(context.Context, pluginrpc.HandleEnv, ...pluginrpc.HandleOption) error
	// Kill a managed process/container (job)
	Kill(context.Context, pluginrpc.HandleEnv, ...pluginrpc.HandleOption) error
	// Delete a managed process/container (job)
	Delete(context.Context, pluginrpc.HandleEnv, ...pluginrpc.HandleOption) error
	// Get a specific checkpoint, or the latest checkpoint for a job (if JID is provided)
	GetCheckpoint(context.Context, pluginrpc.HandleEnv, ...pluginrpc.HandleOption) error
	// List all checkpoints for a job
	ListCheckpoints(context.Context, pluginrpc.HandleEnv, ...pluginrpc.HandleOption) error
	// Delete a checkpoint
	DeleteCheckpoint(context.Context, pluginrpc.HandleEnv, ...pluginrpc.HandleOption) error
	// Generic query call
	Query(context.Context, pluginrpc.HandleEnv, ...pluginrpc.HandleOption) error
	// Health check the daemon, and installed plugins
	HealthCheck(context.Context, pluginrpc.HandleEnv, ...pluginrpc.HandleOption) error
	// Reload plugins in the daemon. Call after installing/removing any plugins.
	ReloadPlugins(context.Context, pluginrpc.HandleEnv, ...pluginrpc.HandleOption) error
	// Create a unix socket
	CreateUnixSocket(context.Context, pluginrpc.HandleEnv, ...pluginrpc.HandleOption) error
}

DaemonServer serves the daemon.Daemon service.

func NewDaemonServer

func NewDaemonServer(handler pluginrpc.Handler, daemonHandler DaemonHandler) DaemonServer

NewDaemonServer constructs a server for the daemon.Daemon service.

type DaemonSpecBuilder

DaemonSpecBuilder builds a Spec for the daemon.Daemon service.

func (DaemonSpecBuilder) Build

func (s DaemonSpecBuilder) Build() (pluginrpc.Spec, error)

Build builds a Spec for the daemon.Daemon service.

Source Files

  • daemon.pluginrpc.go

Jump to