daemongrpc

package
v1.5.1-00000000000000-... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: AGPL-3.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	Daemon_Dump_FullMethodName          = "/daemon.Daemon/Dump"
	Daemon_Restore_FullMethodName       = "/daemon.Daemon/Restore"
	Daemon_Start_FullMethodName         = "/daemon.Daemon/Start"
	Daemon_Manage_FullMethodName        = "/daemon.Daemon/Manage"
	Daemon_List_FullMethodName          = "/daemon.Daemon/List"
	Daemon_Kill_FullMethodName          = "/daemon.Daemon/Kill"
	Daemon_Delete_FullMethodName        = "/daemon.Daemon/Delete"
	Daemon_Attach_FullMethodName        = "/daemon.Daemon/Attach"
	Daemon_ReloadPlugins_FullMethodName = "/daemon.Daemon/ReloadPlugins"
)

Variables

var Daemon_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "daemon.Daemon",
	HandlerType: (*DaemonServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "Dump",
			Handler:    _Daemon_Dump_Handler,
		},
		{
			MethodName: "Restore",
			Handler:    _Daemon_Restore_Handler,
		},
		{
			MethodName: "Start",
			Handler:    _Daemon_Start_Handler,
		},
		{
			MethodName: "Manage",
			Handler:    _Daemon_Manage_Handler,
		},
		{
			MethodName: "List",
			Handler:    _Daemon_List_Handler,
		},
		{
			MethodName: "Kill",
			Handler:    _Daemon_Kill_Handler,
		},
		{
			MethodName: "Delete",
			Handler:    _Daemon_Delete_Handler,
		},
		{
			MethodName: "ReloadPlugins",
			Handler:    _Daemon_ReloadPlugins_Handler,
		},
	},
	Streams: []grpc.StreamDesc{
		{
			StreamName:    "Attach",
			Handler:       _Daemon_Attach_Handler,
			ServerStreams: true,
			ClientStreams: true,
		},
	},
	Metadata: "daemon/daemon.proto",
}

Daemon_ServiceDesc is the grpc.ServiceDesc for Daemon service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterDaemonServer

func RegisterDaemonServer(s grpc.ServiceRegistrar, srv DaemonServer)

Types

type DaemonClient

type DaemonClient interface {
	// C/R
	Dump(ctx context.Context, in *daemon.DumpReq, opts ...grpc.CallOption) (*daemon.DumpResp, error)
	Restore(ctx context.Context, in *daemon.RestoreReq, opts ...grpc.CallOption) (*daemon.RestoreResp, error)
	// Job management
	Start(ctx context.Context, in *daemon.StartReq, opts ...grpc.CallOption) (*daemon.StartResp, error)
	Manage(ctx context.Context, in *daemon.ManageReq, opts ...grpc.CallOption) (*daemon.ManageResp, error)
	List(ctx context.Context, in *daemon.ListReq, opts ...grpc.CallOption) (*daemon.ListResp, error)
	Kill(ctx context.Context, in *daemon.KillReq, opts ...grpc.CallOption) (*daemon.KillResp, error)
	Delete(ctx context.Context, in *daemon.DeleteReq, opts ...grpc.CallOption) (*daemon.DeleteResp, error)
	Attach(ctx context.Context, opts ...grpc.CallOption) (grpc.BidiStreamingClient[daemon.AttachReq, daemon.AttachResp], error)
	// Plugins
	ReloadPlugins(ctx context.Context, in *daemon.Empty, opts ...grpc.CallOption) (*daemon.Empty, error)
}

DaemonClient is the client API for Daemon service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewDaemonClient

func NewDaemonClient(cc grpc.ClientConnInterface) DaemonClient

type DaemonServer

DaemonServer is the server API for Daemon service. All implementations should embed UnimplementedDaemonServer for forward compatibility.

type Daemon_AttachClient

type Daemon_AttachClient = grpc.BidiStreamingClient[daemon.AttachReq, daemon.AttachResp]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type Daemon_AttachServer

type Daemon_AttachServer = grpc.BidiStreamingServer[daemon.AttachReq, daemon.AttachResp]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type UnimplementedDaemonServer

type UnimplementedDaemonServer struct{}

UnimplementedDaemonServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedDaemonServer) Attach

func (UnimplementedDaemonServer) Delete

func (UnimplementedDaemonServer) Dump

func (UnimplementedDaemonServer) Kill

func (UnimplementedDaemonServer) List

func (UnimplementedDaemonServer) Manage

func (UnimplementedDaemonServer) ReloadPlugins

func (UnimplementedDaemonServer) Restore

func (UnimplementedDaemonServer) Start

type UnsafeDaemonServer

type UnsafeDaemonServer interface {
	// contains filtered or unexported methods
}

UnsafeDaemonServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to DaemonServer will result in compilation errors.

Source Files

  • daemon_grpc.pb.go

Jump to