oslcv1alphagrpc

package
v1.6.1-20250217153054-... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: MIT Imports: 5 Imported by: 2

Documentation

Index

Constants

const (
	OslcService_GetPackageInfo_FullMethodName = "/chainalysis_oss.oslc.v1alpha.OslcService/GetPackageInfo"
)

Variables

var OslcService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "chainalysis_oss.oslc.v1alpha.OslcService",
	HandlerType: (*OslcServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetPackageInfo",
			Handler:    _OslcService_GetPackageInfo_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "chainalysis_oss/oslc/v1alpha/oslc.proto",
}

OslcService_ServiceDesc is the grpc.ServiceDesc for OslcService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterOslcServiceServer

func RegisterOslcServiceServer(s grpc.ServiceRegistrar, srv OslcServiceServer)

Types

type OslcServiceClient

type OslcServiceClient interface {
	GetPackageInfo(ctx context.Context, in *v1alpha.GetPackageInfoRequest, opts ...grpc.CallOption) (*v1alpha.GetPackageInfoResponse, error)
}

OslcServiceClient is the client API for OslcService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

* The OSLC service provides licensing information for software packages.

func NewOslcServiceClient

func NewOslcServiceClient(cc grpc.ClientConnInterface) OslcServiceClient

type OslcServiceServer

type OslcServiceServer interface {
	GetPackageInfo(context.Context, *v1alpha.GetPackageInfoRequest) (*v1alpha.GetPackageInfoResponse, error)
}

OslcServiceServer is the server API for OslcService service. All implementations should embed UnimplementedOslcServiceServer for forward compatibility.

* The OSLC service provides licensing information for software packages.

type UnimplementedOslcServiceServer

type UnimplementedOslcServiceServer struct{}

UnimplementedOslcServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedOslcServiceServer) GetPackageInfo

type UnsafeOslcServiceServer

type UnsafeOslcServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeOslcServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to OslcServiceServer will result in compilation errors.

Source Files

  • oslc_grpc.pb.go

Jump to