Documentation
¶
Index ¶
- Constants
- func NewCacheServiceHandler(svc CacheServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
- type CacheServiceClient
- type CacheServiceHandler
- type UnimplementedCacheServiceHandler
- func (UnimplementedCacheServiceHandler) CreateCacheEntry(context.Context, *connect.Request[gharesults.CreateCacheEntryRequest]) (*connect.Response[gharesults.CreateCacheEntryResponse], error)
- func (UnimplementedCacheServiceHandler) FinalizeCacheEntryUpload(context.Context, *connect.Request[gharesults.FinalizeCacheEntryUploadRequest]) (*connect.Response[gharesults.FinalizeCacheEntryUploadResponse], error)
- func (UnimplementedCacheServiceHandler) GetCacheEntryDownloadURL(context.Context, *connect.Request[gharesults.GetCacheEntryDownloadURLRequest]) (*connect.Response[gharesults.GetCacheEntryDownloadURLResponse], error)
Constants ¶
const ( // CacheServiceCreateCacheEntryProcedure is the fully-qualified name of the CacheService's // CreateCacheEntry RPC. CacheServiceCreateCacheEntryProcedure = "/github.actions.results.api.v1.CacheService/CreateCacheEntry" // CacheServiceFinalizeCacheEntryUploadProcedure is the fully-qualified name of the CacheService's // FinalizeCacheEntryUpload RPC. CacheServiceFinalizeCacheEntryUploadProcedure = "/github.actions.results.api.v1.CacheService/FinalizeCacheEntryUpload" // CacheServiceGetCacheEntryDownloadURLProcedure is the fully-qualified name of the CacheService's // GetCacheEntryDownloadURL RPC. CacheServiceGetCacheEntryDownloadURLProcedure = "/github.actions.results.api.v1.CacheService/GetCacheEntryDownloadURL" )
These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.
Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.
const (
// CacheServiceName is the fully-qualified name of the CacheService service.
CacheServiceName = "github.actions.results.api.v1.CacheService"
)
Variables ¶
This section is empty.
Functions ¶
func NewCacheServiceHandler ¶
func NewCacheServiceHandler(svc CacheServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
NewCacheServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.
By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.
Types ¶
type CacheServiceClient ¶
type CacheServiceClient interface {
CreateCacheEntry(context.Context, *connect.Request[gharesults.CreateCacheEntryRequest]) (*connect.Response[gharesults.CreateCacheEntryResponse], error)
FinalizeCacheEntryUpload(context.Context, *connect.Request[gharesults.FinalizeCacheEntryUploadRequest]) (*connect.Response[gharesults.FinalizeCacheEntryUploadResponse], error)
GetCacheEntryDownloadURL(context.Context, *connect.Request[gharesults.GetCacheEntryDownloadURLRequest]) (*connect.Response[gharesults.GetCacheEntryDownloadURLResponse], error)
}
CacheServiceClient is a client for the github.actions.results.api.v1.CacheService service.
func NewCacheServiceClient ¶
func NewCacheServiceClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) CacheServiceClient
NewCacheServiceClient constructs a client for the github.actions.results.api.v1.CacheService service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.
The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).
type CacheServiceHandler ¶
type CacheServiceHandler interface {
CreateCacheEntry(context.Context, *connect.Request[gharesults.CreateCacheEntryRequest]) (*connect.Response[gharesults.CreateCacheEntryResponse], error)
FinalizeCacheEntryUpload(context.Context, *connect.Request[gharesults.FinalizeCacheEntryUploadRequest]) (*connect.Response[gharesults.FinalizeCacheEntryUploadResponse], error)
GetCacheEntryDownloadURL(context.Context, *connect.Request[gharesults.GetCacheEntryDownloadURLRequest]) (*connect.Response[gharesults.GetCacheEntryDownloadURLResponse], error)
}
CacheServiceHandler is an implementation of the github.actions.results.api.v1.CacheService service.
type UnimplementedCacheServiceHandler ¶
type UnimplementedCacheServiceHandler struct{}
UnimplementedCacheServiceHandler returns CodeUnimplemented from all methods.
func (UnimplementedCacheServiceHandler) CreateCacheEntry ¶
func (UnimplementedCacheServiceHandler) CreateCacheEntry(context.Context, *connect.Request[gharesults.CreateCacheEntryRequest]) (*connect.Response[gharesults.CreateCacheEntryResponse], error)
func (UnimplementedCacheServiceHandler) FinalizeCacheEntryUpload ¶
func (UnimplementedCacheServiceHandler) FinalizeCacheEntryUpload(context.Context, *connect.Request[gharesults.FinalizeCacheEntryUploadRequest]) (*connect.Response[gharesults.FinalizeCacheEntryUploadResponse], error)
func (UnimplementedCacheServiceHandler) GetCacheEntryDownloadURL ¶
func (UnimplementedCacheServiceHandler) GetCacheEntryDownloadURL(context.Context, *connect.Request[gharesults.GetCacheEntryDownloadURLRequest]) (*connect.Response[gharesults.GetCacheEntryDownloadURLResponse], error)
Source Files
¶
- gharesults.connect.go