orcav3grpc

package
v1.6.1-20260123205629-... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	OpenRcaService_StreamCoreMetrics_FullMethodName = "/xds.service.orca.v3.OpenRcaService/StreamCoreMetrics"
)

Variables

var OpenRcaService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "xds.service.orca.v3.OpenRcaService",
	HandlerType: (*OpenRcaServiceServer)(nil),
	Methods:     []grpc.MethodDesc{},
	Streams: []grpc.StreamDesc{
		{
			StreamName:    "StreamCoreMetrics",
			Handler:       _OpenRcaService_StreamCoreMetrics_Handler,
			ServerStreams: true,
		},
	},
	Metadata: "xds/service/orca/v3/orca.proto",
}

OpenRcaService_ServiceDesc is the grpc.ServiceDesc for OpenRcaService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterOpenRcaServiceServer

func RegisterOpenRcaServiceServer(s grpc.ServiceRegistrar, srv OpenRcaServiceServer)

Types

type OpenRcaServiceClient

type OpenRcaServiceClient interface {
	StreamCoreMetrics(ctx context.Context, in *v3.OrcaLoadReportRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[v31.OrcaLoadReport], error)
}

OpenRcaServiceClient is the client API for OpenRcaService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

Out-of-band (OOB) load reporting service for the additional load reporting agent that does not sit in the request path. Reports are periodically sampled with sufficient frequency to provide temporal association with requests. OOB reporting compensates the limitation of in-band reporting in revealing costs for backends that do not provide a steady stream of telemetry such as long running stream operations and zero QPS services. This is a server streaming service, client needs to terminate current RPC and initiate a new call to change backend reporting frequency.

func NewOpenRcaServiceClient

func NewOpenRcaServiceClient(cc grpc.ClientConnInterface) OpenRcaServiceClient

type OpenRcaServiceServer

type OpenRcaServiceServer interface {
	StreamCoreMetrics(*v3.OrcaLoadReportRequest, grpc.ServerStreamingServer[v31.OrcaLoadReport]) error
}

OpenRcaServiceServer is the server API for OpenRcaService service. All implementations should embed UnimplementedOpenRcaServiceServer for forward compatibility.

Out-of-band (OOB) load reporting service for the additional load reporting agent that does not sit in the request path. Reports are periodically sampled with sufficient frequency to provide temporal association with requests. OOB reporting compensates the limitation of in-band reporting in revealing costs for backends that do not provide a steady stream of telemetry such as long running stream operations and zero QPS services. This is a server streaming service, client needs to terminate current RPC and initiate a new call to change backend reporting frequency.

type OpenRcaService_StreamCoreMetricsClient

type OpenRcaService_StreamCoreMetricsClient = grpc.ServerStreamingClient[v31.OrcaLoadReport]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type OpenRcaService_StreamCoreMetricsServer

type OpenRcaService_StreamCoreMetricsServer = grpc.ServerStreamingServer[v31.OrcaLoadReport]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type UnimplementedOpenRcaServiceServer

type UnimplementedOpenRcaServiceServer struct{}

UnimplementedOpenRcaServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedOpenRcaServiceServer) StreamCoreMetrics

type UnsafeOpenRcaServiceServer

type UnsafeOpenRcaServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeOpenRcaServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to OpenRcaServiceServer will result in compilation errors.

Source Files

  • orca_grpc.pb.go

Jump to