Documentation
¶
Index ¶
- Variables
- type OrcaLoadReport
- func (x *OrcaLoadReport) GetApplicationUtilization() float64
- func (x *OrcaLoadReport) GetCpuUtilization() float64
- func (x *OrcaLoadReport) GetEps() float64
- func (x *OrcaLoadReport) GetMemUtilization() float64
- func (x *OrcaLoadReport) GetNamedMetrics() map[string]float64
- func (x *OrcaLoadReport) GetRequestCost() map[string]float64
- func (x *OrcaLoadReport) GetRps() uint64deprecated
- func (x *OrcaLoadReport) GetRpsFractional() float64
- func (x *OrcaLoadReport) GetUtilization() map[string]float64
- func (*OrcaLoadReport) ProtoMessage()
- func (x *OrcaLoadReport) ProtoReflect() protoreflect.Message
- func (x *OrcaLoadReport) Reset()
- func (x *OrcaLoadReport) SetApplicationUtilization(v float64)
- func (x *OrcaLoadReport) SetCpuUtilization(v float64)
- func (x *OrcaLoadReport) SetEps(v float64)
- func (x *OrcaLoadReport) SetMemUtilization(v float64)
- func (x *OrcaLoadReport) SetNamedMetrics(v map[string]float64)
- func (x *OrcaLoadReport) SetRequestCost(v map[string]float64)
- func (x *OrcaLoadReport) SetRps(v uint64)deprecated
- func (x *OrcaLoadReport) SetRpsFractional(v float64)
- func (x *OrcaLoadReport) SetUtilization(v map[string]float64)
- func (x *OrcaLoadReport) String() string
- type OrcaLoadReport_builder
Constants ¶
This section is empty.
Variables ¶
var File_xds_data_orca_v3_orca_load_report_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type OrcaLoadReport ¶
type OrcaLoadReport struct {
// CPU utilization expressed as a fraction of available CPU resources. This
// should be derived from the latest sample or measurement. The value may be
// larger than 1.0 when the usage exceeds the reporter dependent notion of
// soft limits.
CpuUtilization float64 `protobuf:"fixed64,1,opt,name=cpu_utilization,json=cpuUtilization,proto3" json:"cpu_utilization,omitempty"`
// Memory utilization expressed as a fraction of available memory
// resources. This should be derived from the latest sample or measurement.
MemUtilization float64 `protobuf:"fixed64,2,opt,name=mem_utilization,json=memUtilization,proto3" json:"mem_utilization,omitempty"`
// Total RPS being served by an endpoint. This should cover all services that an endpoint is
// responsible for.
// Deprecated -- use “rps_fractional“ field instead.
//
// Deprecated: Marked as deprecated in xds/data/orca/v3/orca_load_report.proto.
Rps uint64 `protobuf:"varint,3,opt,name=rps,proto3" json:"rps,omitempty"`
// Application specific requests costs. Each value is an absolute cost (e.g. 3487 bytes of
// storage) associated with the request.
RequestCost map[string]float64 `` /* 170-byte string literal not displayed */
// Resource utilization values. Each value is expressed as a fraction of total resources
// available, derived from the latest sample or measurement.
Utilization map[string]float64 `` /* 151-byte string literal not displayed */
// Total RPS being served by an endpoint. This should cover all services that an endpoint is
// responsible for.
RpsFractional float64 `protobuf:"fixed64,6,opt,name=rps_fractional,json=rpsFractional,proto3" json:"rps_fractional,omitempty"`
// Total EPS (errors/second) being served by an endpoint. This should cover
// all services that an endpoint is responsible for.
Eps float64 `protobuf:"fixed64,7,opt,name=eps,proto3" json:"eps,omitempty"`
// Application specific opaque metrics.
NamedMetrics map[string]float64 `` /* 173-byte string literal not displayed */
// Application specific utilization expressed as a fraction of available
// resources. For example, an application may report the max of CPU and memory
// utilization for better load balancing if it is both CPU and memory bound.
// This should be derived from the latest sample or measurement.
// The value may be larger than 1.0 when the usage exceeds the reporter
// dependent notion of soft limits.
ApplicationUtilization float64 `` /* 129-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*OrcaLoadReport) GetApplicationUtilization ¶
func (x *OrcaLoadReport) GetApplicationUtilization() float64
func (*OrcaLoadReport) GetCpuUtilization ¶
func (x *OrcaLoadReport) GetCpuUtilization() float64
func (*OrcaLoadReport) GetEps ¶
func (x *OrcaLoadReport) GetEps() float64
func (*OrcaLoadReport) GetMemUtilization ¶
func (x *OrcaLoadReport) GetMemUtilization() float64
func (*OrcaLoadReport) GetNamedMetrics ¶
func (x *OrcaLoadReport) GetNamedMetrics() map[string]float64
func (*OrcaLoadReport) GetRequestCost ¶
func (x *OrcaLoadReport) GetRequestCost() map[string]float64
func (*OrcaLoadReport) GetRps
deprecated
func (x *OrcaLoadReport) GetRps() uint64
Deprecated: Marked as deprecated in xds/data/orca/v3/orca_load_report.proto.
func (*OrcaLoadReport) GetRpsFractional ¶
func (x *OrcaLoadReport) GetRpsFractional() float64
func (*OrcaLoadReport) GetUtilization ¶
func (x *OrcaLoadReport) GetUtilization() map[string]float64
func (*OrcaLoadReport) ProtoMessage ¶
func (*OrcaLoadReport) ProtoMessage()
func (*OrcaLoadReport) ProtoReflect ¶
func (x *OrcaLoadReport) ProtoReflect() protoreflect.Message
func (*OrcaLoadReport) Reset ¶
func (x *OrcaLoadReport) Reset()
func (*OrcaLoadReport) SetApplicationUtilization ¶
func (x *OrcaLoadReport) SetApplicationUtilization(v float64)
func (*OrcaLoadReport) SetCpuUtilization ¶
func (x *OrcaLoadReport) SetCpuUtilization(v float64)
func (*OrcaLoadReport) SetEps ¶
func (x *OrcaLoadReport) SetEps(v float64)
func (*OrcaLoadReport) SetMemUtilization ¶
func (x *OrcaLoadReport) SetMemUtilization(v float64)
func (*OrcaLoadReport) SetNamedMetrics ¶
func (x *OrcaLoadReport) SetNamedMetrics(v map[string]float64)
func (*OrcaLoadReport) SetRequestCost ¶
func (x *OrcaLoadReport) SetRequestCost(v map[string]float64)
func (*OrcaLoadReport) SetRps
deprecated
func (x *OrcaLoadReport) SetRps(v uint64)
Deprecated: Marked as deprecated in xds/data/orca/v3/orca_load_report.proto.
func (*OrcaLoadReport) SetRpsFractional ¶
func (x *OrcaLoadReport) SetRpsFractional(v float64)
func (*OrcaLoadReport) SetUtilization ¶
func (x *OrcaLoadReport) SetUtilization(v map[string]float64)
func (*OrcaLoadReport) String ¶
func (x *OrcaLoadReport) String() string
type OrcaLoadReport_builder ¶
type OrcaLoadReport_builder struct {
// CPU utilization expressed as a fraction of available CPU resources. This
// should be derived from the latest sample or measurement. The value may be
// larger than 1.0 when the usage exceeds the reporter dependent notion of
// soft limits.
CpuUtilization float64
// Memory utilization expressed as a fraction of available memory
// resources. This should be derived from the latest sample or measurement.
MemUtilization float64
// Total RPS being served by an endpoint. This should cover all services that an endpoint is
// responsible for.
// Deprecated -- use “rps_fractional“ field instead.
//
// Deprecated: Marked as deprecated in xds/data/orca/v3/orca_load_report.proto.
Rps uint64
// Application specific requests costs. Each value is an absolute cost (e.g. 3487 bytes of
// storage) associated with the request.
RequestCost map[string]float64
// Resource utilization values. Each value is expressed as a fraction of total resources
// available, derived from the latest sample or measurement.
Utilization map[string]float64
// Total RPS being served by an endpoint. This should cover all services that an endpoint is
// responsible for.
RpsFractional float64
// Total EPS (errors/second) being served by an endpoint. This should cover
// all services that an endpoint is responsible for.
Eps float64
// Application specific opaque metrics.
NamedMetrics map[string]float64
// Application specific utilization expressed as a fraction of available
// resources. For example, an application may report the max of CPU and memory
// utilization for better load balancing if it is both CPU and memory bound.
// This should be derived from the latest sample or measurement.
// The value may be larger than 1.0 when the usage exceeds the reporter
// dependent notion of soft limits.
ApplicationUtilization float64
// contains filtered or unexported fields
}
func (OrcaLoadReport_builder) Build ¶
func (b0 OrcaLoadReport_builder) Build() *OrcaLoadReport
Source Files
¶
- orca_load_report.pb.go
Click to show internal directories.
Click to hide internal directories.