elizav1pluginrpc

package
v0.5.0-20230913231627-... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

const (
	// ElizaServiceSayPath is the path of the ElizaService's Say RPC.
	ElizaServiceSayPath = "/connectrpc.eliza.v1.ElizaService/Say"
)

Variables

This section is empty.

Functions

func RegisterElizaServiceServer

func RegisterElizaServiceServer(serverRegistrar pluginrpc.ServerRegistrar, elizaServiceServer ElizaServiceServer)

RegisterElizaServiceServer registers the server for the connectrpc.eliza.v1.ElizaService service.

Types

type ElizaServiceClient

type ElizaServiceClient interface {
	// Say is a unary RPC. Eliza responds to the prompt with a single sentence.
	Say(context.Context, *v1.SayRequest, ...pluginrpc.CallOption) (*v1.SayResponse, error)
}

ElizaServiceClient is a client for the connectrpc.eliza.v1.ElizaService service.

func NewElizaServiceClient

func NewElizaServiceClient(client pluginrpc.Client) (ElizaServiceClient, error)

NewElizaServiceClient constructs a client for the connectrpc.eliza.v1.ElizaService service.

type ElizaServiceHandler

type ElizaServiceHandler interface {
	// Say is a unary RPC. Eliza responds to the prompt with a single sentence.
	Say(context.Context, *v1.SayRequest) (*v1.SayResponse, error)
}

ElizaServiceHandler is an implementation of the connectrpc.eliza.v1.ElizaService service.

type ElizaServiceServer

type ElizaServiceServer interface {
	// Say is a unary RPC. Eliza responds to the prompt with a single sentence.
	Say(context.Context, pluginrpc.HandleEnv, ...pluginrpc.HandleOption) error
}

ElizaServiceServer serves the connectrpc.eliza.v1.ElizaService service.

func NewElizaServiceServer

func NewElizaServiceServer(handler pluginrpc.Handler, elizaServiceHandler ElizaServiceHandler) ElizaServiceServer

NewElizaServiceServer constructs a server for the connectrpc.eliza.v1.ElizaService service.

type ElizaServiceSpecBuilder

type ElizaServiceSpecBuilder struct {
	Say []pluginrpc.ProcedureOption
}

ElizaServiceSpecBuilder builds a Spec for the connectrpc.eliza.v1.ElizaService service.

func (ElizaServiceSpecBuilder) Build

Build builds a Spec for the connectrpc.eliza.v1.ElizaService service.

Source Files

  • eliza.pluginrpc.go

Jump to