tagv1connect

package
v1.19.1-20240905100711... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	// BaseListModuleProcedure is the fully-qualified name of the Base's ListModule RPC.
	BaseListModuleProcedure = "/tag.v1.Base/ListModule"
	// BaseSetModuleProcedure is the fully-qualified name of the Base's SetModule RPC.
	BaseSetModuleProcedure = "/tag.v1.Base/SetModule"
	// BaseSetModuleInfoProcedure is the fully-qualified name of the Base's SetModuleInfo RPC.
	BaseSetModuleInfoProcedure = "/tag.v1.Base/SetModuleInfo"
	// BaseDeleteModuleProcedure is the fully-qualified name of the Base's DeleteModule RPC.
	BaseDeleteModuleProcedure = "/tag.v1.Base/DeleteModule"
	// BaseUpdateModuleVisibleTypeProcedure is the fully-qualified name of the Base's
	// UpdateModuleVisibleType RPC.
	BaseUpdateModuleVisibleTypeProcedure = "/tag.v1.Base/UpdateModuleVisibleType"
	// BaseListTypeProcedure is the fully-qualified name of the Base's ListType RPC.
	BaseListTypeProcedure = "/tag.v1.Base/ListType"
	// BaseSetTypeProcedure is the fully-qualified name of the Base's SetType RPC.
	BaseSetTypeProcedure = "/tag.v1.Base/SetType"
	// BaseSetTypeInfoProcedure is the fully-qualified name of the Base's SetTypeInfo RPC.
	BaseSetTypeInfoProcedure = "/tag.v1.Base/SetTypeInfo"
	// BaseDeleteTypeProcedure is the fully-qualified name of the Base's DeleteType RPC.
	BaseDeleteTypeProcedure = "/tag.v1.Base/DeleteType"
	// BaseUpdateTypeInheritProcedure is the fully-qualified name of the Base's UpdateTypeInherit RPC.
	BaseUpdateTypeInheritProcedure = "/tag.v1.Base/UpdateTypeInherit"
	// BaseUpdateTypeExclusiveProcedure is the fully-qualified name of the Base's UpdateTypeExclusive
	// RPC.
	BaseUpdateTypeExclusiveProcedure = "/tag.v1.Base/UpdateTypeExclusive"
	// BaseListTagProcedure is the fully-qualified name of the Base's ListTag RPC.
	BaseListTagProcedure = "/tag.v1.Base/ListTag"
	// BaseAddTagProcedure is the fully-qualified name of the Base's AddTag RPC.
	BaseAddTagProcedure = "/tag.v1.Base/AddTag"
	// BaseSetTagProcedure is the fully-qualified name of the Base's SetTag RPC.
	BaseSetTagProcedure = "/tag.v1.Base/SetTag"
	// BaseSetTagInfoProcedure is the fully-qualified name of the Base's SetTagInfo RPC.
	BaseSetTagInfoProcedure = "/tag.v1.Base/SetTagInfo"
	// BaseDeleteTagProcedure is the fully-qualified name of the Base's DeleteTag RPC.
	BaseDeleteTagProcedure = "/tag.v1.Base/DeleteTag"
	// BaseUpdateTagTypeProcedure is the fully-qualified name of the Base's UpdateTagType RPC.
	BaseUpdateTagTypeProcedure = "/tag.v1.Base/UpdateTagType"
	// BaseUpdateTagParentProcedure is the fully-qualified name of the Base's UpdateTagParent RPC.
	BaseUpdateTagParentProcedure = "/tag.v1.Base/UpdateTagParent"
)

These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.

Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.

const (
	// InternalGetTagIDTreeizeProcedure is the fully-qualified name of the Internal's GetTagIDTreeize
	// RPC.
	InternalGetTagIDTreeizeProcedure = "/tag.v1.Internal/GetTagIDTreeize"
	// InternalBindRelationProcedure is the fully-qualified name of the Internal's BindRelation RPC.
	InternalBindRelationProcedure = "/tag.v1.Internal/BindRelation"
	// InternalUnbindRelationProcedure is the fully-qualified name of the Internal's UnbindRelation RPC.
	InternalUnbindRelationProcedure = "/tag.v1.Internal/UnbindRelation"
	// InternalGetAllByModuleProcedure is the fully-qualified name of the Internal's GetAllByModule RPC.
	InternalGetAllByModuleProcedure = "/tag.v1.Internal/GetAllByModule"
	// InternalRegisterModuleProcedure is the fully-qualified name of the Internal's RegisterModule RPC.
	InternalRegisterModuleProcedure = "/tag.v1.Internal/RegisterModule"
	// InternalRegisterTagProcedure is the fully-qualified name of the Internal's RegisterTag RPC.
	InternalRegisterTagProcedure = "/tag.v1.Internal/RegisterTag"
	// InternalSetTypeWithModuleProcedure is the fully-qualified name of the Internal's
	// SetTypeWithModule RPC.
	InternalSetTypeWithModuleProcedure = "/tag.v1.Internal/SetTypeWithModule"
	// InternalDeleteTypeWithModuleProcedure is the fully-qualified name of the Internal's
	// DeleteTypeWithModule RPC.
	InternalDeleteTypeWithModuleProcedure = "/tag.v1.Internal/DeleteTypeWithModule"
	// InternalSetTagWithModuleProcedure is the fully-qualified name of the Internal's SetTagWithModule
	// RPC.
	InternalSetTagWithModuleProcedure = "/tag.v1.Internal/SetTagWithModule"
	// InternalDeleteTagWithModuleProcedure is the fully-qualified name of the Internal's
	// DeleteTagWithModule RPC.
	InternalDeleteTagWithModuleProcedure = "/tag.v1.Internal/DeleteTagWithModule"
)

These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.

Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.

const (
	// RelationshipListRelationProcedure is the fully-qualified name of the Relationship's ListRelation
	// RPC.
	RelationshipListRelationProcedure = "/tag.v1.Relationship/ListRelation"
	// RelationshipSetRelationProcedure is the fully-qualified name of the Relationship's SetRelation
	// RPC.
	RelationshipSetRelationProcedure = "/tag.v1.Relationship/SetRelation"
	// RelationshipDeleteRelationProcedure is the fully-qualified name of the Relationship's
	// DeleteRelation RPC.
	RelationshipDeleteRelationProcedure = "/tag.v1.Relationship/DeleteRelation"
	// RelationshipDestroyExternalRelationProcedure is the fully-qualified name of the Relationship's
	// DestroyExternalRelation RPC.
	RelationshipDestroyExternalRelationProcedure = "/tag.v1.Relationship/DestroyExternalRelation"
	// RelationshipDestroyTagRelationProcedure is the fully-qualified name of the Relationship's
	// DestroyTagRelation RPC.
	RelationshipDestroyTagRelationProcedure = "/tag.v1.Relationship/DestroyTagRelation"
)

These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.

Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.

const (
	// BaseName is the fully-qualified name of the Base service.
	BaseName = "tag.v1.Base"
)
const (
	// InternalName is the fully-qualified name of the Internal service.
	InternalName = "tag.v1.Internal"
)
const (
	// RelationshipName is the fully-qualified name of the Relationship service.
	RelationshipName = "tag.v1.Relationship"
)

Variables

This section is empty.

Functions

func NewBaseHandler

func NewBaseHandler(svc BaseHandler, opts ...connect.HandlerOption) (string, http.Handler)

NewBaseHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.

By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.

func NewInternalHandler

func NewInternalHandler(svc InternalHandler, opts ...connect.HandlerOption) (string, http.Handler)

NewInternalHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.

By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.

func NewRelationshipHandler

func NewRelationshipHandler(svc RelationshipHandler, opts ...connect.HandlerOption) (string, http.Handler)

NewRelationshipHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.

By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.

Types

type BaseClient

type BaseClient interface {
	ListModule(context.Context, *connect.Request[v1.ListModuleRequest]) (*connect.Response[v1.ListModuleResponse], error)
	SetModule(context.Context, *connect.Request[v1.SetModuleRequest]) (*connect.Response[v1.SetModuleResponse], error)
	SetModuleInfo(context.Context, *connect.Request[v1.SetModuleInfoRequest]) (*connect.Response[v1.SetModuleInfoResponse], error)
	DeleteModule(context.Context, *connect.Request[v1.DeleteModuleRequest]) (*connect.Response[v1.DeleteModuleResponse], error)
	UpdateModuleVisibleType(context.Context, *connect.Request[v1.UpdateModuleVisibleTypeRequest]) (*connect.Response[v1.UpdateModuleVisibleTypeResponse], error)
	ListType(context.Context, *connect.Request[v1.ListTypeRequest]) (*connect.Response[v1.ListTypeResponse], error)
	SetType(context.Context, *connect.Request[v1.SetTypeRequest]) (*connect.Response[v1.SetTypeResponse], error)
	SetTypeInfo(context.Context, *connect.Request[v1.SetTypeInfoRequest]) (*connect.Response[v1.SetTypeInfoResponse], error)
	DeleteType(context.Context, *connect.Request[v1.DeleteTypeRequest]) (*connect.Response[v1.DeleteTypeResponse], error)
	UpdateTypeInherit(context.Context, *connect.Request[v1.UpdateTypeInheritRequest]) (*connect.Response[v1.UpdateTypeInheritResponse], error)
	UpdateTypeExclusive(context.Context, *connect.Request[v1.UpdateTypeExclusiveRequest]) (*connect.Response[v1.UpdateTypeExclusiveResponse], error)
	ListTag(context.Context, *connect.Request[v1.ListTagRequest]) (*connect.Response[v1.ListTagResponse], error)
	AddTag(context.Context, *connect.Request[v1.AddTagRequest]) (*connect.Response[v1.AddTagResponse], error)
	SetTag(context.Context, *connect.Request[v1.SetTagRequest]) (*connect.Response[v1.SetTagResponse], error)
	SetTagInfo(context.Context, *connect.Request[v1.SetTagInfoRequest]) (*connect.Response[v1.SetTagInfoResponse], error)
	DeleteTag(context.Context, *connect.Request[v1.DeleteTagRequest]) (*connect.Response[v1.DeleteTagResponse], error)
	UpdateTagType(context.Context, *connect.Request[v1.UpdateTagTypeRequest]) (*connect.Response[v1.UpdateTagTypeResponse], error)
	UpdateTagParent(context.Context, *connect.Request[v1.UpdateTagParentRequest]) (*connect.Response[v1.UpdateTagParentResponse], error)
}

BaseClient is a client for the tag.v1.Base service.

func NewBaseClient

func NewBaseClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) BaseClient

NewBaseClient constructs a client for the tag.v1.Base service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.

The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).

type BaseHandler

type BaseHandler interface {
	ListModule(context.Context, *connect.Request[v1.ListModuleRequest]) (*connect.Response[v1.ListModuleResponse], error)
	SetModule(context.Context, *connect.Request[v1.SetModuleRequest]) (*connect.Response[v1.SetModuleResponse], error)
	SetModuleInfo(context.Context, *connect.Request[v1.SetModuleInfoRequest]) (*connect.Response[v1.SetModuleInfoResponse], error)
	DeleteModule(context.Context, *connect.Request[v1.DeleteModuleRequest]) (*connect.Response[v1.DeleteModuleResponse], error)
	UpdateModuleVisibleType(context.Context, *connect.Request[v1.UpdateModuleVisibleTypeRequest]) (*connect.Response[v1.UpdateModuleVisibleTypeResponse], error)
	ListType(context.Context, *connect.Request[v1.ListTypeRequest]) (*connect.Response[v1.ListTypeResponse], error)
	SetType(context.Context, *connect.Request[v1.SetTypeRequest]) (*connect.Response[v1.SetTypeResponse], error)
	SetTypeInfo(context.Context, *connect.Request[v1.SetTypeInfoRequest]) (*connect.Response[v1.SetTypeInfoResponse], error)
	DeleteType(context.Context, *connect.Request[v1.DeleteTypeRequest]) (*connect.Response[v1.DeleteTypeResponse], error)
	UpdateTypeInherit(context.Context, *connect.Request[v1.UpdateTypeInheritRequest]) (*connect.Response[v1.UpdateTypeInheritResponse], error)
	UpdateTypeExclusive(context.Context, *connect.Request[v1.UpdateTypeExclusiveRequest]) (*connect.Response[v1.UpdateTypeExclusiveResponse], error)
	ListTag(context.Context, *connect.Request[v1.ListTagRequest]) (*connect.Response[v1.ListTagResponse], error)
	AddTag(context.Context, *connect.Request[v1.AddTagRequest]) (*connect.Response[v1.AddTagResponse], error)
	SetTag(context.Context, *connect.Request[v1.SetTagRequest]) (*connect.Response[v1.SetTagResponse], error)
	SetTagInfo(context.Context, *connect.Request[v1.SetTagInfoRequest]) (*connect.Response[v1.SetTagInfoResponse], error)
	DeleteTag(context.Context, *connect.Request[v1.DeleteTagRequest]) (*connect.Response[v1.DeleteTagResponse], error)
	UpdateTagType(context.Context, *connect.Request[v1.UpdateTagTypeRequest]) (*connect.Response[v1.UpdateTagTypeResponse], error)
	UpdateTagParent(context.Context, *connect.Request[v1.UpdateTagParentRequest]) (*connect.Response[v1.UpdateTagParentResponse], error)
}

BaseHandler is an implementation of the tag.v1.Base service.

type InternalClient

InternalClient is a client for the tag.v1.Internal service.

func NewInternalClient

func NewInternalClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) InternalClient

NewInternalClient constructs a client for the tag.v1.Internal service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.

The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).

type RelationshipClient

RelationshipClient is a client for the tag.v1.Relationship service.

func NewRelationshipClient

func NewRelationshipClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) RelationshipClient

NewRelationshipClient constructs a client for the tag.v1.Relationship service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.

The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).

type UnimplementedBaseHandler

type UnimplementedBaseHandler struct{}

UnimplementedBaseHandler returns CodeUnimplemented from all methods.

func (UnimplementedBaseHandler) AddTag

func (UnimplementedBaseHandler) DeleteModule

func (UnimplementedBaseHandler) DeleteTag

func (UnimplementedBaseHandler) DeleteType

func (UnimplementedBaseHandler) ListModule

func (UnimplementedBaseHandler) ListTag

func (UnimplementedBaseHandler) ListType

func (UnimplementedBaseHandler) SetModule

func (UnimplementedBaseHandler) SetModuleInfo

func (UnimplementedBaseHandler) SetTag

func (UnimplementedBaseHandler) SetTagInfo

func (UnimplementedBaseHandler) SetType

func (UnimplementedBaseHandler) SetTypeInfo

func (UnimplementedBaseHandler) UpdateModuleVisibleType

func (UnimplementedBaseHandler) UpdateTagParent

func (UnimplementedBaseHandler) UpdateTagType

func (UnimplementedBaseHandler) UpdateTypeExclusive

func (UnimplementedBaseHandler) UpdateTypeInherit

type UnimplementedInternalHandler

type UnimplementedInternalHandler struct{}

UnimplementedInternalHandler returns CodeUnimplemented from all methods.

func (UnimplementedInternalHandler) BindRelation

func (UnimplementedInternalHandler) DeleteTagWithModule

func (UnimplementedInternalHandler) DeleteTypeWithModule

func (UnimplementedInternalHandler) GetAllByModule

func (UnimplementedInternalHandler) GetTagIDTreeize

func (UnimplementedInternalHandler) RegisterModule

func (UnimplementedInternalHandler) RegisterTag

func (UnimplementedInternalHandler) SetTagWithModule

func (UnimplementedInternalHandler) SetTypeWithModule

func (UnimplementedInternalHandler) UnbindRelation

type UnimplementedRelationshipHandler

type UnimplementedRelationshipHandler struct{}

UnimplementedRelationshipHandler returns CodeUnimplemented from all methods.

func (UnimplementedRelationshipHandler) DeleteRelation

func (UnimplementedRelationshipHandler) DestroyExternalRelation

func (UnimplementedRelationshipHandler) DestroyTagRelation

func (UnimplementedRelationshipHandler) ListRelation

func (UnimplementedRelationshipHandler) SetRelation

Source Files

  • service_base.connect.go
  • service_internal.connect.go
  • service_relation.connect.go

Jump to