userv1connect

package
v1.19.1-20240905132201... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	// BaseListUserProcedure is the fully-qualified name of the Base's ListUser RPC.
	BaseListUserProcedure = "/user.v1.Base/ListUser"
	// BaseAddUserProcedure is the fully-qualified name of the Base's AddUser RPC.
	BaseAddUserProcedure = "/user.v1.Base/AddUser"
	// BaseSetUserProcedure is the fully-qualified name of the Base's SetUser RPC.
	BaseSetUserProcedure = "/user.v1.Base/SetUser"
	// BaseSetUserInfoProcedure is the fully-qualified name of the Base's SetUserInfo RPC.
	BaseSetUserInfoProcedure = "/user.v1.Base/SetUserInfo"
	// BaseDeleteUserProcedure is the fully-qualified name of the Base's DeleteUser RPC.
	BaseDeleteUserProcedure = "/user.v1.Base/DeleteUser"
	// BaseSetUserAuthProcedure is the fully-qualified name of the Base's SetUserAuth RPC.
	BaseSetUserAuthProcedure = "/user.v1.Base/SetUserAuth"
	// BaseDeleteUserAuthProcedure is the fully-qualified name of the Base's DeleteUserAuth RPC.
	BaseDeleteUserAuthProcedure = "/user.v1.Base/DeleteUserAuth"
)

These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.

Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.

const (
	// TagGetTagProcedure is the fully-qualified name of the Tag's GetTag RPC.
	TagGetTagProcedure = "/user.v1.Tag/GetTag"
	// TagSetTagTypeProcedure is the fully-qualified name of the Tag's SetTagType RPC.
	TagSetTagTypeProcedure = "/user.v1.Tag/SetTagType"
	// TagDeleteTagTypeProcedure is the fully-qualified name of the Tag's DeleteTagType RPC.
	TagDeleteTagTypeProcedure = "/user.v1.Tag/DeleteTagType"
	// TagSetTagProcedure is the fully-qualified name of the Tag's SetTag RPC.
	TagSetTagProcedure = "/user.v1.Tag/SetTag"
	// TagDeleteTagProcedure is the fully-qualified name of the Tag's DeleteTag RPC.
	TagDeleteTagProcedure = "/user.v1.Tag/DeleteTag"
	// TagSetUserTagProcedure is the fully-qualified name of the Tag's SetUserTag RPC.
	TagSetUserTagProcedure = "/user.v1.Tag/SetUserTag"
	// TagDeleteUserTagProcedure is the fully-qualified name of the Tag's DeleteUserTag RPC.
	TagDeleteUserTagProcedure = "/user.v1.Tag/DeleteUserTag"
)

These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.

Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.

const (
	// BaseName is the fully-qualified name of the Base service.
	BaseName = "user.v1.Base"
)
const (
	// TagName is the fully-qualified name of the Tag service.
	TagName = "user.v1.Tag"
)

Variables

This section is empty.

Functions

func NewBaseHandler

func NewBaseHandler(svc BaseHandler, opts ...connect.HandlerOption) (string, http.Handler)

NewBaseHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.

By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.

func NewTagHandler

func NewTagHandler(svc TagHandler, opts ...connect.HandlerOption) (string, http.Handler)

NewTagHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.

By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.

Types

type BaseClient

BaseClient is a client for the user.v1.Base service.

func NewBaseClient

func NewBaseClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) BaseClient

NewBaseClient constructs a client for the user.v1.Base service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.

The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).

type TagClient

TagClient is a client for the user.v1.Tag service.

func NewTagClient

func NewTagClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) TagClient

NewTagClient constructs a client for the user.v1.Tag service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.

The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).

type UnimplementedBaseHandler

type UnimplementedBaseHandler struct{}

UnimplementedBaseHandler returns CodeUnimplemented from all methods.

func (UnimplementedBaseHandler) AddUser

func (UnimplementedBaseHandler) DeleteUser

func (UnimplementedBaseHandler) DeleteUserAuth

func (UnimplementedBaseHandler) ListUser

func (UnimplementedBaseHandler) SetUser

func (UnimplementedBaseHandler) SetUserAuth

func (UnimplementedBaseHandler) SetUserInfo

type UnimplementedTagHandler

type UnimplementedTagHandler struct{}

UnimplementedTagHandler returns CodeUnimplemented from all methods.

func (UnimplementedTagHandler) DeleteTag

func (UnimplementedTagHandler) DeleteTagType

func (UnimplementedTagHandler) DeleteUserTag

func (UnimplementedTagHandler) GetTag

func (UnimplementedTagHandler) SetTag

func (UnimplementedTagHandler) SetTagType

func (UnimplementedTagHandler) SetUserTag

Source Files

  • service_base.connect.go
  • service_tag.connect.go

Jump to