mercuryv1grpc

package
v1.6.2-20240607072103-... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	Mercury_Deploy_FullMethodName    = "/ctfhub.mercury.v1.Mercury/Deploy"
	Mercury_Inspect_FullMethodName   = "/ctfhub.mercury.v1.Mercury/Inspect"
	Mercury_List_FullMethodName      = "/ctfhub.mercury.v1.Mercury/List"
	Mercury_Remove_FullMethodName    = "/ctfhub.mercury.v1.Mercury/Remove"
	Mercury_Log_FullMethodName       = "/ctfhub.mercury.v1.Mercury/Log"
	Mercury_Exec_FullMethodName      = "/ctfhub.mercury.v1.Mercury/Exec"
	Mercury_Event_FullMethodName     = "/ctfhub.mercury.v1.Mercury/Event"
	Mercury_Watch_FullMethodName     = "/ctfhub.mercury.v1.Mercury/Watch"
	Mercury_LogStream_FullMethodName = "/ctfhub.mercury.v1.Mercury/LogStream"
)

Variables

var Mercury_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "ctfhub.mercury.v1.Mercury",
	HandlerType: (*MercuryServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "Deploy",
			Handler:    _Mercury_Deploy_Handler,
		},
		{
			MethodName: "Inspect",
			Handler:    _Mercury_Inspect_Handler,
		},
		{
			MethodName: "List",
			Handler:    _Mercury_List_Handler,
		},
		{
			MethodName: "Remove",
			Handler:    _Mercury_Remove_Handler,
		},
		{
			MethodName: "Log",
			Handler:    _Mercury_Log_Handler,
		},
		{
			MethodName: "Exec",
			Handler:    _Mercury_Exec_Handler,
		},
		{
			MethodName: "Event",
			Handler:    _Mercury_Event_Handler,
		},
	},
	Streams: []grpc.StreamDesc{
		{
			StreamName:    "Watch",
			Handler:       _Mercury_Watch_Handler,
			ServerStreams: true,
		},
		{
			StreamName:    "LogStream",
			Handler:       _Mercury_LogStream_Handler,
			ServerStreams: true,
		},
	},
	Metadata: "mercury.proto",
}

Mercury_ServiceDesc is the grpc.ServiceDesc for Mercury service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterMercuryServer

func RegisterMercuryServer(s grpc.ServiceRegistrar, srv MercuryServer)

Types

type MercuryClient

type MercuryClient interface {
	Deploy(ctx context.Context, in *_go.DeployReq, opts ...grpc.CallOption) (*_go.PodRsp, error)
	Inspect(ctx context.Context, in *_go.NameReq, opts ...grpc.CallOption) (*_go.PodRsp, error)
	List(ctx context.Context, in *_go.ListReq, opts ...grpc.CallOption) (*_go.ListRsp, error)
	Remove(ctx context.Context, in *_go.NameReq, opts ...grpc.CallOption) (*_go.Empty, error)
	Log(ctx context.Context, in *_go.NameReq, opts ...grpc.CallOption) (*_go.LogRsp, error)
	Exec(ctx context.Context, in *_go.ExecReq, opts ...grpc.CallOption) (*_go.ExecRsp, error)
	Event(ctx context.Context, in *_go.NameReq, opts ...grpc.CallOption) (*_go.EventRsp, error)
	Watch(ctx context.Context, in *_go.NameReq, opts ...grpc.CallOption) (grpc.ServerStreamingClient[_go.PodRsp], error)
	LogStream(ctx context.Context, in *_go.NameReq, opts ...grpc.CallOption) (grpc.ServerStreamingClient[_go.LogRsp_Log], error)
}

MercuryClient is the client API for Mercury service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewMercuryClient

func NewMercuryClient(cc grpc.ClientConnInterface) MercuryClient

type MercuryServer

MercuryServer is the server API for Mercury service. All implementations should embed UnimplementedMercuryServer for forward compatibility.

type Mercury_LogStreamClient

type Mercury_LogStreamClient = grpc.ServerStreamingClient[_go.LogRsp_Log]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type Mercury_LogStreamServer

type Mercury_LogStreamServer = grpc.ServerStreamingServer[_go.LogRsp_Log]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type Mercury_WatchClient

type Mercury_WatchClient = grpc.ServerStreamingClient[_go.PodRsp]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type Mercury_WatchServer

type Mercury_WatchServer = grpc.ServerStreamingServer[_go.PodRsp]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type UnimplementedMercuryServer

type UnimplementedMercuryServer struct{}

UnimplementedMercuryServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedMercuryServer) Deploy

func (UnimplementedMercuryServer) Event

func (UnimplementedMercuryServer) Exec

func (UnimplementedMercuryServer) Inspect

func (UnimplementedMercuryServer) List

func (UnimplementedMercuryServer) Log

func (UnimplementedMercuryServer) LogStream

func (UnimplementedMercuryServer) Remove

func (UnimplementedMercuryServer) Watch

type UnsafeMercuryServer

type UnsafeMercuryServer interface {
	// contains filtered or unexported methods
}

UnsafeMercuryServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to MercuryServer will result in compilation errors.

Source Files

  • mercury_grpc.pb.go

Jump to