specv1alpha1

package
v1.36.11-2025092821081... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: BSD-3-Clause Imports: 6 Imported by: 0

Documentation

Index

Constants

const ContinuousJobSpec_GenericSpec_case case_ContinuousJobSpec_JobSpec = 1
const ContinuousJobSpec_JobSpec_not_set_case case_ContinuousJobSpec_JobSpec = 0
const JobSpec_ExtractHoboTimeFrameSpec_case case_JobSpec_JobSpec = 2
const JobSpec_GenerateImageVariantsSpec_case case_JobSpec_JobSpec = 3
const JobSpec_GenericSpec_case case_JobSpec_JobSpec = 1
const JobSpec_JobSpec_not_set_case case_JobSpec_JobSpec = 0
const JobSpec_ManageIntegrationSpec_case case_JobSpec_JobSpec = 4
const OneShotJobSpec_GenerateImageVariantsSpec_case case_OneShotJobSpec_JobSpec = 2
const OneShotJobSpec_GenericSpec_case case_OneShotJobSpec_JobSpec = 1
const OneShotJobSpec_JobSpec_not_set_case case_OneShotJobSpec_JobSpec = 0
const QueuedJobSpec_GenericSpec_case case_QueuedJobSpec_JobSpec = 1
const QueuedJobSpec_JobSpec_not_set_case case_QueuedJobSpec_JobSpec = 0
const QueuedJobSpec_ManageIntegrationSpec_case case_QueuedJobSpec_JobSpec = 2
const RecurringJobSpec_ExtractHoboTimeFrameSpec_case case_RecurringJobSpec_JobSpec = 2
const RecurringJobSpec_GenericSpec_case case_RecurringJobSpec_JobSpec = 1
const RecurringJobSpec_JobSpec_not_set_case case_RecurringJobSpec_JobSpec = 0

Variables

var File_dendra_job_spec_v1alpha1_extract_hobo_time_frame_spec_proto protoreflect.FileDescriptor
var File_dendra_job_spec_v1alpha1_generate_image_variants_spec_proto protoreflect.FileDescriptor
var File_dendra_job_spec_v1alpha1_generic_spec_proto protoreflect.FileDescriptor
var File_dendra_job_spec_v1alpha1_manage_integration_spec_proto protoreflect.FileDescriptor
var File_dendra_job_spec_v1alpha1_spec_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type ContinuousJobSpec

type ContinuousJobSpec struct {

	// Types that are valid to be assigned to JobSpec:
	//
	//	*ContinuousJobSpec_GenericSpec
	JobSpec isContinuousJobSpec_JobSpec `protobuf_oneof:"job_spec"`
	// contains filtered or unexported fields
}

func (*ContinuousJobSpec) ClearGenericSpec

func (x *ContinuousJobSpec) ClearGenericSpec()

func (*ContinuousJobSpec) ClearJobSpec

func (x *ContinuousJobSpec) ClearJobSpec()

func (*ContinuousJobSpec) GetGenericSpec

func (x *ContinuousJobSpec) GetGenericSpec() *GenericSpec

func (*ContinuousJobSpec) GetJobSpec

func (x *ContinuousJobSpec) GetJobSpec() isContinuousJobSpec_JobSpec

func (*ContinuousJobSpec) HasGenericSpec

func (x *ContinuousJobSpec) HasGenericSpec() bool

func (*ContinuousJobSpec) HasJobSpec

func (x *ContinuousJobSpec) HasJobSpec() bool

func (*ContinuousJobSpec) ProtoMessage

func (*ContinuousJobSpec) ProtoMessage()

func (*ContinuousJobSpec) ProtoReflect

func (x *ContinuousJobSpec) ProtoReflect() protoreflect.Message

func (*ContinuousJobSpec) Reset

func (x *ContinuousJobSpec) Reset()

func (*ContinuousJobSpec) SetGenericSpec

func (x *ContinuousJobSpec) SetGenericSpec(v *GenericSpec)

func (*ContinuousJobSpec) String

func (x *ContinuousJobSpec) String() string

func (*ContinuousJobSpec) WhichJobSpec

func (x *ContinuousJobSpec) WhichJobSpec() case_ContinuousJobSpec_JobSpec

type ContinuousJobSpec_GenericSpec

type ContinuousJobSpec_GenericSpec struct {
	GenericSpec *GenericSpec `protobuf:"bytes,1,opt,name=generic_spec,json=genericSpec,proto3,oneof"`
}

type ContinuousJobSpec_builder

type ContinuousJobSpec_builder struct {

	// Fields of oneof JobSpec:
	GenericSpec *GenericSpec
	// contains filtered or unexported fields
}

func (ContinuousJobSpec_builder) Build

type ExtractHoboTimeFrameSpec

type ExtractHoboTimeFrameSpec struct {
	SourceDefaults *ExtractHoboTimeFrameSpec_Source            `protobuf:"bytes,1,opt,name=source_defaults,json=sourceDefaults,proto3" json:"source_defaults,omitempty"`
	Sources        map[string]*ExtractHoboTimeFrameSpec_Source `` /* 141-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*ExtractHoboTimeFrameSpec) ClearSourceDefaults

func (x *ExtractHoboTimeFrameSpec) ClearSourceDefaults()

func (*ExtractHoboTimeFrameSpec) GetSourceDefaults

func (*ExtractHoboTimeFrameSpec) GetSources

func (*ExtractHoboTimeFrameSpec) HasSourceDefaults

func (x *ExtractHoboTimeFrameSpec) HasSourceDefaults() bool

func (*ExtractHoboTimeFrameSpec) ProtoMessage

func (*ExtractHoboTimeFrameSpec) ProtoMessage()

func (*ExtractHoboTimeFrameSpec) ProtoReflect

func (x *ExtractHoboTimeFrameSpec) ProtoReflect() protoreflect.Message

func (*ExtractHoboTimeFrameSpec) Reset

func (x *ExtractHoboTimeFrameSpec) Reset()

func (*ExtractHoboTimeFrameSpec) SetSourceDefaults

func (*ExtractHoboTimeFrameSpec) SetSources

func (*ExtractHoboTimeFrameSpec) String

func (x *ExtractHoboTimeFrameSpec) String() string

type ExtractHoboTimeFrameSpec_Context

type ExtractHoboTimeFrameSpec_Context struct {
	OrgSlug string `protobuf:"bytes,1,opt,name=org_slug,json=orgSlug,proto3" json:"org_slug,omitempty"`
	Station string `protobuf:"bytes,2,opt,name=station,proto3" json:"station,omitempty"`
	Table   string `protobuf:"bytes,3,opt,name=table,proto3" json:"table,omitempty"`
	// contains filtered or unexported fields
}

func (*ExtractHoboTimeFrameSpec_Context) GetOrgSlug

func (x *ExtractHoboTimeFrameSpec_Context) GetOrgSlug() string

func (*ExtractHoboTimeFrameSpec_Context) GetStation

func (x *ExtractHoboTimeFrameSpec_Context) GetStation() string

func (*ExtractHoboTimeFrameSpec_Context) GetTable

func (*ExtractHoboTimeFrameSpec_Context) ProtoMessage

func (*ExtractHoboTimeFrameSpec_Context) ProtoMessage()

func (*ExtractHoboTimeFrameSpec_Context) ProtoReflect

func (*ExtractHoboTimeFrameSpec_Context) Reset

func (*ExtractHoboTimeFrameSpec_Context) SetOrgSlug

func (x *ExtractHoboTimeFrameSpec_Context) SetOrgSlug(v string)

func (*ExtractHoboTimeFrameSpec_Context) SetStation

func (x *ExtractHoboTimeFrameSpec_Context) SetStation(v string)

func (*ExtractHoboTimeFrameSpec_Context) SetTable

func (*ExtractHoboTimeFrameSpec_Context) String

type ExtractHoboTimeFrameSpec_Context_builder

type ExtractHoboTimeFrameSpec_Context_builder struct {
	OrgSlug string
	Station string
	Table   string
	// contains filtered or unexported fields
}

func (ExtractHoboTimeFrameSpec_Context_builder) Build

type ExtractHoboTimeFrameSpec_Source

type ExtractHoboTimeFrameSpec_Source struct {
	Backfill      *durationpb.Duration              `protobuf:"bytes,1,opt,name=backfill,proto3" json:"backfill,omitempty"`
	QueryDuration *durationpb.Duration              `protobuf:"bytes,2,opt,name=query_duration,json=queryDuration,proto3" json:"query_duration,omitempty"`
	Context       *ExtractHoboTimeFrameSpec_Context `protobuf:"bytes,3,opt,name=context,proto3,oneof" json:"context,omitempty"`
	Description   string                            `protobuf:"bytes,4,opt,name=description,proto3" json:"description,omitempty"`
	PubToSubject  string                            `protobuf:"bytes,6,opt,name=pub_to_subject,json=pubToSubject,proto3" json:"pub_to_subject,omitempty"`
	// contains filtered or unexported fields
}

func (*ExtractHoboTimeFrameSpec_Source) ClearBackfill

func (x *ExtractHoboTimeFrameSpec_Source) ClearBackfill()

func (*ExtractHoboTimeFrameSpec_Source) ClearContext

func (x *ExtractHoboTimeFrameSpec_Source) ClearContext()

func (*ExtractHoboTimeFrameSpec_Source) ClearQueryDuration

func (x *ExtractHoboTimeFrameSpec_Source) ClearQueryDuration()

func (*ExtractHoboTimeFrameSpec_Source) GetBackfill

func (*ExtractHoboTimeFrameSpec_Source) GetContext

func (*ExtractHoboTimeFrameSpec_Source) GetDescription

func (x *ExtractHoboTimeFrameSpec_Source) GetDescription() string

func (*ExtractHoboTimeFrameSpec_Source) GetPubToSubject

func (x *ExtractHoboTimeFrameSpec_Source) GetPubToSubject() string

func (*ExtractHoboTimeFrameSpec_Source) GetQueryDuration

func (x *ExtractHoboTimeFrameSpec_Source) GetQueryDuration() *durationpb.Duration

func (*ExtractHoboTimeFrameSpec_Source) HasBackfill

func (x *ExtractHoboTimeFrameSpec_Source) HasBackfill() bool

func (*ExtractHoboTimeFrameSpec_Source) HasContext

func (x *ExtractHoboTimeFrameSpec_Source) HasContext() bool

func (*ExtractHoboTimeFrameSpec_Source) HasQueryDuration

func (x *ExtractHoboTimeFrameSpec_Source) HasQueryDuration() bool

func (*ExtractHoboTimeFrameSpec_Source) ProtoMessage

func (*ExtractHoboTimeFrameSpec_Source) ProtoMessage()

func (*ExtractHoboTimeFrameSpec_Source) ProtoReflect

func (*ExtractHoboTimeFrameSpec_Source) Reset

func (*ExtractHoboTimeFrameSpec_Source) SetBackfill

func (*ExtractHoboTimeFrameSpec_Source) SetContext

func (*ExtractHoboTimeFrameSpec_Source) SetDescription

func (x *ExtractHoboTimeFrameSpec_Source) SetDescription(v string)

func (*ExtractHoboTimeFrameSpec_Source) SetPubToSubject

func (x *ExtractHoboTimeFrameSpec_Source) SetPubToSubject(v string)

func (*ExtractHoboTimeFrameSpec_Source) SetQueryDuration

func (x *ExtractHoboTimeFrameSpec_Source) SetQueryDuration(v *durationpb.Duration)

func (*ExtractHoboTimeFrameSpec_Source) String

type ExtractHoboTimeFrameSpec_Source_builder

type ExtractHoboTimeFrameSpec_Source_builder struct {
	Backfill      *durationpb.Duration
	QueryDuration *durationpb.Duration
	Context       *ExtractHoboTimeFrameSpec_Context
	Description   string
	PubToSubject  string
	// contains filtered or unexported fields
}

func (ExtractHoboTimeFrameSpec_Source_builder) Build

type ExtractHoboTimeFrameSpec_builder

type ExtractHoboTimeFrameSpec_builder struct {
	SourceDefaults *ExtractHoboTimeFrameSpec_Source
	Sources        map[string]*ExtractHoboTimeFrameSpec_Source
	// contains filtered or unexported fields
}

func (ExtractHoboTimeFrameSpec_builder) Build

type GenerateImageVariantsSpec

type GenerateImageVariantsSpec struct {
	FileToken string `protobuf:"bytes,1,opt,name=file_token,json=fileToken,proto3" json:"file_token,omitempty"`
	// contains filtered or unexported fields
}

func (*GenerateImageVariantsSpec) GetFileToken

func (x *GenerateImageVariantsSpec) GetFileToken() string

func (*GenerateImageVariantsSpec) ProtoMessage

func (*GenerateImageVariantsSpec) ProtoMessage()

func (*GenerateImageVariantsSpec) ProtoReflect

func (*GenerateImageVariantsSpec) Reset

func (x *GenerateImageVariantsSpec) Reset()

func (*GenerateImageVariantsSpec) SetFileToken

func (x *GenerateImageVariantsSpec) SetFileToken(v string)

func (*GenerateImageVariantsSpec) String

func (x *GenerateImageVariantsSpec) String() string

type GenerateImageVariantsSpec_builder

type GenerateImageVariantsSpec_builder struct {
	FileToken string
	// contains filtered or unexported fields
}

func (GenerateImageVariantsSpec_builder) Build

type GenericSpec

type GenericSpec struct {
	Data *structpb.Struct `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

func (*GenericSpec) ClearData

func (x *GenericSpec) ClearData()

func (*GenericSpec) GetData

func (x *GenericSpec) GetData() *structpb.Struct

func (*GenericSpec) HasData

func (x *GenericSpec) HasData() bool

func (*GenericSpec) ProtoMessage

func (*GenericSpec) ProtoMessage()

func (*GenericSpec) ProtoReflect

func (x *GenericSpec) ProtoReflect() protoreflect.Message

func (*GenericSpec) Reset

func (x *GenericSpec) Reset()

func (*GenericSpec) SetData

func (x *GenericSpec) SetData(v *structpb.Struct)

func (*GenericSpec) String

func (x *GenericSpec) String() string

type GenericSpec_builder

type GenericSpec_builder struct {
	Data *structpb.Struct
	// contains filtered or unexported fields
}

func (GenericSpec_builder) Build

func (b0 GenericSpec_builder) Build() *GenericSpec

type JobSpec

type JobSpec struct {

	// Types that are valid to be assigned to JobSpec:
	//
	//	*JobSpec_GenericSpec
	//	*JobSpec_ExtractHoboTimeFrameSpec
	//	*JobSpec_GenerateImageVariantsSpec
	//	*JobSpec_ManageIntegrationSpec
	JobSpec isJobSpec_JobSpec `protobuf_oneof:"job_spec"`
	// contains filtered or unexported fields
}

func (*JobSpec) ClearExtractHoboTimeFrameSpec

func (x *JobSpec) ClearExtractHoboTimeFrameSpec()

func (*JobSpec) ClearGenerateImageVariantsSpec

func (x *JobSpec) ClearGenerateImageVariantsSpec()

func (*JobSpec) ClearGenericSpec

func (x *JobSpec) ClearGenericSpec()

func (*JobSpec) ClearJobSpec

func (x *JobSpec) ClearJobSpec()

func (*JobSpec) ClearManageIntegrationSpec

func (x *JobSpec) ClearManageIntegrationSpec()

func (*JobSpec) GetExtractHoboTimeFrameSpec

func (x *JobSpec) GetExtractHoboTimeFrameSpec() *ExtractHoboTimeFrameSpec

func (*JobSpec) GetGenerateImageVariantsSpec

func (x *JobSpec) GetGenerateImageVariantsSpec() *GenerateImageVariantsSpec

func (*JobSpec) GetGenericSpec

func (x *JobSpec) GetGenericSpec() *GenericSpec

func (*JobSpec) GetJobSpec

func (x *JobSpec) GetJobSpec() isJobSpec_JobSpec

func (*JobSpec) GetManageIntegrationSpec

func (x *JobSpec) GetManageIntegrationSpec() *ManageIntegrationSpec

func (*JobSpec) HasExtractHoboTimeFrameSpec

func (x *JobSpec) HasExtractHoboTimeFrameSpec() bool

func (*JobSpec) HasGenerateImageVariantsSpec

func (x *JobSpec) HasGenerateImageVariantsSpec() bool

func (*JobSpec) HasGenericSpec

func (x *JobSpec) HasGenericSpec() bool

func (*JobSpec) HasJobSpec

func (x *JobSpec) HasJobSpec() bool

func (*JobSpec) HasManageIntegrationSpec

func (x *JobSpec) HasManageIntegrationSpec() bool

func (*JobSpec) ProtoMessage

func (*JobSpec) ProtoMessage()

func (*JobSpec) ProtoReflect

func (x *JobSpec) ProtoReflect() protoreflect.Message

func (*JobSpec) Reset

func (x *JobSpec) Reset()

func (*JobSpec) SetExtractHoboTimeFrameSpec

func (x *JobSpec) SetExtractHoboTimeFrameSpec(v *ExtractHoboTimeFrameSpec)

func (*JobSpec) SetGenerateImageVariantsSpec

func (x *JobSpec) SetGenerateImageVariantsSpec(v *GenerateImageVariantsSpec)

func (*JobSpec) SetGenericSpec

func (x *JobSpec) SetGenericSpec(v *GenericSpec)

func (*JobSpec) SetManageIntegrationSpec

func (x *JobSpec) SetManageIntegrationSpec(v *ManageIntegrationSpec)

func (*JobSpec) String

func (x *JobSpec) String() string

func (*JobSpec) WhichJobSpec

func (x *JobSpec) WhichJobSpec() case_JobSpec_JobSpec

type JobSpec_ExtractHoboTimeFrameSpec

type JobSpec_ExtractHoboTimeFrameSpec struct {
	ExtractHoboTimeFrameSpec *ExtractHoboTimeFrameSpec `protobuf:"bytes,2,opt,name=extract_hobo_time_frame_spec,json=extractHoboTimeFrameSpec,proto3,oneof"`
}

type JobSpec_GenerateImageVariantsSpec

type JobSpec_GenerateImageVariantsSpec struct {
	GenerateImageVariantsSpec *GenerateImageVariantsSpec `protobuf:"bytes,3,opt,name=generate_image_variants_spec,json=generateImageVariantsSpec,proto3,oneof"`
}

type JobSpec_GenericSpec

type JobSpec_GenericSpec struct {
	GenericSpec *GenericSpec `protobuf:"bytes,1,opt,name=generic_spec,json=genericSpec,proto3,oneof"`
}

type JobSpec_ManageIntegrationSpec

type JobSpec_ManageIntegrationSpec struct {
	ManageIntegrationSpec *ManageIntegrationSpec `protobuf:"bytes,4,opt,name=manage_integration_spec,json=manageIntegrationSpec,proto3,oneof"`
}

type JobSpec_builder

type JobSpec_builder struct {

	// Fields of oneof JobSpec:
	GenericSpec               *GenericSpec
	ExtractHoboTimeFrameSpec  *ExtractHoboTimeFrameSpec
	GenerateImageVariantsSpec *GenerateImageVariantsSpec
	ManageIntegrationSpec     *ManageIntegrationSpec
	// contains filtered or unexported fields
}

func (JobSpec_builder) Build

func (b0 JobSpec_builder) Build() *JobSpec

type ManageIntegrationSpec

type ManageIntegrationSpec struct {
	OrganizationId      string `protobuf:"bytes,1,opt,name=organization_id,json=organizationId,proto3" json:"organization_id,omitempty"`
	IntegrationConfigId string `protobuf:"bytes,2,opt,name=integration_config_id,json=integrationConfigId,proto3" json:"integration_config_id,omitempty"`
	// contains filtered or unexported fields
}

func (*ManageIntegrationSpec) GetIntegrationConfigId

func (x *ManageIntegrationSpec) GetIntegrationConfigId() string

func (*ManageIntegrationSpec) GetOrganizationId

func (x *ManageIntegrationSpec) GetOrganizationId() string

func (*ManageIntegrationSpec) ProtoMessage

func (*ManageIntegrationSpec) ProtoMessage()

func (*ManageIntegrationSpec) ProtoReflect

func (x *ManageIntegrationSpec) ProtoReflect() protoreflect.Message

func (*ManageIntegrationSpec) Reset

func (x *ManageIntegrationSpec) Reset()

func (*ManageIntegrationSpec) SetIntegrationConfigId

func (x *ManageIntegrationSpec) SetIntegrationConfigId(v string)

func (*ManageIntegrationSpec) SetOrganizationId

func (x *ManageIntegrationSpec) SetOrganizationId(v string)

func (*ManageIntegrationSpec) String

func (x *ManageIntegrationSpec) String() string

type ManageIntegrationSpec_builder

type ManageIntegrationSpec_builder struct {
	OrganizationId      string
	IntegrationConfigId string
	// contains filtered or unexported fields
}

func (ManageIntegrationSpec_builder) Build

type OneShotJobSpec

type OneShotJobSpec struct {

	// Types that are valid to be assigned to JobSpec:
	//
	//	*OneShotJobSpec_GenericSpec
	//	*OneShotJobSpec_GenerateImageVariantsSpec
	JobSpec isOneShotJobSpec_JobSpec `protobuf_oneof:"job_spec"`
	// contains filtered or unexported fields
}

func (*OneShotJobSpec) ClearGenerateImageVariantsSpec

func (x *OneShotJobSpec) ClearGenerateImageVariantsSpec()

func (*OneShotJobSpec) ClearGenericSpec

func (x *OneShotJobSpec) ClearGenericSpec()

func (*OneShotJobSpec) ClearJobSpec

func (x *OneShotJobSpec) ClearJobSpec()

func (*OneShotJobSpec) GetGenerateImageVariantsSpec

func (x *OneShotJobSpec) GetGenerateImageVariantsSpec() *GenerateImageVariantsSpec

func (*OneShotJobSpec) GetGenericSpec

func (x *OneShotJobSpec) GetGenericSpec() *GenericSpec

func (*OneShotJobSpec) GetJobSpec

func (x *OneShotJobSpec) GetJobSpec() isOneShotJobSpec_JobSpec

func (*OneShotJobSpec) HasGenerateImageVariantsSpec

func (x *OneShotJobSpec) HasGenerateImageVariantsSpec() bool

func (*OneShotJobSpec) HasGenericSpec

func (x *OneShotJobSpec) HasGenericSpec() bool

func (*OneShotJobSpec) HasJobSpec

func (x *OneShotJobSpec) HasJobSpec() bool

func (*OneShotJobSpec) ProtoMessage

func (*OneShotJobSpec) ProtoMessage()

func (*OneShotJobSpec) ProtoReflect

func (x *OneShotJobSpec) ProtoReflect() protoreflect.Message

func (*OneShotJobSpec) Reset

func (x *OneShotJobSpec) Reset()

func (*OneShotJobSpec) SetGenerateImageVariantsSpec

func (x *OneShotJobSpec) SetGenerateImageVariantsSpec(v *GenerateImageVariantsSpec)

func (*OneShotJobSpec) SetGenericSpec

func (x *OneShotJobSpec) SetGenericSpec(v *GenericSpec)

func (*OneShotJobSpec) String

func (x *OneShotJobSpec) String() string

func (*OneShotJobSpec) WhichJobSpec

func (x *OneShotJobSpec) WhichJobSpec() case_OneShotJobSpec_JobSpec

type OneShotJobSpec_GenerateImageVariantsSpec

type OneShotJobSpec_GenerateImageVariantsSpec struct {
	GenerateImageVariantsSpec *GenerateImageVariantsSpec `protobuf:"bytes,2,opt,name=generate_image_variants_spec,json=generateImageVariantsSpec,proto3,oneof"`
}

type OneShotJobSpec_GenericSpec

type OneShotJobSpec_GenericSpec struct {
	GenericSpec *GenericSpec `protobuf:"bytes,1,opt,name=generic_spec,json=genericSpec,proto3,oneof"`
}

type OneShotJobSpec_builder

type OneShotJobSpec_builder struct {

	// Fields of oneof JobSpec:
	GenericSpec               *GenericSpec
	GenerateImageVariantsSpec *GenerateImageVariantsSpec
	// contains filtered or unexported fields
}

func (OneShotJobSpec_builder) Build

type QueuedJobSpec

type QueuedJobSpec struct {

	// Types that are valid to be assigned to JobSpec:
	//
	//	*QueuedJobSpec_GenericSpec
	//	*QueuedJobSpec_ManageIntegrationSpec
	JobSpec isQueuedJobSpec_JobSpec `protobuf_oneof:"job_spec"`
	// contains filtered or unexported fields
}

func (*QueuedJobSpec) ClearGenericSpec

func (x *QueuedJobSpec) ClearGenericSpec()

func (*QueuedJobSpec) ClearJobSpec

func (x *QueuedJobSpec) ClearJobSpec()

func (*QueuedJobSpec) ClearManageIntegrationSpec

func (x *QueuedJobSpec) ClearManageIntegrationSpec()

func (*QueuedJobSpec) GetGenericSpec

func (x *QueuedJobSpec) GetGenericSpec() *GenericSpec

func (*QueuedJobSpec) GetJobSpec

func (x *QueuedJobSpec) GetJobSpec() isQueuedJobSpec_JobSpec

func (*QueuedJobSpec) GetManageIntegrationSpec

func (x *QueuedJobSpec) GetManageIntegrationSpec() *ManageIntegrationSpec

func (*QueuedJobSpec) HasGenericSpec

func (x *QueuedJobSpec) HasGenericSpec() bool

func (*QueuedJobSpec) HasJobSpec

func (x *QueuedJobSpec) HasJobSpec() bool

func (*QueuedJobSpec) HasManageIntegrationSpec

func (x *QueuedJobSpec) HasManageIntegrationSpec() bool

func (*QueuedJobSpec) ProtoMessage

func (*QueuedJobSpec) ProtoMessage()

func (*QueuedJobSpec) ProtoReflect

func (x *QueuedJobSpec) ProtoReflect() protoreflect.Message

func (*QueuedJobSpec) Reset

func (x *QueuedJobSpec) Reset()

func (*QueuedJobSpec) SetGenericSpec

func (x *QueuedJobSpec) SetGenericSpec(v *GenericSpec)

func (*QueuedJobSpec) SetManageIntegrationSpec

func (x *QueuedJobSpec) SetManageIntegrationSpec(v *ManageIntegrationSpec)

func (*QueuedJobSpec) String

func (x *QueuedJobSpec) String() string

func (*QueuedJobSpec) WhichJobSpec

func (x *QueuedJobSpec) WhichJobSpec() case_QueuedJobSpec_JobSpec

type QueuedJobSpec_GenericSpec

type QueuedJobSpec_GenericSpec struct {
	GenericSpec *GenericSpec `protobuf:"bytes,1,opt,name=generic_spec,json=genericSpec,proto3,oneof"`
}

type QueuedJobSpec_ManageIntegrationSpec

type QueuedJobSpec_ManageIntegrationSpec struct {
	ManageIntegrationSpec *ManageIntegrationSpec `protobuf:"bytes,2,opt,name=manage_integration_spec,json=manageIntegrationSpec,proto3,oneof"`
}

type QueuedJobSpec_builder

type QueuedJobSpec_builder struct {

	// Fields of oneof JobSpec:
	GenericSpec           *GenericSpec
	ManageIntegrationSpec *ManageIntegrationSpec
	// contains filtered or unexported fields
}

func (QueuedJobSpec_builder) Build

type RecurringJobSpec

type RecurringJobSpec struct {

	// Types that are valid to be assigned to JobSpec:
	//
	//	*RecurringJobSpec_GenericSpec
	//	*RecurringJobSpec_ExtractHoboTimeFrameSpec
	JobSpec isRecurringJobSpec_JobSpec `protobuf_oneof:"job_spec"`
	// contains filtered or unexported fields
}

func (*RecurringJobSpec) ClearExtractHoboTimeFrameSpec

func (x *RecurringJobSpec) ClearExtractHoboTimeFrameSpec()

func (*RecurringJobSpec) ClearGenericSpec

func (x *RecurringJobSpec) ClearGenericSpec()

func (*RecurringJobSpec) ClearJobSpec

func (x *RecurringJobSpec) ClearJobSpec()

func (*RecurringJobSpec) GetExtractHoboTimeFrameSpec

func (x *RecurringJobSpec) GetExtractHoboTimeFrameSpec() *ExtractHoboTimeFrameSpec

func (*RecurringJobSpec) GetGenericSpec

func (x *RecurringJobSpec) GetGenericSpec() *GenericSpec

func (*RecurringJobSpec) GetJobSpec

func (x *RecurringJobSpec) GetJobSpec() isRecurringJobSpec_JobSpec

func (*RecurringJobSpec) HasExtractHoboTimeFrameSpec

func (x *RecurringJobSpec) HasExtractHoboTimeFrameSpec() bool

func (*RecurringJobSpec) HasGenericSpec

func (x *RecurringJobSpec) HasGenericSpec() bool

func (*RecurringJobSpec) HasJobSpec

func (x *RecurringJobSpec) HasJobSpec() bool

func (*RecurringJobSpec) ProtoMessage

func (*RecurringJobSpec) ProtoMessage()

func (*RecurringJobSpec) ProtoReflect

func (x *RecurringJobSpec) ProtoReflect() protoreflect.Message

func (*RecurringJobSpec) Reset

func (x *RecurringJobSpec) Reset()

func (*RecurringJobSpec) SetExtractHoboTimeFrameSpec

func (x *RecurringJobSpec) SetExtractHoboTimeFrameSpec(v *ExtractHoboTimeFrameSpec)

func (*RecurringJobSpec) SetGenericSpec

func (x *RecurringJobSpec) SetGenericSpec(v *GenericSpec)

func (*RecurringJobSpec) String

func (x *RecurringJobSpec) String() string

func (*RecurringJobSpec) WhichJobSpec

func (x *RecurringJobSpec) WhichJobSpec() case_RecurringJobSpec_JobSpec

type RecurringJobSpec_ExtractHoboTimeFrameSpec

type RecurringJobSpec_ExtractHoboTimeFrameSpec struct {
	ExtractHoboTimeFrameSpec *ExtractHoboTimeFrameSpec `protobuf:"bytes,2,opt,name=extract_hobo_time_frame_spec,json=extractHoboTimeFrameSpec,proto3,oneof"`
}

type RecurringJobSpec_GenericSpec

type RecurringJobSpec_GenericSpec struct {
	GenericSpec *GenericSpec `protobuf:"bytes,1,opt,name=generic_spec,json=genericSpec,proto3,oneof"`
}

type RecurringJobSpec_builder

type RecurringJobSpec_builder struct {

	// Fields of oneof JobSpec:
	GenericSpec              *GenericSpec
	ExtractHoboTimeFrameSpec *ExtractHoboTimeFrameSpec
	// contains filtered or unexported fields
}

func (RecurringJobSpec_builder) Build

Source Files

  • extract_hobo_time_frame_spec.pb.go
  • generate_image_variants_spec.pb.go
  • generic_spec.pb.go
  • manage_integration_spec.pb.go
  • spec.pb.go

Jump to