interestv1beta1grpc

package
v1.6.1-20251222114907-... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	CustomerContactAdvertisingInterestService_ListInterests_FullMethodName = "/stargate.customer.contact.advertising.interest.v1beta1.CustomerContactAdvertisingInterestService/ListInterests"
)

Variables

var CustomerContactAdvertisingInterestService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "stargate.customer.contact.advertising.interest.v1beta1.CustomerContactAdvertisingInterestService",
	HandlerType: (*CustomerContactAdvertisingInterestServiceServer)(nil),
	Methods:     []grpc.MethodDesc{},
	Streams: []grpc.StreamDesc{
		{
			StreamName:    "ListInterests",
			Handler:       _CustomerContactAdvertisingInterestService_ListInterests_Handler,
			ServerStreams: true,
		},
	},
	Metadata: "stargate/customer/contact/advertising/interest/v1beta1/advertising_interest_service.proto",
}

CustomerContactAdvertisingInterestService_ServiceDesc is the grpc.ServiceDesc for CustomerContactAdvertisingInterestService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterCustomerContactAdvertisingInterestServiceServer deprecated

func RegisterCustomerContactAdvertisingInterestServiceServer(s grpc.ServiceRegistrar, srv CustomerContactAdvertisingInterestServiceServer)

Deprecated: Do not use.

Types

type CustomerContactAdvertisingInterestServiceClient deprecated

type CustomerContactAdvertisingInterestServiceClient interface {
	// Lists all possible customer contact advertising interests
	ListInterests(ctx context.Context, in *v1beta1.ListInterestsRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[v1beta1.ListInterestsResponse], error)
}

CustomerContactAdvertisingInterestServiceClient is the client API for CustomerContactAdvertisingInterestService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

Deprecated: Do not use.

func NewCustomerContactAdvertisingInterestServiceClient deprecated

func NewCustomerContactAdvertisingInterestServiceClient(cc grpc.ClientConnInterface) CustomerContactAdvertisingInterestServiceClient

Deprecated: Do not use.

type CustomerContactAdvertisingInterestServiceServer deprecated

type CustomerContactAdvertisingInterestServiceServer interface {
	// Lists all possible customer contact advertising interests
	ListInterests(*v1beta1.ListInterestsRequest, grpc.ServerStreamingServer[v1beta1.ListInterestsResponse]) error
}

CustomerContactAdvertisingInterestServiceServer is the server API for CustomerContactAdvertisingInterestService service. All implementations should embed UnimplementedCustomerContactAdvertisingInterestServiceServer for forward compatibility.

Deprecated: Do not use.

type CustomerContactAdvertisingInterestService_ListInterestsClient

type CustomerContactAdvertisingInterestService_ListInterestsClient = grpc.ServerStreamingClient[v1beta1.ListInterestsResponse]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type CustomerContactAdvertisingInterestService_ListInterestsServer

type CustomerContactAdvertisingInterestService_ListInterestsServer = grpc.ServerStreamingServer[v1beta1.ListInterestsResponse]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type UnimplementedCustomerContactAdvertisingInterestServiceServer

type UnimplementedCustomerContactAdvertisingInterestServiceServer struct{}

UnimplementedCustomerContactAdvertisingInterestServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedCustomerContactAdvertisingInterestServiceServer) ListInterests

type UnsafeCustomerContactAdvertisingInterestServiceServer

type UnsafeCustomerContactAdvertisingInterestServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeCustomerContactAdvertisingInterestServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to CustomerContactAdvertisingInterestServiceServer will result in compilation errors.

Source Files

  • advertising_interest_service_grpc.pb.go

Jump to