Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterSupplierItemServiceServer(s grpc.ServiceRegistrar, srv SupplierItemServiceServer)
- type SupplierItemServiceClient
- type SupplierItemServiceServer
- type SupplierItemService_ListItemsClient
- type SupplierItemService_ListItemsServer
- type UnimplementedSupplierItemServiceServer
- func (UnimplementedSupplierItemServiceServer) CreateItem(context.Context, *v1beta1.CreateItemRequest) (*v1beta1.CreateItemResponse, error)
- func (UnimplementedSupplierItemServiceServer) DeleteItem(context.Context, *v1beta1.DeleteItemRequest) (*v1beta1.DeleteItemResponse, error)
- func (UnimplementedSupplierItemServiceServer) ListItems(*v1beta1.ListItemsRequest, ...) error
- func (UnimplementedSupplierItemServiceServer) UpdateItem(context.Context, *v1beta1.UpdateItemRequest) (*v1beta1.UpdateItemResponse, error)
- type UnsafeSupplierItemServiceServer
Constants ¶
const ( SupplierItemService_ListItems_FullMethodName = "/stargate.supplier.item.v1beta1.SupplierItemService/ListItems" SupplierItemService_CreateItem_FullMethodName = "/stargate.supplier.item.v1beta1.SupplierItemService/CreateItem" SupplierItemService_UpdateItem_FullMethodName = "/stargate.supplier.item.v1beta1.SupplierItemService/UpdateItem" SupplierItemService_DeleteItem_FullMethodName = "/stargate.supplier.item.v1beta1.SupplierItemService/DeleteItem" )
Variables ¶
var SupplierItemService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "stargate.supplier.item.v1beta1.SupplierItemService", HandlerType: (*SupplierItemServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "CreateItem", Handler: _SupplierItemService_CreateItem_Handler, }, { MethodName: "UpdateItem", Handler: _SupplierItemService_UpdateItem_Handler, }, { MethodName: "DeleteItem", Handler: _SupplierItemService_DeleteItem_Handler, }, }, Streams: []grpc.StreamDesc{ { StreamName: "ListItems", Handler: _SupplierItemService_ListItems_Handler, ServerStreams: true, }, }, Metadata: "stargate/supplier/item/v1beta1/supplier_item_service.proto", }
SupplierItemService_ServiceDesc is the grpc.ServiceDesc for SupplierItemService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterSupplierItemServiceServer ¶
func RegisterSupplierItemServiceServer(s grpc.ServiceRegistrar, srv SupplierItemServiceServer)
Types ¶
type SupplierItemServiceClient ¶
type SupplierItemServiceClient interface {
// Lists all supplier items for the specified supplier.
// Required fields:
//
// * `supplier_uuid` - The UUID of the supplier.
ListItems(ctx context.Context, in *v1beta1.ListItemsRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[v1beta1.ListItemsResponse], error)
// Creates a new supplier item for specific supplier.
// Required fields:
//
// * `item.supplier_uuid` - The UUID of the supplier.
// * `item.supplier_item_identifier` - Unique identifier of item in external supplier system.
CreateItem(ctx context.Context, in *v1beta1.CreateItemRequest, opts ...grpc.CallOption) (*v1beta1.CreateItemResponse, error)
// Updates a specific supplier item.
// Required fields:
//
// * `item.supplier_uuid` - The UUID of the supplier.
// * `item.supplier_item_identifier` - Unique identifier of item in external supplier system.
UpdateItem(ctx context.Context, in *v1beta1.UpdateItemRequest, opts ...grpc.CallOption) (*v1beta1.UpdateItemResponse, error)
// Deletes a specific supplier item.
// Required fields:
//
// * `supplier_uuid` - The UUID of the supplier.
// * `supplier_item_identifier` - Unique identifier of item in external supplier system.
DeleteItem(ctx context.Context, in *v1beta1.DeleteItemRequest, opts ...grpc.CallOption) (*v1beta1.DeleteItemResponse, error)
}
SupplierItemServiceClient is the client API for SupplierItemService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
Manages Supplier items.
func NewSupplierItemServiceClient ¶
func NewSupplierItemServiceClient(cc grpc.ClientConnInterface) SupplierItemServiceClient
type SupplierItemServiceServer ¶
type SupplierItemServiceServer interface {
// Lists all supplier items for the specified supplier.
// Required fields:
//
// * `supplier_uuid` - The UUID of the supplier.
ListItems(*v1beta1.ListItemsRequest, grpc.ServerStreamingServer[v1beta1.ListItemsResponse]) error
// Creates a new supplier item for specific supplier.
// Required fields:
//
// * `item.supplier_uuid` - The UUID of the supplier.
// * `item.supplier_item_identifier` - Unique identifier of item in external supplier system.
CreateItem(context.Context, *v1beta1.CreateItemRequest) (*v1beta1.CreateItemResponse, error)
// Updates a specific supplier item.
// Required fields:
//
// * `item.supplier_uuid` - The UUID of the supplier.
// * `item.supplier_item_identifier` - Unique identifier of item in external supplier system.
UpdateItem(context.Context, *v1beta1.UpdateItemRequest) (*v1beta1.UpdateItemResponse, error)
// Deletes a specific supplier item.
// Required fields:
//
// * `supplier_uuid` - The UUID of the supplier.
// * `supplier_item_identifier` - Unique identifier of item in external supplier system.
DeleteItem(context.Context, *v1beta1.DeleteItemRequest) (*v1beta1.DeleteItemResponse, error)
}
SupplierItemServiceServer is the server API for SupplierItemService service. All implementations should embed UnimplementedSupplierItemServiceServer for forward compatibility.
Manages Supplier items.
type SupplierItemService_ListItemsClient ¶
type SupplierItemService_ListItemsClient = grpc.ServerStreamingClient[v1beta1.ListItemsResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type SupplierItemService_ListItemsServer ¶
type SupplierItemService_ListItemsServer = grpc.ServerStreamingServer[v1beta1.ListItemsResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type UnimplementedSupplierItemServiceServer ¶
type UnimplementedSupplierItemServiceServer struct{}
UnimplementedSupplierItemServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedSupplierItemServiceServer) CreateItem ¶
func (UnimplementedSupplierItemServiceServer) CreateItem(context.Context, *v1beta1.CreateItemRequest) (*v1beta1.CreateItemResponse, error)
func (UnimplementedSupplierItemServiceServer) DeleteItem ¶
func (UnimplementedSupplierItemServiceServer) DeleteItem(context.Context, *v1beta1.DeleteItemRequest) (*v1beta1.DeleteItemResponse, error)
func (UnimplementedSupplierItemServiceServer) ListItems ¶
func (UnimplementedSupplierItemServiceServer) UpdateItem ¶
func (UnimplementedSupplierItemServiceServer) UpdateItem(context.Context, *v1beta1.UpdateItemRequest) (*v1beta1.UpdateItemResponse, error)
type UnsafeSupplierItemServiceServer ¶
type UnsafeSupplierItemServiceServer interface {
// contains filtered or unexported methods
}
UnsafeSupplierItemServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to SupplierItemServiceServer will result in compilation errors.
Source Files
¶
- supplier_item_service_grpc.pb.go