Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterSupplierServiceServer(s grpc.ServiceRegistrar, srv SupplierServiceServer)
- type SupplierServiceClient
- type SupplierServiceServer
- type SupplierService_ListItemsClient
- type SupplierService_ListItemsServer
- type UnimplementedSupplierServiceServer
- func (UnimplementedSupplierServiceServer) CreateItem(context.Context, *v1beta2.CreateItemRequest) (*v1beta2.CreateItemResponse, error)
- func (UnimplementedSupplierServiceServer) DeleteItem(context.Context, *v1beta2.DeleteItemRequest) (*v1beta2.DeleteItemResponse, error)
- func (UnimplementedSupplierServiceServer) ListItems(*v1beta2.ListItemsRequest, ...) error
- func (UnimplementedSupplierServiceServer) UpdateItem(context.Context, *v1beta2.UpdateItemRequest) (*v1beta2.UpdateItemResponse, error)
- type UnsafeSupplierServiceServer
Constants ¶
const ( SupplierService_ListItems_FullMethodName = "/stargate.supplier.item.v1beta2.SupplierService/ListItems" SupplierService_CreateItem_FullMethodName = "/stargate.supplier.item.v1beta2.SupplierService/CreateItem" SupplierService_UpdateItem_FullMethodName = "/stargate.supplier.item.v1beta2.SupplierService/UpdateItem" SupplierService_DeleteItem_FullMethodName = "/stargate.supplier.item.v1beta2.SupplierService/DeleteItem" )
Variables ¶
var SupplierService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "stargate.supplier.item.v1beta2.SupplierService", HandlerType: (*SupplierServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "CreateItem", Handler: _SupplierService_CreateItem_Handler, }, { MethodName: "UpdateItem", Handler: _SupplierService_UpdateItem_Handler, }, { MethodName: "DeleteItem", Handler: _SupplierService_DeleteItem_Handler, }, }, Streams: []grpc.StreamDesc{ { StreamName: "ListItems", Handler: _SupplierService_ListItems_Handler, ServerStreams: true, }, }, Metadata: "stargate/supplier/item/v1beta2/supplier_item_service.proto", }
SupplierService_ServiceDesc is the grpc.ServiceDesc for SupplierService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterSupplierServiceServer ¶
func RegisterSupplierServiceServer(s grpc.ServiceRegistrar, srv SupplierServiceServer)
Types ¶
type SupplierServiceClient ¶
type SupplierServiceClient interface {
// Lists all supplier items for the specified supplier.
// Required fields:
//
// * `supplier_uuid` - The UUID of the supplier.
ListItems(ctx context.Context, in *v1beta2.ListItemsRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[v1beta2.ListItemsResponse], error)
// Creates a new supplier item for specific supplier.
// Required fields:
//
// * `item.supplier_uuid` - The UUID of the supplier.
// * `item.supplier_item_identifier` - Unique identifier of item in external supplier system.
CreateItem(ctx context.Context, in *v1beta2.CreateItemRequest, opts ...grpc.CallOption) (*v1beta2.CreateItemResponse, error)
// Updates a specific supplier item.
// Required fields:
//
// * `item.supplier_uuid` - The UUID of the supplier.
// * `item.supplier_item_identifier` - Unique identifier of item in external supplier system.
UpdateItem(ctx context.Context, in *v1beta2.UpdateItemRequest, opts ...grpc.CallOption) (*v1beta2.UpdateItemResponse, error)
// Deletes a specific supplier item.
// Required fields:
//
// * `supplier_uuid` - The UUID of the supplier.
// * `supplier_item_identifier` - Unique identifier of item in external supplier system.
DeleteItem(ctx context.Context, in *v1beta2.DeleteItemRequest, opts ...grpc.CallOption) (*v1beta2.DeleteItemResponse, error)
}
SupplierServiceClient is the client API for SupplierService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
Manages suppliers.
func NewSupplierServiceClient ¶
func NewSupplierServiceClient(cc grpc.ClientConnInterface) SupplierServiceClient
type SupplierServiceServer ¶
type SupplierServiceServer interface {
// Lists all supplier items for the specified supplier.
// Required fields:
//
// * `supplier_uuid` - The UUID of the supplier.
ListItems(*v1beta2.ListItemsRequest, grpc.ServerStreamingServer[v1beta2.ListItemsResponse]) error
// Creates a new supplier item for specific supplier.
// Required fields:
//
// * `item.supplier_uuid` - The UUID of the supplier.
// * `item.supplier_item_identifier` - Unique identifier of item in external supplier system.
CreateItem(context.Context, *v1beta2.CreateItemRequest) (*v1beta2.CreateItemResponse, error)
// Updates a specific supplier item.
// Required fields:
//
// * `item.supplier_uuid` - The UUID of the supplier.
// * `item.supplier_item_identifier` - Unique identifier of item in external supplier system.
UpdateItem(context.Context, *v1beta2.UpdateItemRequest) (*v1beta2.UpdateItemResponse, error)
// Deletes a specific supplier item.
// Required fields:
//
// * `supplier_uuid` - The UUID of the supplier.
// * `supplier_item_identifier` - Unique identifier of item in external supplier system.
DeleteItem(context.Context, *v1beta2.DeleteItemRequest) (*v1beta2.DeleteItemResponse, error)
}
SupplierServiceServer is the server API for SupplierService service. All implementations should embed UnimplementedSupplierServiceServer for forward compatibility.
Manages suppliers.
type SupplierService_ListItemsClient ¶
type SupplierService_ListItemsClient = grpc.ServerStreamingClient[v1beta2.ListItemsResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type SupplierService_ListItemsServer ¶
type SupplierService_ListItemsServer = grpc.ServerStreamingServer[v1beta2.ListItemsResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type UnimplementedSupplierServiceServer ¶
type UnimplementedSupplierServiceServer struct{}
UnimplementedSupplierServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedSupplierServiceServer) CreateItem ¶
func (UnimplementedSupplierServiceServer) CreateItem(context.Context, *v1beta2.CreateItemRequest) (*v1beta2.CreateItemResponse, error)
func (UnimplementedSupplierServiceServer) DeleteItem ¶
func (UnimplementedSupplierServiceServer) DeleteItem(context.Context, *v1beta2.DeleteItemRequest) (*v1beta2.DeleteItemResponse, error)
func (UnimplementedSupplierServiceServer) ListItems ¶
func (UnimplementedSupplierServiceServer) ListItems(*v1beta2.ListItemsRequest, grpc.ServerStreamingServer[v1beta2.ListItemsResponse]) error
func (UnimplementedSupplierServiceServer) UpdateItem ¶
func (UnimplementedSupplierServiceServer) UpdateItem(context.Context, *v1beta2.UpdateItemRequest) (*v1beta2.UpdateItemResponse, error)
type UnsafeSupplierServiceServer ¶
type UnsafeSupplierServiceServer interface {
// contains filtered or unexported methods
}
UnsafeSupplierServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to SupplierServiceServer will result in compilation errors.
Source Files
¶
- supplier_item_service_grpc.pb.go