supplierv1beta1grpc

package
v1.6.0-20250905072930-... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	SupplierItemService_ListSuppliers_FullMethodName = "/stargate.supplier.v1beta1.SupplierItemService/ListSuppliers"
)

Variables

var SupplierItemService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "stargate.supplier.v1beta1.SupplierItemService",
	HandlerType: (*SupplierItemServiceServer)(nil),
	Methods:     []grpc.MethodDesc{},
	Streams: []grpc.StreamDesc{
		{
			StreamName:    "ListSuppliers",
			Handler:       _SupplierItemService_ListSuppliers_Handler,
			ServerStreams: true,
		},
	},
	Metadata: "stargate/supplier/v1beta1/supplier_service.proto",
}

SupplierItemService_ServiceDesc is the grpc.ServiceDesc for SupplierItemService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterSupplierItemServiceServer

func RegisterSupplierItemServiceServer(s grpc.ServiceRegistrar, srv SupplierItemServiceServer)

Types

type SupplierItemServiceClient

type SupplierItemServiceClient interface {
	// Lists all suppliers.
	ListSuppliers(ctx context.Context, in *v1beta1.ListSuppliersRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[v1beta1.ListSuppliersResponse], error)
}

SupplierItemServiceClient is the client API for SupplierItemService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

Manages Supplier items.

func NewSupplierItemServiceClient

func NewSupplierItemServiceClient(cc grpc.ClientConnInterface) SupplierItemServiceClient

type SupplierItemServiceServer

type SupplierItemServiceServer interface {
	// Lists all suppliers.
	ListSuppliers(*v1beta1.ListSuppliersRequest, grpc.ServerStreamingServer[v1beta1.ListSuppliersResponse]) error
}

SupplierItemServiceServer is the server API for SupplierItemService service. All implementations should embed UnimplementedSupplierItemServiceServer for forward compatibility.

Manages Supplier items.

type SupplierItemService_ListSuppliersClient

type SupplierItemService_ListSuppliersClient = grpc.ServerStreamingClient[v1beta1.ListSuppliersResponse]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type SupplierItemService_ListSuppliersServer

type SupplierItemService_ListSuppliersServer = grpc.ServerStreamingServer[v1beta1.ListSuppliersResponse]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type UnimplementedSupplierItemServiceServer

type UnimplementedSupplierItemServiceServer struct{}

UnimplementedSupplierItemServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedSupplierItemServiceServer) ListSuppliers

type UnsafeSupplierItemServiceServer

type UnsafeSupplierItemServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeSupplierItemServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to SupplierItemServiceServer will result in compilation errors.

Source Files

  • supplier_service_grpc.pb.go

Jump to