Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterSupplierServiceServer(s grpc.ServiceRegistrar, srv SupplierServiceServer)
- type SupplierServiceClient
- type SupplierServiceServer
- type SupplierService_ListSuppliersClient
- type SupplierService_ListSuppliersServer
- type UnimplementedSupplierServiceServer
- type UnsafeSupplierServiceServer
Constants ¶
const (
SupplierService_ListSuppliers_FullMethodName = "/stargate.supplier.v1beta2.SupplierService/ListSuppliers"
)
Variables ¶
var SupplierService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "stargate.supplier.v1beta2.SupplierService", HandlerType: (*SupplierServiceServer)(nil), Methods: []grpc.MethodDesc{}, Streams: []grpc.StreamDesc{ { StreamName: "ListSuppliers", Handler: _SupplierService_ListSuppliers_Handler, ServerStreams: true, }, }, Metadata: "stargate/supplier/v1beta2/supplier_service.proto", }
SupplierService_ServiceDesc is the grpc.ServiceDesc for SupplierService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterSupplierServiceServer ¶
func RegisterSupplierServiceServer(s grpc.ServiceRegistrar, srv SupplierServiceServer)
Types ¶
type SupplierServiceClient ¶
type SupplierServiceClient interface {
// Lists all suppliers.
ListSuppliers(ctx context.Context, in *v1beta2.ListSuppliersRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[v1beta2.ListSuppliersResponse], error)
}
SupplierServiceClient is the client API for SupplierService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
Manages suppliers.
func NewSupplierServiceClient ¶
func NewSupplierServiceClient(cc grpc.ClientConnInterface) SupplierServiceClient
type SupplierServiceServer ¶
type SupplierServiceServer interface {
// Lists all suppliers.
ListSuppliers(*v1beta2.ListSuppliersRequest, grpc.ServerStreamingServer[v1beta2.ListSuppliersResponse]) error
}
SupplierServiceServer is the server API for SupplierService service. All implementations should embed UnimplementedSupplierServiceServer for forward compatibility.
Manages suppliers.
type SupplierService_ListSuppliersClient ¶
type SupplierService_ListSuppliersClient = grpc.ServerStreamingClient[v1beta2.ListSuppliersResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type SupplierService_ListSuppliersServer ¶
type SupplierService_ListSuppliersServer = grpc.ServerStreamingServer[v1beta2.ListSuppliersResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type UnimplementedSupplierServiceServer ¶
type UnimplementedSupplierServiceServer struct{}
UnimplementedSupplierServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedSupplierServiceServer) ListSuppliers ¶
func (UnimplementedSupplierServiceServer) ListSuppliers(*v1beta2.ListSuppliersRequest, grpc.ServerStreamingServer[v1beta2.ListSuppliersResponse]) error
type UnsafeSupplierServiceServer ¶
type UnsafeSupplierServiceServer interface {
// contains filtered or unexported methods
}
UnsafeSupplierServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to SupplierServiceServer will result in compilation errors.
Source Files
¶
- supplier_service_grpc.pb.go