Documentation
¶
Index ¶
Constants ¶
const (
UserService_ListUsers_FullMethodName = "/stargate.user.v1beta1.UserService/ListUsers"
)
Variables ¶
var UserService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "stargate.user.v1beta1.UserService", HandlerType: (*UserServiceServer)(nil), Methods: []grpc.MethodDesc{}, Streams: []grpc.StreamDesc{ { StreamName: "ListUsers", Handler: _UserService_ListUsers_Handler, ServerStreams: true, }, }, Metadata: "stargate/user/v1beta1/user_service.proto", }
UserService_ServiceDesc is the grpc.ServiceDesc for UserService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterUserServiceServer ¶
func RegisterUserServiceServer(s grpc.ServiceRegistrar, srv UserServiceServer)
Types ¶
type UnimplementedUserServiceServer ¶
type UnimplementedUserServiceServer struct{}
UnimplementedUserServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedUserServiceServer) ListUsers ¶
func (UnimplementedUserServiceServer) ListUsers(*v1beta1.ListUsersRequest, grpc.ServerStreamingServer[v1beta1.ListUsersResponse]) error
type UnsafeUserServiceServer ¶
type UnsafeUserServiceServer interface {
// contains filtered or unexported methods
}
UnsafeUserServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to UserServiceServer will result in compilation errors.
type UserServiceClient ¶
type UserServiceClient interface {
ListUsers(ctx context.Context, in *v1beta1.ListUsersRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[v1beta1.ListUsersResponse], error)
}
UserServiceClient is the client API for UserService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewUserServiceClient ¶
func NewUserServiceClient(cc grpc.ClientConnInterface) UserServiceClient
type UserServiceServer ¶
type UserServiceServer interface {
ListUsers(*v1beta1.ListUsersRequest, grpc.ServerStreamingServer[v1beta1.ListUsersResponse]) error
}
UserServiceServer is the server API for UserService service. All implementations should embed UnimplementedUserServiceServer for forward compatibility.
type UserService_ListUsersClient ¶
type UserService_ListUsersClient = grpc.ServerStreamingClient[v1beta1.ListUsersResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type UserService_ListUsersServer ¶
type UserService_ListUsersServer = grpc.ServerStreamingServer[v1beta1.ListUsersResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
Source Files
¶
- user_service_grpc.pb.go