contactv1

package
v1.36.10-2025090507293... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 6 Imported by: 2

Documentation

Index

Constants

This section is empty.

Variables

var File_stargate_customer_contact_v1_customer_contact_service_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type AcceptLatestTermsAndConditionsRequest

type AcceptLatestTermsAndConditionsRequest struct {
	ContactUuid *v1.UUID `protobuf:"bytes,1,opt,name=contact_uuid,json=contactUuid,proto3,oneof" json:"contact_uuid,omitempty"`
	// contains filtered or unexported fields
}

func (*AcceptLatestTermsAndConditionsRequest) ClearContactUuid

func (x *AcceptLatestTermsAndConditionsRequest) ClearContactUuid()

func (*AcceptLatestTermsAndConditionsRequest) GetContactUuid

func (x *AcceptLatestTermsAndConditionsRequest) GetContactUuid() *v1.UUID

func (*AcceptLatestTermsAndConditionsRequest) HasContactUuid

func (x *AcceptLatestTermsAndConditionsRequest) HasContactUuid() bool

func (*AcceptLatestTermsAndConditionsRequest) ProtoMessage

func (*AcceptLatestTermsAndConditionsRequest) ProtoMessage()

func (*AcceptLatestTermsAndConditionsRequest) ProtoReflect

func (*AcceptLatestTermsAndConditionsRequest) Reset

func (*AcceptLatestTermsAndConditionsRequest) SetContactUuid

func (x *AcceptLatestTermsAndConditionsRequest) SetContactUuid(v *v1.UUID)

func (*AcceptLatestTermsAndConditionsRequest) String

type AcceptLatestTermsAndConditionsRequest_builder

type AcceptLatestTermsAndConditionsRequest_builder struct {
	ContactUuid *v1.UUID
	// contains filtered or unexported fields
}

func (AcceptLatestTermsAndConditionsRequest_builder) Build

type AcceptLatestTermsAndConditionsResponse

type AcceptLatestTermsAndConditionsResponse struct {
	// contains filtered or unexported fields
}

func (*AcceptLatestTermsAndConditionsResponse) ProtoMessage

func (*AcceptLatestTermsAndConditionsResponse) ProtoReflect

func (*AcceptLatestTermsAndConditionsResponse) Reset

func (*AcceptLatestTermsAndConditionsResponse) String

type AcceptLatestTermsAndConditionsResponse_builder

type AcceptLatestTermsAndConditionsResponse_builder struct {
	// contains filtered or unexported fields
}

func (AcceptLatestTermsAndConditionsResponse_builder) Build

type GetAdvertisingInterestsRequest

type GetAdvertisingInterestsRequest struct {

	// Unique identifier for customer contact.
	ContactUuid *v1.UUID `protobuf:"bytes,1,opt,name=contact_uuid,json=contactUuid,proto3" json:"contact_uuid,omitempty"`
	// contains filtered or unexported fields
}

func (*GetAdvertisingInterestsRequest) ClearContactUuid

func (x *GetAdvertisingInterestsRequest) ClearContactUuid()

func (*GetAdvertisingInterestsRequest) GetContactUuid

func (x *GetAdvertisingInterestsRequest) GetContactUuid() *v1.UUID

func (*GetAdvertisingInterestsRequest) HasContactUuid

func (x *GetAdvertisingInterestsRequest) HasContactUuid() bool

func (*GetAdvertisingInterestsRequest) ProtoMessage

func (*GetAdvertisingInterestsRequest) ProtoMessage()

func (*GetAdvertisingInterestsRequest) ProtoReflect

func (*GetAdvertisingInterestsRequest) Reset

func (x *GetAdvertisingInterestsRequest) Reset()

func (*GetAdvertisingInterestsRequest) SetContactUuid

func (x *GetAdvertisingInterestsRequest) SetContactUuid(v *v1.UUID)

func (*GetAdvertisingInterestsRequest) String

type GetAdvertisingInterestsRequest_builder

type GetAdvertisingInterestsRequest_builder struct {

	// Unique identifier for customer contact.
	ContactUuid *v1.UUID
	// contains filtered or unexported fields
}

func (GetAdvertisingInterestsRequest_builder) Build

type GetAdvertisingInterestsResponse

type GetAdvertisingInterestsResponse struct {

	// List of unique identifier for customer contact advertising interests currently present on the customer contact.
	InterestUuid []*v1.UUID `protobuf:"bytes,1,rep,name=interest_uuid,json=interestUuid,proto3" json:"interest_uuid,omitempty"`
	// contains filtered or unexported fields
}

func (*GetAdvertisingInterestsResponse) GetInterestUuid

func (x *GetAdvertisingInterestsResponse) GetInterestUuid() []*v1.UUID

func (*GetAdvertisingInterestsResponse) ProtoMessage

func (*GetAdvertisingInterestsResponse) ProtoMessage()

func (*GetAdvertisingInterestsResponse) ProtoReflect

func (*GetAdvertisingInterestsResponse) Reset

func (*GetAdvertisingInterestsResponse) SetInterestUuid

func (x *GetAdvertisingInterestsResponse) SetInterestUuid(v []*v1.UUID)

func (*GetAdvertisingInterestsResponse) String

type GetAdvertisingInterestsResponse_builder

type GetAdvertisingInterestsResponse_builder struct {

	// List of unique identifier for customer contact advertising interests currently present on the customer contact.
	InterestUuid []*v1.UUID
	// contains filtered or unexported fields
}

func (GetAdvertisingInterestsResponse_builder) Build

type HasAcceptedLatestTermsAndConditionsRequest

type HasAcceptedLatestTermsAndConditionsRequest struct {
	ContactUuid *v1.UUID `protobuf:"bytes,1,opt,name=contact_uuid,json=contactUuid,proto3" json:"contact_uuid,omitempty"`
	// contains filtered or unexported fields
}

func (*HasAcceptedLatestTermsAndConditionsRequest) ClearContactUuid

func (x *HasAcceptedLatestTermsAndConditionsRequest) ClearContactUuid()

func (*HasAcceptedLatestTermsAndConditionsRequest) GetContactUuid

func (x *HasAcceptedLatestTermsAndConditionsRequest) GetContactUuid() *v1.UUID

func (*HasAcceptedLatestTermsAndConditionsRequest) HasContactUuid

func (*HasAcceptedLatestTermsAndConditionsRequest) ProtoMessage

func (*HasAcceptedLatestTermsAndConditionsRequest) ProtoReflect

func (*HasAcceptedLatestTermsAndConditionsRequest) Reset

func (*HasAcceptedLatestTermsAndConditionsRequest) SetContactUuid

func (x *HasAcceptedLatestTermsAndConditionsRequest) SetContactUuid(v *v1.UUID)

func (*HasAcceptedLatestTermsAndConditionsRequest) String

type HasAcceptedLatestTermsAndConditionsRequest_builder

type HasAcceptedLatestTermsAndConditionsRequest_builder struct {
	ContactUuid *v1.UUID
	// contains filtered or unexported fields
}

func (HasAcceptedLatestTermsAndConditionsRequest_builder) Build

type HasAcceptedLatestTermsAndConditionsResponse

type HasAcceptedLatestTermsAndConditionsResponse struct {
	Accepted bool `protobuf:"varint,1,opt,name=accepted,proto3" json:"accepted,omitempty"`
	// contains filtered or unexported fields
}

func (*HasAcceptedLatestTermsAndConditionsResponse) GetAccepted

func (*HasAcceptedLatestTermsAndConditionsResponse) ProtoMessage

func (*HasAcceptedLatestTermsAndConditionsResponse) ProtoReflect

func (*HasAcceptedLatestTermsAndConditionsResponse) Reset

func (*HasAcceptedLatestTermsAndConditionsResponse) SetAccepted

func (*HasAcceptedLatestTermsAndConditionsResponse) String

type HasAcceptedLatestTermsAndConditionsResponse_builder

type HasAcceptedLatestTermsAndConditionsResponse_builder struct {
	Accepted bool
	// contains filtered or unexported fields
}

func (HasAcceptedLatestTermsAndConditionsResponse_builder) Build

type UpdateAdvertisingInterestsRequest

type UpdateAdvertisingInterestsRequest struct {

	// Unique identifier for customer contact.
	ContactUuid *v1.UUID `protobuf:"bytes,1,opt,name=contact_uuid,json=contactUuid,proto3" json:"contact_uuid,omitempty"`
	// List of unique identifier for customer contact advertising interests.
	// Existing customer contact advertising interests will be replaced with the provided list.
	InterestUuid []*v1.UUID `protobuf:"bytes,2,rep,name=interest_uuid,json=interestUuid,proto3" json:"interest_uuid,omitempty"`
	// contains filtered or unexported fields
}

func (*UpdateAdvertisingInterestsRequest) ClearContactUuid

func (x *UpdateAdvertisingInterestsRequest) ClearContactUuid()

func (*UpdateAdvertisingInterestsRequest) GetContactUuid

func (x *UpdateAdvertisingInterestsRequest) GetContactUuid() *v1.UUID

func (*UpdateAdvertisingInterestsRequest) GetInterestUuid

func (x *UpdateAdvertisingInterestsRequest) GetInterestUuid() []*v1.UUID

func (*UpdateAdvertisingInterestsRequest) HasContactUuid

func (x *UpdateAdvertisingInterestsRequest) HasContactUuid() bool

func (*UpdateAdvertisingInterestsRequest) ProtoMessage

func (*UpdateAdvertisingInterestsRequest) ProtoMessage()

func (*UpdateAdvertisingInterestsRequest) ProtoReflect

func (*UpdateAdvertisingInterestsRequest) Reset

func (*UpdateAdvertisingInterestsRequest) SetContactUuid

func (x *UpdateAdvertisingInterestsRequest) SetContactUuid(v *v1.UUID)

func (*UpdateAdvertisingInterestsRequest) SetInterestUuid

func (x *UpdateAdvertisingInterestsRequest) SetInterestUuid(v []*v1.UUID)

func (*UpdateAdvertisingInterestsRequest) String

type UpdateAdvertisingInterestsRequest_builder

type UpdateAdvertisingInterestsRequest_builder struct {

	// Unique identifier for customer contact.
	ContactUuid *v1.UUID
	// List of unique identifier for customer contact advertising interests.
	// Existing customer contact advertising interests will be replaced with the provided list.
	InterestUuid []*v1.UUID
	// contains filtered or unexported fields
}

func (UpdateAdvertisingInterestsRequest_builder) Build

type UpdateAdvertisingInterestsResponse

type UpdateAdvertisingInterestsResponse struct {
	// contains filtered or unexported fields
}

func (*UpdateAdvertisingInterestsResponse) ProtoMessage

func (*UpdateAdvertisingInterestsResponse) ProtoMessage()

func (*UpdateAdvertisingInterestsResponse) ProtoReflect

func (*UpdateAdvertisingInterestsResponse) Reset

func (*UpdateAdvertisingInterestsResponse) String

type UpdateAdvertisingInterestsResponse_builder

type UpdateAdvertisingInterestsResponse_builder struct {
	// contains filtered or unexported fields
}

func (UpdateAdvertisingInterestsResponse_builder) Build

Source Files

  • customer_contact_service.pb.go

Jump to