itemv1beta1

package
v1.36.11-2025122211490... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 6 Imported by: 2

Documentation

Index

Constants

This section is empty.

Variables

var File_stargate_item_v1beta1_item_service_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type Item

type Item struct {

	// Item description 1.
	Description1 *string `protobuf:"bytes,1,opt,name=description1,proto3,oneof" json:"description1,omitempty"`
	// Item type.
	TypeUuid *v1.UUID `protobuf:"bytes,2,opt,name=type_uuid,json=typeUuid,proto3,oneof" json:"type_uuid,omitempty"`
	// Item category.
	CategoryUuid *v1.UUID `protobuf:"bytes,3,opt,name=category_uuid,json=categoryUuid,proto3,oneof" json:"category_uuid,omitempty"`
	// Item vendor.
	VendorUuid *v1.UUID `protobuf:"bytes,4,opt,name=vendor_uuid,json=vendorUuid,proto3,oneof" json:"vendor_uuid,omitempty"`
	// Item free text.
	FreeText *string `protobuf:"bytes,5,opt,name=free_text,json=freeText,proto3,oneof" json:"free_text,omitempty"`
	// contains filtered or unexported fields
}

func (*Item) ClearCategoryUuid

func (x *Item) ClearCategoryUuid()

func (*Item) ClearDescription1

func (x *Item) ClearDescription1()

func (*Item) ClearFreeText

func (x *Item) ClearFreeText()

func (*Item) ClearTypeUuid

func (x *Item) ClearTypeUuid()

func (*Item) ClearVendorUuid

func (x *Item) ClearVendorUuid()

func (*Item) GetCategoryUuid

func (x *Item) GetCategoryUuid() *v1.UUID

func (*Item) GetDescription1

func (x *Item) GetDescription1() string

func (*Item) GetFreeText

func (x *Item) GetFreeText() string

func (*Item) GetTypeUuid

func (x *Item) GetTypeUuid() *v1.UUID

func (*Item) GetVendorUuid

func (x *Item) GetVendorUuid() *v1.UUID

func (*Item) HasCategoryUuid

func (x *Item) HasCategoryUuid() bool

func (*Item) HasDescription1

func (x *Item) HasDescription1() bool

func (*Item) HasFreeText

func (x *Item) HasFreeText() bool

func (*Item) HasTypeUuid

func (x *Item) HasTypeUuid() bool

func (*Item) HasVendorUuid

func (x *Item) HasVendorUuid() bool

func (*Item) ProtoMessage

func (*Item) ProtoMessage()

func (*Item) ProtoReflect

func (x *Item) ProtoReflect() protoreflect.Message

func (*Item) Reset

func (x *Item) Reset()

func (*Item) SetCategoryUuid

func (x *Item) SetCategoryUuid(v *v1.UUID)

func (*Item) SetDescription1

func (x *Item) SetDescription1(v string)

func (*Item) SetFreeText

func (x *Item) SetFreeText(v string)

func (*Item) SetTypeUuid

func (x *Item) SetTypeUuid(v *v1.UUID)

func (*Item) SetVendorUuid

func (x *Item) SetVendorUuid(v *v1.UUID)

func (*Item) String

func (x *Item) String() string

type ItemOptions

type ItemOptions struct {

	// Defines if the item is a bundle (containing multiple items).
	IsBundle *bool `protobuf:"varint,1,opt,name=is_bundle,json=isBundle,proto3,oneof" json:"is_bundle,omitempty"`
	// Defines if the item is bound to a customer.
	IsCustomerBinding *bool `protobuf:"varint,2,opt,name=is_customer_binding,json=isCustomerBinding,proto3,oneof" json:"is_customer_binding,omitempty"`
	// Defines if the item follows an OPG.
	// “Order Processing Guideline” or “OPG” means a document issued by HP
	// detailing a specific end-user customer deal or promotions for which HP grants Special Pricing.
	IsOpg *bool `protobuf:"varint,3,opt,name=is_opg,json=isOpg,proto3,oneof" json:"is_opg,omitempty"`
	// Defines if an item is second-hand.
	IsPreowned *bool `protobuf:"varint,4,opt,name=is_preowned,json=isPreowned,proto3,oneof" json:"is_preowned,omitempty"`
	// Defines if the item is service bound.
	IsService *bool `protobuf:"varint,5,opt,name=is_service,json=isService,proto3,oneof" json:"is_service,omitempty"`
	// Defines if the item is a factory item.
	IsFactory *bool `protobuf:"varint,6,opt,name=is_factory,json=isFactory,proto3,oneof" json:"is_factory,omitempty"`
	// Defines if the item is factory integrated by default. ('%-L21%' / '%FIO%')
	IsFactoryIntegrated *bool `` /* 127-byte string literal not displayed */
	// Defines if the item is excluded from assembling.
	HasAssemblingExclusion *bool `` /* 136-byte string literal not displayed */
	// Defines if the item is highlighted on the assembling order document.
	IsHighlightedOnAssemblingOrder *bool `` /* 164-byte string literal not displayed */
	// Defines if the item is assembled by the manufacturer. ('%0D1%' / '%#B19%')
	IsAssembledByManufacturer *bool `` /* 148-byte string literal not displayed */
	// Defines if the item is excluded from any statistics.
	StockOptionNoStatistic *bool `` /* 139-byte string literal not displayed */
	// Defines if the item can only be invoiced in contracts.
	UseContract *bool `protobuf:"varint,12,opt,name=use_contract,json=useContract,proto3,oneof" json:"use_contract,omitempty"`
	// Defines if the item can be used in sales.
	UseSales *bool `protobuf:"varint,13,opt,name=use_sales,json=useSales,proto3,oneof" json:"use_sales,omitempty"`
	// Defines if the sales price is be fixed and can't be changed by user.
	HasFixedSalesPrice *bool `` /* 127-byte string literal not displayed */
	// Defines if the item is getting resolved when added to a document.
	BillOfMaterialDissolve *bool `` /* 139-byte string literal not displayed */
	// Defines if the purchase price can always be edited, overriding any other conditions.
	ForceEditablePurchasePrice *bool `` /* 151-byte string literal not displayed */
	// Defines if the purchase price of the order position is linked to the purchase order position.
	IndividualPrice *bool `protobuf:"varint,17,opt,name=individual_price,json=individualPrice,proto3,oneof" json:"individual_price,omitempty"`
	// Defines if the free text is hidden on purchase orders.
	FreeTextNotOnPurchaseOrder *bool `` /* 155-byte string literal not displayed */
	// Defines if the item can only be used in sets.
	HasSetBinding *bool `protobuf:"varint,19,opt,name=has_set_binding,json=hasSetBinding,proto3,oneof" json:"has_set_binding,omitempty"`
	// Defines if the item is prohibited in sets and can only be added as a normal position.
	IsProhibitedInSet *bool `protobuf:"varint,20,opt,name=is_prohibited_in_set,json=isProhibitedInSet,proto3,oneof" json:"is_prohibited_in_set,omitempty"`
	// Defines if the item is always hidden on all printed documents.
	IsHiddenOnPrintedDocument *bool `` /* 150-byte string literal not displayed */
	// Defines if the item can only be used in offers.
	IsOfferOnly *bool `protobuf:"varint,22,opt,name=is_offer_only,json=isOfferOnly,proto3,oneof" json:"is_offer_only,omitempty"`
	// Defines if the item property "use_sales" was set automatically by the system (only used for filtering, doesn't have any effect).
	IsOrderableByDefault *bool `` /* 133-byte string literal not displayed */
	// Defines if the price is always visible to the user.
	PriceIsAlwaysVisible *bool `` /* 133-byte string literal not displayed */
	// Defines if the item is readonly in documents, i.e. cannot be edited.
	IsReadonly *bool `protobuf:"varint,25,opt,name=is_readonly,json=isReadonly,proto3,oneof" json:"is_readonly,omitempty"`
	// Defines if the item is shown as sold out on web shop.
	IsSoldOut *bool `protobuf:"varint,26,opt,name=is_sold_out,json=isSoldOut,proto3,oneof" json:"is_sold_out,omitempty"`
	// Defines if the item is a customized HP "top config" item.
	// "Top config" items are built by HP and sent directly to the customer.
	IsTopConfig *bool `protobuf:"varint,27,opt,name=is_top_config,json=isTopConfig,proto3,oneof" json:"is_top_config,omitempty"`
	// Defines if the item can be sold without being in stock anymore.
	IsNegativeDisposable *bool `` /* 131-byte string literal not displayed */
	// Defines if the item has special highlighting in offers and orders.
	IsFocusProduct *bool `protobuf:"varint,29,opt,name=is_focus_product,json=isFocusProduct,proto3,oneof" json:"is_focus_product,omitempty"`
	// Defines if the item is shown in web shop.
	IsWebShop *bool `protobuf:"varint,30,opt,name=is_web_shop,json=isWebShop,proto3,oneof" json:"is_web_shop,omitempty"`
	// Defines if the item is NEVER shown in the web shop.
	ShopStateNoShop *bool `protobuf:"varint,31,opt,name=shop_state_no_shop,json=shopStateNoShop,proto3,oneof" json:"shop_state_no_shop,omitempty"`
	// Defines if a "request for quotation" option is shown instead of a normal sales price in the web shop.
	ShopPriceOnDemand *bool `protobuf:"varint,32,opt,name=shop_price_on_demand,json=shopPriceOnDemand,proto3,oneof" json:"shop_price_on_demand,omitempty"`
	// Defines if the item is marked to be checked (only used for filtering, doesn't have any effect).
	ShopStateCheck *bool `protobuf:"varint,33,opt,name=shop_state_check,json=shopStateCheck,proto3,oneof" json:"shop_state_check,omitempty"`
	// Defines if the description will be used for web shop, instead of 1worldsync.
	SyncDescriptionLong *bool `` /* 128-byte string literal not displayed */
	// Defines if the description will be forced for web shop, instead of 1worldsync.
	SyncForceDescription *bool `` /* 131-byte string literal not displayed */
	// Defines if external properties are shown on the item.
	SkipPropertySync *bool `protobuf:"varint,34,opt,name=skip_property_sync,json=skipPropertySync,proto3,oneof" json:"skip_property_sync,omitempty"`
	// Defines if a order number is required on stock in.
	StockOptionNoOrderNumber *bool `` /* 147-byte string literal not displayed */
	// Defines if the item can't be picked for picking.
	StockOptionNoPicking *bool `` /* 133-byte string literal not displayed */
	// Defines if the item is not RMA-able.
	StockOptionNoRma *bool `protobuf:"varint,37,opt,name=stock_option_no_rma,json=stockOptionNoRma,proto3,oneof" json:"stock_option_no_rma,omitempty"`
	// Defines if a serial number is required on stock in.
	StockOptionNoSerialNumber *bool `` /* 150-byte string literal not displayed */
	// Defines if the item is listed in stock validation reports.
	StockOptionNoStocktaking *bool `` /* 145-byte string literal not displayed */
	// Defines if the item is unique per document when added by cross selling.
	IsUniqueCrossSellingItem *bool `` /* 147-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*ItemOptions) ClearBillOfMaterialDissolve

func (x *ItemOptions) ClearBillOfMaterialDissolve()

func (*ItemOptions) ClearForceEditablePurchasePrice

func (x *ItemOptions) ClearForceEditablePurchasePrice()

func (*ItemOptions) ClearFreeTextNotOnPurchaseOrder

func (x *ItemOptions) ClearFreeTextNotOnPurchaseOrder()

func (*ItemOptions) ClearHasAssemblingExclusion

func (x *ItemOptions) ClearHasAssemblingExclusion()

func (*ItemOptions) ClearHasFixedSalesPrice

func (x *ItemOptions) ClearHasFixedSalesPrice()

func (*ItemOptions) ClearHasSetBinding

func (x *ItemOptions) ClearHasSetBinding()

func (*ItemOptions) ClearIndividualPrice

func (x *ItemOptions) ClearIndividualPrice()

func (*ItemOptions) ClearIsAssembledByManufacturer

func (x *ItemOptions) ClearIsAssembledByManufacturer()

func (*ItemOptions) ClearIsBundle

func (x *ItemOptions) ClearIsBundle()

func (*ItemOptions) ClearIsCustomerBinding

func (x *ItemOptions) ClearIsCustomerBinding()

func (*ItemOptions) ClearIsFactory

func (x *ItemOptions) ClearIsFactory()

func (*ItemOptions) ClearIsFactoryIntegrated

func (x *ItemOptions) ClearIsFactoryIntegrated()

func (*ItemOptions) ClearIsFocusProduct

func (x *ItemOptions) ClearIsFocusProduct()

func (*ItemOptions) ClearIsHiddenOnPrintedDocument

func (x *ItemOptions) ClearIsHiddenOnPrintedDocument()

func (*ItemOptions) ClearIsHighlightedOnAssemblingOrder

func (x *ItemOptions) ClearIsHighlightedOnAssemblingOrder()

func (*ItemOptions) ClearIsNegativeDisposable

func (x *ItemOptions) ClearIsNegativeDisposable()

func (*ItemOptions) ClearIsOfferOnly

func (x *ItemOptions) ClearIsOfferOnly()

func (*ItemOptions) ClearIsOpg

func (x *ItemOptions) ClearIsOpg()

func (*ItemOptions) ClearIsOrderableByDefault

func (x *ItemOptions) ClearIsOrderableByDefault()

func (*ItemOptions) ClearIsPreowned

func (x *ItemOptions) ClearIsPreowned()

func (*ItemOptions) ClearIsProhibitedInSet

func (x *ItemOptions) ClearIsProhibitedInSet()

func (*ItemOptions) ClearIsReadonly

func (x *ItemOptions) ClearIsReadonly()

func (*ItemOptions) ClearIsService

func (x *ItemOptions) ClearIsService()

func (*ItemOptions) ClearIsSoldOut

func (x *ItemOptions) ClearIsSoldOut()

func (*ItemOptions) ClearIsTopConfig

func (x *ItemOptions) ClearIsTopConfig()

func (*ItemOptions) ClearIsUniqueCrossSellingItem

func (x *ItemOptions) ClearIsUniqueCrossSellingItem()

func (*ItemOptions) ClearIsWebShop

func (x *ItemOptions) ClearIsWebShop()

func (*ItemOptions) ClearPriceIsAlwaysVisible

func (x *ItemOptions) ClearPriceIsAlwaysVisible()

func (*ItemOptions) ClearShopPriceOnDemand

func (x *ItemOptions) ClearShopPriceOnDemand()

func (*ItemOptions) ClearShopStateCheck

func (x *ItemOptions) ClearShopStateCheck()

func (*ItemOptions) ClearShopStateNoShop

func (x *ItemOptions) ClearShopStateNoShop()

func (*ItemOptions) ClearSkipPropertySync

func (x *ItemOptions) ClearSkipPropertySync()

func (*ItemOptions) ClearStockOptionNoOrderNumber

func (x *ItemOptions) ClearStockOptionNoOrderNumber()

func (*ItemOptions) ClearStockOptionNoPicking

func (x *ItemOptions) ClearStockOptionNoPicking()

func (*ItemOptions) ClearStockOptionNoRma

func (x *ItemOptions) ClearStockOptionNoRma()

func (*ItemOptions) ClearStockOptionNoSerialNumber

func (x *ItemOptions) ClearStockOptionNoSerialNumber()

func (*ItemOptions) ClearStockOptionNoStatistic

func (x *ItemOptions) ClearStockOptionNoStatistic()

func (*ItemOptions) ClearStockOptionNoStocktaking

func (x *ItemOptions) ClearStockOptionNoStocktaking()

func (*ItemOptions) ClearSyncDescriptionLong

func (x *ItemOptions) ClearSyncDescriptionLong()

func (*ItemOptions) ClearSyncForceDescription

func (x *ItemOptions) ClearSyncForceDescription()

func (*ItemOptions) ClearUseContract

func (x *ItemOptions) ClearUseContract()

func (*ItemOptions) ClearUseSales

func (x *ItemOptions) ClearUseSales()

func (*ItemOptions) GetBillOfMaterialDissolve

func (x *ItemOptions) GetBillOfMaterialDissolve() bool

func (*ItemOptions) GetForceEditablePurchasePrice

func (x *ItemOptions) GetForceEditablePurchasePrice() bool

func (*ItemOptions) GetFreeTextNotOnPurchaseOrder

func (x *ItemOptions) GetFreeTextNotOnPurchaseOrder() bool

func (*ItemOptions) GetHasAssemblingExclusion

func (x *ItemOptions) GetHasAssemblingExclusion() bool

func (*ItemOptions) GetHasFixedSalesPrice

func (x *ItemOptions) GetHasFixedSalesPrice() bool

func (*ItemOptions) GetHasSetBinding

func (x *ItemOptions) GetHasSetBinding() bool

func (*ItemOptions) GetIndividualPrice

func (x *ItemOptions) GetIndividualPrice() bool

func (*ItemOptions) GetIsAssembledByManufacturer

func (x *ItemOptions) GetIsAssembledByManufacturer() bool

func (*ItemOptions) GetIsBundle

func (x *ItemOptions) GetIsBundle() bool

func (*ItemOptions) GetIsCustomerBinding

func (x *ItemOptions) GetIsCustomerBinding() bool

func (*ItemOptions) GetIsFactory

func (x *ItemOptions) GetIsFactory() bool

func (*ItemOptions) GetIsFactoryIntegrated

func (x *ItemOptions) GetIsFactoryIntegrated() bool

func (*ItemOptions) GetIsFocusProduct

func (x *ItemOptions) GetIsFocusProduct() bool

func (*ItemOptions) GetIsHiddenOnPrintedDocument

func (x *ItemOptions) GetIsHiddenOnPrintedDocument() bool

func (*ItemOptions) GetIsHighlightedOnAssemblingOrder

func (x *ItemOptions) GetIsHighlightedOnAssemblingOrder() bool

func (*ItemOptions) GetIsNegativeDisposable

func (x *ItemOptions) GetIsNegativeDisposable() bool

func (*ItemOptions) GetIsOfferOnly

func (x *ItemOptions) GetIsOfferOnly() bool

func (*ItemOptions) GetIsOpg

func (x *ItemOptions) GetIsOpg() bool

func (*ItemOptions) GetIsOrderableByDefault

func (x *ItemOptions) GetIsOrderableByDefault() bool

func (*ItemOptions) GetIsPreowned

func (x *ItemOptions) GetIsPreowned() bool

func (*ItemOptions) GetIsProhibitedInSet

func (x *ItemOptions) GetIsProhibitedInSet() bool

func (*ItemOptions) GetIsReadonly

func (x *ItemOptions) GetIsReadonly() bool

func (*ItemOptions) GetIsService

func (x *ItemOptions) GetIsService() bool

func (*ItemOptions) GetIsSoldOut

func (x *ItemOptions) GetIsSoldOut() bool

func (*ItemOptions) GetIsTopConfig

func (x *ItemOptions) GetIsTopConfig() bool

func (*ItemOptions) GetIsUniqueCrossSellingItem

func (x *ItemOptions) GetIsUniqueCrossSellingItem() bool

func (*ItemOptions) GetIsWebShop

func (x *ItemOptions) GetIsWebShop() bool

func (*ItemOptions) GetPriceIsAlwaysVisible

func (x *ItemOptions) GetPriceIsAlwaysVisible() bool

func (*ItemOptions) GetShopPriceOnDemand

func (x *ItemOptions) GetShopPriceOnDemand() bool

func (*ItemOptions) GetShopStateCheck

func (x *ItemOptions) GetShopStateCheck() bool

func (*ItemOptions) GetShopStateNoShop

func (x *ItemOptions) GetShopStateNoShop() bool

func (*ItemOptions) GetSkipPropertySync

func (x *ItemOptions) GetSkipPropertySync() bool

func (*ItemOptions) GetStockOptionNoOrderNumber

func (x *ItemOptions) GetStockOptionNoOrderNumber() bool

func (*ItemOptions) GetStockOptionNoPicking

func (x *ItemOptions) GetStockOptionNoPicking() bool

func (*ItemOptions) GetStockOptionNoRma

func (x *ItemOptions) GetStockOptionNoRma() bool

func (*ItemOptions) GetStockOptionNoSerialNumber

func (x *ItemOptions) GetStockOptionNoSerialNumber() bool

func (*ItemOptions) GetStockOptionNoStatistic

func (x *ItemOptions) GetStockOptionNoStatistic() bool

func (*ItemOptions) GetStockOptionNoStocktaking

func (x *ItemOptions) GetStockOptionNoStocktaking() bool

func (*ItemOptions) GetSyncDescriptionLong

func (x *ItemOptions) GetSyncDescriptionLong() bool

func (*ItemOptions) GetSyncForceDescription

func (x *ItemOptions) GetSyncForceDescription() bool

func (*ItemOptions) GetUseContract

func (x *ItemOptions) GetUseContract() bool

func (*ItemOptions) GetUseSales

func (x *ItemOptions) GetUseSales() bool

func (*ItemOptions) HasBillOfMaterialDissolve

func (x *ItemOptions) HasBillOfMaterialDissolve() bool

func (*ItemOptions) HasForceEditablePurchasePrice

func (x *ItemOptions) HasForceEditablePurchasePrice() bool

func (*ItemOptions) HasFreeTextNotOnPurchaseOrder

func (x *ItemOptions) HasFreeTextNotOnPurchaseOrder() bool

func (*ItemOptions) HasHasAssemblingExclusion

func (x *ItemOptions) HasHasAssemblingExclusion() bool

func (*ItemOptions) HasHasFixedSalesPrice

func (x *ItemOptions) HasHasFixedSalesPrice() bool

func (*ItemOptions) HasHasSetBinding

func (x *ItemOptions) HasHasSetBinding() bool

func (*ItemOptions) HasIndividualPrice

func (x *ItemOptions) HasIndividualPrice() bool

func (*ItemOptions) HasIsAssembledByManufacturer

func (x *ItemOptions) HasIsAssembledByManufacturer() bool

func (*ItemOptions) HasIsBundle

func (x *ItemOptions) HasIsBundle() bool

func (*ItemOptions) HasIsCustomerBinding

func (x *ItemOptions) HasIsCustomerBinding() bool

func (*ItemOptions) HasIsFactory

func (x *ItemOptions) HasIsFactory() bool

func (*ItemOptions) HasIsFactoryIntegrated

func (x *ItemOptions) HasIsFactoryIntegrated() bool

func (*ItemOptions) HasIsFocusProduct

func (x *ItemOptions) HasIsFocusProduct() bool

func (*ItemOptions) HasIsHiddenOnPrintedDocument

func (x *ItemOptions) HasIsHiddenOnPrintedDocument() bool

func (*ItemOptions) HasIsHighlightedOnAssemblingOrder

func (x *ItemOptions) HasIsHighlightedOnAssemblingOrder() bool

func (*ItemOptions) HasIsNegativeDisposable

func (x *ItemOptions) HasIsNegativeDisposable() bool

func (*ItemOptions) HasIsOfferOnly

func (x *ItemOptions) HasIsOfferOnly() bool

func (*ItemOptions) HasIsOpg

func (x *ItemOptions) HasIsOpg() bool

func (*ItemOptions) HasIsOrderableByDefault

func (x *ItemOptions) HasIsOrderableByDefault() bool

func (*ItemOptions) HasIsPreowned

func (x *ItemOptions) HasIsPreowned() bool

func (*ItemOptions) HasIsProhibitedInSet

func (x *ItemOptions) HasIsProhibitedInSet() bool

func (*ItemOptions) HasIsReadonly

func (x *ItemOptions) HasIsReadonly() bool

func (*ItemOptions) HasIsService

func (x *ItemOptions) HasIsService() bool

func (*ItemOptions) HasIsSoldOut

func (x *ItemOptions) HasIsSoldOut() bool

func (*ItemOptions) HasIsTopConfig

func (x *ItemOptions) HasIsTopConfig() bool

func (*ItemOptions) HasIsUniqueCrossSellingItem

func (x *ItemOptions) HasIsUniqueCrossSellingItem() bool

func (*ItemOptions) HasIsWebShop

func (x *ItemOptions) HasIsWebShop() bool

func (*ItemOptions) HasPriceIsAlwaysVisible

func (x *ItemOptions) HasPriceIsAlwaysVisible() bool

func (*ItemOptions) HasShopPriceOnDemand

func (x *ItemOptions) HasShopPriceOnDemand() bool

func (*ItemOptions) HasShopStateCheck

func (x *ItemOptions) HasShopStateCheck() bool

func (*ItemOptions) HasShopStateNoShop

func (x *ItemOptions) HasShopStateNoShop() bool

func (*ItemOptions) HasSkipPropertySync

func (x *ItemOptions) HasSkipPropertySync() bool

func (*ItemOptions) HasStockOptionNoOrderNumber

func (x *ItemOptions) HasStockOptionNoOrderNumber() bool

func (*ItemOptions) HasStockOptionNoPicking

func (x *ItemOptions) HasStockOptionNoPicking() bool

func (*ItemOptions) HasStockOptionNoRma

func (x *ItemOptions) HasStockOptionNoRma() bool

func (*ItemOptions) HasStockOptionNoSerialNumber

func (x *ItemOptions) HasStockOptionNoSerialNumber() bool

func (*ItemOptions) HasStockOptionNoStatistic

func (x *ItemOptions) HasStockOptionNoStatistic() bool

func (*ItemOptions) HasStockOptionNoStocktaking

func (x *ItemOptions) HasStockOptionNoStocktaking() bool

func (*ItemOptions) HasSyncDescriptionLong

func (x *ItemOptions) HasSyncDescriptionLong() bool

func (*ItemOptions) HasSyncForceDescription

func (x *ItemOptions) HasSyncForceDescription() bool

func (*ItemOptions) HasUseContract

func (x *ItemOptions) HasUseContract() bool

func (*ItemOptions) HasUseSales

func (x *ItemOptions) HasUseSales() bool

func (*ItemOptions) ProtoMessage

func (*ItemOptions) ProtoMessage()

func (*ItemOptions) ProtoReflect

func (x *ItemOptions) ProtoReflect() protoreflect.Message

func (*ItemOptions) Reset

func (x *ItemOptions) Reset()

func (*ItemOptions) SetBillOfMaterialDissolve

func (x *ItemOptions) SetBillOfMaterialDissolve(v bool)

func (*ItemOptions) SetForceEditablePurchasePrice

func (x *ItemOptions) SetForceEditablePurchasePrice(v bool)

func (*ItemOptions) SetFreeTextNotOnPurchaseOrder

func (x *ItemOptions) SetFreeTextNotOnPurchaseOrder(v bool)

func (*ItemOptions) SetHasAssemblingExclusion

func (x *ItemOptions) SetHasAssemblingExclusion(v bool)

func (*ItemOptions) SetHasFixedSalesPrice

func (x *ItemOptions) SetHasFixedSalesPrice(v bool)

func (*ItemOptions) SetHasSetBinding

func (x *ItemOptions) SetHasSetBinding(v bool)

func (*ItemOptions) SetIndividualPrice

func (x *ItemOptions) SetIndividualPrice(v bool)

func (*ItemOptions) SetIsAssembledByManufacturer

func (x *ItemOptions) SetIsAssembledByManufacturer(v bool)

func (*ItemOptions) SetIsBundle

func (x *ItemOptions) SetIsBundle(v bool)

func (*ItemOptions) SetIsCustomerBinding

func (x *ItemOptions) SetIsCustomerBinding(v bool)

func (*ItemOptions) SetIsFactory

func (x *ItemOptions) SetIsFactory(v bool)

func (*ItemOptions) SetIsFactoryIntegrated

func (x *ItemOptions) SetIsFactoryIntegrated(v bool)

func (*ItemOptions) SetIsFocusProduct

func (x *ItemOptions) SetIsFocusProduct(v bool)

func (*ItemOptions) SetIsHiddenOnPrintedDocument

func (x *ItemOptions) SetIsHiddenOnPrintedDocument(v bool)

func (*ItemOptions) SetIsHighlightedOnAssemblingOrder

func (x *ItemOptions) SetIsHighlightedOnAssemblingOrder(v bool)

func (*ItemOptions) SetIsNegativeDisposable

func (x *ItemOptions) SetIsNegativeDisposable(v bool)

func (*ItemOptions) SetIsOfferOnly

func (x *ItemOptions) SetIsOfferOnly(v bool)

func (*ItemOptions) SetIsOpg

func (x *ItemOptions) SetIsOpg(v bool)

func (*ItemOptions) SetIsOrderableByDefault

func (x *ItemOptions) SetIsOrderableByDefault(v bool)

func (*ItemOptions) SetIsPreowned

func (x *ItemOptions) SetIsPreowned(v bool)

func (*ItemOptions) SetIsProhibitedInSet

func (x *ItemOptions) SetIsProhibitedInSet(v bool)

func (*ItemOptions) SetIsReadonly

func (x *ItemOptions) SetIsReadonly(v bool)

func (*ItemOptions) SetIsService

func (x *ItemOptions) SetIsService(v bool)

func (*ItemOptions) SetIsSoldOut

func (x *ItemOptions) SetIsSoldOut(v bool)

func (*ItemOptions) SetIsTopConfig

func (x *ItemOptions) SetIsTopConfig(v bool)

func (*ItemOptions) SetIsUniqueCrossSellingItem

func (x *ItemOptions) SetIsUniqueCrossSellingItem(v bool)

func (*ItemOptions) SetIsWebShop

func (x *ItemOptions) SetIsWebShop(v bool)

func (*ItemOptions) SetPriceIsAlwaysVisible

func (x *ItemOptions) SetPriceIsAlwaysVisible(v bool)

func (*ItemOptions) SetShopPriceOnDemand

func (x *ItemOptions) SetShopPriceOnDemand(v bool)

func (*ItemOptions) SetShopStateCheck

func (x *ItemOptions) SetShopStateCheck(v bool)

func (*ItemOptions) SetShopStateNoShop

func (x *ItemOptions) SetShopStateNoShop(v bool)

func (*ItemOptions) SetSkipPropertySync

func (x *ItemOptions) SetSkipPropertySync(v bool)

func (*ItemOptions) SetStockOptionNoOrderNumber

func (x *ItemOptions) SetStockOptionNoOrderNumber(v bool)

func (*ItemOptions) SetStockOptionNoPicking

func (x *ItemOptions) SetStockOptionNoPicking(v bool)

func (*ItemOptions) SetStockOptionNoRma

func (x *ItemOptions) SetStockOptionNoRma(v bool)

func (*ItemOptions) SetStockOptionNoSerialNumber

func (x *ItemOptions) SetStockOptionNoSerialNumber(v bool)

func (*ItemOptions) SetStockOptionNoStatistic

func (x *ItemOptions) SetStockOptionNoStatistic(v bool)

func (*ItemOptions) SetStockOptionNoStocktaking

func (x *ItemOptions) SetStockOptionNoStocktaking(v bool)

func (*ItemOptions) SetSyncDescriptionLong

func (x *ItemOptions) SetSyncDescriptionLong(v bool)

func (*ItemOptions) SetSyncForceDescription

func (x *ItemOptions) SetSyncForceDescription(v bool)

func (*ItemOptions) SetUseContract

func (x *ItemOptions) SetUseContract(v bool)

func (*ItemOptions) SetUseSales

func (x *ItemOptions) SetUseSales(v bool)

func (*ItemOptions) String

func (x *ItemOptions) String() string

type ItemOptions_builder

type ItemOptions_builder struct {

	// Defines if the item is a bundle (containing multiple items).
	IsBundle *bool
	// Defines if the item is bound to a customer.
	IsCustomerBinding *bool
	// Defines if the item follows an OPG.
	// “Order Processing Guideline” or “OPG” means a document issued by HP
	// detailing a specific end-user customer deal or promotions for which HP grants Special Pricing.
	IsOpg *bool
	// Defines if an item is second-hand.
	IsPreowned *bool
	// Defines if the item is service bound.
	IsService *bool
	// Defines if the item is a factory item.
	IsFactory *bool
	// Defines if the item is factory integrated by default. ('%-L21%' / '%FIO%')
	IsFactoryIntegrated *bool
	// Defines if the item is excluded from assembling.
	HasAssemblingExclusion *bool
	// Defines if the item is highlighted on the assembling order document.
	IsHighlightedOnAssemblingOrder *bool
	// Defines if the item is assembled by the manufacturer. ('%0D1%' / '%#B19%')
	IsAssembledByManufacturer *bool
	// Defines if the item is excluded from any statistics.
	StockOptionNoStatistic *bool
	// Defines if the item can only be invoiced in contracts.
	UseContract *bool
	// Defines if the item can be used in sales.
	UseSales *bool
	// Defines if the sales price is be fixed and can't be changed by user.
	HasFixedSalesPrice *bool
	// Defines if the item is getting resolved when added to a document.
	BillOfMaterialDissolve *bool
	// Defines if the purchase price can always be edited, overriding any other conditions.
	ForceEditablePurchasePrice *bool
	// Defines if the purchase price of the order position is linked to the purchase order position.
	IndividualPrice *bool
	// Defines if the free text is hidden on purchase orders.
	FreeTextNotOnPurchaseOrder *bool
	// Defines if the item can only be used in sets.
	HasSetBinding *bool
	// Defines if the item is prohibited in sets and can only be added as a normal position.
	IsProhibitedInSet *bool
	// Defines if the item is always hidden on all printed documents.
	IsHiddenOnPrintedDocument *bool
	// Defines if the item can only be used in offers.
	IsOfferOnly *bool
	// Defines if the item property "use_sales" was set automatically by the system (only used for filtering, doesn't have any effect).
	IsOrderableByDefault *bool
	// Defines if the price is always visible to the user.
	PriceIsAlwaysVisible *bool
	// Defines if the item is readonly in documents, i.e. cannot be edited.
	IsReadonly *bool
	// Defines if the item is shown as sold out on web shop.
	IsSoldOut *bool
	// Defines if the item is a customized HP "top config" item.
	// "Top config" items are built by HP and sent directly to the customer.
	IsTopConfig *bool
	// Defines if the item can be sold without being in stock anymore.
	IsNegativeDisposable *bool
	// Defines if the item has special highlighting in offers and orders.
	IsFocusProduct *bool
	// Defines if the item is shown in web shop.
	IsWebShop *bool
	// Defines if the item is NEVER shown in the web shop.
	ShopStateNoShop *bool
	// Defines if a "request for quotation" option is shown instead of a normal sales price in the web shop.
	ShopPriceOnDemand *bool
	// Defines if the item is marked to be checked (only used for filtering, doesn't have any effect).
	ShopStateCheck *bool
	// Defines if the description will be used for web shop, instead of 1worldsync.
	SyncDescriptionLong *bool
	// Defines if the description will be forced for web shop, instead of 1worldsync.
	SyncForceDescription *bool
	// Defines if external properties are shown on the item.
	SkipPropertySync *bool
	// Defines if a order number is required on stock in.
	StockOptionNoOrderNumber *bool
	// Defines if the item can't be picked for picking.
	StockOptionNoPicking *bool
	// Defines if the item is not RMA-able.
	StockOptionNoRma *bool
	// Defines if a serial number is required on stock in.
	StockOptionNoSerialNumber *bool
	// Defines if the item is listed in stock validation reports.
	StockOptionNoStocktaking *bool
	// Defines if the item is unique per document when added by cross selling.
	IsUniqueCrossSellingItem *bool
	// contains filtered or unexported fields
}

func (ItemOptions_builder) Build

func (b0 ItemOptions_builder) Build() *ItemOptions

type Item_builder

type Item_builder struct {

	// Item description 1.
	Description1 *string
	// Item type.
	TypeUuid *v1.UUID
	// Item category.
	CategoryUuid *v1.UUID
	// Item vendor.
	VendorUuid *v1.UUID
	// Item free text.
	FreeText *string
	// contains filtered or unexported fields
}

func (Item_builder) Build

func (b0 Item_builder) Build() *Item

type UpdateItemsRequest

type UpdateItemsRequest struct {

	// Unique identifier to identify the item.
	ItemNo  []string     `protobuf:"bytes,1,rep,name=item_no,json=itemNo,proto3" json:"item_no,omitempty"`
	Item    *Item        `protobuf:"bytes,2,opt,name=item,proto3,oneof" json:"item,omitempty"`
	Options *ItemOptions `protobuf:"bytes,3,opt,name=options,proto3,oneof" json:"options,omitempty"`
	// contains filtered or unexported fields
}

func (*UpdateItemsRequest) ClearItem

func (x *UpdateItemsRequest) ClearItem()

func (*UpdateItemsRequest) ClearOptions

func (x *UpdateItemsRequest) ClearOptions()

func (*UpdateItemsRequest) GetItem

func (x *UpdateItemsRequest) GetItem() *Item

func (*UpdateItemsRequest) GetItemNo

func (x *UpdateItemsRequest) GetItemNo() []string

func (*UpdateItemsRequest) GetOptions

func (x *UpdateItemsRequest) GetOptions() *ItemOptions

func (*UpdateItemsRequest) HasItem

func (x *UpdateItemsRequest) HasItem() bool

func (*UpdateItemsRequest) HasOptions

func (x *UpdateItemsRequest) HasOptions() bool

func (*UpdateItemsRequest) ProtoMessage

func (*UpdateItemsRequest) ProtoMessage()

func (*UpdateItemsRequest) ProtoReflect

func (x *UpdateItemsRequest) ProtoReflect() protoreflect.Message

func (*UpdateItemsRequest) Reset

func (x *UpdateItemsRequest) Reset()

func (*UpdateItemsRequest) SetItem

func (x *UpdateItemsRequest) SetItem(v *Item)

func (*UpdateItemsRequest) SetItemNo

func (x *UpdateItemsRequest) SetItemNo(v []string)

func (*UpdateItemsRequest) SetOptions

func (x *UpdateItemsRequest) SetOptions(v *ItemOptions)

func (*UpdateItemsRequest) String

func (x *UpdateItemsRequest) String() string

type UpdateItemsRequest_builder

type UpdateItemsRequest_builder struct {

	// Unique identifier to identify the item.
	ItemNo  []string
	Item    *Item
	Options *ItemOptions
	// contains filtered or unexported fields
}

func (UpdateItemsRequest_builder) Build

type UpdateItemsResponse

type UpdateItemsResponse struct {
	// contains filtered or unexported fields
}

func (*UpdateItemsResponse) ProtoMessage

func (*UpdateItemsResponse) ProtoMessage()

func (*UpdateItemsResponse) ProtoReflect

func (x *UpdateItemsResponse) ProtoReflect() protoreflect.Message

func (*UpdateItemsResponse) Reset

func (x *UpdateItemsResponse) Reset()

func (*UpdateItemsResponse) String

func (x *UpdateItemsResponse) String() string

type UpdateItemsResponse_builder

type UpdateItemsResponse_builder struct {
	// contains filtered or unexported fields
}

func (UpdateItemsResponse_builder) Build

Source Files

  • item_service.pb.go

Jump to