endpointv3gateway

package
v2.28.0-20260311202139... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 15 Imported by: 0

Documentation

Overview

Package endpointv3gateway is a reverse proxy.

It translates gRPC into RESTful JSON APIs.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func RegisterEndpointDiscoveryServiceHandler

func RegisterEndpointDiscoveryServiceHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error

RegisterEndpointDiscoveryServiceHandler registers the http handlers for service EndpointDiscoveryService to "mux". The handlers forward requests to the grpc endpoint over "conn".

func RegisterEndpointDiscoveryServiceHandlerClient

func RegisterEndpointDiscoveryServiceHandlerClient(ctx context.Context, mux *runtime.ServeMux, client endpointv3grpc.EndpointDiscoveryServiceClient) error

RegisterEndpointDiscoveryServiceHandlerClient registers the http handlers for service EndpointDiscoveryService to "mux". The handlers forward requests to the grpc endpoint over the given implementation of "endpointv3grpc.EndpointDiscoveryServiceClient". Note: the gRPC framework executes interceptors within the gRPC handler. If the passed in "endpointv3grpc.EndpointDiscoveryServiceClient" doesn't go through the normal gRPC flow (creating a gRPC client etc.) then it will be up to the passed in "endpointv3grpc.EndpointDiscoveryServiceClient" to call the correct interceptors. This client ignores the HTTP middlewares.

func RegisterEndpointDiscoveryServiceHandlerFromEndpoint

func RegisterEndpointDiscoveryServiceHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, opts []grpc.DialOption) (err error)

RegisterEndpointDiscoveryServiceHandlerFromEndpoint is same as RegisterEndpointDiscoveryServiceHandler but automatically dials to "endpoint" and closes the connection when "ctx" gets done.

func RegisterEndpointDiscoveryServiceHandlerServer

func RegisterEndpointDiscoveryServiceHandlerServer(ctx context.Context, mux *runtime.ServeMux, server endpointv3grpc.EndpointDiscoveryServiceServer) error

RegisterEndpointDiscoveryServiceHandlerServer registers the http handlers for service EndpointDiscoveryService to "mux". UnaryRPC :call EndpointDiscoveryServiceServer directly. StreamingRPC :currently unsupported pending https://github.com/grpc/grpc-go/issues/906. Note that using this registration option will cause many gRPC library features to stop working. Consider using RegisterEndpointDiscoveryServiceHandlerFromEndpoint instead. GRPC interceptors will not work for this type of registration. To use interceptors, you must use the "runtime.WithMiddlewares" option in the "runtime.NewServeMux" call.

Types

This section is empty.

Source Files

  • eds.pb.gw.go

Jump to