listenerv3gateway

package
v2.27.4-20251211201056... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 15 Imported by: 0

Documentation

Overview

Package listenerv3gateway is a reverse proxy.

It translates gRPC into RESTful JSON APIs.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func RegisterListenerDiscoveryServiceHandler

func RegisterListenerDiscoveryServiceHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error

RegisterListenerDiscoveryServiceHandler registers the http handlers for service ListenerDiscoveryService to "mux". The handlers forward requests to the grpc endpoint over "conn".

func RegisterListenerDiscoveryServiceHandlerClient

func RegisterListenerDiscoveryServiceHandlerClient(ctx context.Context, mux *runtime.ServeMux, client listenerv3grpc.ListenerDiscoveryServiceClient) error

RegisterListenerDiscoveryServiceHandlerClient registers the http handlers for service ListenerDiscoveryService to "mux". The handlers forward requests to the grpc endpoint over the given implementation of "listenerv3grpc.ListenerDiscoveryServiceClient". Note: the gRPC framework executes interceptors within the gRPC handler. If the passed in "listenerv3grpc.ListenerDiscoveryServiceClient" doesn't go through the normal gRPC flow (creating a gRPC client etc.) then it will be up to the passed in "listenerv3grpc.ListenerDiscoveryServiceClient" to call the correct interceptors. This client ignores the HTTP middlewares.

func RegisterListenerDiscoveryServiceHandlerFromEndpoint

func RegisterListenerDiscoveryServiceHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, opts []grpc.DialOption) (err error)

RegisterListenerDiscoveryServiceHandlerFromEndpoint is same as RegisterListenerDiscoveryServiceHandler but automatically dials to "endpoint" and closes the connection when "ctx" gets done.

func RegisterListenerDiscoveryServiceHandlerServer

func RegisterListenerDiscoveryServiceHandlerServer(ctx context.Context, mux *runtime.ServeMux, server listenerv3grpc.ListenerDiscoveryServiceServer) error

RegisterListenerDiscoveryServiceHandlerServer registers the http handlers for service ListenerDiscoveryService to "mux". UnaryRPC :call ListenerDiscoveryServiceServer directly. StreamingRPC :currently unsupported pending https://github.com/grpc/grpc-go/issues/906. Note that using this registration option will cause many gRPC library features to stop working. Consider using RegisterListenerDiscoveryServiceHandlerFromEndpoint instead. GRPC interceptors will not work for this type of registration. To use interceptors, you must use the "runtime.WithMiddlewares" option in the "runtime.NewServeMux" call.

Types

This section is empty.

Source Files

  • lds.pb.gw.go

Jump to