statusv3gateway

package
v2.27.7-20260115205353... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 14 Imported by: 0

Documentation

Overview

Package statusv3gateway is a reverse proxy.

It translates gRPC into RESTful JSON APIs.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func RegisterClientStatusDiscoveryServiceHandler

func RegisterClientStatusDiscoveryServiceHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error

RegisterClientStatusDiscoveryServiceHandler registers the http handlers for service ClientStatusDiscoveryService to "mux". The handlers forward requests to the grpc endpoint over "conn".

func RegisterClientStatusDiscoveryServiceHandlerClient

func RegisterClientStatusDiscoveryServiceHandlerClient(ctx context.Context, mux *runtime.ServeMux, client statusv3grpc.ClientStatusDiscoveryServiceClient) error

RegisterClientStatusDiscoveryServiceHandlerClient registers the http handlers for service ClientStatusDiscoveryService to "mux". The handlers forward requests to the grpc endpoint over the given implementation of "statusv3grpc.ClientStatusDiscoveryServiceClient". Note: the gRPC framework executes interceptors within the gRPC handler. If the passed in "statusv3grpc.ClientStatusDiscoveryServiceClient" doesn't go through the normal gRPC flow (creating a gRPC client etc.) then it will be up to the passed in "statusv3grpc.ClientStatusDiscoveryServiceClient" to call the correct interceptors. This client ignores the HTTP middlewares.

func RegisterClientStatusDiscoveryServiceHandlerFromEndpoint

func RegisterClientStatusDiscoveryServiceHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, opts []grpc.DialOption) (err error)

RegisterClientStatusDiscoveryServiceHandlerFromEndpoint is same as RegisterClientStatusDiscoveryServiceHandler but automatically dials to "endpoint" and closes the connection when "ctx" gets done.

func RegisterClientStatusDiscoveryServiceHandlerServer

func RegisterClientStatusDiscoveryServiceHandlerServer(ctx context.Context, mux *runtime.ServeMux, server statusv3grpc.ClientStatusDiscoveryServiceServer) error

RegisterClientStatusDiscoveryServiceHandlerServer registers the http handlers for service ClientStatusDiscoveryService to "mux". UnaryRPC :call ClientStatusDiscoveryServiceServer directly. StreamingRPC :currently unsupported pending https://github.com/grpc/grpc-go/issues/906. Note that using this registration option will cause many gRPC library features to stop working. Consider using RegisterClientStatusDiscoveryServiceHandlerFromEndpoint instead. GRPC interceptors will not work for this type of registration. To use interceptors, you must use the "runtime.WithMiddlewares" option in the "runtime.NewServeMux" call.

Types

This section is empty.

Source Files

  • csds.pb.gw.go

Jump to