Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterTraServiceServer(s grpc.ServiceRegistrar, srv TraServiceServer)
- type TraServiceClient
- type TraServiceServer
- type TraService_SubscribeClient
- type TraService_SubscribeServer
- type UnimplementedTraServiceServer
- func (UnimplementedTraServiceServer) Create(context.Context, *v3alpha.TraServiceRequest) (*v3alpha.TraServiceResponse, error)
- func (UnimplementedTraServiceServer) Delete(context.Context, *v3alpha.TraServiceRequest) (*v3alpha.TraServiceResponse, error)
- func (UnimplementedTraServiceServer) Retrieve(context.Context, *v3alpha.TraServiceRequest) (*v3alpha.TraServiceResponse, error)
- func (UnimplementedTraServiceServer) Subscribe(*v3alpha.TraServiceRequest, ...) error
- func (UnimplementedTraServiceServer) Update(context.Context, *v3alpha.TraServiceRequest) (*v3alpha.TraServiceResponse, error)
- type UnsafeTraServiceServer
Constants ¶
const ( TraService_Create_FullMethodName = "/envoy.extensions.filters.network.sip_proxy.tra.v3alpha.TraService/Create" TraService_Update_FullMethodName = "/envoy.extensions.filters.network.sip_proxy.tra.v3alpha.TraService/Update" TraService_Retrieve_FullMethodName = "/envoy.extensions.filters.network.sip_proxy.tra.v3alpha.TraService/Retrieve" TraService_Delete_FullMethodName = "/envoy.extensions.filters.network.sip_proxy.tra.v3alpha.TraService/Delete" TraService_Subscribe_FullMethodName = "/envoy.extensions.filters.network.sip_proxy.tra.v3alpha.TraService/Subscribe" )
Variables ¶
var TraService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "envoy.extensions.filters.network.sip_proxy.tra.v3alpha.TraService", HandlerType: (*TraServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "Create", Handler: _TraService_Create_Handler, }, { MethodName: "Update", Handler: _TraService_Update_Handler, }, { MethodName: "Retrieve", Handler: _TraService_Retrieve_Handler, }, { MethodName: "Delete", Handler: _TraService_Delete_Handler, }, }, Streams: []grpc.StreamDesc{ { StreamName: "Subscribe", Handler: _TraService_Subscribe_Handler, ServerStreams: true, }, }, Metadata: "contrib/envoy/extensions/filters/network/sip_proxy/tra/v3alpha/tra.proto", }
TraService_ServiceDesc is the grpc.ServiceDesc for TraService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterTraServiceServer ¶
func RegisterTraServiceServer(s grpc.ServiceRegistrar, srv TraServiceServer)
Types ¶
type TraServiceClient ¶
type TraServiceClient interface {
Create(ctx context.Context, in *v3alpha.TraServiceRequest, opts ...grpc.CallOption) (*v3alpha.TraServiceResponse, error)
Update(ctx context.Context, in *v3alpha.TraServiceRequest, opts ...grpc.CallOption) (*v3alpha.TraServiceResponse, error)
Retrieve(ctx context.Context, in *v3alpha.TraServiceRequest, opts ...grpc.CallOption) (*v3alpha.TraServiceResponse, error)
Delete(ctx context.Context, in *v3alpha.TraServiceRequest, opts ...grpc.CallOption) (*v3alpha.TraServiceResponse, error)
Subscribe(ctx context.Context, in *v3alpha.TraServiceRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[v3alpha.TraServiceResponse], error)
}
TraServiceClient is the client API for TraService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewTraServiceClient ¶
func NewTraServiceClient(cc grpc.ClientConnInterface) TraServiceClient
type TraServiceServer ¶
type TraServiceServer interface {
Create(context.Context, *v3alpha.TraServiceRequest) (*v3alpha.TraServiceResponse, error)
Update(context.Context, *v3alpha.TraServiceRequest) (*v3alpha.TraServiceResponse, error)
Retrieve(context.Context, *v3alpha.TraServiceRequest) (*v3alpha.TraServiceResponse, error)
Delete(context.Context, *v3alpha.TraServiceRequest) (*v3alpha.TraServiceResponse, error)
Subscribe(*v3alpha.TraServiceRequest, grpc.ServerStreamingServer[v3alpha.TraServiceResponse]) error
}
TraServiceServer is the server API for TraService service. All implementations should embed UnimplementedTraServiceServer for forward compatibility.
type TraService_SubscribeClient ¶
type TraService_SubscribeClient = grpc.ServerStreamingClient[v3alpha.TraServiceResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type TraService_SubscribeServer ¶
type TraService_SubscribeServer = grpc.ServerStreamingServer[v3alpha.TraServiceResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type UnimplementedTraServiceServer ¶
type UnimplementedTraServiceServer struct{}
UnimplementedTraServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedTraServiceServer) Create ¶
func (UnimplementedTraServiceServer) Create(context.Context, *v3alpha.TraServiceRequest) (*v3alpha.TraServiceResponse, error)
func (UnimplementedTraServiceServer) Delete ¶
func (UnimplementedTraServiceServer) Delete(context.Context, *v3alpha.TraServiceRequest) (*v3alpha.TraServiceResponse, error)
func (UnimplementedTraServiceServer) Retrieve ¶
func (UnimplementedTraServiceServer) Retrieve(context.Context, *v3alpha.TraServiceRequest) (*v3alpha.TraServiceResponse, error)
func (UnimplementedTraServiceServer) Subscribe ¶
func (UnimplementedTraServiceServer) Subscribe(*v3alpha.TraServiceRequest, grpc.ServerStreamingServer[v3alpha.TraServiceResponse]) error
func (UnimplementedTraServiceServer) Update ¶
func (UnimplementedTraServiceServer) Update(context.Context, *v3alpha.TraServiceRequest) (*v3alpha.TraServiceResponse, error)
type UnsafeTraServiceServer ¶
type UnsafeTraServiceServer interface {
// contains filtered or unexported methods
}
UnsafeTraServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to TraServiceServer will result in compilation errors.
Source Files
¶
- tra_grpc.pb.go