Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterAccessLogServiceServer(s grpc.ServiceRegistrar, srv AccessLogServiceServer)
- type AccessLogServiceClient
- type AccessLogServiceServer
- type AccessLogService_StreamAccessLogsClient
- type AccessLogService_StreamAccessLogsServer
- type UnimplementedAccessLogServiceServer
- type UnsafeAccessLogServiceServer
Constants ¶
const (
AccessLogService_StreamAccessLogs_FullMethodName = "/envoy.service.accesslog.v3.AccessLogService/StreamAccessLogs"
)
Variables ¶
var AccessLogService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "envoy.service.accesslog.v3.AccessLogService", HandlerType: (*AccessLogServiceServer)(nil), Methods: []grpc.MethodDesc{}, Streams: []grpc.StreamDesc{ { StreamName: "StreamAccessLogs", Handler: _AccessLogService_StreamAccessLogs_Handler, ClientStreams: true, }, }, Metadata: "envoy/service/accesslog/v3/als.proto", }
AccessLogService_ServiceDesc is the grpc.ServiceDesc for AccessLogService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterAccessLogServiceServer ¶
func RegisterAccessLogServiceServer(s grpc.ServiceRegistrar, srv AccessLogServiceServer)
Types ¶
type AccessLogServiceClient ¶
type AccessLogServiceClient interface {
// Envoy will connect and send StreamAccessLogsMessage messages forever. It does not expect any
// response to be sent as nothing would be done in the case of failure. The server should
// disconnect if it expects Envoy to reconnect. In the future we may decide to add a different
// API for "critical" access logs in which Envoy will buffer access logs for some period of time
// until it gets an ACK so it could then retry. This API is designed for high throughput with the
// expectation that it might be lossy.
StreamAccessLogs(ctx context.Context, opts ...grpc.CallOption) (grpc.ClientStreamingClient[v3.StreamAccessLogsMessage, v3.StreamAccessLogsResponse], error)
}
AccessLogServiceClient is the client API for AccessLogService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
Service for streaming access logs from Envoy to an access log server.
func NewAccessLogServiceClient ¶
func NewAccessLogServiceClient(cc grpc.ClientConnInterface) AccessLogServiceClient
type AccessLogServiceServer ¶
type AccessLogServiceServer interface {
// Envoy will connect and send StreamAccessLogsMessage messages forever. It does not expect any
// response to be sent as nothing would be done in the case of failure. The server should
// disconnect if it expects Envoy to reconnect. In the future we may decide to add a different
// API for "critical" access logs in which Envoy will buffer access logs for some period of time
// until it gets an ACK so it could then retry. This API is designed for high throughput with the
// expectation that it might be lossy.
StreamAccessLogs(grpc.ClientStreamingServer[v3.StreamAccessLogsMessage, v3.StreamAccessLogsResponse]) error
}
AccessLogServiceServer is the server API for AccessLogService service. All implementations should embed UnimplementedAccessLogServiceServer for forward compatibility.
Service for streaming access logs from Envoy to an access log server.
type AccessLogService_StreamAccessLogsClient ¶
type AccessLogService_StreamAccessLogsClient = grpc.ClientStreamingClient[v3.StreamAccessLogsMessage, v3.StreamAccessLogsResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type AccessLogService_StreamAccessLogsServer ¶
type AccessLogService_StreamAccessLogsServer = grpc.ClientStreamingServer[v3.StreamAccessLogsMessage, v3.StreamAccessLogsResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type UnimplementedAccessLogServiceServer ¶
type UnimplementedAccessLogServiceServer struct{}
UnimplementedAccessLogServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedAccessLogServiceServer) StreamAccessLogs ¶
func (UnimplementedAccessLogServiceServer) StreamAccessLogs(grpc.ClientStreamingServer[v3.StreamAccessLogsMessage, v3.StreamAccessLogsResponse]) error
type UnsafeAccessLogServiceServer ¶
type UnsafeAccessLogServiceServer interface {
// contains filtered or unexported methods
}
UnsafeAccessLogServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to AccessLogServiceServer will result in compilation errors.
Source Files
¶
- als_grpc.pb.go