Documentation
¶
Index ¶
Constants ¶
const (
Authorization_Check_FullMethodName = "/envoy.service.auth.v3.Authorization/Check"
)
Variables ¶
var Authorization_ServiceDesc = grpc.ServiceDesc{ ServiceName: "envoy.service.auth.v3.Authorization", HandlerType: (*AuthorizationServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "Check", Handler: _Authorization_Check_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "envoy/service/auth/v3/external_auth.proto", }
Authorization_ServiceDesc is the grpc.ServiceDesc for Authorization service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterAuthorizationServer ¶
func RegisterAuthorizationServer(s grpc.ServiceRegistrar, srv AuthorizationServer)
Types ¶
type AuthorizationClient ¶
type AuthorizationClient interface {
// Performs authorization check based on the attributes associated with the
// incoming request, and returns status `OK` or not `OK`.
Check(ctx context.Context, in *v3.CheckRequest, opts ...grpc.CallOption) (*v3.CheckResponse, error)
}
AuthorizationClient is the client API for Authorization service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
A generic interface for performing authorization check on incoming requests to a networked service.
func NewAuthorizationClient ¶
func NewAuthorizationClient(cc grpc.ClientConnInterface) AuthorizationClient
type AuthorizationServer ¶
type AuthorizationServer interface {
// Performs authorization check based on the attributes associated with the
// incoming request, and returns status `OK` or not `OK`.
Check(context.Context, *v3.CheckRequest) (*v3.CheckResponse, error)
}
AuthorizationServer is the server API for Authorization service. All implementations should embed UnimplementedAuthorizationServer for forward compatibility.
A generic interface for performing authorization check on incoming requests to a networked service.
type UnimplementedAuthorizationServer ¶
type UnimplementedAuthorizationServer struct{}
UnimplementedAuthorizationServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedAuthorizationServer) Check ¶
func (UnimplementedAuthorizationServer) Check(context.Context, *v3.CheckRequest) (*v3.CheckResponse, error)
type UnsafeAuthorizationServer ¶
type UnsafeAuthorizationServer interface {
// contains filtered or unexported methods
}
UnsafeAuthorizationServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to AuthorizationServer will result in compilation errors.
Source Files
¶
- external_auth_grpc.pb.go