clusterv3grpc

package
v1.6.0-20251211201056-... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 5 Imported by: 1

Documentation

Index

Constants

const (
	ClusterDiscoveryService_StreamClusters_FullMethodName = "/envoy.service.cluster.v3.ClusterDiscoveryService/StreamClusters"
	ClusterDiscoveryService_DeltaClusters_FullMethodName  = "/envoy.service.cluster.v3.ClusterDiscoveryService/DeltaClusters"
	ClusterDiscoveryService_FetchClusters_FullMethodName  = "/envoy.service.cluster.v3.ClusterDiscoveryService/FetchClusters"
)

Variables

var ClusterDiscoveryService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "envoy.service.cluster.v3.ClusterDiscoveryService",
	HandlerType: (*ClusterDiscoveryServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "FetchClusters",
			Handler:    _ClusterDiscoveryService_FetchClusters_Handler,
		},
	},
	Streams: []grpc.StreamDesc{
		{
			StreamName:    "StreamClusters",
			Handler:       _ClusterDiscoveryService_StreamClusters_Handler,
			ServerStreams: true,
			ClientStreams: true,
		},
		{
			StreamName:    "DeltaClusters",
			Handler:       _ClusterDiscoveryService_DeltaClusters_Handler,
			ServerStreams: true,
			ClientStreams: true,
		},
	},
	Metadata: "envoy/service/cluster/v3/cds.proto",
}

ClusterDiscoveryService_ServiceDesc is the grpc.ServiceDesc for ClusterDiscoveryService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterClusterDiscoveryServiceServer

func RegisterClusterDiscoveryServiceServer(s grpc.ServiceRegistrar, srv ClusterDiscoveryServiceServer)

Types

type ClusterDiscoveryServiceClient

type ClusterDiscoveryServiceClient interface {
	StreamClusters(ctx context.Context, opts ...grpc.CallOption) (grpc.BidiStreamingClient[v3.DiscoveryRequest, v3.DiscoveryResponse], error)
	DeltaClusters(ctx context.Context, opts ...grpc.CallOption) (grpc.BidiStreamingClient[v3.DeltaDiscoveryRequest, v3.DeltaDiscoveryResponse], error)
	FetchClusters(ctx context.Context, in *v3.DiscoveryRequest, opts ...grpc.CallOption) (*v3.DiscoveryResponse, error)
}

ClusterDiscoveryServiceClient is the client API for ClusterDiscoveryService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

Return list of all clusters this proxy will load balance to.

func NewClusterDiscoveryServiceClient

func NewClusterDiscoveryServiceClient(cc grpc.ClientConnInterface) ClusterDiscoveryServiceClient

type ClusterDiscoveryServiceServer

ClusterDiscoveryServiceServer is the server API for ClusterDiscoveryService service. All implementations should embed UnimplementedClusterDiscoveryServiceServer for forward compatibility.

Return list of all clusters this proxy will load balance to.

type ClusterDiscoveryService_DeltaClustersClient

type ClusterDiscoveryService_DeltaClustersClient = grpc.BidiStreamingClient[v3.DeltaDiscoveryRequest, v3.DeltaDiscoveryResponse]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type ClusterDiscoveryService_DeltaClustersServer

type ClusterDiscoveryService_DeltaClustersServer = grpc.BidiStreamingServer[v3.DeltaDiscoveryRequest, v3.DeltaDiscoveryResponse]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type ClusterDiscoveryService_StreamClustersClient

type ClusterDiscoveryService_StreamClustersClient = grpc.BidiStreamingClient[v3.DiscoveryRequest, v3.DiscoveryResponse]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type ClusterDiscoveryService_StreamClustersServer

type ClusterDiscoveryService_StreamClustersServer = grpc.BidiStreamingServer[v3.DiscoveryRequest, v3.DiscoveryResponse]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type UnimplementedClusterDiscoveryServiceServer

type UnimplementedClusterDiscoveryServiceServer struct{}

UnimplementedClusterDiscoveryServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedClusterDiscoveryServiceServer) DeltaClusters

func (UnimplementedClusterDiscoveryServiceServer) FetchClusters

func (UnimplementedClusterDiscoveryServiceServer) StreamClusters

type UnsafeClusterDiscoveryServiceServer

type UnsafeClusterDiscoveryServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeClusterDiscoveryServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ClusterDiscoveryServiceServer will result in compilation errors.

Source Files

  • cds_grpc.pb.go

Jump to