discoveryv3grpc

package
v1.6.0-20251211201056-... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	AggregatedDiscoveryService_StreamAggregatedResources_FullMethodName = "/envoy.service.discovery.v3.AggregatedDiscoveryService/StreamAggregatedResources"
	AggregatedDiscoveryService_DeltaAggregatedResources_FullMethodName  = "/envoy.service.discovery.v3.AggregatedDiscoveryService/DeltaAggregatedResources"
)

Variables

var AggregatedDiscoveryService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "envoy.service.discovery.v3.AggregatedDiscoveryService",
	HandlerType: (*AggregatedDiscoveryServiceServer)(nil),
	Methods:     []grpc.MethodDesc{},
	Streams: []grpc.StreamDesc{
		{
			StreamName:    "StreamAggregatedResources",
			Handler:       _AggregatedDiscoveryService_StreamAggregatedResources_Handler,
			ServerStreams: true,
			ClientStreams: true,
		},
		{
			StreamName:    "DeltaAggregatedResources",
			Handler:       _AggregatedDiscoveryService_DeltaAggregatedResources_Handler,
			ServerStreams: true,
			ClientStreams: true,
		},
	},
	Metadata: "envoy/service/discovery/v3/ads.proto",
}

AggregatedDiscoveryService_ServiceDesc is the grpc.ServiceDesc for AggregatedDiscoveryService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterAggregatedDiscoveryServiceServer

func RegisterAggregatedDiscoveryServiceServer(s grpc.ServiceRegistrar, srv AggregatedDiscoveryServiceServer)

Types

type AggregatedDiscoveryServiceClient

type AggregatedDiscoveryServiceClient interface {
	// This is a gRPC-only API.
	StreamAggregatedResources(ctx context.Context, opts ...grpc.CallOption) (grpc.BidiStreamingClient[v3.DiscoveryRequest, v3.DiscoveryResponse], error)
	DeltaAggregatedResources(ctx context.Context, opts ...grpc.CallOption) (grpc.BidiStreamingClient[v3.DeltaDiscoveryRequest, v3.DeltaDiscoveryResponse], error)
}

AggregatedDiscoveryServiceClient is the client API for AggregatedDiscoveryService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

See https://github.com/envoyproxy/envoy-api#apis for a description of the role of ADS and how it is intended to be used by a management server. ADS requests have the same structure as their singleton xDS counterparts, but can multiplex many resource types on a single stream. The type_url in the DiscoveryRequest/DiscoveryResponse provides sufficient information to recover the multiplexed singleton APIs at the Envoy instance and management server.

func NewAggregatedDiscoveryServiceClient

func NewAggregatedDiscoveryServiceClient(cc grpc.ClientConnInterface) AggregatedDiscoveryServiceClient

type AggregatedDiscoveryServiceServer

type AggregatedDiscoveryServiceServer interface {
	// This is a gRPC-only API.
	StreamAggregatedResources(grpc.BidiStreamingServer[v3.DiscoveryRequest, v3.DiscoveryResponse]) error
	DeltaAggregatedResources(grpc.BidiStreamingServer[v3.DeltaDiscoveryRequest, v3.DeltaDiscoveryResponse]) error
}

AggregatedDiscoveryServiceServer is the server API for AggregatedDiscoveryService service. All implementations should embed UnimplementedAggregatedDiscoveryServiceServer for forward compatibility.

See https://github.com/envoyproxy/envoy-api#apis for a description of the role of ADS and how it is intended to be used by a management server. ADS requests have the same structure as their singleton xDS counterparts, but can multiplex many resource types on a single stream. The type_url in the DiscoveryRequest/DiscoveryResponse provides sufficient information to recover the multiplexed singleton APIs at the Envoy instance and management server.

type AggregatedDiscoveryService_DeltaAggregatedResourcesClient

type AggregatedDiscoveryService_DeltaAggregatedResourcesClient = grpc.BidiStreamingClient[v3.DeltaDiscoveryRequest, v3.DeltaDiscoveryResponse]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type AggregatedDiscoveryService_DeltaAggregatedResourcesServer

type AggregatedDiscoveryService_DeltaAggregatedResourcesServer = grpc.BidiStreamingServer[v3.DeltaDiscoveryRequest, v3.DeltaDiscoveryResponse]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type AggregatedDiscoveryService_StreamAggregatedResourcesClient

type AggregatedDiscoveryService_StreamAggregatedResourcesClient = grpc.BidiStreamingClient[v3.DiscoveryRequest, v3.DiscoveryResponse]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type AggregatedDiscoveryService_StreamAggregatedResourcesServer

type AggregatedDiscoveryService_StreamAggregatedResourcesServer = grpc.BidiStreamingServer[v3.DiscoveryRequest, v3.DiscoveryResponse]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type UnimplementedAggregatedDiscoveryServiceServer

type UnimplementedAggregatedDiscoveryServiceServer struct{}

UnimplementedAggregatedDiscoveryServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedAggregatedDiscoveryServiceServer) DeltaAggregatedResources

func (UnimplementedAggregatedDiscoveryServiceServer) StreamAggregatedResources

type UnsafeAggregatedDiscoveryServiceServer

type UnsafeAggregatedDiscoveryServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeAggregatedDiscoveryServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to AggregatedDiscoveryServiceServer will result in compilation errors.

Source Files

  • ads_grpc.pb.go

Jump to