Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterEventReportingServiceServer(s grpc.ServiceRegistrar, srv EventReportingServiceServer)
- type EventReportingServiceClient
- type EventReportingServiceServer
- type EventReportingService_StreamEventsClient
- type EventReportingService_StreamEventsServer
- type UnimplementedEventReportingServiceServer
- type UnsafeEventReportingServiceServer
Constants ¶
const (
EventReportingService_StreamEvents_FullMethodName = "/envoy.service.event_reporting.v3.EventReportingService/StreamEvents"
)
Variables ¶
var EventReportingService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "envoy.service.event_reporting.v3.EventReportingService", HandlerType: (*EventReportingServiceServer)(nil), Methods: []grpc.MethodDesc{}, Streams: []grpc.StreamDesc{ { StreamName: "StreamEvents", Handler: _EventReportingService_StreamEvents_Handler, ServerStreams: true, ClientStreams: true, }, }, Metadata: "envoy/service/event_reporting/v3/event_reporting_service.proto", }
EventReportingService_ServiceDesc is the grpc.ServiceDesc for EventReportingService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterEventReportingServiceServer ¶
func RegisterEventReportingServiceServer(s grpc.ServiceRegistrar, srv EventReportingServiceServer)
Types ¶
type EventReportingServiceClient ¶
type EventReportingServiceClient interface {
// Envoy will connect and send StreamEventsRequest messages forever.
// The management server may send StreamEventsResponse to configure event stream. See below.
// This API is designed for high throughput with the expectation that it might be lossy.
StreamEvents(ctx context.Context, opts ...grpc.CallOption) (grpc.BidiStreamingClient[v3.StreamEventsRequest, v3.StreamEventsResponse], error)
}
EventReportingServiceClient is the client API for EventReportingService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
[#not-implemented-hide:] Service for streaming different types of events from Envoy to a server. The examples of such events may be health check or outlier detection events.
func NewEventReportingServiceClient ¶
func NewEventReportingServiceClient(cc grpc.ClientConnInterface) EventReportingServiceClient
type EventReportingServiceServer ¶
type EventReportingServiceServer interface {
// Envoy will connect and send StreamEventsRequest messages forever.
// The management server may send StreamEventsResponse to configure event stream. See below.
// This API is designed for high throughput with the expectation that it might be lossy.
StreamEvents(grpc.BidiStreamingServer[v3.StreamEventsRequest, v3.StreamEventsResponse]) error
}
EventReportingServiceServer is the server API for EventReportingService service. All implementations should embed UnimplementedEventReportingServiceServer for forward compatibility.
[#not-implemented-hide:] Service for streaming different types of events from Envoy to a server. The examples of such events may be health check or outlier detection events.
type EventReportingService_StreamEventsClient ¶
type EventReportingService_StreamEventsClient = grpc.BidiStreamingClient[v3.StreamEventsRequest, v3.StreamEventsResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type EventReportingService_StreamEventsServer ¶
type EventReportingService_StreamEventsServer = grpc.BidiStreamingServer[v3.StreamEventsRequest, v3.StreamEventsResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type UnimplementedEventReportingServiceServer ¶
type UnimplementedEventReportingServiceServer struct{}
UnimplementedEventReportingServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedEventReportingServiceServer) StreamEvents ¶
func (UnimplementedEventReportingServiceServer) StreamEvents(grpc.BidiStreamingServer[v3.StreamEventsRequest, v3.StreamEventsResponse]) error
type UnsafeEventReportingServiceServer ¶
type UnsafeEventReportingServiceServer interface {
// contains filtered or unexported methods
}
UnsafeEventReportingServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to EventReportingServiceServer will result in compilation errors.
Source Files
¶
- event_reporting_service_grpc.pb.go