rate_limit_quotav3grpc

package
v1.6.0-20251211201056-... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	RateLimitQuotaService_StreamRateLimitQuotas_FullMethodName = "/envoy.service.rate_limit_quota.v3.RateLimitQuotaService/StreamRateLimitQuotas"
)

Variables

var RateLimitQuotaService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "envoy.service.rate_limit_quota.v3.RateLimitQuotaService",
	HandlerType: (*RateLimitQuotaServiceServer)(nil),
	Methods:     []grpc.MethodDesc{},
	Streams: []grpc.StreamDesc{
		{
			StreamName:    "StreamRateLimitQuotas",
			Handler:       _RateLimitQuotaService_StreamRateLimitQuotas_Handler,
			ServerStreams: true,
			ClientStreams: true,
		},
	},
	Metadata: "envoy/service/rate_limit_quota/v3/rlqs.proto",
}

RateLimitQuotaService_ServiceDesc is the grpc.ServiceDesc for RateLimitQuotaService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterRateLimitQuotaServiceServer

func RegisterRateLimitQuotaServiceServer(s grpc.ServiceRegistrar, srv RateLimitQuotaServiceServer)

Types

type RateLimitQuotaServiceClient

type RateLimitQuotaServiceClient interface {
	// Main communication channel: the data plane sends usage reports to the RLQS server,
	// and the server asynchronously responding with the assignments.
	StreamRateLimitQuotas(ctx context.Context, opts ...grpc.CallOption) (grpc.BidiStreamingClient[v3.RateLimitQuotaUsageReports, v3.RateLimitQuotaResponse], error)
}

RateLimitQuotaServiceClient is the client API for RateLimitQuotaService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

Defines the Rate Limit Quota Service (RLQS).

func NewRateLimitQuotaServiceClient

func NewRateLimitQuotaServiceClient(cc grpc.ClientConnInterface) RateLimitQuotaServiceClient

type RateLimitQuotaServiceServer

type RateLimitQuotaServiceServer interface {
	// Main communication channel: the data plane sends usage reports to the RLQS server,
	// and the server asynchronously responding with the assignments.
	StreamRateLimitQuotas(grpc.BidiStreamingServer[v3.RateLimitQuotaUsageReports, v3.RateLimitQuotaResponse]) error
}

RateLimitQuotaServiceServer is the server API for RateLimitQuotaService service. All implementations should embed UnimplementedRateLimitQuotaServiceServer for forward compatibility.

Defines the Rate Limit Quota Service (RLQS).

type RateLimitQuotaService_StreamRateLimitQuotasClient

type RateLimitQuotaService_StreamRateLimitQuotasClient = grpc.BidiStreamingClient[v3.RateLimitQuotaUsageReports, v3.RateLimitQuotaResponse]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type RateLimitQuotaService_StreamRateLimitQuotasServer

type RateLimitQuotaService_StreamRateLimitQuotasServer = grpc.BidiStreamingServer[v3.RateLimitQuotaUsageReports, v3.RateLimitQuotaResponse]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type UnimplementedRateLimitQuotaServiceServer

type UnimplementedRateLimitQuotaServiceServer struct{}

UnimplementedRateLimitQuotaServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedRateLimitQuotaServiceServer) StreamRateLimitQuotas

type UnsafeRateLimitQuotaServiceServer

type UnsafeRateLimitQuotaServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeRateLimitQuotaServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to RateLimitQuotaServiceServer will result in compilation errors.

Source Files

  • rlqs_grpc.pb.go

Jump to