Documentation
¶
Index ¶
Constants ¶
const (
RateLimitService_ShouldRateLimit_FullMethodName = "/envoy.service.ratelimit.v2.RateLimitService/ShouldRateLimit"
)
Variables ¶
var RateLimitService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "envoy.service.ratelimit.v2.RateLimitService", HandlerType: (*RateLimitServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "ShouldRateLimit", Handler: _RateLimitService_ShouldRateLimit_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "envoy/service/ratelimit/v2/rls.proto", }
RateLimitService_ServiceDesc is the grpc.ServiceDesc for RateLimitService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterRateLimitServiceServer ¶
func RegisterRateLimitServiceServer(s grpc.ServiceRegistrar, srv RateLimitServiceServer)
Types ¶
type RateLimitServiceClient ¶
type RateLimitServiceClient interface {
// Determine whether rate limiting should take place.
ShouldRateLimit(ctx context.Context, in *v2.RateLimitRequest, opts ...grpc.CallOption) (*v2.RateLimitResponse, error)
}
RateLimitServiceClient is the client API for RateLimitService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewRateLimitServiceClient ¶
func NewRateLimitServiceClient(cc grpc.ClientConnInterface) RateLimitServiceClient
type RateLimitServiceServer ¶
type RateLimitServiceServer interface {
// Determine whether rate limiting should take place.
ShouldRateLimit(context.Context, *v2.RateLimitRequest) (*v2.RateLimitResponse, error)
}
RateLimitServiceServer is the server API for RateLimitService service. All implementations should embed UnimplementedRateLimitServiceServer for forward compatibility.
type UnimplementedRateLimitServiceServer ¶
type UnimplementedRateLimitServiceServer struct{}
UnimplementedRateLimitServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedRateLimitServiceServer) ShouldRateLimit ¶
func (UnimplementedRateLimitServiceServer) ShouldRateLimit(context.Context, *v2.RateLimitRequest) (*v2.RateLimitResponse, error)
type UnsafeRateLimitServiceServer ¶
type UnsafeRateLimitServiceServer interface {
// contains filtered or unexported methods
}
UnsafeRateLimitServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to RateLimitServiceServer will result in compilation errors.
Source Files
¶
- rls_grpc.pb.go