Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterClientStatusDiscoveryServiceServer(s grpc.ServiceRegistrar, srv ClientStatusDiscoveryServiceServer)
- type ClientStatusDiscoveryServiceClient
- type ClientStatusDiscoveryServiceServer
- type ClientStatusDiscoveryService_StreamClientStatusClient
- type ClientStatusDiscoveryService_StreamClientStatusServer
- type UnimplementedClientStatusDiscoveryServiceServer
- func (UnimplementedClientStatusDiscoveryServiceServer) FetchClientStatus(context.Context, *v2.ClientStatusRequest) (*v2.ClientStatusResponse, error)
- func (UnimplementedClientStatusDiscoveryServiceServer) StreamClientStatus(grpc.BidiStreamingServer[v2.ClientStatusRequest, v2.ClientStatusResponse]) error
- type UnsafeClientStatusDiscoveryServiceServer
Constants ¶
const ( ClientStatusDiscoveryService_StreamClientStatus_FullMethodName = "/envoy.service.status.v2.ClientStatusDiscoveryService/StreamClientStatus" ClientStatusDiscoveryService_FetchClientStatus_FullMethodName = "/envoy.service.status.v2.ClientStatusDiscoveryService/FetchClientStatus" )
Variables ¶
var ClientStatusDiscoveryService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "envoy.service.status.v2.ClientStatusDiscoveryService", HandlerType: (*ClientStatusDiscoveryServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "FetchClientStatus", Handler: _ClientStatusDiscoveryService_FetchClientStatus_Handler, }, }, Streams: []grpc.StreamDesc{ { StreamName: "StreamClientStatus", Handler: _ClientStatusDiscoveryService_StreamClientStatus_Handler, ServerStreams: true, ClientStreams: true, }, }, Metadata: "envoy/service/status/v2/csds.proto", }
ClientStatusDiscoveryService_ServiceDesc is the grpc.ServiceDesc for ClientStatusDiscoveryService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterClientStatusDiscoveryServiceServer ¶
func RegisterClientStatusDiscoveryServiceServer(s grpc.ServiceRegistrar, srv ClientStatusDiscoveryServiceServer)
Types ¶
type ClientStatusDiscoveryServiceClient ¶
type ClientStatusDiscoveryServiceClient interface {
StreamClientStatus(ctx context.Context, opts ...grpc.CallOption) (grpc.BidiStreamingClient[v2.ClientStatusRequest, v2.ClientStatusResponse], error)
FetchClientStatus(ctx context.Context, in *v2.ClientStatusRequest, opts ...grpc.CallOption) (*v2.ClientStatusResponse, error)
}
ClientStatusDiscoveryServiceClient is the client API for ClientStatusDiscoveryService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
CSDS is Client Status Discovery Service. It can be used to get the status of an xDS-compliant client from the management server's point of view. In the future, it can potentially be used as an interface to get the current state directly from the client.
func NewClientStatusDiscoveryServiceClient ¶
func NewClientStatusDiscoveryServiceClient(cc grpc.ClientConnInterface) ClientStatusDiscoveryServiceClient
type ClientStatusDiscoveryServiceServer ¶
type ClientStatusDiscoveryServiceServer interface {
StreamClientStatus(grpc.BidiStreamingServer[v2.ClientStatusRequest, v2.ClientStatusResponse]) error
FetchClientStatus(context.Context, *v2.ClientStatusRequest) (*v2.ClientStatusResponse, error)
}
ClientStatusDiscoveryServiceServer is the server API for ClientStatusDiscoveryService service. All implementations should embed UnimplementedClientStatusDiscoveryServiceServer for forward compatibility.
CSDS is Client Status Discovery Service. It can be used to get the status of an xDS-compliant client from the management server's point of view. In the future, it can potentially be used as an interface to get the current state directly from the client.
type ClientStatusDiscoveryService_StreamClientStatusClient ¶
type ClientStatusDiscoveryService_StreamClientStatusClient = grpc.BidiStreamingClient[v2.ClientStatusRequest, v2.ClientStatusResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type ClientStatusDiscoveryService_StreamClientStatusServer ¶
type ClientStatusDiscoveryService_StreamClientStatusServer = grpc.BidiStreamingServer[v2.ClientStatusRequest, v2.ClientStatusResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type UnimplementedClientStatusDiscoveryServiceServer ¶
type UnimplementedClientStatusDiscoveryServiceServer struct{}
UnimplementedClientStatusDiscoveryServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedClientStatusDiscoveryServiceServer) FetchClientStatus ¶
func (UnimplementedClientStatusDiscoveryServiceServer) FetchClientStatus(context.Context, *v2.ClientStatusRequest) (*v2.ClientStatusResponse, error)
func (UnimplementedClientStatusDiscoveryServiceServer) StreamClientStatus ¶
func (UnimplementedClientStatusDiscoveryServiceServer) StreamClientStatus(grpc.BidiStreamingServer[v2.ClientStatusRequest, v2.ClientStatusResponse]) error
type UnsafeClientStatusDiscoveryServiceServer ¶
type UnsafeClientStatusDiscoveryServiceServer interface {
// contains filtered or unexported methods
}
UnsafeClientStatusDiscoveryServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ClientStatusDiscoveryServiceServer will result in compilation errors.
Source Files
¶
- csds_grpc.pb.go