Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterTapSinkServiceServer(s grpc.ServiceRegistrar, srv TapSinkServiceServer)
- type TapSinkServiceClient
- type TapSinkServiceServer
- type TapSinkService_StreamTapsClient
- type TapSinkService_StreamTapsServer
- type UnimplementedTapSinkServiceServer
- type UnsafeTapSinkServiceServer
Constants ¶
const (
TapSinkService_StreamTaps_FullMethodName = "/envoy.service.tap.v3.TapSinkService/StreamTaps"
)
Variables ¶
var TapSinkService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "envoy.service.tap.v3.TapSinkService", HandlerType: (*TapSinkServiceServer)(nil), Methods: []grpc.MethodDesc{}, Streams: []grpc.StreamDesc{ { StreamName: "StreamTaps", Handler: _TapSinkService_StreamTaps_Handler, ClientStreams: true, }, }, Metadata: "envoy/service/tap/v3/tap.proto", }
TapSinkService_ServiceDesc is the grpc.ServiceDesc for TapSinkService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterTapSinkServiceServer ¶
func RegisterTapSinkServiceServer(s grpc.ServiceRegistrar, srv TapSinkServiceServer)
Types ¶
type TapSinkServiceClient ¶
type TapSinkServiceClient interface {
// Envoy will connect and send StreamTapsRequest messages forever. It does not expect any
// response to be sent as nothing would be done in the case of failure. The server should
// disconnect if it expects Envoy to reconnect.
StreamTaps(ctx context.Context, opts ...grpc.CallOption) (grpc.ClientStreamingClient[v3.StreamTapsRequest, v3.StreamTapsResponse], error)
}
TapSinkServiceClient is the client API for TapSinkService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
[#not-implemented-hide:] A tap service to receive incoming taps. Envoy will call StreamTaps to deliver captured taps to the server
func NewTapSinkServiceClient ¶
func NewTapSinkServiceClient(cc grpc.ClientConnInterface) TapSinkServiceClient
type TapSinkServiceServer ¶
type TapSinkServiceServer interface {
// Envoy will connect and send StreamTapsRequest messages forever. It does not expect any
// response to be sent as nothing would be done in the case of failure. The server should
// disconnect if it expects Envoy to reconnect.
StreamTaps(grpc.ClientStreamingServer[v3.StreamTapsRequest, v3.StreamTapsResponse]) error
}
TapSinkServiceServer is the server API for TapSinkService service. All implementations should embed UnimplementedTapSinkServiceServer for forward compatibility.
[#not-implemented-hide:] A tap service to receive incoming taps. Envoy will call StreamTaps to deliver captured taps to the server
type TapSinkService_StreamTapsClient ¶
type TapSinkService_StreamTapsClient = grpc.ClientStreamingClient[v3.StreamTapsRequest, v3.StreamTapsResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type TapSinkService_StreamTapsServer ¶
type TapSinkService_StreamTapsServer = grpc.ClientStreamingServer[v3.StreamTapsRequest, v3.StreamTapsResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type UnimplementedTapSinkServiceServer ¶
type UnimplementedTapSinkServiceServer struct{}
UnimplementedTapSinkServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedTapSinkServiceServer) StreamTaps ¶
func (UnimplementedTapSinkServiceServer) StreamTaps(grpc.ClientStreamingServer[v3.StreamTapsRequest, v3.StreamTapsResponse]) error
type UnsafeTapSinkServiceServer ¶
type UnsafeTapSinkServiceServer interface {
// contains filtered or unexported methods
}
UnsafeTapSinkServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to TapSinkServiceServer will result in compilation errors.
Source Files
¶
- tap_grpc.pb.go