Documentation
¶
Index ¶
- Variables
- type Qatzip
- func (x *Qatzip) ClearChunkSize()
- func (x *Qatzip) ClearCompressionLevel()
- func (x *Qatzip) ClearInputSizeThreshold()
- func (x *Qatzip) ClearStreamBufferSize()
- func (x *Qatzip) GetChunkSize() *wrapperspb.UInt32Value
- func (x *Qatzip) GetCompressionLevel() *wrapperspb.UInt32Value
- func (x *Qatzip) GetHardwareBufferSize() Qatzip_HardwareBufferSize
- func (x *Qatzip) GetInputSizeThreshold() *wrapperspb.UInt32Value
- func (x *Qatzip) GetStreamBufferSize() *wrapperspb.UInt32Value
- func (x *Qatzip) HasChunkSize() bool
- func (x *Qatzip) HasCompressionLevel() bool
- func (x *Qatzip) HasInputSizeThreshold() bool
- func (x *Qatzip) HasStreamBufferSize() bool
- func (*Qatzip) ProtoMessage()
- func (x *Qatzip) ProtoReflect() protoreflect.Message
- func (x *Qatzip) Reset()
- func (x *Qatzip) SetChunkSize(v *wrapperspb.UInt32Value)
- func (x *Qatzip) SetCompressionLevel(v *wrapperspb.UInt32Value)
- func (x *Qatzip) SetHardwareBufferSize(v Qatzip_HardwareBufferSize)
- func (x *Qatzip) SetInputSizeThreshold(v *wrapperspb.UInt32Value)
- func (x *Qatzip) SetStreamBufferSize(v *wrapperspb.UInt32Value)
- func (x *Qatzip) String() string
- type Qatzip_HardwareBufferSize
- func (Qatzip_HardwareBufferSize) Descriptor() protoreflect.EnumDescriptor
- func (x Qatzip_HardwareBufferSize) Enum() *Qatzip_HardwareBufferSize
- func (x Qatzip_HardwareBufferSize) Number() protoreflect.EnumNumber
- func (x Qatzip_HardwareBufferSize) String() string
- func (Qatzip_HardwareBufferSize) Type() protoreflect.EnumType
- type Qatzip_builder
Constants ¶
This section is empty.
Variables ¶
var ( Qatzip_HardwareBufferSize_name = map[int32]string{ 0: "DEFAULT", 1: "SZ_4K", 2: "SZ_8K", 3: "SZ_32K", 4: "SZ_64K", 5: "SZ_128K", 6: "SZ_512K", } Qatzip_HardwareBufferSize_value = map[string]int32{ "DEFAULT": 0, "SZ_4K": 1, "SZ_8K": 2, "SZ_32K": 3, "SZ_64K": 4, "SZ_128K": 5, "SZ_512K": 6, } )
Enum value maps for Qatzip_HardwareBufferSize.
var File_contrib_envoy_extensions_compression_qatzip_compressor_v3alpha_qatzip_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Qatzip ¶
type Qatzip struct {
// Value from 1 to 9 that controls the main compression speed-density lever.
// The higher quality, the slower compression. The default value is 1.
CompressionLevel *wrapperspb.UInt32Value `protobuf:"bytes,1,opt,name=compression_level,json=compressionLevel,proto3" json:"compression_level,omitempty"`
// A size of qat hardware buffer. This field will be set to "DEFAULT" if not specified.
HardwareBufferSize Qatzip_HardwareBufferSize `` /* 204-byte string literal not displayed */
// Threshold of compression service’s input size for software failover.
// If the size of input request less than the threshold, qatzip will route the request to software
// compressor. The default value is 1024. The maximum value is 512*1024.
InputSizeThreshold *wrapperspb.UInt32Value `protobuf:"bytes,3,opt,name=input_size_threshold,json=inputSizeThreshold,proto3" json:"input_size_threshold,omitempty"`
// A size of stream buffer. The default value is 128 * 1024. The maximum value is 2*1024*1024 -
// 5*1024
StreamBufferSize *wrapperspb.UInt32Value `protobuf:"bytes,4,opt,name=stream_buffer_size,json=streamBufferSize,proto3" json:"stream_buffer_size,omitempty"`
// Value for compressor's next output buffer. If not set, defaults to 4096.
ChunkSize *wrapperspb.UInt32Value `protobuf:"bytes,5,opt,name=chunk_size,json=chunkSize,proto3" json:"chunk_size,omitempty"`
// contains filtered or unexported fields
}
[#next-free-field: 6]
func (*Qatzip) GetChunkSize ¶
func (x *Qatzip) GetChunkSize() *wrapperspb.UInt32Value
func (*Qatzip) GetCompressionLevel ¶
func (x *Qatzip) GetCompressionLevel() *wrapperspb.UInt32Value
func (*Qatzip) GetHardwareBufferSize ¶
func (x *Qatzip) GetHardwareBufferSize() Qatzip_HardwareBufferSize
func (*Qatzip) GetInputSizeThreshold ¶
func (x *Qatzip) GetInputSizeThreshold() *wrapperspb.UInt32Value
func (*Qatzip) GetStreamBufferSize ¶
func (x *Qatzip) GetStreamBufferSize() *wrapperspb.UInt32Value
func (*Qatzip) ProtoReflect ¶
func (x *Qatzip) ProtoReflect() protoreflect.Message
func (*Qatzip) SetChunkSize ¶
func (x *Qatzip) SetChunkSize(v *wrapperspb.UInt32Value)
func (*Qatzip) SetCompressionLevel ¶
func (x *Qatzip) SetCompressionLevel(v *wrapperspb.UInt32Value)
func (*Qatzip) SetHardwareBufferSize ¶
func (x *Qatzip) SetHardwareBufferSize(v Qatzip_HardwareBufferSize)
func (*Qatzip) SetInputSizeThreshold ¶
func (x *Qatzip) SetInputSizeThreshold(v *wrapperspb.UInt32Value)
func (*Qatzip) SetStreamBufferSize ¶
func (x *Qatzip) SetStreamBufferSize(v *wrapperspb.UInt32Value)
type Qatzip_HardwareBufferSize ¶
type Qatzip_HardwareBufferSize int32
const ( Qatzip_DEFAULT Qatzip_HardwareBufferSize = 0 Qatzip_SZ_4K Qatzip_HardwareBufferSize = 1 Qatzip_SZ_8K Qatzip_HardwareBufferSize = 2 Qatzip_SZ_32K Qatzip_HardwareBufferSize = 3 Qatzip_SZ_64K Qatzip_HardwareBufferSize = 4 Qatzip_SZ_128K Qatzip_HardwareBufferSize = 5 Qatzip_SZ_512K Qatzip_HardwareBufferSize = 6 )
func (Qatzip_HardwareBufferSize) Descriptor ¶
func (Qatzip_HardwareBufferSize) Descriptor() protoreflect.EnumDescriptor
func (Qatzip_HardwareBufferSize) Enum ¶
func (x Qatzip_HardwareBufferSize) Enum() *Qatzip_HardwareBufferSize
func (Qatzip_HardwareBufferSize) Number ¶
func (x Qatzip_HardwareBufferSize) Number() protoreflect.EnumNumber
func (Qatzip_HardwareBufferSize) String ¶
func (x Qatzip_HardwareBufferSize) String() string
func (Qatzip_HardwareBufferSize) Type ¶
func (Qatzip_HardwareBufferSize) Type() protoreflect.EnumType
type Qatzip_builder ¶
type Qatzip_builder struct {
// Value from 1 to 9 that controls the main compression speed-density lever.
// The higher quality, the slower compression. The default value is 1.
CompressionLevel *wrapperspb.UInt32Value
// A size of qat hardware buffer. This field will be set to "DEFAULT" if not specified.
HardwareBufferSize Qatzip_HardwareBufferSize
// Threshold of compression service’s input size for software failover.
// If the size of input request less than the threshold, qatzip will route the request to software
// compressor. The default value is 1024. The maximum value is 512*1024.
InputSizeThreshold *wrapperspb.UInt32Value
// A size of stream buffer. The default value is 128 * 1024. The maximum value is 2*1024*1024 -
// 5*1024
StreamBufferSize *wrapperspb.UInt32Value
// Value for compressor's next output buffer. If not set, defaults to 4096.
ChunkSize *wrapperspb.UInt32Value
// contains filtered or unexported fields
}
func (Qatzip_builder) Build ¶
func (b0 Qatzip_builder) Build() *Qatzip
Source Files
¶
- qatzip.pb.go
Click to show internal directories.
Click to hide internal directories.