golangv3alpha

package
v1.36.11-2026011520535... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

const RouterPlugin_Config_case case_RouterPlugin_Override = 2
const RouterPlugin_Disabled_case case_RouterPlugin_Override = 1
const RouterPlugin_Override_not_set_case case_RouterPlugin_Override = 0

Variables

var (
	Config_MergePolicy_name = map[int32]string{
		0: "MERGE_VIRTUALHOST_ROUTER_FILTER",
		1: "MERGE_VIRTUALHOST_ROUTER",
		3: "OVERRIDE",
	}
	Config_MergePolicy_value = map[string]int32{
		"MERGE_VIRTUALHOST_ROUTER_FILTER": 0,
		"MERGE_VIRTUALHOST_ROUTER":        1,
		"OVERRIDE":                        3,
	}
)

Enum value maps for Config_MergePolicy.

var File_contrib_envoy_extensions_filters_http_golang_v3alpha_golang_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type Config

type Config struct {

	// Globally unique ID for a dynamic library file.
	LibraryId string `protobuf:"bytes,1,opt,name=library_id,json=libraryId,proto3" json:"library_id,omitempty"`
	// Path to a dynamic library implementing the
	// :repo:`StreamFilter API <contrib/golang/common/go/api.StreamFilter>`
	// interface.
	// [#comment:TODO(wangfakang): Support for downloading libraries from remote repositories.]
	LibraryPath string `protobuf:"bytes,2,opt,name=library_path,json=libraryPath,proto3" json:"library_path,omitempty"`
	// Globally unique name of the Go plugin.
	//
	// This name **must** be consistent with the name registered in “http::RegisterHttpFilterConfigFactory“,
	// and can be used to associate :ref:`route and virtualHost plugin configuration
	// <envoy_v3_api_field_extensions.filters.http.golang.v3alpha.ConfigsPerRoute.plugins_config>`.
	PluginName string `protobuf:"bytes,3,opt,name=plugin_name,json=pluginName,proto3" json:"plugin_name,omitempty"`
	// Configuration for the Go plugin.
	//
	// .. note::
	//
	//	This configuration is only parsed in the go plugin, and is therefore not validated
	//	by Envoy.
	//
	//	See the :repo:`StreamFilter API <contrib/golang/common/go/api/filter.go>`
	//	for more information about how the plugin's configuration data can be accessed.
	PluginConfig *anypb.Any `protobuf:"bytes,4,opt,name=plugin_config,json=pluginConfig,proto3" json:"plugin_config,omitempty"`
	// Merge policy for plugin configuration.
	//
	// The Go plugin configuration supports three dimensions:
	//
	// * Virtual host’s :ref:`typed_per_filter_config <envoy_v3_api_field_config.route.v3.VirtualHost.typed_per_filter_config>`
	// * Route’s :ref:`typed_per_filter_config <envoy_v3_api_field_config.route.v3.Route.typed_per_filter_config>`
	// * The filter's :ref:`plugin_config <envoy_v3_api_field_extensions.filters.http.golang.v3alpha.Config.plugin_config>`
	//
	// [#not-implemented-hide:]
	MergePolicy Config_MergePolicy `` /* 164-byte string literal not displayed */
	// Generic secret list available to the plugin.
	// Looks into SDS or static bootstrap configuration.
	//
	// See :repo:`StreamFilter API <contrib/golang/common/go/api/filter.go>`
	// for more information about how to access secrets from Go.
	GenericSecrets []*v3.SdsSecretConfig `protobuf:"bytes,6,rep,name=generic_secrets,json=genericSecrets,proto3" json:"generic_secrets,omitempty"`
	// contains filtered or unexported fields
}

[#next-free-field: 7]

func (*Config) ClearPluginConfig

func (x *Config) ClearPluginConfig()

func (*Config) GetGenericSecrets

func (x *Config) GetGenericSecrets() []*v3.SdsSecretConfig

func (*Config) GetLibraryId

func (x *Config) GetLibraryId() string

func (*Config) GetLibraryPath

func (x *Config) GetLibraryPath() string

func (*Config) GetMergePolicy

func (x *Config) GetMergePolicy() Config_MergePolicy

func (*Config) GetPluginConfig

func (x *Config) GetPluginConfig() *anypb.Any

func (*Config) GetPluginName

func (x *Config) GetPluginName() string

func (*Config) HasPluginConfig

func (x *Config) HasPluginConfig() bool

func (*Config) ProtoMessage

func (*Config) ProtoMessage()

func (*Config) ProtoReflect

func (x *Config) ProtoReflect() protoreflect.Message

func (*Config) Reset

func (x *Config) Reset()

func (*Config) SetGenericSecrets

func (x *Config) SetGenericSecrets(v []*v3.SdsSecretConfig)

func (*Config) SetLibraryId

func (x *Config) SetLibraryId(v string)

func (*Config) SetLibraryPath

func (x *Config) SetLibraryPath(v string)

func (*Config) SetMergePolicy

func (x *Config) SetMergePolicy(v Config_MergePolicy)

func (*Config) SetPluginConfig

func (x *Config) SetPluginConfig(v *anypb.Any)

func (*Config) SetPluginName

func (x *Config) SetPluginName(v string)

func (*Config) String

func (x *Config) String() string

type Config_MergePolicy

type Config_MergePolicy int32

The meanings are as follows:

:“MERGE_VIRTUALHOST_ROUTER_FILTER“: Pass all configuration into Go plugin. :“MERGE_VIRTUALHOST_ROUTER“: Pass merged Virtual host and Router configuration into Go plugin. :“OVERRIDE“: Pass merged Virtual host, Router, and plugin configuration into Go plugin.

[#not-implemented-hide:]

const (
	Config_MERGE_VIRTUALHOST_ROUTER_FILTER Config_MergePolicy = 0
	Config_MERGE_VIRTUALHOST_ROUTER        Config_MergePolicy = 1
	Config_OVERRIDE                        Config_MergePolicy = 3
)

func (Config_MergePolicy) Descriptor

func (Config_MergePolicy) Enum

func (Config_MergePolicy) Number

func (Config_MergePolicy) String

func (x Config_MergePolicy) String() string

func (Config_MergePolicy) Type

type Config_builder

type Config_builder struct {

	// Globally unique ID for a dynamic library file.
	LibraryId string
	// Path to a dynamic library implementing the
	// :repo:`StreamFilter API <contrib/golang/common/go/api.StreamFilter>`
	// interface.
	// [#comment:TODO(wangfakang): Support for downloading libraries from remote repositories.]
	LibraryPath string
	// Globally unique name of the Go plugin.
	//
	// This name **must** be consistent with the name registered in “http::RegisterHttpFilterConfigFactory“,
	// and can be used to associate :ref:`route and virtualHost plugin configuration
	// <envoy_v3_api_field_extensions.filters.http.golang.v3alpha.ConfigsPerRoute.plugins_config>`.
	PluginName string
	// Configuration for the Go plugin.
	//
	// .. note::
	//
	//	This configuration is only parsed in the go plugin, and is therefore not validated
	//	by Envoy.
	//
	//	See the :repo:`StreamFilter API <contrib/golang/common/go/api/filter.go>`
	//	for more information about how the plugin's configuration data can be accessed.
	PluginConfig *anypb.Any
	// Merge policy for plugin configuration.
	//
	// The Go plugin configuration supports three dimensions:
	//
	// * Virtual host’s :ref:`typed_per_filter_config <envoy_v3_api_field_config.route.v3.VirtualHost.typed_per_filter_config>`
	// * Route’s :ref:`typed_per_filter_config <envoy_v3_api_field_config.route.v3.Route.typed_per_filter_config>`
	// * The filter's :ref:`plugin_config <envoy_v3_api_field_extensions.filters.http.golang.v3alpha.Config.plugin_config>`
	//
	// [#not-implemented-hide:]
	MergePolicy Config_MergePolicy
	// Generic secret list available to the plugin.
	// Looks into SDS or static bootstrap configuration.
	//
	// See :repo:`StreamFilter API <contrib/golang/common/go/api/filter.go>`
	// for more information about how to access secrets from Go.
	GenericSecrets []*v3.SdsSecretConfig
	// contains filtered or unexported fields
}

func (Config_builder) Build

func (b0 Config_builder) Build() *Config

type ConfigsPerRoute

type ConfigsPerRoute struct {

	// Configuration of the Go plugin at the per-router or per-virtualhost level,
	// keyed on the :ref:`plugin_name <envoy_v3_api_field_extensions.filters.http.golang.v3alpha.Config.plugin_name>`
	// of the Go plugin.
	PluginsConfig map[string]*RouterPlugin `` /* 174-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*ConfigsPerRoute) GetPluginsConfig

func (x *ConfigsPerRoute) GetPluginsConfig() map[string]*RouterPlugin

func (*ConfigsPerRoute) ProtoMessage

func (*ConfigsPerRoute) ProtoMessage()

func (*ConfigsPerRoute) ProtoReflect

func (x *ConfigsPerRoute) ProtoReflect() protoreflect.Message

func (*ConfigsPerRoute) Reset

func (x *ConfigsPerRoute) Reset()

func (*ConfigsPerRoute) SetPluginsConfig

func (x *ConfigsPerRoute) SetPluginsConfig(v map[string]*RouterPlugin)

func (*ConfigsPerRoute) String

func (x *ConfigsPerRoute) String() string

type ConfigsPerRoute_builder

type ConfigsPerRoute_builder struct {

	// Configuration of the Go plugin at the per-router or per-virtualhost level,
	// keyed on the :ref:`plugin_name <envoy_v3_api_field_extensions.filters.http.golang.v3alpha.Config.plugin_name>`
	// of the Go plugin.
	PluginsConfig map[string]*RouterPlugin
	// contains filtered or unexported fields
}

func (ConfigsPerRoute_builder) Build

type RouterPlugin

type RouterPlugin struct {

	// Types that are valid to be assigned to Override:
	//
	//	*RouterPlugin_Disabled
	//	*RouterPlugin_Config
	Override isRouterPlugin_Override `protobuf_oneof:"override"`
	// contains filtered or unexported fields
}

func (*RouterPlugin) ClearConfig

func (x *RouterPlugin) ClearConfig()

func (*RouterPlugin) ClearDisabled

func (x *RouterPlugin) ClearDisabled()

func (*RouterPlugin) ClearOverride

func (x *RouterPlugin) ClearOverride()

func (*RouterPlugin) GetConfig

func (x *RouterPlugin) GetConfig() *anypb.Any

func (*RouterPlugin) GetDisabled

func (x *RouterPlugin) GetDisabled() bool

func (*RouterPlugin) GetOverride

func (x *RouterPlugin) GetOverride() isRouterPlugin_Override

func (*RouterPlugin) HasConfig

func (x *RouterPlugin) HasConfig() bool

func (*RouterPlugin) HasDisabled

func (x *RouterPlugin) HasDisabled() bool

func (*RouterPlugin) HasOverride

func (x *RouterPlugin) HasOverride() bool

func (*RouterPlugin) ProtoMessage

func (*RouterPlugin) ProtoMessage()

func (*RouterPlugin) ProtoReflect

func (x *RouterPlugin) ProtoReflect() protoreflect.Message

func (*RouterPlugin) Reset

func (x *RouterPlugin) Reset()

func (*RouterPlugin) SetConfig

func (x *RouterPlugin) SetConfig(v *anypb.Any)

func (*RouterPlugin) SetDisabled

func (x *RouterPlugin) SetDisabled(v bool)

func (*RouterPlugin) String

func (x *RouterPlugin) String() string

func (*RouterPlugin) WhichOverride

func (x *RouterPlugin) WhichOverride() case_RouterPlugin_Override

type RouterPlugin_Config

type RouterPlugin_Config struct {
	// The config field is used for setting per-route and per-virtualhost plugin config.
	Config *anypb.Any `protobuf:"bytes,2,opt,name=config,proto3,oneof"`
}

type RouterPlugin_Disabled

type RouterPlugin_Disabled struct {
	// [#not-implemented-hide:]
	// Disable the filter for this particular vhost or route.
	// If disabled is specified in multiple per-filter-configs, the most specific one will be used.
	Disabled bool `protobuf:"varint,1,opt,name=disabled,proto3,oneof"`
}

type RouterPlugin_builder

type RouterPlugin_builder struct {

	// Fields of oneof Override:
	// [#not-implemented-hide:]
	// Disable the filter for this particular vhost or route.
	// If disabled is specified in multiple per-filter-configs, the most specific one will be used.
	Disabled *bool
	// The config field is used for setting per-route and per-virtualhost plugin config.
	Config *anypb.Any
	// contains filtered or unexported fields
}

func (RouterPlugin_builder) Build

func (b0 RouterPlugin_builder) Build() *RouterPlugin

Source Files

  • golang.pb.go

Jump to