Documentation
¶
Index ¶
- Variables
- type Language
- func (x *Language) GetClearRouteCache() bool
- func (x *Language) GetDefaultLanguage() string
- func (x *Language) GetSupportedLanguages() []string
- func (*Language) ProtoMessage()
- func (x *Language) ProtoReflect() protoreflect.Message
- func (x *Language) Reset()
- func (x *Language) SetClearRouteCache(v bool)
- func (x *Language) SetDefaultLanguage(v string)
- func (x *Language) SetSupportedLanguages(v []string)
- func (x *Language) String() string
- type Language_builder
Constants ¶
This section is empty.
Variables ¶
var File_contrib_envoy_extensions_filters_http_language_v3alpha_language_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Language ¶
type Language struct {
// The default language to be used as a fallback.
// The value will be included in the list of the supported languages.
//
// See https://unicode-org.github.io/icu/userguide/locale/
DefaultLanguage string `protobuf:"bytes,1,opt,name=default_language,json=defaultLanguage,proto3" json:"default_language,omitempty"`
// The set of supported languages. There is no order priority.
// The order will be determined by the Accept-Language header priority list
// of the client.
//
// See https://unicode-org.github.io/icu/userguide/locale/
SupportedLanguages []string `protobuf:"bytes,2,rep,name=supported_languages,json=supportedLanguages,proto3" json:"supported_languages,omitempty"`
// If the x-language header is altered, clear the route cache for the current request.
// This should be set if the route configuration may depend on the x-language header.
// Otherwise it should be unset to avoid the performance cost of route recalculation.
ClearRouteCache bool `protobuf:"varint,3,opt,name=clear_route_cache,json=clearRouteCache,proto3" json:"clear_route_cache,omitempty"`
// contains filtered or unexported fields
}
Language detection filter config.
func (*Language) ProtoReflect ¶
func (x *Language) ProtoReflect() protoreflect.Message
type Language_builder ¶
type Language_builder struct {
// The default language to be used as a fallback.
// The value will be included in the list of the supported languages.
//
// See https://unicode-org.github.io/icu/userguide/locale/
DefaultLanguage string
// The set of supported languages. There is no order priority.
// The order will be determined by the Accept-Language header priority list
// of the client.
//
// See https://unicode-org.github.io/icu/userguide/locale/
SupportedLanguages []string
// If the x-language header is altered, clear the route cache for the current request.
// This should be set if the route configuration may depend on the x-language header.
// Otherwise it should be unset to avoid the performance cost of route recalculation.
ClearRouteCache bool
// contains filtered or unexported fields
}
func (Language_builder) Build ¶
func (b0 Language_builder) Build() *Language
Source Files
¶
- language.pb.go
Click to show internal directories.
Click to hide internal directories.