Documentation
¶
Index ¶
- Variables
- type Config
- func (x *Config) ClearPluginConfig()
- func (x *Config) GetIsTerminalFilter() bool
- func (x *Config) GetLibraryId() string
- func (x *Config) GetLibraryPath() string
- func (x *Config) GetPluginConfig() *anypb.Any
- func (x *Config) GetPluginName() string
- func (x *Config) HasPluginConfig() bool
- func (*Config) ProtoMessage()
- func (x *Config) ProtoReflect() protoreflect.Message
- func (x *Config) Reset()
- func (x *Config) SetIsTerminalFilter(v bool)
- func (x *Config) SetLibraryId(v string)
- func (x *Config) SetLibraryPath(v string)
- func (x *Config) SetPluginConfig(v *anypb.Any)
- func (x *Config) SetPluginName(v string)
- func (x *Config) String() string
- type Config_builder
Constants ¶
This section is empty.
Variables ¶
var File_contrib_envoy_extensions_filters_network_golang_v3alpha_golang_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
// Bool “true“ if this filter must be the last filter in a filter chain, “false“ otherwise.
IsTerminalFilter bool `protobuf:"varint,1,opt,name=is_terminal_filter,json=isTerminalFilter,proto3" json:"is_terminal_filter,omitempty"`
// Globally unique ID for a dynamic library file.
LibraryId string `protobuf:"bytes,2,opt,name=library_id,json=libraryId,proto3" json:"library_id,omitempty"`
// Path to a dynamic library implementing the
// :repo:`DownstreamFilter API <contrib/golang/common/go/api.DownstreamFilter>`
// interface.
// [#comment:TODO(wangfakang): Support for downloading libraries from remote repositories.]
LibraryPath string `protobuf:"bytes,3,opt,name=library_path,json=libraryPath,proto3" json:"library_path,omitempty"`
// Globally unique name of the Go plugin.
//
// This name **must** be consistent with the name registered in “network::RegisterNetworkFilterConfigFactory“
PluginName string `protobuf:"bytes,4,opt,name=plugin_name,json=pluginName,proto3" json:"plugin_name,omitempty"`
// Configuration for the Go plugin.
//
// .. note::
//
// This configuration is only parsed in the go plugin, and is therefore not validated
// by Envoy.
//
// See the :repo:`DownstreamFilter API <contrib/golang/common/go/api/filter.go>`
// for more information about how the plugin's configuration data can be accessed.
PluginConfig *anypb.Any `protobuf:"bytes,5,opt,name=plugin_config,json=pluginConfig,proto3" json:"plugin_config,omitempty"`
// contains filtered or unexported fields
}
[#next-free-field: 6]
func (*Config) ProtoReflect ¶
func (x *Config) ProtoReflect() protoreflect.Message
type Config_builder ¶
type Config_builder struct {
// Bool “true“ if this filter must be the last filter in a filter chain, “false“ otherwise.
IsTerminalFilter bool
// Globally unique ID for a dynamic library file.
LibraryId string
// Path to a dynamic library implementing the
// :repo:`DownstreamFilter API <contrib/golang/common/go/api.DownstreamFilter>`
// interface.
// [#comment:TODO(wangfakang): Support for downloading libraries from remote repositories.]
LibraryPath string
// Globally unique name of the Go plugin.
//
// This name **must** be consistent with the name registered in “network::RegisterNetworkFilterConfigFactory“
PluginName string
// Configuration for the Go plugin.
//
// .. note::
//
// This configuration is only parsed in the go plugin, and is therefore not validated
// by Envoy.
//
// See the :repo:`DownstreamFilter API <contrib/golang/common/go/api/filter.go>`
// for more information about how the plugin's configuration data can be accessed.
PluginConfig *anypb.Any
// contains filtered or unexported fields
}
func (Config_builder) Build ¶
func (b0 Config_builder) Build() *Config
Source Files
¶
- golang.pb.go
Click to show internal directories.
Click to hide internal directories.