Documentation
¶
Index ¶
- Variables
- type MySQLProxy
- func (x *MySQLProxy) GetAccessLog() string
- func (x *MySQLProxy) GetStatPrefix() string
- func (*MySQLProxy) ProtoMessage()
- func (x *MySQLProxy) ProtoReflect() protoreflect.Message
- func (x *MySQLProxy) Reset()
- func (x *MySQLProxy) SetAccessLog(v string)
- func (x *MySQLProxy) SetStatPrefix(v string)
- func (x *MySQLProxy) String() string
- type MySQLProxy_builder
Constants ¶
This section is empty.
Variables ¶
var File_contrib_envoy_extensions_filters_network_mysql_proxy_v3_mysql_proxy_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type MySQLProxy ¶
type MySQLProxy struct {
// The human readable prefix to use when emitting :ref:`statistics
// <config_network_filters_mysql_proxy_stats>`.
StatPrefix string `protobuf:"bytes,1,opt,name=stat_prefix,json=statPrefix,proto3" json:"stat_prefix,omitempty"`
// [#not-implemented-hide:] The optional path to use for writing MySQL access logs.
// If the access log field is empty, access logs will not be written.
AccessLog string `protobuf:"bytes,2,opt,name=access_log,json=accessLog,proto3" json:"access_log,omitempty"`
// contains filtered or unexported fields
}
func (*MySQLProxy) GetAccessLog ¶
func (x *MySQLProxy) GetAccessLog() string
func (*MySQLProxy) GetStatPrefix ¶
func (x *MySQLProxy) GetStatPrefix() string
func (*MySQLProxy) ProtoMessage ¶
func (*MySQLProxy) ProtoMessage()
func (*MySQLProxy) ProtoReflect ¶
func (x *MySQLProxy) ProtoReflect() protoreflect.Message
func (*MySQLProxy) Reset ¶
func (x *MySQLProxy) Reset()
func (*MySQLProxy) SetAccessLog ¶
func (x *MySQLProxy) SetAccessLog(v string)
func (*MySQLProxy) SetStatPrefix ¶
func (x *MySQLProxy) SetStatPrefix(v string)
func (*MySQLProxy) String ¶
func (x *MySQLProxy) String() string
type MySQLProxy_builder ¶
type MySQLProxy_builder struct {
// The human readable prefix to use when emitting :ref:`statistics
// <config_network_filters_mysql_proxy_stats>`.
StatPrefix string
// [#not-implemented-hide:] The optional path to use for writing MySQL access logs.
// If the access log field is empty, access logs will not be written.
AccessLog string
// contains filtered or unexported fields
}
func (MySQLProxy_builder) Build ¶
func (b0 MySQLProxy_builder) Build() *MySQLProxy
Source Files
¶
- mysql_proxy.pb.go
Click to show internal directories.
Click to hide internal directories.