Documentation
¶
Index ¶
- Variables
- type PostgresProxy
- func (x *PostgresProxy) ClearEnableSqlParsing()
- func (x *PostgresProxy) GetDownstreamSsl() PostgresProxy_SSLMode
- func (x *PostgresProxy) GetEnableSqlParsing() *wrapperspb.BoolValue
- func (x *PostgresProxy) GetStatPrefix() string
- func (x *PostgresProxy) GetTerminateSsl() booldeprecated
- func (x *PostgresProxy) GetUpstreamSsl() PostgresProxy_SSLMode
- func (x *PostgresProxy) HasEnableSqlParsing() bool
- func (*PostgresProxy) ProtoMessage()
- func (x *PostgresProxy) ProtoReflect() protoreflect.Message
- func (x *PostgresProxy) Reset()
- func (x *PostgresProxy) SetDownstreamSsl(v PostgresProxy_SSLMode)
- func (x *PostgresProxy) SetEnableSqlParsing(v *wrapperspb.BoolValue)
- func (x *PostgresProxy) SetStatPrefix(v string)
- func (x *PostgresProxy) SetTerminateSsl(v bool)deprecated
- func (x *PostgresProxy) SetUpstreamSsl(v PostgresProxy_SSLMode)
- func (x *PostgresProxy) String() string
- type PostgresProxy_SSLMode
- type PostgresProxy_builder
Constants ¶
This section is empty.
Variables ¶
var ( PostgresProxy_SSLMode_name = map[int32]string{ 0: "DISABLE", 1: "REQUIRE", 2: "ALLOW", } PostgresProxy_SSLMode_value = map[string]int32{ "DISABLE": 0, "REQUIRE": 1, "ALLOW": 2, } )
Enum value maps for PostgresProxy_SSLMode.
var File_contrib_envoy_extensions_filters_network_postgres_proxy_v3alpha_postgres_proxy_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type PostgresProxy ¶
type PostgresProxy struct {
// The human readable prefix to use when emitting :ref:`statistics
// <config_network_filters_postgres_proxy_stats>`.
StatPrefix string `protobuf:"bytes,1,opt,name=stat_prefix,json=statPrefix,proto3" json:"stat_prefix,omitempty"`
// Controls whether SQL statements received in Frontend Query messages
// are parsed. Parsing is required to produce Postgres proxy filter
// metadata. Defaults to true.
EnableSqlParsing *wrapperspb.BoolValue `protobuf:"bytes,2,opt,name=enable_sql_parsing,json=enableSqlParsing,proto3" json:"enable_sql_parsing,omitempty"`
// Controls whether to terminate SSL session initiated by a client.
// If the value is false, the Postgres proxy filter will not try to
// terminate SSL session, but will pass all the packets to the upstream server.
// If the value is true, the Postgres proxy filter will try to terminate SSL
// session. In order to do that, the filter chain must use :ref:`starttls transport socket
// <envoy_v3_api_msg_extensions.transport_sockets.starttls.v3.StartTlsConfig>`.
// If the filter does not manage to terminate the SSL session, it will close the connection from the client.
// Refer to official documentation for details
// `SSL Session Encryption Message Flow <https://www.postgresql.org/docs/current/protocol-flow.html#id-1.10.5.7.11>`_.
// This field is deprecated.
// Please use :ref:`downstream_ssl <envoy_v3_api_field_extensions.filters.network.postgres_proxy.v3alpha.PostgresProxy.downstream_ssl>`.
//
// Deprecated: Marked as deprecated in contrib/envoy/extensions/filters/network/postgres_proxy/v3alpha/postgres_proxy.proto.
TerminateSsl bool `protobuf:"varint,3,opt,name=terminate_ssl,json=terminateSsl,proto3" json:"terminate_ssl,omitempty"`
// Controls whether to establish upstream SSL connection to the server.
// Envoy will try to establish upstream SSL connection to the server only when
// Postgres filter is able to read Postgres payload in clear-text. It happens when
// a client established a clear-text connection to Envoy or when a client established
// SSL connection to Envoy and Postgres filter is configured to terminate SSL.
// In order for upstream encryption to work, the corresponding cluster must be configured to use
// :ref:`starttls transport socket <envoy_v3_api_msg_extensions.transport_sockets.starttls.v3.UpstreamStartTlsConfig>`.
// Defaults to “DISABLE“.
UpstreamSsl PostgresProxy_SSLMode `` /* 178-byte string literal not displayed */
// Controls whether to close downstream connections that refuse to upgrade to SSL.
// If enabled, the filter chain must use
// :ref:`starttls transport socket <envoy_v3_api_msg_extensions.transport_sockets.starttls.v3.UpstreamStartTlsConfig>`.
// Defaults to “DISABLE“.
DownstreamSsl PostgresProxy_SSLMode `` /* 184-byte string literal not displayed */
// contains filtered or unexported fields
}
[#next-free-field: 6]
func (*PostgresProxy) ClearEnableSqlParsing ¶
func (x *PostgresProxy) ClearEnableSqlParsing()
func (*PostgresProxy) GetDownstreamSsl ¶
func (x *PostgresProxy) GetDownstreamSsl() PostgresProxy_SSLMode
func (*PostgresProxy) GetEnableSqlParsing ¶
func (x *PostgresProxy) GetEnableSqlParsing() *wrapperspb.BoolValue
func (*PostgresProxy) GetStatPrefix ¶
func (x *PostgresProxy) GetStatPrefix() string
func (*PostgresProxy) GetTerminateSsl
deprecated
func (x *PostgresProxy) GetTerminateSsl() bool
Deprecated: Marked as deprecated in contrib/envoy/extensions/filters/network/postgres_proxy/v3alpha/postgres_proxy.proto.
func (*PostgresProxy) GetUpstreamSsl ¶
func (x *PostgresProxy) GetUpstreamSsl() PostgresProxy_SSLMode
func (*PostgresProxy) HasEnableSqlParsing ¶
func (x *PostgresProxy) HasEnableSqlParsing() bool
func (*PostgresProxy) ProtoMessage ¶
func (*PostgresProxy) ProtoMessage()
func (*PostgresProxy) ProtoReflect ¶
func (x *PostgresProxy) ProtoReflect() protoreflect.Message
func (*PostgresProxy) Reset ¶
func (x *PostgresProxy) Reset()
func (*PostgresProxy) SetDownstreamSsl ¶
func (x *PostgresProxy) SetDownstreamSsl(v PostgresProxy_SSLMode)
func (*PostgresProxy) SetEnableSqlParsing ¶
func (x *PostgresProxy) SetEnableSqlParsing(v *wrapperspb.BoolValue)
func (*PostgresProxy) SetStatPrefix ¶
func (x *PostgresProxy) SetStatPrefix(v string)
func (*PostgresProxy) SetTerminateSsl
deprecated
func (x *PostgresProxy) SetTerminateSsl(v bool)
Deprecated: Marked as deprecated in contrib/envoy/extensions/filters/network/postgres_proxy/v3alpha/postgres_proxy.proto.
func (*PostgresProxy) SetUpstreamSsl ¶
func (x *PostgresProxy) SetUpstreamSsl(v PostgresProxy_SSLMode)
func (*PostgresProxy) String ¶
func (x *PostgresProxy) String() string
type PostgresProxy_SSLMode ¶
type PostgresProxy_SSLMode int32
Downstream and Upstream SSL operational modes.
const ( // If used in downstream ssl, do not terminate SSL session initiated by a client. // The Postgres proxy filter will pass all encrypted and unencrypted packets to the upstream server. // If used in upstream ssl, do not encrypt upstream connection to the server. PostgresProxy_DISABLE PostgresProxy_SSLMode = 0 // If used in downstream ssl, the Postgres proxy filter will terminate SSL // session and close downstream connections that refuse to upgrade to SSL. // If used in upstream SSL, establish upstream SSL connection to the server. If the server does not // accept the request for SSL connection, the session is terminated. PostgresProxy_REQUIRE PostgresProxy_SSLMode = 1 // If used in downstream SSL, the Postgres proxy filter will accept downstream // client's encryption settings. If the client wants to use clear-text, // Envoy will not enforce SSL encryption. // If the client wants to use encryption, Envoy will terminate SSL. PostgresProxy_ALLOW PostgresProxy_SSLMode = 2 )
func (PostgresProxy_SSLMode) Descriptor ¶
func (PostgresProxy_SSLMode) Descriptor() protoreflect.EnumDescriptor
func (PostgresProxy_SSLMode) Enum ¶
func (x PostgresProxy_SSLMode) Enum() *PostgresProxy_SSLMode
func (PostgresProxy_SSLMode) Number ¶
func (x PostgresProxy_SSLMode) Number() protoreflect.EnumNumber
func (PostgresProxy_SSLMode) String ¶
func (x PostgresProxy_SSLMode) String() string
func (PostgresProxy_SSLMode) Type ¶
func (PostgresProxy_SSLMode) Type() protoreflect.EnumType
type PostgresProxy_builder ¶
type PostgresProxy_builder struct {
// The human readable prefix to use when emitting :ref:`statistics
// <config_network_filters_postgres_proxy_stats>`.
StatPrefix string
// Controls whether SQL statements received in Frontend Query messages
// are parsed. Parsing is required to produce Postgres proxy filter
// metadata. Defaults to true.
EnableSqlParsing *wrapperspb.BoolValue
// Controls whether to terminate SSL session initiated by a client.
// If the value is false, the Postgres proxy filter will not try to
// terminate SSL session, but will pass all the packets to the upstream server.
// If the value is true, the Postgres proxy filter will try to terminate SSL
// session. In order to do that, the filter chain must use :ref:`starttls transport socket
// <envoy_v3_api_msg_extensions.transport_sockets.starttls.v3.StartTlsConfig>`.
// If the filter does not manage to terminate the SSL session, it will close the connection from the client.
// Refer to official documentation for details
// `SSL Session Encryption Message Flow <https://www.postgresql.org/docs/current/protocol-flow.html#id-1.10.5.7.11>`_.
// This field is deprecated.
// Please use :ref:`downstream_ssl <envoy_v3_api_field_extensions.filters.network.postgres_proxy.v3alpha.PostgresProxy.downstream_ssl>`.
//
// Deprecated: Marked as deprecated in contrib/envoy/extensions/filters/network/postgres_proxy/v3alpha/postgres_proxy.proto.
TerminateSsl bool
// Controls whether to establish upstream SSL connection to the server.
// Envoy will try to establish upstream SSL connection to the server only when
// Postgres filter is able to read Postgres payload in clear-text. It happens when
// a client established a clear-text connection to Envoy or when a client established
// SSL connection to Envoy and Postgres filter is configured to terminate SSL.
// In order for upstream encryption to work, the corresponding cluster must be configured to use
// :ref:`starttls transport socket <envoy_v3_api_msg_extensions.transport_sockets.starttls.v3.UpstreamStartTlsConfig>`.
// Defaults to “DISABLE“.
UpstreamSsl PostgresProxy_SSLMode
// Controls whether to close downstream connections that refuse to upgrade to SSL.
// If enabled, the filter chain must use
// :ref:`starttls transport socket <envoy_v3_api_msg_extensions.transport_sockets.starttls.v3.UpstreamStartTlsConfig>`.
// Defaults to “DISABLE“.
DownstreamSsl PostgresProxy_SSLMode
// contains filtered or unexported fields
}
func (PostgresProxy_builder) Build ¶
func (b0 PostgresProxy_builder) Build() *PostgresProxy
Source Files
¶
- postgres_proxy.pb.go
Click to show internal directories.
Click to hide internal directories.