rocketmq_proxyv3

package
v1.36.11-2026011520535... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var File_contrib_envoy_extensions_filters_network_rocketmq_proxy_v3_rocketmq_proxy_proto protoreflect.FileDescriptor
var File_contrib_envoy_extensions_filters_network_rocketmq_proxy_v3_route_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type RocketmqProxy

type RocketmqProxy struct {

	// The human readable prefix to use when emitting statistics.
	StatPrefix string `protobuf:"bytes,1,opt,name=stat_prefix,json=statPrefix,proto3" json:"stat_prefix,omitempty"`
	// The route table for the connection manager is specified in this property.
	RouteConfig *RouteConfiguration `protobuf:"bytes,2,opt,name=route_config,json=routeConfig,proto3" json:"route_config,omitempty"`
	// The largest duration transient object expected to live, more than 10s is recommended.
	TransientObjectLifeSpan *durationpb.Duration `` /* 134-byte string literal not displayed */
	// If develop_mode is enabled, this proxy plugin may work without dedicated traffic intercepting
	// facility without considering backward compatibility of exiting RocketMQ client SDK.
	DevelopMode bool `protobuf:"varint,4,opt,name=develop_mode,json=developMode,proto3" json:"develop_mode,omitempty"`
	// contains filtered or unexported fields
}

func (*RocketmqProxy) ClearRouteConfig

func (x *RocketmqProxy) ClearRouteConfig()

func (*RocketmqProxy) ClearTransientObjectLifeSpan

func (x *RocketmqProxy) ClearTransientObjectLifeSpan()

func (*RocketmqProxy) GetDevelopMode

func (x *RocketmqProxy) GetDevelopMode() bool

func (*RocketmqProxy) GetRouteConfig

func (x *RocketmqProxy) GetRouteConfig() *RouteConfiguration

func (*RocketmqProxy) GetStatPrefix

func (x *RocketmqProxy) GetStatPrefix() string

func (*RocketmqProxy) GetTransientObjectLifeSpan

func (x *RocketmqProxy) GetTransientObjectLifeSpan() *durationpb.Duration

func (*RocketmqProxy) HasRouteConfig

func (x *RocketmqProxy) HasRouteConfig() bool

func (*RocketmqProxy) HasTransientObjectLifeSpan

func (x *RocketmqProxy) HasTransientObjectLifeSpan() bool

func (*RocketmqProxy) ProtoMessage

func (*RocketmqProxy) ProtoMessage()

func (*RocketmqProxy) ProtoReflect

func (x *RocketmqProxy) ProtoReflect() protoreflect.Message

func (*RocketmqProxy) Reset

func (x *RocketmqProxy) Reset()

func (*RocketmqProxy) SetDevelopMode

func (x *RocketmqProxy) SetDevelopMode(v bool)

func (*RocketmqProxy) SetRouteConfig

func (x *RocketmqProxy) SetRouteConfig(v *RouteConfiguration)

func (*RocketmqProxy) SetStatPrefix

func (x *RocketmqProxy) SetStatPrefix(v string)

func (*RocketmqProxy) SetTransientObjectLifeSpan

func (x *RocketmqProxy) SetTransientObjectLifeSpan(v *durationpb.Duration)

func (*RocketmqProxy) String

func (x *RocketmqProxy) String() string

type RocketmqProxy_builder

type RocketmqProxy_builder struct {

	// The human readable prefix to use when emitting statistics.
	StatPrefix string
	// The route table for the connection manager is specified in this property.
	RouteConfig *RouteConfiguration
	// The largest duration transient object expected to live, more than 10s is recommended.
	TransientObjectLifeSpan *durationpb.Duration
	// If develop_mode is enabled, this proxy plugin may work without dedicated traffic intercepting
	// facility without considering backward compatibility of exiting RocketMQ client SDK.
	DevelopMode bool
	// contains filtered or unexported fields
}

func (RocketmqProxy_builder) Build

type Route

type Route struct {

	// Route matching parameters.
	Match *RouteMatch `protobuf:"bytes,1,opt,name=match,proto3" json:"match,omitempty"`
	// Route request to some upstream cluster.
	Route *RouteAction `protobuf:"bytes,2,opt,name=route,proto3" json:"route,omitempty"`
	// contains filtered or unexported fields
}

func (*Route) ClearMatch

func (x *Route) ClearMatch()

func (*Route) ClearRoute

func (x *Route) ClearRoute()

func (*Route) GetMatch

func (x *Route) GetMatch() *RouteMatch

func (*Route) GetRoute

func (x *Route) GetRoute() *RouteAction

func (*Route) HasMatch

func (x *Route) HasMatch() bool

func (*Route) HasRoute

func (x *Route) HasRoute() bool

func (*Route) ProtoMessage

func (*Route) ProtoMessage()

func (*Route) ProtoReflect

func (x *Route) ProtoReflect() protoreflect.Message

func (*Route) Reset

func (x *Route) Reset()

func (*Route) SetMatch

func (x *Route) SetMatch(v *RouteMatch)

func (*Route) SetRoute

func (x *Route) SetRoute(v *RouteAction)

func (*Route) String

func (x *Route) String() string

type RouteAction

type RouteAction struct {

	// Indicates the upstream cluster to which the request should be routed.
	Cluster string `protobuf:"bytes,1,opt,name=cluster,proto3" json:"cluster,omitempty"`
	// Optional endpoint metadata match criteria used by the subset load balancer.
	MetadataMatch *v32.Metadata `protobuf:"bytes,2,opt,name=metadata_match,json=metadataMatch,proto3" json:"metadata_match,omitempty"`
	// contains filtered or unexported fields
}

func (*RouteAction) ClearMetadataMatch

func (x *RouteAction) ClearMetadataMatch()

func (*RouteAction) GetCluster

func (x *RouteAction) GetCluster() string

func (*RouteAction) GetMetadataMatch

func (x *RouteAction) GetMetadataMatch() *v32.Metadata

func (*RouteAction) HasMetadataMatch

func (x *RouteAction) HasMetadataMatch() bool

func (*RouteAction) ProtoMessage

func (*RouteAction) ProtoMessage()

func (*RouteAction) ProtoReflect

func (x *RouteAction) ProtoReflect() protoreflect.Message

func (*RouteAction) Reset

func (x *RouteAction) Reset()

func (*RouteAction) SetCluster

func (x *RouteAction) SetCluster(v string)

func (*RouteAction) SetMetadataMatch

func (x *RouteAction) SetMetadataMatch(v *v32.Metadata)

func (*RouteAction) String

func (x *RouteAction) String() string

type RouteAction_builder

type RouteAction_builder struct {

	// Indicates the upstream cluster to which the request should be routed.
	Cluster string
	// Optional endpoint metadata match criteria used by the subset load balancer.
	MetadataMatch *v32.Metadata
	// contains filtered or unexported fields
}

func (RouteAction_builder) Build

func (b0 RouteAction_builder) Build() *RouteAction

type RouteConfiguration

type RouteConfiguration struct {

	// The name of the route configuration.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// The list of routes that will be matched, in order, against incoming requests. The first route
	// that matches will be used.
	Routes []*Route `protobuf:"bytes,2,rep,name=routes,proto3" json:"routes,omitempty"`
	// contains filtered or unexported fields
}

func (*RouteConfiguration) GetName

func (x *RouteConfiguration) GetName() string

func (*RouteConfiguration) GetRoutes

func (x *RouteConfiguration) GetRoutes() []*Route

func (*RouteConfiguration) ProtoMessage

func (*RouteConfiguration) ProtoMessage()

func (*RouteConfiguration) ProtoReflect

func (x *RouteConfiguration) ProtoReflect() protoreflect.Message

func (*RouteConfiguration) Reset

func (x *RouteConfiguration) Reset()

func (*RouteConfiguration) SetName

func (x *RouteConfiguration) SetName(v string)

func (*RouteConfiguration) SetRoutes

func (x *RouteConfiguration) SetRoutes(v []*Route)

func (*RouteConfiguration) String

func (x *RouteConfiguration) String() string

type RouteConfiguration_builder

type RouteConfiguration_builder struct {

	// The name of the route configuration.
	Name string
	// The list of routes that will be matched, in order, against incoming requests. The first route
	// that matches will be used.
	Routes []*Route
	// contains filtered or unexported fields
}

func (RouteConfiguration_builder) Build

type RouteMatch

type RouteMatch struct {

	// The name of the topic.
	Topic *v3.StringMatcher `protobuf:"bytes,1,opt,name=topic,proto3" json:"topic,omitempty"`
	// Specifies a set of headers that the route should match on. The router will check the request’s
	// headers against all the specified headers in the route config. A match will happen if all the
	// headers in the route are present in the request with the same values (or based on presence if
	// the value field is not in the config).
	Headers []*v31.HeaderMatcher `protobuf:"bytes,2,rep,name=headers,proto3" json:"headers,omitempty"`
	// contains filtered or unexported fields
}

func (*RouteMatch) ClearTopic

func (x *RouteMatch) ClearTopic()

func (*RouteMatch) GetHeaders

func (x *RouteMatch) GetHeaders() []*v31.HeaderMatcher

func (*RouteMatch) GetTopic

func (x *RouteMatch) GetTopic() *v3.StringMatcher

func (*RouteMatch) HasTopic

func (x *RouteMatch) HasTopic() bool

func (*RouteMatch) ProtoMessage

func (*RouteMatch) ProtoMessage()

func (*RouteMatch) ProtoReflect

func (x *RouteMatch) ProtoReflect() protoreflect.Message

func (*RouteMatch) Reset

func (x *RouteMatch) Reset()

func (*RouteMatch) SetHeaders

func (x *RouteMatch) SetHeaders(v []*v31.HeaderMatcher)

func (*RouteMatch) SetTopic

func (x *RouteMatch) SetTopic(v *v3.StringMatcher)

func (*RouteMatch) String

func (x *RouteMatch) String() string

type RouteMatch_builder

type RouteMatch_builder struct {

	// The name of the topic.
	Topic *v3.StringMatcher
	// Specifies a set of headers that the route should match on. The router will check the request’s
	// headers against all the specified headers in the route config. A match will happen if all the
	// headers in the route are present in the request with the same values (or based on presence if
	// the value field is not in the config).
	Headers []*v31.HeaderMatcher
	// contains filtered or unexported fields
}

func (RouteMatch_builder) Build

func (b0 RouteMatch_builder) Build() *RouteMatch

type Route_builder

type Route_builder struct {

	// Route matching parameters.
	Match *RouteMatch
	// Route request to some upstream cluster.
	Route *RouteAction
	// contains filtered or unexported fields
}

func (Route_builder) Build

func (b0 Route_builder) Build() *Route

Source Files

  • rocketmq_proxy.pb.go
  • route.pb.go

Jump to