Documentation
¶
Index ¶
- Constants
- Variables
- type CreateRequest
- func (x *CreateRequest) GetContext() map[string]string
- func (x *CreateRequest) GetData() map[string]string
- func (*CreateRequest) ProtoMessage()
- func (x *CreateRequest) ProtoReflect() protoreflect.Message
- func (x *CreateRequest) Reset()
- func (x *CreateRequest) SetContext(v map[string]string)
- func (x *CreateRequest) SetData(v map[string]string)
- func (x *CreateRequest) String() string
- type CreateRequest_builder
- type CreateResponse
- type CreateResponse_builder
- type DeleteRequest
- func (x *DeleteRequest) GetContext() map[string]string
- func (x *DeleteRequest) GetKey() string
- func (*DeleteRequest) ProtoMessage()
- func (x *DeleteRequest) ProtoReflect() protoreflect.Message
- func (x *DeleteRequest) Reset()
- func (x *DeleteRequest) SetContext(v map[string]string)
- func (x *DeleteRequest) SetKey(v string)
- func (x *DeleteRequest) String() string
- type DeleteRequest_builder
- type DeleteResponse
- type DeleteResponse_builder
- type RetrieveRequest
- func (x *RetrieveRequest) GetContext() map[string]string
- func (x *RetrieveRequest) GetKey() string
- func (*RetrieveRequest) ProtoMessage()
- func (x *RetrieveRequest) ProtoReflect() protoreflect.Message
- func (x *RetrieveRequest) Reset()
- func (x *RetrieveRequest) SetContext(v map[string]string)
- func (x *RetrieveRequest) SetKey(v string)
- func (x *RetrieveRequest) String() string
- type RetrieveRequest_builder
- type RetrieveResponse
- type RetrieveResponse_builder
- type SubscribeRequest
- type SubscribeRequest_builder
- type SubscribeResponse
- type SubscribeResponse_builder
- type TraServiceConfig
- func (x *TraServiceConfig) ClearGrpcService()
- func (x *TraServiceConfig) ClearTimeout()
- func (x *TraServiceConfig) GetGrpcService() *v3.GrpcService
- func (x *TraServiceConfig) GetTimeout() *durationpb.Duration
- func (x *TraServiceConfig) GetTransportApiVersion() v3.ApiVersion
- func (x *TraServiceConfig) HasGrpcService() bool
- func (x *TraServiceConfig) HasTimeout() bool
- func (*TraServiceConfig) ProtoMessage()
- func (x *TraServiceConfig) ProtoReflect() protoreflect.Message
- func (x *TraServiceConfig) Reset()
- func (x *TraServiceConfig) SetGrpcService(v *v3.GrpcService)
- func (x *TraServiceConfig) SetTimeout(v *durationpb.Duration)
- func (x *TraServiceConfig) SetTransportApiVersion(v v3.ApiVersion)
- func (x *TraServiceConfig) String() string
- type TraServiceConfig_builder
- type TraServiceRequest
- func (x *TraServiceRequest) ClearCreateRequest()
- func (x *TraServiceRequest) ClearDeleteRequest()
- func (x *TraServiceRequest) ClearRequest()
- func (x *TraServiceRequest) ClearRetrieveRequest()
- func (x *TraServiceRequest) ClearSubscribeRequest()
- func (x *TraServiceRequest) ClearUpdateRequest()
- func (x *TraServiceRequest) GetCreateRequest() *CreateRequest
- func (x *TraServiceRequest) GetDeleteRequest() *DeleteRequest
- func (x *TraServiceRequest) GetRequest() isTraServiceRequest_Request
- func (x *TraServiceRequest) GetRetrieveRequest() *RetrieveRequest
- func (x *TraServiceRequest) GetSubscribeRequest() *SubscribeRequest
- func (x *TraServiceRequest) GetType() string
- func (x *TraServiceRequest) GetUpdateRequest() *UpdateRequest
- func (x *TraServiceRequest) HasCreateRequest() bool
- func (x *TraServiceRequest) HasDeleteRequest() bool
- func (x *TraServiceRequest) HasRequest() bool
- func (x *TraServiceRequest) HasRetrieveRequest() bool
- func (x *TraServiceRequest) HasSubscribeRequest() bool
- func (x *TraServiceRequest) HasUpdateRequest() bool
- func (*TraServiceRequest) ProtoMessage()
- func (x *TraServiceRequest) ProtoReflect() protoreflect.Message
- func (x *TraServiceRequest) Reset()
- func (x *TraServiceRequest) SetCreateRequest(v *CreateRequest)
- func (x *TraServiceRequest) SetDeleteRequest(v *DeleteRequest)
- func (x *TraServiceRequest) SetRetrieveRequest(v *RetrieveRequest)
- func (x *TraServiceRequest) SetSubscribeRequest(v *SubscribeRequest)
- func (x *TraServiceRequest) SetType(v string)
- func (x *TraServiceRequest) SetUpdateRequest(v *UpdateRequest)
- func (x *TraServiceRequest) String() string
- func (x *TraServiceRequest) WhichRequest() case_TraServiceRequest_Request
- type TraServiceRequest_CreateRequest
- type TraServiceRequest_DeleteRequest
- type TraServiceRequest_RetrieveRequest
- type TraServiceRequest_SubscribeRequest
- type TraServiceRequest_UpdateRequest
- type TraServiceRequest_builder
- type TraServiceResponse
- func (x *TraServiceResponse) ClearCreateResponse()
- func (x *TraServiceResponse) ClearDeleteResponse()
- func (x *TraServiceResponse) ClearResponse()
- func (x *TraServiceResponse) ClearRetrieveResponse()
- func (x *TraServiceResponse) ClearSubscribeResponse()
- func (x *TraServiceResponse) ClearUpdateResponse()
- func (x *TraServiceResponse) GetCreateResponse() *CreateResponse
- func (x *TraServiceResponse) GetDeleteResponse() *DeleteResponse
- func (x *TraServiceResponse) GetReason() string
- func (x *TraServiceResponse) GetResponse() isTraServiceResponse_Response
- func (x *TraServiceResponse) GetRet() int32
- func (x *TraServiceResponse) GetRetrieveResponse() *RetrieveResponse
- func (x *TraServiceResponse) GetSubscribeResponse() *SubscribeResponse
- func (x *TraServiceResponse) GetType() string
- func (x *TraServiceResponse) GetUpdateResponse() *UpdateResponse
- func (x *TraServiceResponse) HasCreateResponse() bool
- func (x *TraServiceResponse) HasDeleteResponse() bool
- func (x *TraServiceResponse) HasResponse() bool
- func (x *TraServiceResponse) HasRetrieveResponse() bool
- func (x *TraServiceResponse) HasSubscribeResponse() bool
- func (x *TraServiceResponse) HasUpdateResponse() bool
- func (*TraServiceResponse) ProtoMessage()
- func (x *TraServiceResponse) ProtoReflect() protoreflect.Message
- func (x *TraServiceResponse) Reset()
- func (x *TraServiceResponse) SetCreateResponse(v *CreateResponse)
- func (x *TraServiceResponse) SetDeleteResponse(v *DeleteResponse)
- func (x *TraServiceResponse) SetReason(v string)
- func (x *TraServiceResponse) SetRet(v int32)
- func (x *TraServiceResponse) SetRetrieveResponse(v *RetrieveResponse)
- func (x *TraServiceResponse) SetSubscribeResponse(v *SubscribeResponse)
- func (x *TraServiceResponse) SetType(v string)
- func (x *TraServiceResponse) SetUpdateResponse(v *UpdateResponse)
- func (x *TraServiceResponse) String() string
- func (x *TraServiceResponse) WhichResponse() case_TraServiceResponse_Response
- type TraServiceResponse_CreateResponse
- type TraServiceResponse_DeleteResponse
- type TraServiceResponse_RetrieveResponse
- type TraServiceResponse_SubscribeResponse
- type TraServiceResponse_UpdateResponse
- type TraServiceResponse_builder
- type UpdateRequest
- func (x *UpdateRequest) GetContext() map[string]string
- func (x *UpdateRequest) GetData() map[string]string
- func (*UpdateRequest) ProtoMessage()
- func (x *UpdateRequest) ProtoReflect() protoreflect.Message
- func (x *UpdateRequest) Reset()
- func (x *UpdateRequest) SetContext(v map[string]string)
- func (x *UpdateRequest) SetData(v map[string]string)
- func (x *UpdateRequest) String() string
- type UpdateRequest_builder
- type UpdateResponse
- type UpdateResponse_builder
Constants ¶
const TraServiceRequest_CreateRequest_case case_TraServiceRequest_Request = 2
const TraServiceRequest_DeleteRequest_case case_TraServiceRequest_Request = 5
const TraServiceRequest_Request_not_set_case case_TraServiceRequest_Request = 0
const TraServiceRequest_RetrieveRequest_case case_TraServiceRequest_Request = 4
const TraServiceRequest_SubscribeRequest_case case_TraServiceRequest_Request = 6
const TraServiceRequest_UpdateRequest_case case_TraServiceRequest_Request = 3
const TraServiceResponse_CreateResponse_case case_TraServiceResponse_Response = 4
const TraServiceResponse_DeleteResponse_case case_TraServiceResponse_Response = 7
const TraServiceResponse_Response_not_set_case case_TraServiceResponse_Response = 0
const TraServiceResponse_RetrieveResponse_case case_TraServiceResponse_Response = 6
const TraServiceResponse_SubscribeResponse_case case_TraServiceResponse_Response = 8
const TraServiceResponse_UpdateResponse_case case_TraServiceResponse_Response = 5
Variables ¶
var File_contrib_envoy_extensions_filters_network_sip_proxy_tra_v3alpha_tra_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type CreateRequest ¶
type CreateRequest struct {
Data map[string]string `` /* 135-byte string literal not displayed */
Context map[string]string `` /* 141-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*CreateRequest) GetContext ¶
func (x *CreateRequest) GetContext() map[string]string
func (*CreateRequest) GetData ¶
func (x *CreateRequest) GetData() map[string]string
func (*CreateRequest) ProtoMessage ¶
func (*CreateRequest) ProtoMessage()
func (*CreateRequest) ProtoReflect ¶
func (x *CreateRequest) ProtoReflect() protoreflect.Message
func (*CreateRequest) Reset ¶
func (x *CreateRequest) Reset()
func (*CreateRequest) SetContext ¶
func (x *CreateRequest) SetContext(v map[string]string)
func (*CreateRequest) SetData ¶
func (x *CreateRequest) SetData(v map[string]string)
func (*CreateRequest) String ¶
func (x *CreateRequest) String() string
type CreateRequest_builder ¶
type CreateRequest_builder struct {
Data map[string]string
Context map[string]string
// contains filtered or unexported fields
}
func (CreateRequest_builder) Build ¶
func (b0 CreateRequest_builder) Build() *CreateRequest
type CreateResponse ¶
type CreateResponse struct {
// contains filtered or unexported fields
}
func (*CreateResponse) ProtoMessage ¶
func (*CreateResponse) ProtoMessage()
func (*CreateResponse) ProtoReflect ¶
func (x *CreateResponse) ProtoReflect() protoreflect.Message
func (*CreateResponse) Reset ¶
func (x *CreateResponse) Reset()
func (*CreateResponse) String ¶
func (x *CreateResponse) String() string
type CreateResponse_builder ¶
type CreateResponse_builder struct {
// contains filtered or unexported fields
}
func (CreateResponse_builder) Build ¶
func (b0 CreateResponse_builder) Build() *CreateResponse
type DeleteRequest ¶
type DeleteRequest struct {
Key string `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
Context map[string]string `` /* 141-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*DeleteRequest) GetContext ¶
func (x *DeleteRequest) GetContext() map[string]string
func (*DeleteRequest) GetKey ¶
func (x *DeleteRequest) GetKey() string
func (*DeleteRequest) ProtoMessage ¶
func (*DeleteRequest) ProtoMessage()
func (*DeleteRequest) ProtoReflect ¶
func (x *DeleteRequest) ProtoReflect() protoreflect.Message
func (*DeleteRequest) Reset ¶
func (x *DeleteRequest) Reset()
func (*DeleteRequest) SetContext ¶
func (x *DeleteRequest) SetContext(v map[string]string)
func (*DeleteRequest) SetKey ¶
func (x *DeleteRequest) SetKey(v string)
func (*DeleteRequest) String ¶
func (x *DeleteRequest) String() string
type DeleteRequest_builder ¶
type DeleteRequest_builder struct {
Key string
Context map[string]string
// contains filtered or unexported fields
}
func (DeleteRequest_builder) Build ¶
func (b0 DeleteRequest_builder) Build() *DeleteRequest
type DeleteResponse ¶
type DeleteResponse struct {
// contains filtered or unexported fields
}
func (*DeleteResponse) ProtoMessage ¶
func (*DeleteResponse) ProtoMessage()
func (*DeleteResponse) ProtoReflect ¶
func (x *DeleteResponse) ProtoReflect() protoreflect.Message
func (*DeleteResponse) Reset ¶
func (x *DeleteResponse) Reset()
func (*DeleteResponse) String ¶
func (x *DeleteResponse) String() string
type DeleteResponse_builder ¶
type DeleteResponse_builder struct {
// contains filtered or unexported fields
}
func (DeleteResponse_builder) Build ¶
func (b0 DeleteResponse_builder) Build() *DeleteResponse
type RetrieveRequest ¶
type RetrieveRequest struct {
Key string `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
Context map[string]string `` /* 141-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*RetrieveRequest) GetContext ¶
func (x *RetrieveRequest) GetContext() map[string]string
func (*RetrieveRequest) GetKey ¶
func (x *RetrieveRequest) GetKey() string
func (*RetrieveRequest) ProtoMessage ¶
func (*RetrieveRequest) ProtoMessage()
func (*RetrieveRequest) ProtoReflect ¶
func (x *RetrieveRequest) ProtoReflect() protoreflect.Message
func (*RetrieveRequest) Reset ¶
func (x *RetrieveRequest) Reset()
func (*RetrieveRequest) SetContext ¶
func (x *RetrieveRequest) SetContext(v map[string]string)
func (*RetrieveRequest) SetKey ¶
func (x *RetrieveRequest) SetKey(v string)
func (*RetrieveRequest) String ¶
func (x *RetrieveRequest) String() string
type RetrieveRequest_builder ¶
type RetrieveRequest_builder struct {
Key string
Context map[string]string
// contains filtered or unexported fields
}
func (RetrieveRequest_builder) Build ¶
func (b0 RetrieveRequest_builder) Build() *RetrieveRequest
type RetrieveResponse ¶
type RetrieveResponse struct {
Data map[string]string `` /* 135-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*RetrieveResponse) GetData ¶
func (x *RetrieveResponse) GetData() map[string]string
func (*RetrieveResponse) ProtoMessage ¶
func (*RetrieveResponse) ProtoMessage()
func (*RetrieveResponse) ProtoReflect ¶
func (x *RetrieveResponse) ProtoReflect() protoreflect.Message
func (*RetrieveResponse) Reset ¶
func (x *RetrieveResponse) Reset()
func (*RetrieveResponse) SetData ¶
func (x *RetrieveResponse) SetData(v map[string]string)
func (*RetrieveResponse) String ¶
func (x *RetrieveResponse) String() string
type RetrieveResponse_builder ¶
type RetrieveResponse_builder struct {
Data map[string]string
// contains filtered or unexported fields
}
func (RetrieveResponse_builder) Build ¶
func (b0 RetrieveResponse_builder) Build() *RetrieveResponse
type SubscribeRequest ¶
type SubscribeRequest struct {
// contains filtered or unexported fields
}
func (*SubscribeRequest) ProtoMessage ¶
func (*SubscribeRequest) ProtoMessage()
func (*SubscribeRequest) ProtoReflect ¶
func (x *SubscribeRequest) ProtoReflect() protoreflect.Message
func (*SubscribeRequest) Reset ¶
func (x *SubscribeRequest) Reset()
func (*SubscribeRequest) String ¶
func (x *SubscribeRequest) String() string
type SubscribeRequest_builder ¶
type SubscribeRequest_builder struct {
// contains filtered or unexported fields
}
func (SubscribeRequest_builder) Build ¶
func (b0 SubscribeRequest_builder) Build() *SubscribeRequest
type SubscribeResponse ¶
type SubscribeResponse struct {
Data map[string]string `` /* 135-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*SubscribeResponse) GetData ¶
func (x *SubscribeResponse) GetData() map[string]string
func (*SubscribeResponse) ProtoMessage ¶
func (*SubscribeResponse) ProtoMessage()
func (*SubscribeResponse) ProtoReflect ¶
func (x *SubscribeResponse) ProtoReflect() protoreflect.Message
func (*SubscribeResponse) Reset ¶
func (x *SubscribeResponse) Reset()
func (*SubscribeResponse) SetData ¶
func (x *SubscribeResponse) SetData(v map[string]string)
func (*SubscribeResponse) String ¶
func (x *SubscribeResponse) String() string
type SubscribeResponse_builder ¶
type SubscribeResponse_builder struct {
Data map[string]string
// contains filtered or unexported fields
}
func (SubscribeResponse_builder) Build ¶
func (b0 SubscribeResponse_builder) Build() *SubscribeResponse
type TraServiceConfig ¶
type TraServiceConfig struct {
// Specifies the gRPC service that hosts the rate limit service. The client
// will connect to this cluster when it needs to make rate limit service
// requests.
GrpcService *v3.GrpcService `protobuf:"bytes,1,opt,name=grpc_service,json=grpcService,proto3" json:"grpc_service,omitempty"`
// API version for rate limit transport protocol. This describes the rate limit gRPC endpoint and
// version of messages used on the wire.
TransportApiVersion v3.ApiVersion `` /* 158-byte string literal not displayed */
Timeout *durationpb.Duration `protobuf:"bytes,3,opt,name=timeout,proto3" json:"timeout,omitempty"`
// contains filtered or unexported fields
}
func (*TraServiceConfig) ClearGrpcService ¶
func (x *TraServiceConfig) ClearGrpcService()
func (*TraServiceConfig) ClearTimeout ¶
func (x *TraServiceConfig) ClearTimeout()
func (*TraServiceConfig) GetGrpcService ¶
func (x *TraServiceConfig) GetGrpcService() *v3.GrpcService
func (*TraServiceConfig) GetTimeout ¶
func (x *TraServiceConfig) GetTimeout() *durationpb.Duration
func (*TraServiceConfig) GetTransportApiVersion ¶
func (x *TraServiceConfig) GetTransportApiVersion() v3.ApiVersion
func (*TraServiceConfig) HasGrpcService ¶
func (x *TraServiceConfig) HasGrpcService() bool
func (*TraServiceConfig) HasTimeout ¶
func (x *TraServiceConfig) HasTimeout() bool
func (*TraServiceConfig) ProtoMessage ¶
func (*TraServiceConfig) ProtoMessage()
func (*TraServiceConfig) ProtoReflect ¶
func (x *TraServiceConfig) ProtoReflect() protoreflect.Message
func (*TraServiceConfig) Reset ¶
func (x *TraServiceConfig) Reset()
func (*TraServiceConfig) SetGrpcService ¶
func (x *TraServiceConfig) SetGrpcService(v *v3.GrpcService)
func (*TraServiceConfig) SetTimeout ¶
func (x *TraServiceConfig) SetTimeout(v *durationpb.Duration)
func (*TraServiceConfig) SetTransportApiVersion ¶
func (x *TraServiceConfig) SetTransportApiVersion(v v3.ApiVersion)
func (*TraServiceConfig) String ¶
func (x *TraServiceConfig) String() string
type TraServiceConfig_builder ¶
type TraServiceConfig_builder struct {
// Specifies the gRPC service that hosts the rate limit service. The client
// will connect to this cluster when it needs to make rate limit service
// requests.
GrpcService *v3.GrpcService
// API version for rate limit transport protocol. This describes the rate limit gRPC endpoint and
// version of messages used on the wire.
TransportApiVersion v3.ApiVersion
Timeout *durationpb.Duration
// contains filtered or unexported fields
}
func (TraServiceConfig_builder) Build ¶
func (b0 TraServiceConfig_builder) Build() *TraServiceConfig
type TraServiceRequest ¶
type TraServiceRequest struct {
Type string `protobuf:"bytes,1,opt,name=type,proto3" json:"type,omitempty"`
// Types that are valid to be assigned to Request:
//
// *TraServiceRequest_CreateRequest
// *TraServiceRequest_UpdateRequest
// *TraServiceRequest_RetrieveRequest
// *TraServiceRequest_DeleteRequest
// *TraServiceRequest_SubscribeRequest
Request isTraServiceRequest_Request `protobuf_oneof:"request"`
// contains filtered or unexported fields
}
[#next-free-field: 7]
func (*TraServiceRequest) ClearCreateRequest ¶
func (x *TraServiceRequest) ClearCreateRequest()
func (*TraServiceRequest) ClearDeleteRequest ¶
func (x *TraServiceRequest) ClearDeleteRequest()
func (*TraServiceRequest) ClearRequest ¶
func (x *TraServiceRequest) ClearRequest()
func (*TraServiceRequest) ClearRetrieveRequest ¶
func (x *TraServiceRequest) ClearRetrieveRequest()
func (*TraServiceRequest) ClearSubscribeRequest ¶
func (x *TraServiceRequest) ClearSubscribeRequest()
func (*TraServiceRequest) ClearUpdateRequest ¶
func (x *TraServiceRequest) ClearUpdateRequest()
func (*TraServiceRequest) GetCreateRequest ¶
func (x *TraServiceRequest) GetCreateRequest() *CreateRequest
func (*TraServiceRequest) GetDeleteRequest ¶
func (x *TraServiceRequest) GetDeleteRequest() *DeleteRequest
func (*TraServiceRequest) GetRequest ¶
func (x *TraServiceRequest) GetRequest() isTraServiceRequest_Request
func (*TraServiceRequest) GetRetrieveRequest ¶
func (x *TraServiceRequest) GetRetrieveRequest() *RetrieveRequest
func (*TraServiceRequest) GetSubscribeRequest ¶
func (x *TraServiceRequest) GetSubscribeRequest() *SubscribeRequest
func (*TraServiceRequest) GetType ¶
func (x *TraServiceRequest) GetType() string
func (*TraServiceRequest) GetUpdateRequest ¶
func (x *TraServiceRequest) GetUpdateRequest() *UpdateRequest
func (*TraServiceRequest) HasCreateRequest ¶
func (x *TraServiceRequest) HasCreateRequest() bool
func (*TraServiceRequest) HasDeleteRequest ¶
func (x *TraServiceRequest) HasDeleteRequest() bool
func (*TraServiceRequest) HasRequest ¶
func (x *TraServiceRequest) HasRequest() bool
func (*TraServiceRequest) HasRetrieveRequest ¶
func (x *TraServiceRequest) HasRetrieveRequest() bool
func (*TraServiceRequest) HasSubscribeRequest ¶
func (x *TraServiceRequest) HasSubscribeRequest() bool
func (*TraServiceRequest) HasUpdateRequest ¶
func (x *TraServiceRequest) HasUpdateRequest() bool
func (*TraServiceRequest) ProtoMessage ¶
func (*TraServiceRequest) ProtoMessage()
func (*TraServiceRequest) ProtoReflect ¶
func (x *TraServiceRequest) ProtoReflect() protoreflect.Message
func (*TraServiceRequest) Reset ¶
func (x *TraServiceRequest) Reset()
func (*TraServiceRequest) SetCreateRequest ¶
func (x *TraServiceRequest) SetCreateRequest(v *CreateRequest)
func (*TraServiceRequest) SetDeleteRequest ¶
func (x *TraServiceRequest) SetDeleteRequest(v *DeleteRequest)
func (*TraServiceRequest) SetRetrieveRequest ¶
func (x *TraServiceRequest) SetRetrieveRequest(v *RetrieveRequest)
func (*TraServiceRequest) SetSubscribeRequest ¶
func (x *TraServiceRequest) SetSubscribeRequest(v *SubscribeRequest)
func (*TraServiceRequest) SetType ¶
func (x *TraServiceRequest) SetType(v string)
func (*TraServiceRequest) SetUpdateRequest ¶
func (x *TraServiceRequest) SetUpdateRequest(v *UpdateRequest)
func (*TraServiceRequest) String ¶
func (x *TraServiceRequest) String() string
func (*TraServiceRequest) WhichRequest ¶
func (x *TraServiceRequest) WhichRequest() case_TraServiceRequest_Request
type TraServiceRequest_CreateRequest ¶
type TraServiceRequest_CreateRequest struct {
CreateRequest *CreateRequest `protobuf:"bytes,2,opt,name=create_request,json=createRequest,proto3,oneof"`
}
type TraServiceRequest_DeleteRequest ¶
type TraServiceRequest_DeleteRequest struct {
DeleteRequest *DeleteRequest `protobuf:"bytes,5,opt,name=delete_request,json=deleteRequest,proto3,oneof"`
}
type TraServiceRequest_RetrieveRequest ¶
type TraServiceRequest_RetrieveRequest struct {
RetrieveRequest *RetrieveRequest `protobuf:"bytes,4,opt,name=retrieve_request,json=retrieveRequest,proto3,oneof"`
}
type TraServiceRequest_SubscribeRequest ¶
type TraServiceRequest_SubscribeRequest struct {
SubscribeRequest *SubscribeRequest `protobuf:"bytes,6,opt,name=subscribe_request,json=subscribeRequest,proto3,oneof"`
}
type TraServiceRequest_UpdateRequest ¶
type TraServiceRequest_UpdateRequest struct {
UpdateRequest *UpdateRequest `protobuf:"bytes,3,opt,name=update_request,json=updateRequest,proto3,oneof"`
}
type TraServiceRequest_builder ¶
type TraServiceRequest_builder struct {
Type string
// Fields of oneof Request:
CreateRequest *CreateRequest
UpdateRequest *UpdateRequest
RetrieveRequest *RetrieveRequest
DeleteRequest *DeleteRequest
SubscribeRequest *SubscribeRequest
// contains filtered or unexported fields
}
func (TraServiceRequest_builder) Build ¶
func (b0 TraServiceRequest_builder) Build() *TraServiceRequest
type TraServiceResponse ¶
type TraServiceResponse struct {
Type string `protobuf:"bytes,1,opt,name=type,proto3" json:"type,omitempty"`
Ret int32 `protobuf:"varint,2,opt,name=ret,proto3" json:"ret,omitempty"`
Reason string `protobuf:"bytes,3,opt,name=reason,proto3" json:"reason,omitempty"`
// Types that are valid to be assigned to Response:
//
// *TraServiceResponse_CreateResponse
// *TraServiceResponse_UpdateResponse
// *TraServiceResponse_RetrieveResponse
// *TraServiceResponse_DeleteResponse
// *TraServiceResponse_SubscribeResponse
Response isTraServiceResponse_Response `protobuf_oneof:"response"`
// contains filtered or unexported fields
}
[#next-free-field: 9]
func (*TraServiceResponse) ClearCreateResponse ¶
func (x *TraServiceResponse) ClearCreateResponse()
func (*TraServiceResponse) ClearDeleteResponse ¶
func (x *TraServiceResponse) ClearDeleteResponse()
func (*TraServiceResponse) ClearResponse ¶
func (x *TraServiceResponse) ClearResponse()
func (*TraServiceResponse) ClearRetrieveResponse ¶
func (x *TraServiceResponse) ClearRetrieveResponse()
func (*TraServiceResponse) ClearSubscribeResponse ¶
func (x *TraServiceResponse) ClearSubscribeResponse()
func (*TraServiceResponse) ClearUpdateResponse ¶
func (x *TraServiceResponse) ClearUpdateResponse()
func (*TraServiceResponse) GetCreateResponse ¶
func (x *TraServiceResponse) GetCreateResponse() *CreateResponse
func (*TraServiceResponse) GetDeleteResponse ¶
func (x *TraServiceResponse) GetDeleteResponse() *DeleteResponse
func (*TraServiceResponse) GetReason ¶
func (x *TraServiceResponse) GetReason() string
func (*TraServiceResponse) GetResponse ¶
func (x *TraServiceResponse) GetResponse() isTraServiceResponse_Response
func (*TraServiceResponse) GetRet ¶
func (x *TraServiceResponse) GetRet() int32
func (*TraServiceResponse) GetRetrieveResponse ¶
func (x *TraServiceResponse) GetRetrieveResponse() *RetrieveResponse
func (*TraServiceResponse) GetSubscribeResponse ¶
func (x *TraServiceResponse) GetSubscribeResponse() *SubscribeResponse
func (*TraServiceResponse) GetType ¶
func (x *TraServiceResponse) GetType() string
func (*TraServiceResponse) GetUpdateResponse ¶
func (x *TraServiceResponse) GetUpdateResponse() *UpdateResponse
func (*TraServiceResponse) HasCreateResponse ¶
func (x *TraServiceResponse) HasCreateResponse() bool
func (*TraServiceResponse) HasDeleteResponse ¶
func (x *TraServiceResponse) HasDeleteResponse() bool
func (*TraServiceResponse) HasResponse ¶
func (x *TraServiceResponse) HasResponse() bool
func (*TraServiceResponse) HasRetrieveResponse ¶
func (x *TraServiceResponse) HasRetrieveResponse() bool
func (*TraServiceResponse) HasSubscribeResponse ¶
func (x *TraServiceResponse) HasSubscribeResponse() bool
func (*TraServiceResponse) HasUpdateResponse ¶
func (x *TraServiceResponse) HasUpdateResponse() bool
func (*TraServiceResponse) ProtoMessage ¶
func (*TraServiceResponse) ProtoMessage()
func (*TraServiceResponse) ProtoReflect ¶
func (x *TraServiceResponse) ProtoReflect() protoreflect.Message
func (*TraServiceResponse) Reset ¶
func (x *TraServiceResponse) Reset()
func (*TraServiceResponse) SetCreateResponse ¶
func (x *TraServiceResponse) SetCreateResponse(v *CreateResponse)
func (*TraServiceResponse) SetDeleteResponse ¶
func (x *TraServiceResponse) SetDeleteResponse(v *DeleteResponse)
func (*TraServiceResponse) SetReason ¶
func (x *TraServiceResponse) SetReason(v string)
func (*TraServiceResponse) SetRet ¶
func (x *TraServiceResponse) SetRet(v int32)
func (*TraServiceResponse) SetRetrieveResponse ¶
func (x *TraServiceResponse) SetRetrieveResponse(v *RetrieveResponse)
func (*TraServiceResponse) SetSubscribeResponse ¶
func (x *TraServiceResponse) SetSubscribeResponse(v *SubscribeResponse)
func (*TraServiceResponse) SetType ¶
func (x *TraServiceResponse) SetType(v string)
func (*TraServiceResponse) SetUpdateResponse ¶
func (x *TraServiceResponse) SetUpdateResponse(v *UpdateResponse)
func (*TraServiceResponse) String ¶
func (x *TraServiceResponse) String() string
func (*TraServiceResponse) WhichResponse ¶
func (x *TraServiceResponse) WhichResponse() case_TraServiceResponse_Response
type TraServiceResponse_CreateResponse ¶
type TraServiceResponse_CreateResponse struct {
CreateResponse *CreateResponse `protobuf:"bytes,4,opt,name=create_response,json=createResponse,proto3,oneof"`
}
type TraServiceResponse_DeleteResponse ¶
type TraServiceResponse_DeleteResponse struct {
DeleteResponse *DeleteResponse `protobuf:"bytes,7,opt,name=delete_response,json=deleteResponse,proto3,oneof"`
}
type TraServiceResponse_RetrieveResponse ¶
type TraServiceResponse_RetrieveResponse struct {
RetrieveResponse *RetrieveResponse `protobuf:"bytes,6,opt,name=retrieve_response,json=retrieveResponse,proto3,oneof"`
}
type TraServiceResponse_SubscribeResponse ¶
type TraServiceResponse_SubscribeResponse struct {
SubscribeResponse *SubscribeResponse `protobuf:"bytes,8,opt,name=subscribe_response,json=subscribeResponse,proto3,oneof"`
}
type TraServiceResponse_UpdateResponse ¶
type TraServiceResponse_UpdateResponse struct {
UpdateResponse *UpdateResponse `protobuf:"bytes,5,opt,name=update_response,json=updateResponse,proto3,oneof"`
}
type TraServiceResponse_builder ¶
type TraServiceResponse_builder struct {
Type string
Ret int32
Reason string
// Fields of oneof Response:
CreateResponse *CreateResponse
UpdateResponse *UpdateResponse
RetrieveResponse *RetrieveResponse
DeleteResponse *DeleteResponse
SubscribeResponse *SubscribeResponse
// contains filtered or unexported fields
}
func (TraServiceResponse_builder) Build ¶
func (b0 TraServiceResponse_builder) Build() *TraServiceResponse
type UpdateRequest ¶
type UpdateRequest struct {
Data map[string]string `` /* 135-byte string literal not displayed */
Context map[string]string `` /* 141-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*UpdateRequest) GetContext ¶
func (x *UpdateRequest) GetContext() map[string]string
func (*UpdateRequest) GetData ¶
func (x *UpdateRequest) GetData() map[string]string
func (*UpdateRequest) ProtoMessage ¶
func (*UpdateRequest) ProtoMessage()
func (*UpdateRequest) ProtoReflect ¶
func (x *UpdateRequest) ProtoReflect() protoreflect.Message
func (*UpdateRequest) Reset ¶
func (x *UpdateRequest) Reset()
func (*UpdateRequest) SetContext ¶
func (x *UpdateRequest) SetContext(v map[string]string)
func (*UpdateRequest) SetData ¶
func (x *UpdateRequest) SetData(v map[string]string)
func (*UpdateRequest) String ¶
func (x *UpdateRequest) String() string
type UpdateRequest_builder ¶
type UpdateRequest_builder struct {
Data map[string]string
Context map[string]string
// contains filtered or unexported fields
}
func (UpdateRequest_builder) Build ¶
func (b0 UpdateRequest_builder) Build() *UpdateRequest
type UpdateResponse ¶
type UpdateResponse struct {
// contains filtered or unexported fields
}
func (*UpdateResponse) ProtoMessage ¶
func (*UpdateResponse) ProtoMessage()
func (*UpdateResponse) ProtoReflect ¶
func (x *UpdateResponse) ProtoReflect() protoreflect.Message
func (*UpdateResponse) Reset ¶
func (x *UpdateResponse) Reset()
func (*UpdateResponse) String ¶
func (x *UpdateResponse) String() string
type UpdateResponse_builder ¶
type UpdateResponse_builder struct {
// contains filtered or unexported fields
}
func (UpdateResponse_builder) Build ¶
func (b0 UpdateResponse_builder) Build() *UpdateResponse
Source Files
¶
- tra.pb.go
Click to show internal directories.
Click to hide internal directories.