Documentation
¶
Index ¶
- Constants
- Variables
- type Cache
- func (x *Cache) GetAddQueryToCache() bool
- func (x *Cache) GetMaxCacheItem() int32
- func (*Cache) ProtoMessage()
- func (x *Cache) ProtoReflect() protoreflect.Message
- func (x *Cache) Reset()
- func (x *Cache) SetAddQueryToCache(v bool)
- func (x *Cache) SetMaxCacheItem(v int32)
- func (x *Cache) String() string
- type Cache_builder
- type CustomizedAffinity
- func (x *CustomizedAffinity) GetEntries() []*CustomizedAffinityEntry
- func (x *CustomizedAffinity) GetStopLoadBalance() bool
- func (*CustomizedAffinity) ProtoMessage()
- func (x *CustomizedAffinity) ProtoReflect() protoreflect.Message
- func (x *CustomizedAffinity) Reset()
- func (x *CustomizedAffinity) SetEntries(v []*CustomizedAffinityEntry)
- func (x *CustomizedAffinity) SetStopLoadBalance(v bool)
- func (x *CustomizedAffinity) String() string
- type CustomizedAffinityEntry
- func (x *CustomizedAffinityEntry) ClearCache()
- func (x *CustomizedAffinityEntry) GetCache() *Cache
- func (x *CustomizedAffinityEntry) GetHeader() string
- func (x *CustomizedAffinityEntry) GetKeyName() string
- func (x *CustomizedAffinityEntry) GetQuery() bool
- func (x *CustomizedAffinityEntry) GetSubscribe() bool
- func (x *CustomizedAffinityEntry) HasCache() bool
- func (*CustomizedAffinityEntry) ProtoMessage()
- func (x *CustomizedAffinityEntry) ProtoReflect() protoreflect.Message
- func (x *CustomizedAffinityEntry) Reset()
- func (x *CustomizedAffinityEntry) SetCache(v *Cache)
- func (x *CustomizedAffinityEntry) SetHeader(v string)
- func (x *CustomizedAffinityEntry) SetKeyName(v string)
- func (x *CustomizedAffinityEntry) SetQuery(v bool)
- func (x *CustomizedAffinityEntry) SetSubscribe(v bool)
- func (x *CustomizedAffinityEntry) String() string
- type CustomizedAffinityEntry_builder
- type CustomizedAffinity_builder
- type LocalService
- func (x *LocalService) GetDomain() string
- func (x *LocalService) GetParameter() string
- func (*LocalService) ProtoMessage()
- func (x *LocalService) ProtoReflect() protoreflect.Message
- func (x *LocalService) Reset()
- func (x *LocalService) SetDomain(v string)
- func (x *LocalService) SetParameter(v string)
- func (x *LocalService) String() string
- type LocalService_builder
- type Route
- func (x *Route) ClearMatch()
- func (x *Route) ClearRoute()
- func (x *Route) GetMatch() *RouteMatch
- func (x *Route) GetRoute() *RouteAction
- func (x *Route) HasMatch() bool
- func (x *Route) HasRoute() bool
- func (*Route) ProtoMessage()
- func (x *Route) ProtoReflect() protoreflect.Message
- func (x *Route) Reset()
- func (x *Route) SetMatch(v *RouteMatch)
- func (x *Route) SetRoute(v *RouteAction)
- func (x *Route) String() string
- type RouteAction
- func (x *RouteAction) ClearCluster()
- func (x *RouteAction) ClearClusterSpecifier()
- func (x *RouteAction) GetCluster() string
- func (x *RouteAction) GetClusterSpecifier() isRouteAction_ClusterSpecifier
- func (x *RouteAction) HasCluster() bool
- func (x *RouteAction) HasClusterSpecifier() bool
- func (*RouteAction) ProtoMessage()
- func (x *RouteAction) ProtoReflect() protoreflect.Message
- func (x *RouteAction) Reset()
- func (x *RouteAction) SetCluster(v string)
- func (x *RouteAction) String() string
- func (x *RouteAction) WhichClusterSpecifier() case_RouteAction_ClusterSpecifier
- type RouteAction_Cluster
- type RouteAction_builder
- type RouteConfiguration
- func (x *RouteConfiguration) GetName() string
- func (x *RouteConfiguration) GetRoutes() []*Route
- func (*RouteConfiguration) ProtoMessage()
- func (x *RouteConfiguration) ProtoReflect() protoreflect.Message
- func (x *RouteConfiguration) Reset()
- func (x *RouteConfiguration) SetName(v string)
- func (x *RouteConfiguration) SetRoutes(v []*Route)
- func (x *RouteConfiguration) String() string
- type RouteConfiguration_builder
- type RouteMatch
- func (x *RouteMatch) ClearDomain()
- func (x *RouteMatch) ClearMatchSpecifier()
- func (x *RouteMatch) GetDomain() string
- func (x *RouteMatch) GetHeader() string
- func (x *RouteMatch) GetMatchSpecifier() isRouteMatch_MatchSpecifier
- func (x *RouteMatch) GetParameter() string
- func (x *RouteMatch) HasDomain() bool
- func (x *RouteMatch) HasMatchSpecifier() bool
- func (*RouteMatch) ProtoMessage()
- func (x *RouteMatch) ProtoReflect() protoreflect.Message
- func (x *RouteMatch) Reset()
- func (x *RouteMatch) SetDomain(v string)
- func (x *RouteMatch) SetHeader(v string)
- func (x *RouteMatch) SetParameter(v string)
- func (x *RouteMatch) String() string
- func (x *RouteMatch) WhichMatchSpecifier() case_RouteMatch_MatchSpecifier
- type RouteMatch_Domain
- type RouteMatch_builder
- type Route_builder
- type SipFilter
- func (x *SipFilter) ClearConfigType()
- func (x *SipFilter) ClearTypedConfig()
- func (x *SipFilter) GetConfigType() isSipFilter_ConfigType
- func (x *SipFilter) GetName() string
- func (x *SipFilter) GetTypedConfig() *anypb.Any
- func (x *SipFilter) HasConfigType() bool
- func (x *SipFilter) HasTypedConfig() bool
- func (*SipFilter) ProtoMessage()
- func (x *SipFilter) ProtoReflect() protoreflect.Message
- func (x *SipFilter) Reset()
- func (x *SipFilter) SetName(v string)
- func (x *SipFilter) SetTypedConfig(v *anypb.Any)
- func (x *SipFilter) String() string
- func (x *SipFilter) WhichConfigType() case_SipFilter_ConfigType
- type SipFilter_TypedConfig
- type SipFilter_builder
- type SipProtocolOptions
- func (x *SipProtocolOptions) ClearCustomizedAffinity()
- func (x *SipProtocolOptions) GetCustomizedAffinity() *CustomizedAffinity
- func (x *SipProtocolOptions) GetRegistrationAffinity() bool
- func (x *SipProtocolOptions) GetSessionAffinity() bool
- func (x *SipProtocolOptions) HasCustomizedAffinity() bool
- func (*SipProtocolOptions) ProtoMessage()
- func (x *SipProtocolOptions) ProtoReflect() protoreflect.Message
- func (x *SipProtocolOptions) Reset()
- func (x *SipProtocolOptions) SetCustomizedAffinity(v *CustomizedAffinity)
- func (x *SipProtocolOptions) SetRegistrationAffinity(v bool)
- func (x *SipProtocolOptions) SetSessionAffinity(v bool)
- func (x *SipProtocolOptions) String() string
- type SipProtocolOptions_builder
- type SipProxy
- func (x *SipProxy) ClearRouteConfig()
- func (x *SipProxy) ClearSettings()
- func (x *SipProxy) GetRouteConfig() *RouteConfiguration
- func (x *SipProxy) GetSettings() *SipProxy_SipSettings
- func (x *SipProxy) GetSipFilters() []*SipFilter
- func (x *SipProxy) GetStatPrefix() string
- func (x *SipProxy) HasRouteConfig() bool
- func (x *SipProxy) HasSettings() bool
- func (*SipProxy) ProtoMessage()
- func (x *SipProxy) ProtoReflect() protoreflect.Message
- func (x *SipProxy) Reset()
- func (x *SipProxy) SetRouteConfig(v *RouteConfiguration)
- func (x *SipProxy) SetSettings(v *SipProxy_SipSettings)
- func (x *SipProxy) SetSipFilters(v []*SipFilter)
- func (x *SipProxy) SetStatPrefix(v string)
- func (x *SipProxy) String() string
- type SipProxy_SipSettings
- func (x *SipProxy_SipSettings) ClearTraServiceConfig()
- func (x *SipProxy_SipSettings) ClearTransactionTimeout()
- func (x *SipProxy_SipSettings) GetLocalServices() []*LocalService
- func (x *SipProxy_SipSettings) GetOperateVia() bool
- func (x *SipProxy_SipSettings) GetTraServiceConfig() *v3alpha.TraServiceConfig
- func (x *SipProxy_SipSettings) GetTransactionTimeout() *durationpb.Duration
- func (x *SipProxy_SipSettings) HasTraServiceConfig() bool
- func (x *SipProxy_SipSettings) HasTransactionTimeout() bool
- func (*SipProxy_SipSettings) ProtoMessage()
- func (x *SipProxy_SipSettings) ProtoReflect() protoreflect.Message
- func (x *SipProxy_SipSettings) Reset()
- func (x *SipProxy_SipSettings) SetLocalServices(v []*LocalService)
- func (x *SipProxy_SipSettings) SetOperateVia(v bool)
- func (x *SipProxy_SipSettings) SetTraServiceConfig(v *v3alpha.TraServiceConfig)
- func (x *SipProxy_SipSettings) SetTransactionTimeout(v *durationpb.Duration)
- func (x *SipProxy_SipSettings) String() string
- type SipProxy_SipSettings_builder
- type SipProxy_builder
Constants ¶
const RouteAction_ClusterSpecifier_not_set_case case_RouteAction_ClusterSpecifier = 0
const RouteAction_Cluster_case case_RouteAction_ClusterSpecifier = 1
const RouteMatch_Domain_case case_RouteMatch_MatchSpecifier = 1
const RouteMatch_MatchSpecifier_not_set_case case_RouteMatch_MatchSpecifier = 0
const SipFilter_ConfigType_not_set_case case_SipFilter_ConfigType = 0
const SipFilter_TypedConfig_case case_SipFilter_ConfigType = 3
Variables ¶
var File_contrib_envoy_extensions_filters_network_sip_proxy_v3alpha_route_proto protoreflect.FileDescriptor
var File_contrib_envoy_extensions_filters_network_sip_proxy_v3alpha_sip_proxy_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Cache ¶
type Cache struct {
// Affinity local cache item max number
MaxCacheItem int32 `protobuf:"varint,1,opt,name=max_cache_item,json=maxCacheItem,proto3" json:"max_cache_item,omitempty"`
// Whether query result can be added to local cache
AddQueryToCache bool `protobuf:"varint,2,opt,name=add_query_to_cache,json=addQueryToCache,proto3" json:"add_query_to_cache,omitempty"`
// contains filtered or unexported fields
}
func (*Cache) ProtoReflect ¶
func (x *Cache) ProtoReflect() protoreflect.Message
type Cache_builder ¶
type Cache_builder struct {
// Affinity local cache item max number
MaxCacheItem int32
// Whether query result can be added to local cache
AddQueryToCache bool
// contains filtered or unexported fields
}
func (Cache_builder) Build ¶
func (b0 Cache_builder) Build() *Cache
type CustomizedAffinity ¶
type CustomizedAffinity struct {
// Affinity rules to conclude the upstream endpoint
Entries []*CustomizedAffinityEntry `protobuf:"bytes,1,rep,name=entries,proto3" json:"entries,omitempty"`
// Configures whether load balance should be stopped or continued after affinity handling.
StopLoadBalance bool `protobuf:"varint,2,opt,name=stop_load_balance,json=stopLoadBalance,proto3" json:"stop_load_balance,omitempty"`
// contains filtered or unexported fields
}
For affinity
func (*CustomizedAffinity) GetEntries ¶
func (x *CustomizedAffinity) GetEntries() []*CustomizedAffinityEntry
func (*CustomizedAffinity) GetStopLoadBalance ¶
func (x *CustomizedAffinity) GetStopLoadBalance() bool
func (*CustomizedAffinity) ProtoMessage ¶
func (*CustomizedAffinity) ProtoMessage()
func (*CustomizedAffinity) ProtoReflect ¶
func (x *CustomizedAffinity) ProtoReflect() protoreflect.Message
func (*CustomizedAffinity) Reset ¶
func (x *CustomizedAffinity) Reset()
func (*CustomizedAffinity) SetEntries ¶
func (x *CustomizedAffinity) SetEntries(v []*CustomizedAffinityEntry)
func (*CustomizedAffinity) SetStopLoadBalance ¶
func (x *CustomizedAffinity) SetStopLoadBalance(v bool)
func (*CustomizedAffinity) String ¶
func (x *CustomizedAffinity) String() string
type CustomizedAffinityEntry ¶
type CustomizedAffinityEntry struct {
// The header name to match, e.g. "From", if not specified, default is "Route"
Header string `protobuf:"bytes,1,opt,name=header,proto3" json:"header,omitempty"`
// Affinity key for TRA query/subscribe, e.g. "lskpmc", if key_name is "text" means use the header content as key.
KeyName string `protobuf:"bytes,2,opt,name=key_name,json=keyName,proto3" json:"key_name,omitempty"`
// Whether subscribe to TRA is required
Subscribe bool `protobuf:"varint,3,opt,name=subscribe,proto3" json:"subscribe,omitempty"`
// Whether query to TRA is required
Query bool `protobuf:"varint,4,opt,name=query,proto3" json:"query,omitempty"`
// Local cache
Cache *Cache `protobuf:"bytes,5,opt,name=cache,proto3" json:"cache,omitempty"`
// contains filtered or unexported fields
}
[#next-free-field: 6]
func (*CustomizedAffinityEntry) ClearCache ¶
func (x *CustomizedAffinityEntry) ClearCache()
func (*CustomizedAffinityEntry) GetCache ¶
func (x *CustomizedAffinityEntry) GetCache() *Cache
func (*CustomizedAffinityEntry) GetHeader ¶
func (x *CustomizedAffinityEntry) GetHeader() string
func (*CustomizedAffinityEntry) GetKeyName ¶
func (x *CustomizedAffinityEntry) GetKeyName() string
func (*CustomizedAffinityEntry) GetQuery ¶
func (x *CustomizedAffinityEntry) GetQuery() bool
func (*CustomizedAffinityEntry) GetSubscribe ¶
func (x *CustomizedAffinityEntry) GetSubscribe() bool
func (*CustomizedAffinityEntry) HasCache ¶
func (x *CustomizedAffinityEntry) HasCache() bool
func (*CustomizedAffinityEntry) ProtoMessage ¶
func (*CustomizedAffinityEntry) ProtoMessage()
func (*CustomizedAffinityEntry) ProtoReflect ¶
func (x *CustomizedAffinityEntry) ProtoReflect() protoreflect.Message
func (*CustomizedAffinityEntry) Reset ¶
func (x *CustomizedAffinityEntry) Reset()
func (*CustomizedAffinityEntry) SetCache ¶
func (x *CustomizedAffinityEntry) SetCache(v *Cache)
func (*CustomizedAffinityEntry) SetHeader ¶
func (x *CustomizedAffinityEntry) SetHeader(v string)
func (*CustomizedAffinityEntry) SetKeyName ¶
func (x *CustomizedAffinityEntry) SetKeyName(v string)
func (*CustomizedAffinityEntry) SetQuery ¶
func (x *CustomizedAffinityEntry) SetQuery(v bool)
func (*CustomizedAffinityEntry) SetSubscribe ¶
func (x *CustomizedAffinityEntry) SetSubscribe(v bool)
func (*CustomizedAffinityEntry) String ¶
func (x *CustomizedAffinityEntry) String() string
type CustomizedAffinityEntry_builder ¶
type CustomizedAffinityEntry_builder struct {
// The header name to match, e.g. "From", if not specified, default is "Route"
Header string
// Affinity key for TRA query/subscribe, e.g. "lskpmc", if key_name is "text" means use the header content as key.
KeyName string
// Whether subscribe to TRA is required
Subscribe bool
// Whether query to TRA is required
Query bool
// Local cache
Cache *Cache
// contains filtered or unexported fields
}
func (CustomizedAffinityEntry_builder) Build ¶
func (b0 CustomizedAffinityEntry_builder) Build() *CustomizedAffinityEntry
type CustomizedAffinity_builder ¶
type CustomizedAffinity_builder struct {
// Affinity rules to conclude the upstream endpoint
Entries []*CustomizedAffinityEntry
// Configures whether load balance should be stopped or continued after affinity handling.
StopLoadBalance bool
// contains filtered or unexported fields
}
func (CustomizedAffinity_builder) Build ¶
func (b0 CustomizedAffinity_builder) Build() *CustomizedAffinity
type LocalService ¶
type LocalService struct {
// The domain need to matched
Domain string `protobuf:"bytes,1,opt,name=domain,proto3" json:"domain,omitempty"`
// The parameter to get domain
Parameter string `protobuf:"bytes,2,opt,name=parameter,proto3" json:"parameter,omitempty"`
// contains filtered or unexported fields
}
Local Service
func (*LocalService) GetDomain ¶
func (x *LocalService) GetDomain() string
func (*LocalService) GetParameter ¶
func (x *LocalService) GetParameter() string
func (*LocalService) ProtoMessage ¶
func (*LocalService) ProtoMessage()
func (*LocalService) ProtoReflect ¶
func (x *LocalService) ProtoReflect() protoreflect.Message
func (*LocalService) Reset ¶
func (x *LocalService) Reset()
func (*LocalService) SetDomain ¶
func (x *LocalService) SetDomain(v string)
func (*LocalService) SetParameter ¶
func (x *LocalService) SetParameter(v string)
func (*LocalService) String ¶
func (x *LocalService) String() string
type LocalService_builder ¶
type LocalService_builder struct {
// The domain need to matched
Domain string
// The parameter to get domain
Parameter string
// contains filtered or unexported fields
}
func (LocalService_builder) Build ¶
func (b0 LocalService_builder) Build() *LocalService
type Route ¶
type Route struct {
// Route matching parameters.
Match *RouteMatch `protobuf:"bytes,1,opt,name=match,proto3" json:"match,omitempty"`
// Route request to some upstream cluster.
Route *RouteAction `protobuf:"bytes,2,opt,name=route,proto3" json:"route,omitempty"`
// contains filtered or unexported fields
}
func (*Route) GetMatch ¶
func (x *Route) GetMatch() *RouteMatch
func (*Route) GetRoute ¶
func (x *Route) GetRoute() *RouteAction
func (*Route) ProtoReflect ¶
func (x *Route) ProtoReflect() protoreflect.Message
func (*Route) SetMatch ¶
func (x *Route) SetMatch(v *RouteMatch)
func (*Route) SetRoute ¶
func (x *Route) SetRoute(v *RouteAction)
type RouteAction ¶
type RouteAction struct {
// Types that are valid to be assigned to ClusterSpecifier:
//
// *RouteAction_Cluster
ClusterSpecifier isRouteAction_ClusterSpecifier `protobuf_oneof:"cluster_specifier"`
// contains filtered or unexported fields
}
func (*RouteAction) ClearCluster ¶
func (x *RouteAction) ClearCluster()
func (*RouteAction) ClearClusterSpecifier ¶
func (x *RouteAction) ClearClusterSpecifier()
func (*RouteAction) GetCluster ¶
func (x *RouteAction) GetCluster() string
func (*RouteAction) GetClusterSpecifier ¶
func (x *RouteAction) GetClusterSpecifier() isRouteAction_ClusterSpecifier
func (*RouteAction) HasCluster ¶
func (x *RouteAction) HasCluster() bool
func (*RouteAction) HasClusterSpecifier ¶
func (x *RouteAction) HasClusterSpecifier() bool
func (*RouteAction) ProtoMessage ¶
func (*RouteAction) ProtoMessage()
func (*RouteAction) ProtoReflect ¶
func (x *RouteAction) ProtoReflect() protoreflect.Message
func (*RouteAction) Reset ¶
func (x *RouteAction) Reset()
func (*RouteAction) SetCluster ¶
func (x *RouteAction) SetCluster(v string)
func (*RouteAction) String ¶
func (x *RouteAction) String() string
func (*RouteAction) WhichClusterSpecifier ¶
func (x *RouteAction) WhichClusterSpecifier() case_RouteAction_ClusterSpecifier
type RouteAction_Cluster ¶
type RouteAction_Cluster struct {
// Indicates a single upstream cluster to which the request should be routed
// to.
Cluster string `protobuf:"bytes,1,opt,name=cluster,proto3,oneof"`
}
type RouteAction_builder ¶
type RouteAction_builder struct {
// Fields of oneof ClusterSpecifier:
// Indicates a single upstream cluster to which the request should be routed
// to.
Cluster *string
// contains filtered or unexported fields
}
func (RouteAction_builder) Build ¶
func (b0 RouteAction_builder) Build() *RouteAction
type RouteConfiguration ¶
type RouteConfiguration struct {
// The name of the route configuration. Reserved for future use in asynchronous route discovery.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// The list of routes that will be matched, in order, against incoming requests. The first route
// that matches will be used.
Routes []*Route `protobuf:"bytes,2,rep,name=routes,proto3" json:"routes,omitempty"`
// contains filtered or unexported fields
}
func (*RouteConfiguration) GetName ¶
func (x *RouteConfiguration) GetName() string
func (*RouteConfiguration) GetRoutes ¶
func (x *RouteConfiguration) GetRoutes() []*Route
func (*RouteConfiguration) ProtoMessage ¶
func (*RouteConfiguration) ProtoMessage()
func (*RouteConfiguration) ProtoReflect ¶
func (x *RouteConfiguration) ProtoReflect() protoreflect.Message
func (*RouteConfiguration) Reset ¶
func (x *RouteConfiguration) Reset()
func (*RouteConfiguration) SetName ¶
func (x *RouteConfiguration) SetName(v string)
func (*RouteConfiguration) SetRoutes ¶
func (x *RouteConfiguration) SetRoutes(v []*Route)
func (*RouteConfiguration) String ¶
func (x *RouteConfiguration) String() string
type RouteConfiguration_builder ¶
type RouteConfiguration_builder struct {
// The name of the route configuration. Reserved for future use in asynchronous route discovery.
Name string
// The list of routes that will be matched, in order, against incoming requests. The first route
// that matches will be used.
Routes []*Route
// contains filtered or unexported fields
}
func (RouteConfiguration_builder) Build ¶
func (b0 RouteConfiguration_builder) Build() *RouteConfiguration
type RouteMatch ¶
type RouteMatch struct {
// Types that are valid to be assigned to MatchSpecifier:
//
// *RouteMatch_Domain
MatchSpecifier isRouteMatch_MatchSpecifier `protobuf_oneof:"match_specifier"`
// The header to get match parameter, default is "Route".
Header string `protobuf:"bytes,2,opt,name=header,proto3" json:"header,omitempty"`
// The parameter to get domain, default is "host".
Parameter string `protobuf:"bytes,3,opt,name=parameter,proto3" json:"parameter,omitempty"`
// contains filtered or unexported fields
}
func (*RouteMatch) ClearDomain ¶
func (x *RouteMatch) ClearDomain()
func (*RouteMatch) ClearMatchSpecifier ¶
func (x *RouteMatch) ClearMatchSpecifier()
func (*RouteMatch) GetDomain ¶
func (x *RouteMatch) GetDomain() string
func (*RouteMatch) GetHeader ¶
func (x *RouteMatch) GetHeader() string
func (*RouteMatch) GetMatchSpecifier ¶
func (x *RouteMatch) GetMatchSpecifier() isRouteMatch_MatchSpecifier
func (*RouteMatch) GetParameter ¶
func (x *RouteMatch) GetParameter() string
func (*RouteMatch) HasDomain ¶
func (x *RouteMatch) HasDomain() bool
func (*RouteMatch) HasMatchSpecifier ¶
func (x *RouteMatch) HasMatchSpecifier() bool
func (*RouteMatch) ProtoMessage ¶
func (*RouteMatch) ProtoMessage()
func (*RouteMatch) ProtoReflect ¶
func (x *RouteMatch) ProtoReflect() protoreflect.Message
func (*RouteMatch) Reset ¶
func (x *RouteMatch) Reset()
func (*RouteMatch) SetDomain ¶
func (x *RouteMatch) SetDomain(v string)
func (*RouteMatch) SetHeader ¶
func (x *RouteMatch) SetHeader(v string)
func (*RouteMatch) SetParameter ¶
func (x *RouteMatch) SetParameter(v string)
func (*RouteMatch) String ¶
func (x *RouteMatch) String() string
func (*RouteMatch) WhichMatchSpecifier ¶
func (x *RouteMatch) WhichMatchSpecifier() case_RouteMatch_MatchSpecifier
type RouteMatch_Domain ¶
type RouteMatch_Domain struct {
// The domain from Request URI or Route Header.
Domain string `protobuf:"bytes,1,opt,name=domain,proto3,oneof"`
}
type RouteMatch_builder ¶
type RouteMatch_builder struct {
// Fields of oneof MatchSpecifier:
// The domain from Request URI or Route Header.
Domain *string
// -- end of MatchSpecifier
// The header to get match parameter, default is "Route".
Header string
// The parameter to get domain, default is "host".
Parameter string
// contains filtered or unexported fields
}
func (RouteMatch_builder) Build ¶
func (b0 RouteMatch_builder) Build() *RouteMatch
type Route_builder ¶
type Route_builder struct {
// Route matching parameters.
Match *RouteMatch
// Route request to some upstream cluster.
Route *RouteAction
// contains filtered or unexported fields
}
func (Route_builder) Build ¶
func (b0 Route_builder) Build() *Route
type SipFilter ¶
type SipFilter struct {
// The name of the filter to instantiate. The name must match a supported
// filter. The built-in filters are:
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// Filter specific configuration which depends on the filter being instantiated. See the supported
// filters for further documentation.
//
// Types that are valid to be assigned to ConfigType:
//
// *SipFilter_TypedConfig
ConfigType isSipFilter_ConfigType `protobuf_oneof:"config_type"`
// contains filtered or unexported fields
}
SipFilter configures a Sip filter.
func (*SipFilter) ProtoReflect ¶
func (x *SipFilter) ProtoReflect() protoreflect.Message
type SipFilter_TypedConfig ¶
type SipFilter_builder ¶
type SipFilter_builder struct {
// The name of the filter to instantiate. The name must match a supported
// filter. The built-in filters are:
Name string
// Fields of oneof ConfigType:
TypedConfig *anypb.Any
// contains filtered or unexported fields
}
func (SipFilter_builder) Build ¶
func (b0 SipFilter_builder) Build() *SipFilter
type SipProtocolOptions ¶
type SipProtocolOptions struct {
// All sip messages in one dialog should go to the same endpoint.
SessionAffinity bool `protobuf:"varint,1,opt,name=session_affinity,json=sessionAffinity,proto3" json:"session_affinity,omitempty"`
// The Register with Authorization header should go to the same endpoint which send out the 401 Unauthorized.
RegistrationAffinity bool `protobuf:"varint,2,opt,name=registration_affinity,json=registrationAffinity,proto3" json:"registration_affinity,omitempty"`
// Customized affinity
CustomizedAffinity *CustomizedAffinity `protobuf:"bytes,3,opt,name=customized_affinity,json=customizedAffinity,proto3" json:"customized_affinity,omitempty"`
// contains filtered or unexported fields
}
SipProtocolOptions specifies Sip upstream protocol options. This object is used in :ref:`typed_extension_protocol_options<envoy_v3_api_field_config.cluster.v3.Cluster.typed_extension_protocol_options>`, keyed by the name “envoy.filters.network.sip_proxy“.
func (*SipProtocolOptions) ClearCustomizedAffinity ¶
func (x *SipProtocolOptions) ClearCustomizedAffinity()
func (*SipProtocolOptions) GetCustomizedAffinity ¶
func (x *SipProtocolOptions) GetCustomizedAffinity() *CustomizedAffinity
func (*SipProtocolOptions) GetRegistrationAffinity ¶
func (x *SipProtocolOptions) GetRegistrationAffinity() bool
func (*SipProtocolOptions) GetSessionAffinity ¶
func (x *SipProtocolOptions) GetSessionAffinity() bool
func (*SipProtocolOptions) HasCustomizedAffinity ¶
func (x *SipProtocolOptions) HasCustomizedAffinity() bool
func (*SipProtocolOptions) ProtoMessage ¶
func (*SipProtocolOptions) ProtoMessage()
func (*SipProtocolOptions) ProtoReflect ¶
func (x *SipProtocolOptions) ProtoReflect() protoreflect.Message
func (*SipProtocolOptions) Reset ¶
func (x *SipProtocolOptions) Reset()
func (*SipProtocolOptions) SetCustomizedAffinity ¶
func (x *SipProtocolOptions) SetCustomizedAffinity(v *CustomizedAffinity)
func (*SipProtocolOptions) SetRegistrationAffinity ¶
func (x *SipProtocolOptions) SetRegistrationAffinity(v bool)
func (*SipProtocolOptions) SetSessionAffinity ¶
func (x *SipProtocolOptions) SetSessionAffinity(v bool)
func (*SipProtocolOptions) String ¶
func (x *SipProtocolOptions) String() string
type SipProtocolOptions_builder ¶
type SipProtocolOptions_builder struct {
// All sip messages in one dialog should go to the same endpoint.
SessionAffinity bool
// The Register with Authorization header should go to the same endpoint which send out the 401 Unauthorized.
RegistrationAffinity bool
// Customized affinity
CustomizedAffinity *CustomizedAffinity
// contains filtered or unexported fields
}
func (SipProtocolOptions_builder) Build ¶
func (b0 SipProtocolOptions_builder) Build() *SipProtocolOptions
type SipProxy ¶
type SipProxy struct {
// The human readable prefix to use when emitting statistics.
StatPrefix string `protobuf:"bytes,1,opt,name=stat_prefix,json=statPrefix,proto3" json:"stat_prefix,omitempty"`
// The route table for the connection manager is static and is specified in this property.
RouteConfig *RouteConfiguration `protobuf:"bytes,2,opt,name=route_config,json=routeConfig,proto3" json:"route_config,omitempty"`
// A list of individual Sip filters that make up the filter chain for requests made to the
// Sip proxy. Order matters as the filters are processed sequentially. For backwards
// compatibility, if no sip_filters are specified, a default Sip router filter
// (“envoy.filters.sip.router“) is used.
// [#extension-category: envoy.sip_proxy.filters]
SipFilters []*SipFilter `protobuf:"bytes,3,rep,name=sip_filters,json=sipFilters,proto3" json:"sip_filters,omitempty"`
Settings *SipProxy_SipSettings `protobuf:"bytes,4,opt,name=settings,proto3" json:"settings,omitempty"`
// contains filtered or unexported fields
}
func (*SipProxy) GetRouteConfig ¶
func (x *SipProxy) GetRouteConfig() *RouteConfiguration
func (*SipProxy) GetSettings ¶
func (x *SipProxy) GetSettings() *SipProxy_SipSettings
func (*SipProxy) ProtoReflect ¶
func (x *SipProxy) ProtoReflect() protoreflect.Message
func (*SipProxy) SetRouteConfig ¶
func (x *SipProxy) SetRouteConfig(v *RouteConfiguration)
func (*SipProxy) SetSettings ¶
func (x *SipProxy) SetSettings(v *SipProxy_SipSettings)
type SipProxy_SipSettings ¶
type SipProxy_SipSettings struct {
// transaction timeout timer [Timer B] unit is milliseconds, default value 64*T1.
//
// # Session Initiation Protocol (SIP) timer summary
//
// +---------+-------------------------+----------+------------------------------------------------------------------------------+
// | Timer | Default value | Section | Meaning |
// +=========+=========================+==========+==============================================================================+
// | T1 | 500 ms | 17.1.1.1 | Round-trip time (RTT) estimate |
// +---------+-------------------------+----------+------------------------------------------------------------------------------+
// | T2 | 4 sec | 17.1.2.2 | Maximum re-transmission interval for non-INVITE requests and INVITE responses|
// +---------+-------------------------+----------+------------------------------------------------------------------------------+
// | T4 | 5 sec | 17.1.2.2 | Maximum duration that a message can remain in the network |
// +---------+-------------------------+----------+------------------------------------------------------------------------------+
// | Timer A | initially T1 | 17.1.1.2 | INVITE request re-transmission interval, for UDP only |
// +---------+-------------------------+----------+------------------------------------------------------------------------------+
// | Timer B | 64*T1 | 17.1.1.2 | INVITE transaction timeout timer |
// +---------+-------------------------+----------+------------------------------------------------------------------------------+
// | Timer D | > 32 sec. for UDP | 17.1.1.2 | Wait time for response re-transmissions |
// | | 0 sec. for TCP and SCTP | | |
// +---------+-------------------------+----------+------------------------------------------------------------------------------+
// | Timer E | initially T1 | 17.1.2.2 | Non-INVITE request re-transmission interval, UDP only |
// +---------+-------------------------+----------+------------------------------------------------------------------------------+
// | Timer F | 64*T1 | 17.1.2.2 | Non-INVITE transaction timeout timer |
// +---------+-------------------------+----------+------------------------------------------------------------------------------+
// | Timer G | initially T1 | 17.2.1 | INVITE response re-transmission interval |
// +---------+-------------------------+----------+------------------------------------------------------------------------------+
// | Timer H | 64*T1 | 17.2.1 | Wait time for ACK receipt |
// +---------+-------------------------+----------+------------------------------------------------------------------------------+
// | Timer I | T4 for UDP | 17.2.1 | Wait time for ACK re-transmissions |
// | | 0 sec. for TCP and SCTP | | |
// +---------+-------------------------+----------+------------------------------------------------------------------------------+
// | Timer J | 64*T1 for UDP | 17.2.2 | Wait time for re-transmissions of non-INVITE requests |
// | | 0 sec. for TCP and SCTP | | |
// +---------+-------------------------+----------+------------------------------------------------------------------------------+
// | Timer K | T4 for UDP | 17.1.2.2 | Wait time for response re-transmissions |
// | | 0 sec. for TCP and SCTP | | |
// +---------+-------------------------+----------+------------------------------------------------------------------------------+
TransactionTimeout *durationpb.Duration `protobuf:"bytes,1,opt,name=transaction_timeout,json=transactionTimeout,proto3" json:"transaction_timeout,omitempty"`
// The service to match for ep insert
LocalServices []*LocalService `protobuf:"bytes,2,rep,name=local_services,json=localServices,proto3" json:"local_services,omitempty"`
TraServiceConfig *v3alpha.TraServiceConfig `protobuf:"bytes,3,opt,name=tra_service_config,json=traServiceConfig,proto3" json:"tra_service_config,omitempty"`
// Whether via header is operated, including add via for request and pop via for response
// False: sip service proxy
// True: sip load balancer
OperateVia bool `protobuf:"varint,4,opt,name=operate_via,json=operateVia,proto3" json:"operate_via,omitempty"`
// contains filtered or unexported fields
}
func (*SipProxy_SipSettings) ClearTraServiceConfig ¶
func (x *SipProxy_SipSettings) ClearTraServiceConfig()
func (*SipProxy_SipSettings) ClearTransactionTimeout ¶
func (x *SipProxy_SipSettings) ClearTransactionTimeout()
func (*SipProxy_SipSettings) GetLocalServices ¶
func (x *SipProxy_SipSettings) GetLocalServices() []*LocalService
func (*SipProxy_SipSettings) GetOperateVia ¶
func (x *SipProxy_SipSettings) GetOperateVia() bool
func (*SipProxy_SipSettings) GetTraServiceConfig ¶
func (x *SipProxy_SipSettings) GetTraServiceConfig() *v3alpha.TraServiceConfig
func (*SipProxy_SipSettings) GetTransactionTimeout ¶
func (x *SipProxy_SipSettings) GetTransactionTimeout() *durationpb.Duration
func (*SipProxy_SipSettings) HasTraServiceConfig ¶
func (x *SipProxy_SipSettings) HasTraServiceConfig() bool
func (*SipProxy_SipSettings) HasTransactionTimeout ¶
func (x *SipProxy_SipSettings) HasTransactionTimeout() bool
func (*SipProxy_SipSettings) ProtoMessage ¶
func (*SipProxy_SipSettings) ProtoMessage()
func (*SipProxy_SipSettings) ProtoReflect ¶
func (x *SipProxy_SipSettings) ProtoReflect() protoreflect.Message
func (*SipProxy_SipSettings) Reset ¶
func (x *SipProxy_SipSettings) Reset()
func (*SipProxy_SipSettings) SetLocalServices ¶
func (x *SipProxy_SipSettings) SetLocalServices(v []*LocalService)
func (*SipProxy_SipSettings) SetOperateVia ¶
func (x *SipProxy_SipSettings) SetOperateVia(v bool)
func (*SipProxy_SipSettings) SetTraServiceConfig ¶
func (x *SipProxy_SipSettings) SetTraServiceConfig(v *v3alpha.TraServiceConfig)
func (*SipProxy_SipSettings) SetTransactionTimeout ¶
func (x *SipProxy_SipSettings) SetTransactionTimeout(v *durationpb.Duration)
func (*SipProxy_SipSettings) String ¶
func (x *SipProxy_SipSettings) String() string
type SipProxy_SipSettings_builder ¶
type SipProxy_SipSettings_builder struct {
// transaction timeout timer [Timer B] unit is milliseconds, default value 64*T1.
//
// # Session Initiation Protocol (SIP) timer summary
//
// +---------+-------------------------+----------+------------------------------------------------------------------------------+
// | Timer | Default value | Section | Meaning |
// +=========+=========================+==========+==============================================================================+
// | T1 | 500 ms | 17.1.1.1 | Round-trip time (RTT) estimate |
// +---------+-------------------------+----------+------------------------------------------------------------------------------+
// | T2 | 4 sec | 17.1.2.2 | Maximum re-transmission interval for non-INVITE requests and INVITE responses|
// +---------+-------------------------+----------+------------------------------------------------------------------------------+
// | T4 | 5 sec | 17.1.2.2 | Maximum duration that a message can remain in the network |
// +---------+-------------------------+----------+------------------------------------------------------------------------------+
// | Timer A | initially T1 | 17.1.1.2 | INVITE request re-transmission interval, for UDP only |
// +---------+-------------------------+----------+------------------------------------------------------------------------------+
// | Timer B | 64*T1 | 17.1.1.2 | INVITE transaction timeout timer |
// +---------+-------------------------+----------+------------------------------------------------------------------------------+
// | Timer D | > 32 sec. for UDP | 17.1.1.2 | Wait time for response re-transmissions |
// | | 0 sec. for TCP and SCTP | | |
// +---------+-------------------------+----------+------------------------------------------------------------------------------+
// | Timer E | initially T1 | 17.1.2.2 | Non-INVITE request re-transmission interval, UDP only |
// +---------+-------------------------+----------+------------------------------------------------------------------------------+
// | Timer F | 64*T1 | 17.1.2.2 | Non-INVITE transaction timeout timer |
// +---------+-------------------------+----------+------------------------------------------------------------------------------+
// | Timer G | initially T1 | 17.2.1 | INVITE response re-transmission interval |
// +---------+-------------------------+----------+------------------------------------------------------------------------------+
// | Timer H | 64*T1 | 17.2.1 | Wait time for ACK receipt |
// +---------+-------------------------+----------+------------------------------------------------------------------------------+
// | Timer I | T4 for UDP | 17.2.1 | Wait time for ACK re-transmissions |
// | | 0 sec. for TCP and SCTP | | |
// +---------+-------------------------+----------+------------------------------------------------------------------------------+
// | Timer J | 64*T1 for UDP | 17.2.2 | Wait time for re-transmissions of non-INVITE requests |
// | | 0 sec. for TCP and SCTP | | |
// +---------+-------------------------+----------+------------------------------------------------------------------------------+
// | Timer K | T4 for UDP | 17.1.2.2 | Wait time for response re-transmissions |
// | | 0 sec. for TCP and SCTP | | |
// +---------+-------------------------+----------+------------------------------------------------------------------------------+
TransactionTimeout *durationpb.Duration
// The service to match for ep insert
LocalServices []*LocalService
TraServiceConfig *v3alpha.TraServiceConfig
// Whether via header is operated, including add via for request and pop via for response
// False: sip service proxy
// True: sip load balancer
OperateVia bool
// contains filtered or unexported fields
}
func (SipProxy_SipSettings_builder) Build ¶
func (b0 SipProxy_SipSettings_builder) Build() *SipProxy_SipSettings
type SipProxy_builder ¶
type SipProxy_builder struct {
// The human readable prefix to use when emitting statistics.
StatPrefix string
// The route table for the connection manager is static and is specified in this property.
RouteConfig *RouteConfiguration
// A list of individual Sip filters that make up the filter chain for requests made to the
// Sip proxy. Order matters as the filters are processed sequentially. For backwards
// compatibility, if no sip_filters are specified, a default Sip router filter
// (“envoy.filters.sip.router“) is used.
// [#extension-category: envoy.sip_proxy.filters]
SipFilters []*SipFilter
Settings *SipProxy_SipSettings
// contains filtered or unexported fields
}
func (SipProxy_builder) Build ¶
func (b0 SipProxy_builder) Build() *SipProxy
Source Files
¶
- route.pb.go
- sip_proxy.pb.go
Click to show internal directories.
Click to hide internal directories.