Documentation
¶
Index ¶
- Variables
- type Config
- func (x *Config) ClearConfig()
- func (x *Config) GetConfig() *anypb.Any
- func (x *Config) GetDefaultCluster() string
- func (x *Config) GetLibraryId() string
- func (x *Config) GetLibraryPath() string
- func (x *Config) HasConfig() bool
- func (*Config) ProtoMessage()
- func (x *Config) ProtoReflect() protoreflect.Message
- func (x *Config) Reset()
- func (x *Config) SetConfig(v *anypb.Any)
- func (x *Config) SetDefaultCluster(v string)
- func (x *Config) SetLibraryId(v string)
- func (x *Config) SetLibraryPath(v string)
- func (x *Config) String() string
- type Config_builder
Constants ¶
This section is empty.
Variables ¶
var File_contrib_envoy_extensions_router_cluster_specifier_golang_v3alpha_golang_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
// Globally unique ID for a dynamic library file.
LibraryId string `protobuf:"bytes,1,opt,name=library_id,json=libraryId,proto3" json:"library_id,omitempty"`
// Path to a dynamic library implementing the
// :repo:`ClusterSpecifier API <contrib/golang/router/cluster_specifier/source/go/pkg/api.ClusterSpecifier>`
// interface.
// [#comment:TODO(wangfakang): Support for downloading libraries from remote repositories.]
LibraryPath string `protobuf:"bytes,2,opt,name=library_path,json=libraryPath,proto3" json:"library_path,omitempty"`
// Default cluster.
//
// It will be used when the specifier interface return empty string or panic.
DefaultCluster string `protobuf:"bytes,3,opt,name=default_cluster,json=defaultCluster,proto3" json:"default_cluster,omitempty"`
// Configuration for the Go cluster specifier plugin.
//
// .. note::
//
// This configuration is only parsed in the go cluster specifier, and is therefore not validated
// by Envoy.
//
// See the :repo:`StreamFilter API <contrib/golang/router/cluster_specifier/source/go/pkg/cluster_specifier/config.go>`
// for more information about how the plugin's configuration data can be accessed.
Config *anypb.Any `protobuf:"bytes,4,opt,name=config,proto3" json:"config,omitempty"`
// contains filtered or unexported fields
}
[#extension-category: envoy.router.cluster_specifier_plugin]
func (*Config) ProtoReflect ¶
func (x *Config) ProtoReflect() protoreflect.Message
type Config_builder ¶
type Config_builder struct {
// Globally unique ID for a dynamic library file.
LibraryId string
// Path to a dynamic library implementing the
// :repo:`ClusterSpecifier API <contrib/golang/router/cluster_specifier/source/go/pkg/api.ClusterSpecifier>`
// interface.
// [#comment:TODO(wangfakang): Support for downloading libraries from remote repositories.]
LibraryPath string
// Default cluster.
//
// It will be used when the specifier interface return empty string or panic.
DefaultCluster string
// Configuration for the Go cluster specifier plugin.
//
// .. note::
//
// This configuration is only parsed in the go cluster specifier, and is therefore not validated
// by Envoy.
//
// See the :repo:`StreamFilter API <contrib/golang/router/cluster_specifier/source/go/pkg/cluster_specifier/config.go>`
// for more information about how the plugin's configuration data can be accessed.
Config *anypb.Any
// contains filtered or unexported fields
}
func (Config_builder) Build ¶
func (b0 Config_builder) Build() *Config
Source Files
¶
- golang.pb.go
Click to show internal directories.
Click to hide internal directories.