Documentation
¶
Index ¶
- Variables
- type CircuitBreakers
- func (x *CircuitBreakers) GetThresholds() []*CircuitBreakers_Thresholds
- func (*CircuitBreakers) ProtoMessage()
- func (x *CircuitBreakers) ProtoReflect() protoreflect.Message
- func (x *CircuitBreakers) Reset()
- func (x *CircuitBreakers) SetThresholds(v []*CircuitBreakers_Thresholds)
- func (x *CircuitBreakers) String() string
- type CircuitBreakers_Thresholds
- func (x *CircuitBreakers_Thresholds) ClearMaxConnectionPools()
- func (x *CircuitBreakers_Thresholds) ClearMaxConnections()
- func (x *CircuitBreakers_Thresholds) ClearMaxPendingRequests()
- func (x *CircuitBreakers_Thresholds) ClearMaxRequests()
- func (x *CircuitBreakers_Thresholds) ClearMaxRetries()
- func (x *CircuitBreakers_Thresholds) ClearRetryBudget()
- func (x *CircuitBreakers_Thresholds) GetMaxConnectionPools() *wrapperspb.UInt32Value
- func (x *CircuitBreakers_Thresholds) GetMaxConnections() *wrapperspb.UInt32Value
- func (x *CircuitBreakers_Thresholds) GetMaxPendingRequests() *wrapperspb.UInt32Value
- func (x *CircuitBreakers_Thresholds) GetMaxRequests() *wrapperspb.UInt32Value
- func (x *CircuitBreakers_Thresholds) GetMaxRetries() *wrapperspb.UInt32Value
- func (x *CircuitBreakers_Thresholds) GetPriority() core.RoutingPriority
- func (x *CircuitBreakers_Thresholds) GetRetryBudget() *CircuitBreakers_Thresholds_RetryBudget
- func (x *CircuitBreakers_Thresholds) GetTrackRemaining() bool
- func (x *CircuitBreakers_Thresholds) HasMaxConnectionPools() bool
- func (x *CircuitBreakers_Thresholds) HasMaxConnections() bool
- func (x *CircuitBreakers_Thresholds) HasMaxPendingRequests() bool
- func (x *CircuitBreakers_Thresholds) HasMaxRequests() bool
- func (x *CircuitBreakers_Thresholds) HasMaxRetries() bool
- func (x *CircuitBreakers_Thresholds) HasRetryBudget() bool
- func (*CircuitBreakers_Thresholds) ProtoMessage()
- func (x *CircuitBreakers_Thresholds) ProtoReflect() protoreflect.Message
- func (x *CircuitBreakers_Thresholds) Reset()
- func (x *CircuitBreakers_Thresholds) SetMaxConnectionPools(v *wrapperspb.UInt32Value)
- func (x *CircuitBreakers_Thresholds) SetMaxConnections(v *wrapperspb.UInt32Value)
- func (x *CircuitBreakers_Thresholds) SetMaxPendingRequests(v *wrapperspb.UInt32Value)
- func (x *CircuitBreakers_Thresholds) SetMaxRequests(v *wrapperspb.UInt32Value)
- func (x *CircuitBreakers_Thresholds) SetMaxRetries(v *wrapperspb.UInt32Value)
- func (x *CircuitBreakers_Thresholds) SetPriority(v core.RoutingPriority)
- func (x *CircuitBreakers_Thresholds) SetRetryBudget(v *CircuitBreakers_Thresholds_RetryBudget)
- func (x *CircuitBreakers_Thresholds) SetTrackRemaining(v bool)
- func (x *CircuitBreakers_Thresholds) String() string
- type CircuitBreakers_Thresholds_RetryBudget
- func (x *CircuitBreakers_Thresholds_RetryBudget) ClearBudgetPercent()
- func (x *CircuitBreakers_Thresholds_RetryBudget) ClearMinRetryConcurrency()
- func (x *CircuitBreakers_Thresholds_RetryBudget) GetBudgetPercent() *_type.Percent
- func (x *CircuitBreakers_Thresholds_RetryBudget) GetMinRetryConcurrency() *wrapperspb.UInt32Value
- func (x *CircuitBreakers_Thresholds_RetryBudget) HasBudgetPercent() bool
- func (x *CircuitBreakers_Thresholds_RetryBudget) HasMinRetryConcurrency() bool
- func (*CircuitBreakers_Thresholds_RetryBudget) ProtoMessage()
- func (x *CircuitBreakers_Thresholds_RetryBudget) ProtoReflect() protoreflect.Message
- func (x *CircuitBreakers_Thresholds_RetryBudget) Reset()
- func (x *CircuitBreakers_Thresholds_RetryBudget) SetBudgetPercent(v *_type.Percent)
- func (x *CircuitBreakers_Thresholds_RetryBudget) SetMinRetryConcurrency(v *wrapperspb.UInt32Value)
- func (x *CircuitBreakers_Thresholds_RetryBudget) String() string
- type CircuitBreakers_Thresholds_RetryBudget_builder
- type CircuitBreakers_Thresholds_builder
- type CircuitBreakers_builder
- type Filter
- func (x *Filter) ClearTypedConfig()
- func (x *Filter) GetName() string
- func (x *Filter) GetTypedConfig() *anypb.Any
- func (x *Filter) HasTypedConfig() bool
- func (*Filter) ProtoMessage()
- func (x *Filter) ProtoReflect() protoreflect.Message
- func (x *Filter) Reset()
- func (x *Filter) SetName(v string)
- func (x *Filter) SetTypedConfig(v *anypb.Any)
- func (x *Filter) String() string
- type Filter_builder
- type OutlierDetection
- func (x *OutlierDetection) ClearBaseEjectionTime()
- func (x *OutlierDetection) ClearConsecutiveGatewayFailure()
- func (x *OutlierDetection) ClearConsecutiveLocalOriginFailure()
- func (x *OutlierDetection) ClearConsecutive_5Xx()
- func (x *OutlierDetection) ClearEnforcingConsecutiveGatewayFailure()
- func (x *OutlierDetection) ClearEnforcingConsecutiveLocalOriginFailure()
- func (x *OutlierDetection) ClearEnforcingConsecutive_5Xx()
- func (x *OutlierDetection) ClearEnforcingFailurePercentage()
- func (x *OutlierDetection) ClearEnforcingFailurePercentageLocalOrigin()
- func (x *OutlierDetection) ClearEnforcingLocalOriginSuccessRate()
- func (x *OutlierDetection) ClearEnforcingSuccessRate()
- func (x *OutlierDetection) ClearFailurePercentageMinimumHosts()
- func (x *OutlierDetection) ClearFailurePercentageRequestVolume()
- func (x *OutlierDetection) ClearFailurePercentageThreshold()
- func (x *OutlierDetection) ClearInterval()
- func (x *OutlierDetection) ClearMaxEjectionPercent()
- func (x *OutlierDetection) ClearSuccessRateMinimumHosts()
- func (x *OutlierDetection) ClearSuccessRateRequestVolume()
- func (x *OutlierDetection) ClearSuccessRateStdevFactor()
- func (x *OutlierDetection) GetBaseEjectionTime() *durationpb.Duration
- func (x *OutlierDetection) GetConsecutiveGatewayFailure() *wrapperspb.UInt32Value
- func (x *OutlierDetection) GetConsecutiveLocalOriginFailure() *wrapperspb.UInt32Value
- func (x *OutlierDetection) GetConsecutive_5Xx() *wrapperspb.UInt32Value
- func (x *OutlierDetection) GetEnforcingConsecutiveGatewayFailure() *wrapperspb.UInt32Value
- func (x *OutlierDetection) GetEnforcingConsecutiveLocalOriginFailure() *wrapperspb.UInt32Value
- func (x *OutlierDetection) GetEnforcingConsecutive_5Xx() *wrapperspb.UInt32Value
- func (x *OutlierDetection) GetEnforcingFailurePercentage() *wrapperspb.UInt32Value
- func (x *OutlierDetection) GetEnforcingFailurePercentageLocalOrigin() *wrapperspb.UInt32Value
- func (x *OutlierDetection) GetEnforcingLocalOriginSuccessRate() *wrapperspb.UInt32Value
- func (x *OutlierDetection) GetEnforcingSuccessRate() *wrapperspb.UInt32Value
- func (x *OutlierDetection) GetFailurePercentageMinimumHosts() *wrapperspb.UInt32Value
- func (x *OutlierDetection) GetFailurePercentageRequestVolume() *wrapperspb.UInt32Value
- func (x *OutlierDetection) GetFailurePercentageThreshold() *wrapperspb.UInt32Value
- func (x *OutlierDetection) GetInterval() *durationpb.Duration
- func (x *OutlierDetection) GetMaxEjectionPercent() *wrapperspb.UInt32Value
- func (x *OutlierDetection) GetSplitExternalLocalOriginErrors() bool
- func (x *OutlierDetection) GetSuccessRateMinimumHosts() *wrapperspb.UInt32Value
- func (x *OutlierDetection) GetSuccessRateRequestVolume() *wrapperspb.UInt32Value
- func (x *OutlierDetection) GetSuccessRateStdevFactor() *wrapperspb.UInt32Value
- func (x *OutlierDetection) HasBaseEjectionTime() bool
- func (x *OutlierDetection) HasConsecutiveGatewayFailure() bool
- func (x *OutlierDetection) HasConsecutiveLocalOriginFailure() bool
- func (x *OutlierDetection) HasConsecutive_5Xx() bool
- func (x *OutlierDetection) HasEnforcingConsecutiveGatewayFailure() bool
- func (x *OutlierDetection) HasEnforcingConsecutiveLocalOriginFailure() bool
- func (x *OutlierDetection) HasEnforcingConsecutive_5Xx() bool
- func (x *OutlierDetection) HasEnforcingFailurePercentage() bool
- func (x *OutlierDetection) HasEnforcingFailurePercentageLocalOrigin() bool
- func (x *OutlierDetection) HasEnforcingLocalOriginSuccessRate() bool
- func (x *OutlierDetection) HasEnforcingSuccessRate() bool
- func (x *OutlierDetection) HasFailurePercentageMinimumHosts() bool
- func (x *OutlierDetection) HasFailurePercentageRequestVolume() bool
- func (x *OutlierDetection) HasFailurePercentageThreshold() bool
- func (x *OutlierDetection) HasInterval() bool
- func (x *OutlierDetection) HasMaxEjectionPercent() bool
- func (x *OutlierDetection) HasSuccessRateMinimumHosts() bool
- func (x *OutlierDetection) HasSuccessRateRequestVolume() bool
- func (x *OutlierDetection) HasSuccessRateStdevFactor() bool
- func (*OutlierDetection) ProtoMessage()
- func (x *OutlierDetection) ProtoReflect() protoreflect.Message
- func (x *OutlierDetection) Reset()
- func (x *OutlierDetection) SetBaseEjectionTime(v *durationpb.Duration)
- func (x *OutlierDetection) SetConsecutiveGatewayFailure(v *wrapperspb.UInt32Value)
- func (x *OutlierDetection) SetConsecutiveLocalOriginFailure(v *wrapperspb.UInt32Value)
- func (x *OutlierDetection) SetConsecutive_5Xx(v *wrapperspb.UInt32Value)
- func (x *OutlierDetection) SetEnforcingConsecutiveGatewayFailure(v *wrapperspb.UInt32Value)
- func (x *OutlierDetection) SetEnforcingConsecutiveLocalOriginFailure(v *wrapperspb.UInt32Value)
- func (x *OutlierDetection) SetEnforcingConsecutive_5Xx(v *wrapperspb.UInt32Value)
- func (x *OutlierDetection) SetEnforcingFailurePercentage(v *wrapperspb.UInt32Value)
- func (x *OutlierDetection) SetEnforcingFailurePercentageLocalOrigin(v *wrapperspb.UInt32Value)
- func (x *OutlierDetection) SetEnforcingLocalOriginSuccessRate(v *wrapperspb.UInt32Value)
- func (x *OutlierDetection) SetEnforcingSuccessRate(v *wrapperspb.UInt32Value)
- func (x *OutlierDetection) SetFailurePercentageMinimumHosts(v *wrapperspb.UInt32Value)
- func (x *OutlierDetection) SetFailurePercentageRequestVolume(v *wrapperspb.UInt32Value)
- func (x *OutlierDetection) SetFailurePercentageThreshold(v *wrapperspb.UInt32Value)
- func (x *OutlierDetection) SetInterval(v *durationpb.Duration)
- func (x *OutlierDetection) SetMaxEjectionPercent(v *wrapperspb.UInt32Value)
- func (x *OutlierDetection) SetSplitExternalLocalOriginErrors(v bool)
- func (x *OutlierDetection) SetSuccessRateMinimumHosts(v *wrapperspb.UInt32Value)
- func (x *OutlierDetection) SetSuccessRateRequestVolume(v *wrapperspb.UInt32Value)
- func (x *OutlierDetection) SetSuccessRateStdevFactor(v *wrapperspb.UInt32Value)
- func (x *OutlierDetection) String() string
- type OutlierDetection_builder
Constants ¶
This section is empty.
Variables ¶
var File_envoy_api_v2_cluster_circuit_breaker_proto protoreflect.FileDescriptor
var File_envoy_api_v2_cluster_filter_proto protoreflect.FileDescriptor
var File_envoy_api_v2_cluster_outlier_detection_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type CircuitBreakers ¶
type CircuitBreakers struct {
// If multiple :ref:`Thresholds<envoy_api_msg_cluster.CircuitBreakers.Thresholds>`
// are defined with the same :ref:`RoutingPriority<envoy_api_enum_core.RoutingPriority>`,
// the first one in the list is used. If no Thresholds is defined for a given
// :ref:`RoutingPriority<envoy_api_enum_core.RoutingPriority>`, the default values
// are used.
Thresholds []*CircuitBreakers_Thresholds `protobuf:"bytes,1,rep,name=thresholds,proto3" json:"thresholds,omitempty"`
// contains filtered or unexported fields
}
:ref:`Circuit breaking<arch_overview_circuit_break>` settings can be specified individually for each defined priority.
func (*CircuitBreakers) GetThresholds ¶
func (x *CircuitBreakers) GetThresholds() []*CircuitBreakers_Thresholds
func (*CircuitBreakers) ProtoMessage ¶
func (*CircuitBreakers) ProtoMessage()
func (*CircuitBreakers) ProtoReflect ¶
func (x *CircuitBreakers) ProtoReflect() protoreflect.Message
func (*CircuitBreakers) Reset ¶
func (x *CircuitBreakers) Reset()
func (*CircuitBreakers) SetThresholds ¶
func (x *CircuitBreakers) SetThresholds(v []*CircuitBreakers_Thresholds)
func (*CircuitBreakers) String ¶
func (x *CircuitBreakers) String() string
type CircuitBreakers_Thresholds ¶
type CircuitBreakers_Thresholds struct {
// The :ref:`RoutingPriority<envoy_api_enum_core.RoutingPriority>`
// the specified CircuitBreaker settings apply to.
Priority core.RoutingPriority `protobuf:"varint,1,opt,name=priority,proto3,enum=envoy.api.v2.core.RoutingPriority" json:"priority,omitempty"`
// The maximum number of connections that Envoy will make to the upstream
// cluster. If not specified, the default is 1024.
MaxConnections *wrapperspb.UInt32Value `protobuf:"bytes,2,opt,name=max_connections,json=maxConnections,proto3" json:"max_connections,omitempty"`
// The maximum number of pending requests that Envoy will allow to the
// upstream cluster. If not specified, the default is 1024.
MaxPendingRequests *wrapperspb.UInt32Value `protobuf:"bytes,3,opt,name=max_pending_requests,json=maxPendingRequests,proto3" json:"max_pending_requests,omitempty"`
// The maximum number of parallel requests that Envoy will make to the
// upstream cluster. If not specified, the default is 1024.
MaxRequests *wrapperspb.UInt32Value `protobuf:"bytes,4,opt,name=max_requests,json=maxRequests,proto3" json:"max_requests,omitempty"`
// The maximum number of parallel retries that Envoy will allow to the
// upstream cluster. If not specified, the default is 3.
MaxRetries *wrapperspb.UInt32Value `protobuf:"bytes,5,opt,name=max_retries,json=maxRetries,proto3" json:"max_retries,omitempty"`
// Specifies a limit on concurrent retries in relation to the number of active requests. This
// parameter is optional.
//
// .. note::
//
// If this field is set, the retry budget will override any configured retry circuit
// breaker.
RetryBudget *CircuitBreakers_Thresholds_RetryBudget `protobuf:"bytes,8,opt,name=retry_budget,json=retryBudget,proto3" json:"retry_budget,omitempty"`
// If track_remaining is true, then stats will be published that expose
// the number of resources remaining until the circuit breakers open. If
// not specified, the default is false.
//
// .. note::
//
// If a retry budget is used in lieu of the max_retries circuit breaker,
// the remaining retry resources remaining will not be tracked.
TrackRemaining bool `protobuf:"varint,6,opt,name=track_remaining,json=trackRemaining,proto3" json:"track_remaining,omitempty"`
// The maximum number of connection pools per cluster that Envoy will concurrently support at
// once. If not specified, the default is unlimited. Set this for clusters which create a
// large number of connection pools. See
// :ref:`Circuit Breaking <arch_overview_circuit_break_cluster_maximum_connection_pools>` for
// more details.
MaxConnectionPools *wrapperspb.UInt32Value `protobuf:"bytes,7,opt,name=max_connection_pools,json=maxConnectionPools,proto3" json:"max_connection_pools,omitempty"`
// contains filtered or unexported fields
}
A Thresholds defines CircuitBreaker settings for a :ref:`RoutingPriority<envoy_api_enum_core.RoutingPriority>`. [#next-free-field: 9]
func (*CircuitBreakers_Thresholds) ClearMaxConnectionPools ¶
func (x *CircuitBreakers_Thresholds) ClearMaxConnectionPools()
func (*CircuitBreakers_Thresholds) ClearMaxConnections ¶
func (x *CircuitBreakers_Thresholds) ClearMaxConnections()
func (*CircuitBreakers_Thresholds) ClearMaxPendingRequests ¶
func (x *CircuitBreakers_Thresholds) ClearMaxPendingRequests()
func (*CircuitBreakers_Thresholds) ClearMaxRequests ¶
func (x *CircuitBreakers_Thresholds) ClearMaxRequests()
func (*CircuitBreakers_Thresholds) ClearMaxRetries ¶
func (x *CircuitBreakers_Thresholds) ClearMaxRetries()
func (*CircuitBreakers_Thresholds) ClearRetryBudget ¶
func (x *CircuitBreakers_Thresholds) ClearRetryBudget()
func (*CircuitBreakers_Thresholds) GetMaxConnectionPools ¶
func (x *CircuitBreakers_Thresholds) GetMaxConnectionPools() *wrapperspb.UInt32Value
func (*CircuitBreakers_Thresholds) GetMaxConnections ¶
func (x *CircuitBreakers_Thresholds) GetMaxConnections() *wrapperspb.UInt32Value
func (*CircuitBreakers_Thresholds) GetMaxPendingRequests ¶
func (x *CircuitBreakers_Thresholds) GetMaxPendingRequests() *wrapperspb.UInt32Value
func (*CircuitBreakers_Thresholds) GetMaxRequests ¶
func (x *CircuitBreakers_Thresholds) GetMaxRequests() *wrapperspb.UInt32Value
func (*CircuitBreakers_Thresholds) GetMaxRetries ¶
func (x *CircuitBreakers_Thresholds) GetMaxRetries() *wrapperspb.UInt32Value
func (*CircuitBreakers_Thresholds) GetPriority ¶
func (x *CircuitBreakers_Thresholds) GetPriority() core.RoutingPriority
func (*CircuitBreakers_Thresholds) GetRetryBudget ¶
func (x *CircuitBreakers_Thresholds) GetRetryBudget() *CircuitBreakers_Thresholds_RetryBudget
func (*CircuitBreakers_Thresholds) GetTrackRemaining ¶
func (x *CircuitBreakers_Thresholds) GetTrackRemaining() bool
func (*CircuitBreakers_Thresholds) HasMaxConnectionPools ¶
func (x *CircuitBreakers_Thresholds) HasMaxConnectionPools() bool
func (*CircuitBreakers_Thresholds) HasMaxConnections ¶
func (x *CircuitBreakers_Thresholds) HasMaxConnections() bool
func (*CircuitBreakers_Thresholds) HasMaxPendingRequests ¶
func (x *CircuitBreakers_Thresholds) HasMaxPendingRequests() bool
func (*CircuitBreakers_Thresholds) HasMaxRequests ¶
func (x *CircuitBreakers_Thresholds) HasMaxRequests() bool
func (*CircuitBreakers_Thresholds) HasMaxRetries ¶
func (x *CircuitBreakers_Thresholds) HasMaxRetries() bool
func (*CircuitBreakers_Thresholds) HasRetryBudget ¶
func (x *CircuitBreakers_Thresholds) HasRetryBudget() bool
func (*CircuitBreakers_Thresholds) ProtoMessage ¶
func (*CircuitBreakers_Thresholds) ProtoMessage()
func (*CircuitBreakers_Thresholds) ProtoReflect ¶
func (x *CircuitBreakers_Thresholds) ProtoReflect() protoreflect.Message
func (*CircuitBreakers_Thresholds) Reset ¶
func (x *CircuitBreakers_Thresholds) Reset()
func (*CircuitBreakers_Thresholds) SetMaxConnectionPools ¶
func (x *CircuitBreakers_Thresholds) SetMaxConnectionPools(v *wrapperspb.UInt32Value)
func (*CircuitBreakers_Thresholds) SetMaxConnections ¶
func (x *CircuitBreakers_Thresholds) SetMaxConnections(v *wrapperspb.UInt32Value)
func (*CircuitBreakers_Thresholds) SetMaxPendingRequests ¶
func (x *CircuitBreakers_Thresholds) SetMaxPendingRequests(v *wrapperspb.UInt32Value)
func (*CircuitBreakers_Thresholds) SetMaxRequests ¶
func (x *CircuitBreakers_Thresholds) SetMaxRequests(v *wrapperspb.UInt32Value)
func (*CircuitBreakers_Thresholds) SetMaxRetries ¶
func (x *CircuitBreakers_Thresholds) SetMaxRetries(v *wrapperspb.UInt32Value)
func (*CircuitBreakers_Thresholds) SetPriority ¶
func (x *CircuitBreakers_Thresholds) SetPriority(v core.RoutingPriority)
func (*CircuitBreakers_Thresholds) SetRetryBudget ¶
func (x *CircuitBreakers_Thresholds) SetRetryBudget(v *CircuitBreakers_Thresholds_RetryBudget)
func (*CircuitBreakers_Thresholds) SetTrackRemaining ¶
func (x *CircuitBreakers_Thresholds) SetTrackRemaining(v bool)
func (*CircuitBreakers_Thresholds) String ¶
func (x *CircuitBreakers_Thresholds) String() string
type CircuitBreakers_Thresholds_RetryBudget ¶
type CircuitBreakers_Thresholds_RetryBudget struct {
// Specifies the limit on concurrent retries as a percentage of the sum of active requests and
// active pending requests. For example, if there are 100 active requests and the
// budget_percent is set to 25, there may be 25 active retries.
//
// This parameter is optional. Defaults to 20%.
BudgetPercent *_type.Percent `protobuf:"bytes,1,opt,name=budget_percent,json=budgetPercent,proto3" json:"budget_percent,omitempty"`
// Specifies the minimum retry concurrency allowed for the retry budget. The limit on the
// number of active retries may never go below this number.
//
// This parameter is optional. Defaults to 3.
MinRetryConcurrency *wrapperspb.UInt32Value `protobuf:"bytes,2,opt,name=min_retry_concurrency,json=minRetryConcurrency,proto3" json:"min_retry_concurrency,omitempty"`
// contains filtered or unexported fields
}
func (*CircuitBreakers_Thresholds_RetryBudget) ClearBudgetPercent ¶
func (x *CircuitBreakers_Thresholds_RetryBudget) ClearBudgetPercent()
func (*CircuitBreakers_Thresholds_RetryBudget) ClearMinRetryConcurrency ¶
func (x *CircuitBreakers_Thresholds_RetryBudget) ClearMinRetryConcurrency()
func (*CircuitBreakers_Thresholds_RetryBudget) GetBudgetPercent ¶
func (x *CircuitBreakers_Thresholds_RetryBudget) GetBudgetPercent() *_type.Percent
func (*CircuitBreakers_Thresholds_RetryBudget) GetMinRetryConcurrency ¶
func (x *CircuitBreakers_Thresholds_RetryBudget) GetMinRetryConcurrency() *wrapperspb.UInt32Value
func (*CircuitBreakers_Thresholds_RetryBudget) HasBudgetPercent ¶
func (x *CircuitBreakers_Thresholds_RetryBudget) HasBudgetPercent() bool
func (*CircuitBreakers_Thresholds_RetryBudget) HasMinRetryConcurrency ¶
func (x *CircuitBreakers_Thresholds_RetryBudget) HasMinRetryConcurrency() bool
func (*CircuitBreakers_Thresholds_RetryBudget) ProtoMessage ¶
func (*CircuitBreakers_Thresholds_RetryBudget) ProtoMessage()
func (*CircuitBreakers_Thresholds_RetryBudget) ProtoReflect ¶
func (x *CircuitBreakers_Thresholds_RetryBudget) ProtoReflect() protoreflect.Message
func (*CircuitBreakers_Thresholds_RetryBudget) Reset ¶
func (x *CircuitBreakers_Thresholds_RetryBudget) Reset()
func (*CircuitBreakers_Thresholds_RetryBudget) SetBudgetPercent ¶
func (x *CircuitBreakers_Thresholds_RetryBudget) SetBudgetPercent(v *_type.Percent)
func (*CircuitBreakers_Thresholds_RetryBudget) SetMinRetryConcurrency ¶
func (x *CircuitBreakers_Thresholds_RetryBudget) SetMinRetryConcurrency(v *wrapperspb.UInt32Value)
func (*CircuitBreakers_Thresholds_RetryBudget) String ¶
func (x *CircuitBreakers_Thresholds_RetryBudget) String() string
type CircuitBreakers_Thresholds_RetryBudget_builder ¶
type CircuitBreakers_Thresholds_RetryBudget_builder struct {
// Specifies the limit on concurrent retries as a percentage of the sum of active requests and
// active pending requests. For example, if there are 100 active requests and the
// budget_percent is set to 25, there may be 25 active retries.
//
// This parameter is optional. Defaults to 20%.
BudgetPercent *_type.Percent
// Specifies the minimum retry concurrency allowed for the retry budget. The limit on the
// number of active retries may never go below this number.
//
// This parameter is optional. Defaults to 3.
MinRetryConcurrency *wrapperspb.UInt32Value
// contains filtered or unexported fields
}
func (CircuitBreakers_Thresholds_RetryBudget_builder) Build ¶
type CircuitBreakers_Thresholds_builder ¶
type CircuitBreakers_Thresholds_builder struct {
// The :ref:`RoutingPriority<envoy_api_enum_core.RoutingPriority>`
// the specified CircuitBreaker settings apply to.
Priority core.RoutingPriority
// The maximum number of connections that Envoy will make to the upstream
// cluster. If not specified, the default is 1024.
MaxConnections *wrapperspb.UInt32Value
// The maximum number of pending requests that Envoy will allow to the
// upstream cluster. If not specified, the default is 1024.
MaxPendingRequests *wrapperspb.UInt32Value
// The maximum number of parallel requests that Envoy will make to the
// upstream cluster. If not specified, the default is 1024.
MaxRequests *wrapperspb.UInt32Value
// The maximum number of parallel retries that Envoy will allow to the
// upstream cluster. If not specified, the default is 3.
MaxRetries *wrapperspb.UInt32Value
// Specifies a limit on concurrent retries in relation to the number of active requests. This
// parameter is optional.
//
// .. note::
//
// If this field is set, the retry budget will override any configured retry circuit
// breaker.
RetryBudget *CircuitBreakers_Thresholds_RetryBudget
// If track_remaining is true, then stats will be published that expose
// the number of resources remaining until the circuit breakers open. If
// not specified, the default is false.
//
// .. note::
//
// If a retry budget is used in lieu of the max_retries circuit breaker,
// the remaining retry resources remaining will not be tracked.
TrackRemaining bool
// The maximum number of connection pools per cluster that Envoy will concurrently support at
// once. If not specified, the default is unlimited. Set this for clusters which create a
// large number of connection pools. See
// :ref:`Circuit Breaking <arch_overview_circuit_break_cluster_maximum_connection_pools>` for
// more details.
MaxConnectionPools *wrapperspb.UInt32Value
// contains filtered or unexported fields
}
func (CircuitBreakers_Thresholds_builder) Build ¶
func (b0 CircuitBreakers_Thresholds_builder) Build() *CircuitBreakers_Thresholds
type CircuitBreakers_builder ¶
type CircuitBreakers_builder struct {
// If multiple :ref:`Thresholds<envoy_api_msg_cluster.CircuitBreakers.Thresholds>`
// are defined with the same :ref:`RoutingPriority<envoy_api_enum_core.RoutingPriority>`,
// the first one in the list is used. If no Thresholds is defined for a given
// :ref:`RoutingPriority<envoy_api_enum_core.RoutingPriority>`, the default values
// are used.
Thresholds []*CircuitBreakers_Thresholds
// contains filtered or unexported fields
}
func (CircuitBreakers_builder) Build ¶
func (b0 CircuitBreakers_builder) Build() *CircuitBreakers
type Filter ¶
type Filter struct {
// The name of the filter to instantiate. The name must match a
// :ref:`supported filter <config_network_filters>`.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// Filter specific configuration which depends on the filter being
// instantiated. See the supported filters for further documentation.
TypedConfig *anypb.Any `protobuf:"bytes,2,opt,name=typed_config,json=typedConfig,proto3" json:"typed_config,omitempty"`
// contains filtered or unexported fields
}
func (*Filter) ProtoReflect ¶
func (x *Filter) ProtoReflect() protoreflect.Message
type Filter_builder ¶
type Filter_builder struct {
// The name of the filter to instantiate. The name must match a
// :ref:`supported filter <config_network_filters>`.
Name string
// Filter specific configuration which depends on the filter being
// instantiated. See the supported filters for further documentation.
TypedConfig *anypb.Any
// contains filtered or unexported fields
}
func (Filter_builder) Build ¶
func (b0 Filter_builder) Build() *Filter
type OutlierDetection ¶
type OutlierDetection struct {
// The number of consecutive server-side error responses (for HTTP traffic,
// 5xx responses; for TCP traffic, connection failures; for Redis, failure to
// respond PONG; etc.) before a consecutive 5xx ejection occurs. Defaults to 5.
Consecutive_5Xx *wrapperspb.UInt32Value `protobuf:"bytes,1,opt,name=consecutive_5xx,json=consecutive5xx,proto3" json:"consecutive_5xx,omitempty"`
// The time interval between ejection analysis sweeps. This can result in
// both new ejections as well as hosts being returned to service. Defaults
// to 10000ms or 10s.
Interval *durationpb.Duration `protobuf:"bytes,2,opt,name=interval,proto3" json:"interval,omitempty"`
// The base time that a host is ejected for. The real time is equal to the
// base time multiplied by the number of times the host has been ejected.
// Defaults to 30000ms or 30s.
BaseEjectionTime *durationpb.Duration `protobuf:"bytes,3,opt,name=base_ejection_time,json=baseEjectionTime,proto3" json:"base_ejection_time,omitempty"`
// The maximum % of an upstream cluster that can be ejected due to outlier
// detection. Defaults to 10% but will eject at least one host regardless of the value.
MaxEjectionPercent *wrapperspb.UInt32Value `protobuf:"bytes,4,opt,name=max_ejection_percent,json=maxEjectionPercent,proto3" json:"max_ejection_percent,omitempty"`
// The % chance that a host will be actually ejected when an outlier status
// is detected through consecutive 5xx. This setting can be used to disable
// ejection or to ramp it up slowly. Defaults to 100.
EnforcingConsecutive_5Xx *wrapperspb.UInt32Value `` /* 132-byte string literal not displayed */
// The % chance that a host will be actually ejected when an outlier status
// is detected through success rate statistics. This setting can be used to
// disable ejection or to ramp it up slowly. Defaults to 100.
EnforcingSuccessRate *wrapperspb.UInt32Value `protobuf:"bytes,6,opt,name=enforcing_success_rate,json=enforcingSuccessRate,proto3" json:"enforcing_success_rate,omitempty"`
// The number of hosts in a cluster that must have enough request volume to
// detect success rate outliers. If the number of hosts is less than this
// setting, outlier detection via success rate statistics is not performed
// for any host in the cluster. Defaults to 5.
SuccessRateMinimumHosts *wrapperspb.UInt32Value `` /* 134-byte string literal not displayed */
// The minimum number of total requests that must be collected in one
// interval (as defined by the interval duration above) to include this host
// in success rate based outlier detection. If the volume is lower than this
// setting, outlier detection via success rate statistics is not performed
// for that host. Defaults to 100.
SuccessRateRequestVolume *wrapperspb.UInt32Value `` /* 137-byte string literal not displayed */
// This factor is used to determine the ejection threshold for success rate
// outlier ejection. The ejection threshold is the difference between the
// mean success rate, and the product of this factor and the standard
// deviation of the mean success rate: mean - (stdev *
// success_rate_stdev_factor). This factor is divided by a thousand to get a
// double. That is, if the desired factor is 1.9, the runtime value should
// be 1900. Defaults to 1900.
SuccessRateStdevFactor *wrapperspb.UInt32Value `` /* 131-byte string literal not displayed */
// The number of consecutive gateway failures (502, 503, 504 status codes)
// before a consecutive gateway failure ejection occurs. Defaults to 5.
ConsecutiveGatewayFailure *wrapperspb.UInt32Value `` /* 139-byte string literal not displayed */
// The % chance that a host will be actually ejected when an outlier status
// is detected through consecutive gateway failures. This setting can be
// used to disable ejection or to ramp it up slowly. Defaults to 0.
EnforcingConsecutiveGatewayFailure *wrapperspb.UInt32Value `` /* 168-byte string literal not displayed */
// Determines whether to distinguish local origin failures from external errors. If set to true
// the following configuration parameters are taken into account:
// :ref:`consecutive_local_origin_failure<envoy_api_field_cluster.OutlierDetection.consecutive_local_origin_failure>`,
// :ref:`enforcing_consecutive_local_origin_failure<envoy_api_field_cluster.OutlierDetection.enforcing_consecutive_local_origin_failure>`
// and
// :ref:`enforcing_local_origin_success_rate<envoy_api_field_cluster.OutlierDetection.enforcing_local_origin_success_rate>`.
// Defaults to false.
SplitExternalLocalOriginErrors bool `` /* 159-byte string literal not displayed */
// The number of consecutive locally originated failures before ejection
// occurs. Defaults to 5. Parameter takes effect only when
// :ref:`split_external_local_origin_errors<envoy_api_field_cluster.OutlierDetection.split_external_local_origin_errors>`
// is set to true.
ConsecutiveLocalOriginFailure *wrapperspb.UInt32Value `` /* 153-byte string literal not displayed */
// The % chance that a host will be actually ejected when an outlier status
// is detected through consecutive locally originated failures. This setting can be
// used to disable ejection or to ramp it up slowly. Defaults to 100.
// Parameter takes effect only when
// :ref:`split_external_local_origin_errors<envoy_api_field_cluster.OutlierDetection.split_external_local_origin_errors>`
// is set to true.
EnforcingConsecutiveLocalOriginFailure *wrapperspb.UInt32Value `` /* 182-byte string literal not displayed */
// The % chance that a host will be actually ejected when an outlier status
// is detected through success rate statistics for locally originated errors.
// This setting can be used to disable ejection or to ramp it up slowly. Defaults to 100.
// Parameter takes effect only when
// :ref:`split_external_local_origin_errors<envoy_api_field_cluster.OutlierDetection.split_external_local_origin_errors>`
// is set to true.
EnforcingLocalOriginSuccessRate *wrapperspb.UInt32Value `` /* 161-byte string literal not displayed */
// The failure percentage to use when determining failure percentage-based outlier detection. If
// the failure percentage of a given host is greater than or equal to this value, it will be
// ejected. Defaults to 85.
FailurePercentageThreshold *wrapperspb.UInt32Value `` /* 142-byte string literal not displayed */
// The % chance that a host will be actually ejected when an outlier status is detected through
// failure percentage statistics. This setting can be used to disable ejection or to ramp it up
// slowly. Defaults to 0.
//
// [#next-major-version: setting this without setting failure_percentage_threshold should be
// invalid in v4.]
EnforcingFailurePercentage *wrapperspb.UInt32Value `` /* 142-byte string literal not displayed */
// The % chance that a host will be actually ejected when an outlier status is detected through
// local-origin failure percentage statistics. This setting can be used to disable ejection or to
// ramp it up slowly. Defaults to 0.
EnforcingFailurePercentageLocalOrigin *wrapperspb.UInt32Value `` /* 179-byte string literal not displayed */
// The minimum number of hosts in a cluster in order to perform failure percentage-based ejection.
// If the total number of hosts in the cluster is less than this value, failure percentage-based
// ejection will not be performed. Defaults to 5.
FailurePercentageMinimumHosts *wrapperspb.UInt32Value `` /* 153-byte string literal not displayed */
// The minimum number of total requests that must be collected in one interval (as defined by the
// interval duration above) to perform failure percentage-based ejection for this host. If the
// volume is lower than this setting, failure percentage-based ejection will not be performed for
// this host. Defaults to 50.
FailurePercentageRequestVolume *wrapperspb.UInt32Value `` /* 156-byte string literal not displayed */
// contains filtered or unexported fields
}
See the :ref:`architecture overview <arch_overview_outlier_detection>` for more information on outlier detection. [#next-free-field: 21]
func (*OutlierDetection) ClearBaseEjectionTime ¶
func (x *OutlierDetection) ClearBaseEjectionTime()
func (*OutlierDetection) ClearConsecutiveGatewayFailure ¶
func (x *OutlierDetection) ClearConsecutiveGatewayFailure()
func (*OutlierDetection) ClearConsecutiveLocalOriginFailure ¶
func (x *OutlierDetection) ClearConsecutiveLocalOriginFailure()
func (*OutlierDetection) ClearConsecutive_5Xx ¶
func (x *OutlierDetection) ClearConsecutive_5Xx()
func (*OutlierDetection) ClearEnforcingConsecutiveGatewayFailure ¶
func (x *OutlierDetection) ClearEnforcingConsecutiveGatewayFailure()
func (*OutlierDetection) ClearEnforcingConsecutiveLocalOriginFailure ¶
func (x *OutlierDetection) ClearEnforcingConsecutiveLocalOriginFailure()
func (*OutlierDetection) ClearEnforcingConsecutive_5Xx ¶
func (x *OutlierDetection) ClearEnforcingConsecutive_5Xx()
func (*OutlierDetection) ClearEnforcingFailurePercentage ¶
func (x *OutlierDetection) ClearEnforcingFailurePercentage()
func (*OutlierDetection) ClearEnforcingFailurePercentageLocalOrigin ¶
func (x *OutlierDetection) ClearEnforcingFailurePercentageLocalOrigin()
func (*OutlierDetection) ClearEnforcingLocalOriginSuccessRate ¶
func (x *OutlierDetection) ClearEnforcingLocalOriginSuccessRate()
func (*OutlierDetection) ClearEnforcingSuccessRate ¶
func (x *OutlierDetection) ClearEnforcingSuccessRate()
func (*OutlierDetection) ClearFailurePercentageMinimumHosts ¶
func (x *OutlierDetection) ClearFailurePercentageMinimumHosts()
func (*OutlierDetection) ClearFailurePercentageRequestVolume ¶
func (x *OutlierDetection) ClearFailurePercentageRequestVolume()
func (*OutlierDetection) ClearFailurePercentageThreshold ¶
func (x *OutlierDetection) ClearFailurePercentageThreshold()
func (*OutlierDetection) ClearInterval ¶
func (x *OutlierDetection) ClearInterval()
func (*OutlierDetection) ClearMaxEjectionPercent ¶
func (x *OutlierDetection) ClearMaxEjectionPercent()
func (*OutlierDetection) ClearSuccessRateMinimumHosts ¶
func (x *OutlierDetection) ClearSuccessRateMinimumHosts()
func (*OutlierDetection) ClearSuccessRateRequestVolume ¶
func (x *OutlierDetection) ClearSuccessRateRequestVolume()
func (*OutlierDetection) ClearSuccessRateStdevFactor ¶
func (x *OutlierDetection) ClearSuccessRateStdevFactor()
func (*OutlierDetection) GetBaseEjectionTime ¶
func (x *OutlierDetection) GetBaseEjectionTime() *durationpb.Duration
func (*OutlierDetection) GetConsecutiveGatewayFailure ¶
func (x *OutlierDetection) GetConsecutiveGatewayFailure() *wrapperspb.UInt32Value
func (*OutlierDetection) GetConsecutiveLocalOriginFailure ¶
func (x *OutlierDetection) GetConsecutiveLocalOriginFailure() *wrapperspb.UInt32Value
func (*OutlierDetection) GetConsecutive_5Xx ¶
func (x *OutlierDetection) GetConsecutive_5Xx() *wrapperspb.UInt32Value
func (*OutlierDetection) GetEnforcingConsecutiveGatewayFailure ¶
func (x *OutlierDetection) GetEnforcingConsecutiveGatewayFailure() *wrapperspb.UInt32Value
func (*OutlierDetection) GetEnforcingConsecutiveLocalOriginFailure ¶
func (x *OutlierDetection) GetEnforcingConsecutiveLocalOriginFailure() *wrapperspb.UInt32Value
func (*OutlierDetection) GetEnforcingConsecutive_5Xx ¶
func (x *OutlierDetection) GetEnforcingConsecutive_5Xx() *wrapperspb.UInt32Value
func (*OutlierDetection) GetEnforcingFailurePercentage ¶
func (x *OutlierDetection) GetEnforcingFailurePercentage() *wrapperspb.UInt32Value
func (*OutlierDetection) GetEnforcingFailurePercentageLocalOrigin ¶
func (x *OutlierDetection) GetEnforcingFailurePercentageLocalOrigin() *wrapperspb.UInt32Value
func (*OutlierDetection) GetEnforcingLocalOriginSuccessRate ¶
func (x *OutlierDetection) GetEnforcingLocalOriginSuccessRate() *wrapperspb.UInt32Value
func (*OutlierDetection) GetEnforcingSuccessRate ¶
func (x *OutlierDetection) GetEnforcingSuccessRate() *wrapperspb.UInt32Value
func (*OutlierDetection) GetFailurePercentageMinimumHosts ¶
func (x *OutlierDetection) GetFailurePercentageMinimumHosts() *wrapperspb.UInt32Value
func (*OutlierDetection) GetFailurePercentageRequestVolume ¶
func (x *OutlierDetection) GetFailurePercentageRequestVolume() *wrapperspb.UInt32Value
func (*OutlierDetection) GetFailurePercentageThreshold ¶
func (x *OutlierDetection) GetFailurePercentageThreshold() *wrapperspb.UInt32Value
func (*OutlierDetection) GetInterval ¶
func (x *OutlierDetection) GetInterval() *durationpb.Duration
func (*OutlierDetection) GetMaxEjectionPercent ¶
func (x *OutlierDetection) GetMaxEjectionPercent() *wrapperspb.UInt32Value
func (*OutlierDetection) GetSplitExternalLocalOriginErrors ¶
func (x *OutlierDetection) GetSplitExternalLocalOriginErrors() bool
func (*OutlierDetection) GetSuccessRateMinimumHosts ¶
func (x *OutlierDetection) GetSuccessRateMinimumHosts() *wrapperspb.UInt32Value
func (*OutlierDetection) GetSuccessRateRequestVolume ¶
func (x *OutlierDetection) GetSuccessRateRequestVolume() *wrapperspb.UInt32Value
func (*OutlierDetection) GetSuccessRateStdevFactor ¶
func (x *OutlierDetection) GetSuccessRateStdevFactor() *wrapperspb.UInt32Value
func (*OutlierDetection) HasBaseEjectionTime ¶
func (x *OutlierDetection) HasBaseEjectionTime() bool
func (*OutlierDetection) HasConsecutiveGatewayFailure ¶
func (x *OutlierDetection) HasConsecutiveGatewayFailure() bool
func (*OutlierDetection) HasConsecutiveLocalOriginFailure ¶
func (x *OutlierDetection) HasConsecutiveLocalOriginFailure() bool
func (*OutlierDetection) HasConsecutive_5Xx ¶
func (x *OutlierDetection) HasConsecutive_5Xx() bool
func (*OutlierDetection) HasEnforcingConsecutiveGatewayFailure ¶
func (x *OutlierDetection) HasEnforcingConsecutiveGatewayFailure() bool
func (*OutlierDetection) HasEnforcingConsecutiveLocalOriginFailure ¶
func (x *OutlierDetection) HasEnforcingConsecutiveLocalOriginFailure() bool
func (*OutlierDetection) HasEnforcingConsecutive_5Xx ¶
func (x *OutlierDetection) HasEnforcingConsecutive_5Xx() bool
func (*OutlierDetection) HasEnforcingFailurePercentage ¶
func (x *OutlierDetection) HasEnforcingFailurePercentage() bool
func (*OutlierDetection) HasEnforcingFailurePercentageLocalOrigin ¶
func (x *OutlierDetection) HasEnforcingFailurePercentageLocalOrigin() bool
func (*OutlierDetection) HasEnforcingLocalOriginSuccessRate ¶
func (x *OutlierDetection) HasEnforcingLocalOriginSuccessRate() bool
func (*OutlierDetection) HasEnforcingSuccessRate ¶
func (x *OutlierDetection) HasEnforcingSuccessRate() bool
func (*OutlierDetection) HasFailurePercentageMinimumHosts ¶
func (x *OutlierDetection) HasFailurePercentageMinimumHosts() bool
func (*OutlierDetection) HasFailurePercentageRequestVolume ¶
func (x *OutlierDetection) HasFailurePercentageRequestVolume() bool
func (*OutlierDetection) HasFailurePercentageThreshold ¶
func (x *OutlierDetection) HasFailurePercentageThreshold() bool
func (*OutlierDetection) HasInterval ¶
func (x *OutlierDetection) HasInterval() bool
func (*OutlierDetection) HasMaxEjectionPercent ¶
func (x *OutlierDetection) HasMaxEjectionPercent() bool
func (*OutlierDetection) HasSuccessRateMinimumHosts ¶
func (x *OutlierDetection) HasSuccessRateMinimumHosts() bool
func (*OutlierDetection) HasSuccessRateRequestVolume ¶
func (x *OutlierDetection) HasSuccessRateRequestVolume() bool
func (*OutlierDetection) HasSuccessRateStdevFactor ¶
func (x *OutlierDetection) HasSuccessRateStdevFactor() bool
func (*OutlierDetection) ProtoMessage ¶
func (*OutlierDetection) ProtoMessage()
func (*OutlierDetection) ProtoReflect ¶
func (x *OutlierDetection) ProtoReflect() protoreflect.Message
func (*OutlierDetection) Reset ¶
func (x *OutlierDetection) Reset()
func (*OutlierDetection) SetBaseEjectionTime ¶
func (x *OutlierDetection) SetBaseEjectionTime(v *durationpb.Duration)
func (*OutlierDetection) SetConsecutiveGatewayFailure ¶
func (x *OutlierDetection) SetConsecutiveGatewayFailure(v *wrapperspb.UInt32Value)
func (*OutlierDetection) SetConsecutiveLocalOriginFailure ¶
func (x *OutlierDetection) SetConsecutiveLocalOriginFailure(v *wrapperspb.UInt32Value)
func (*OutlierDetection) SetConsecutive_5Xx ¶
func (x *OutlierDetection) SetConsecutive_5Xx(v *wrapperspb.UInt32Value)
func (*OutlierDetection) SetEnforcingConsecutiveGatewayFailure ¶
func (x *OutlierDetection) SetEnforcingConsecutiveGatewayFailure(v *wrapperspb.UInt32Value)
func (*OutlierDetection) SetEnforcingConsecutiveLocalOriginFailure ¶
func (x *OutlierDetection) SetEnforcingConsecutiveLocalOriginFailure(v *wrapperspb.UInt32Value)
func (*OutlierDetection) SetEnforcingConsecutive_5Xx ¶
func (x *OutlierDetection) SetEnforcingConsecutive_5Xx(v *wrapperspb.UInt32Value)
func (*OutlierDetection) SetEnforcingFailurePercentage ¶
func (x *OutlierDetection) SetEnforcingFailurePercentage(v *wrapperspb.UInt32Value)
func (*OutlierDetection) SetEnforcingFailurePercentageLocalOrigin ¶
func (x *OutlierDetection) SetEnforcingFailurePercentageLocalOrigin(v *wrapperspb.UInt32Value)
func (*OutlierDetection) SetEnforcingLocalOriginSuccessRate ¶
func (x *OutlierDetection) SetEnforcingLocalOriginSuccessRate(v *wrapperspb.UInt32Value)
func (*OutlierDetection) SetEnforcingSuccessRate ¶
func (x *OutlierDetection) SetEnforcingSuccessRate(v *wrapperspb.UInt32Value)
func (*OutlierDetection) SetFailurePercentageMinimumHosts ¶
func (x *OutlierDetection) SetFailurePercentageMinimumHosts(v *wrapperspb.UInt32Value)
func (*OutlierDetection) SetFailurePercentageRequestVolume ¶
func (x *OutlierDetection) SetFailurePercentageRequestVolume(v *wrapperspb.UInt32Value)
func (*OutlierDetection) SetFailurePercentageThreshold ¶
func (x *OutlierDetection) SetFailurePercentageThreshold(v *wrapperspb.UInt32Value)
func (*OutlierDetection) SetInterval ¶
func (x *OutlierDetection) SetInterval(v *durationpb.Duration)
func (*OutlierDetection) SetMaxEjectionPercent ¶
func (x *OutlierDetection) SetMaxEjectionPercent(v *wrapperspb.UInt32Value)
func (*OutlierDetection) SetSplitExternalLocalOriginErrors ¶
func (x *OutlierDetection) SetSplitExternalLocalOriginErrors(v bool)
func (*OutlierDetection) SetSuccessRateMinimumHosts ¶
func (x *OutlierDetection) SetSuccessRateMinimumHosts(v *wrapperspb.UInt32Value)
func (*OutlierDetection) SetSuccessRateRequestVolume ¶
func (x *OutlierDetection) SetSuccessRateRequestVolume(v *wrapperspb.UInt32Value)
func (*OutlierDetection) SetSuccessRateStdevFactor ¶
func (x *OutlierDetection) SetSuccessRateStdevFactor(v *wrapperspb.UInt32Value)
func (*OutlierDetection) String ¶
func (x *OutlierDetection) String() string
type OutlierDetection_builder ¶
type OutlierDetection_builder struct {
// The number of consecutive server-side error responses (for HTTP traffic,
// 5xx responses; for TCP traffic, connection failures; for Redis, failure to
// respond PONG; etc.) before a consecutive 5xx ejection occurs. Defaults to 5.
Consecutive_5Xx *wrapperspb.UInt32Value
// The time interval between ejection analysis sweeps. This can result in
// both new ejections as well as hosts being returned to service. Defaults
// to 10000ms or 10s.
Interval *durationpb.Duration
// The base time that a host is ejected for. The real time is equal to the
// base time multiplied by the number of times the host has been ejected.
// Defaults to 30000ms or 30s.
BaseEjectionTime *durationpb.Duration
// The maximum % of an upstream cluster that can be ejected due to outlier
// detection. Defaults to 10% but will eject at least one host regardless of the value.
MaxEjectionPercent *wrapperspb.UInt32Value
// The % chance that a host will be actually ejected when an outlier status
// is detected through consecutive 5xx. This setting can be used to disable
// ejection or to ramp it up slowly. Defaults to 100.
EnforcingConsecutive_5Xx *wrapperspb.UInt32Value
// The % chance that a host will be actually ejected when an outlier status
// is detected through success rate statistics. This setting can be used to
// disable ejection or to ramp it up slowly. Defaults to 100.
EnforcingSuccessRate *wrapperspb.UInt32Value
// The number of hosts in a cluster that must have enough request volume to
// detect success rate outliers. If the number of hosts is less than this
// setting, outlier detection via success rate statistics is not performed
// for any host in the cluster. Defaults to 5.
SuccessRateMinimumHosts *wrapperspb.UInt32Value
// The minimum number of total requests that must be collected in one
// interval (as defined by the interval duration above) to include this host
// in success rate based outlier detection. If the volume is lower than this
// setting, outlier detection via success rate statistics is not performed
// for that host. Defaults to 100.
SuccessRateRequestVolume *wrapperspb.UInt32Value
// This factor is used to determine the ejection threshold for success rate
// outlier ejection. The ejection threshold is the difference between the
// mean success rate, and the product of this factor and the standard
// deviation of the mean success rate: mean - (stdev *
// success_rate_stdev_factor). This factor is divided by a thousand to get a
// double. That is, if the desired factor is 1.9, the runtime value should
// be 1900. Defaults to 1900.
SuccessRateStdevFactor *wrapperspb.UInt32Value
// The number of consecutive gateway failures (502, 503, 504 status codes)
// before a consecutive gateway failure ejection occurs. Defaults to 5.
ConsecutiveGatewayFailure *wrapperspb.UInt32Value
// The % chance that a host will be actually ejected when an outlier status
// is detected through consecutive gateway failures. This setting can be
// used to disable ejection or to ramp it up slowly. Defaults to 0.
EnforcingConsecutiveGatewayFailure *wrapperspb.UInt32Value
// Determines whether to distinguish local origin failures from external errors. If set to true
// the following configuration parameters are taken into account:
// :ref:`consecutive_local_origin_failure<envoy_api_field_cluster.OutlierDetection.consecutive_local_origin_failure>`,
// :ref:`enforcing_consecutive_local_origin_failure<envoy_api_field_cluster.OutlierDetection.enforcing_consecutive_local_origin_failure>`
// and
// :ref:`enforcing_local_origin_success_rate<envoy_api_field_cluster.OutlierDetection.enforcing_local_origin_success_rate>`.
// Defaults to false.
SplitExternalLocalOriginErrors bool
// The number of consecutive locally originated failures before ejection
// occurs. Defaults to 5. Parameter takes effect only when
// :ref:`split_external_local_origin_errors<envoy_api_field_cluster.OutlierDetection.split_external_local_origin_errors>`
// is set to true.
ConsecutiveLocalOriginFailure *wrapperspb.UInt32Value
// The % chance that a host will be actually ejected when an outlier status
// is detected through consecutive locally originated failures. This setting can be
// used to disable ejection or to ramp it up slowly. Defaults to 100.
// Parameter takes effect only when
// :ref:`split_external_local_origin_errors<envoy_api_field_cluster.OutlierDetection.split_external_local_origin_errors>`
// is set to true.
EnforcingConsecutiveLocalOriginFailure *wrapperspb.UInt32Value
// The % chance that a host will be actually ejected when an outlier status
// is detected through success rate statistics for locally originated errors.
// This setting can be used to disable ejection or to ramp it up slowly. Defaults to 100.
// Parameter takes effect only when
// :ref:`split_external_local_origin_errors<envoy_api_field_cluster.OutlierDetection.split_external_local_origin_errors>`
// is set to true.
EnforcingLocalOriginSuccessRate *wrapperspb.UInt32Value
// The failure percentage to use when determining failure percentage-based outlier detection. If
// the failure percentage of a given host is greater than or equal to this value, it will be
// ejected. Defaults to 85.
FailurePercentageThreshold *wrapperspb.UInt32Value
// The % chance that a host will be actually ejected when an outlier status is detected through
// failure percentage statistics. This setting can be used to disable ejection or to ramp it up
// slowly. Defaults to 0.
//
// [#next-major-version: setting this without setting failure_percentage_threshold should be
// invalid in v4.]
EnforcingFailurePercentage *wrapperspb.UInt32Value
// The % chance that a host will be actually ejected when an outlier status is detected through
// local-origin failure percentage statistics. This setting can be used to disable ejection or to
// ramp it up slowly. Defaults to 0.
EnforcingFailurePercentageLocalOrigin *wrapperspb.UInt32Value
// The minimum number of hosts in a cluster in order to perform failure percentage-based ejection.
// If the total number of hosts in the cluster is less than this value, failure percentage-based
// ejection will not be performed. Defaults to 5.
FailurePercentageMinimumHosts *wrapperspb.UInt32Value
// The minimum number of total requests that must be collected in one interval (as defined by the
// interval duration above) to perform failure percentage-based ejection for this host. If the
// volume is lower than this setting, failure percentage-based ejection will not be performed for
// this host. Defaults to 50.
FailurePercentageRequestVolume *wrapperspb.UInt32Value
// contains filtered or unexported fields
}
func (OutlierDetection_builder) Build ¶
func (b0 OutlierDetection_builder) Build() *OutlierDetection
Source Files
¶
- circuit_breaker.pb.go
- filter.pb.go
- outlier_detection.pb.go
Click to show internal directories.
Click to hide internal directories.