Documentation
¶
Index ¶
- Variables
- type ClusterConfig
- func (x *ClusterConfig) ClearDnsCacheConfig()
- func (x *ClusterConfig) GetDnsCacheConfig() *v2alpha.DnsCacheConfig
- func (x *ClusterConfig) HasDnsCacheConfig() bool
- func (*ClusterConfig) ProtoMessage()
- func (x *ClusterConfig) ProtoReflect() protoreflect.Message
- func (x *ClusterConfig) Reset()
- func (x *ClusterConfig) SetDnsCacheConfig(v *v2alpha.DnsCacheConfig)
- func (x *ClusterConfig) String() string
- type ClusterConfig_builder
Constants ¶
This section is empty.
Variables ¶
var File_envoy_config_cluster_dynamic_forward_proxy_v2alpha_cluster_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type ClusterConfig ¶
type ClusterConfig struct {
// The DNS cache configuration that the cluster will attach to. Note this configuration must
// match that of associated :ref:`dynamic forward proxy HTTP filter configuration
// <envoy_api_field_config.filter.http.dynamic_forward_proxy.v2alpha.FilterConfig.dns_cache_config>`.
DnsCacheConfig *v2alpha.DnsCacheConfig `protobuf:"bytes,1,opt,name=dns_cache_config,json=dnsCacheConfig,proto3" json:"dns_cache_config,omitempty"`
// contains filtered or unexported fields
}
Configuration for the dynamic forward proxy cluster. See the :ref:`architecture overview <arch_overview_http_dynamic_forward_proxy>` for more information. [#extension: envoy.clusters.dynamic_forward_proxy]
func (*ClusterConfig) ClearDnsCacheConfig ¶
func (x *ClusterConfig) ClearDnsCacheConfig()
func (*ClusterConfig) GetDnsCacheConfig ¶
func (x *ClusterConfig) GetDnsCacheConfig() *v2alpha.DnsCacheConfig
func (*ClusterConfig) HasDnsCacheConfig ¶
func (x *ClusterConfig) HasDnsCacheConfig() bool
func (*ClusterConfig) ProtoMessage ¶
func (*ClusterConfig) ProtoMessage()
func (*ClusterConfig) ProtoReflect ¶
func (x *ClusterConfig) ProtoReflect() protoreflect.Message
func (*ClusterConfig) Reset ¶
func (x *ClusterConfig) Reset()
func (*ClusterConfig) SetDnsCacheConfig ¶
func (x *ClusterConfig) SetDnsCacheConfig(v *v2alpha.DnsCacheConfig)
func (*ClusterConfig) String ¶
func (x *ClusterConfig) String() string
type ClusterConfig_builder ¶
type ClusterConfig_builder struct {
// The DNS cache configuration that the cluster will attach to. Note this configuration must
// match that of associated :ref:`dynamic forward proxy HTTP filter configuration
// <envoy_api_field_config.filter.http.dynamic_forward_proxy.v2alpha.FilterConfig.dns_cache_config>`.
DnsCacheConfig *v2alpha.DnsCacheConfig
// contains filtered or unexported fields
}
func (ClusterConfig_builder) Build ¶
func (b0 ClusterConfig_builder) Build() *ClusterConfig
Source Files
¶
- cluster.pb.go
Click to show internal directories.
Click to hide internal directories.