Documentation
¶
Index ¶
- Variables
- type AwsRequestSigning
- func (x *AwsRequestSigning) GetHostRewrite() string
- func (x *AwsRequestSigning) GetRegion() string
- func (x *AwsRequestSigning) GetServiceName() string
- func (*AwsRequestSigning) ProtoMessage()
- func (x *AwsRequestSigning) ProtoReflect() protoreflect.Message
- func (x *AwsRequestSigning) Reset()
- func (x *AwsRequestSigning) SetHostRewrite(v string)
- func (x *AwsRequestSigning) SetRegion(v string)
- func (x *AwsRequestSigning) SetServiceName(v string)
- func (x *AwsRequestSigning) String() string
- type AwsRequestSigning_builder
Constants ¶
This section is empty.
Variables ¶
var File_envoy_config_filter_http_aws_request_signing_v2alpha_aws_request_signing_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type AwsRequestSigning ¶
type AwsRequestSigning struct {
// The `service namespace
// <https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html#genref-aws-service-namespaces>`_
// of the HTTP endpoint.
//
// Example: s3
ServiceName string `protobuf:"bytes,1,opt,name=service_name,json=serviceName,proto3" json:"service_name,omitempty"`
// The `region <https://docs.aws.amazon.com/general/latest/gr/rande.html>`_ hosting the HTTP
// endpoint.
//
// Example: us-west-2
Region string `protobuf:"bytes,2,opt,name=region,proto3" json:"region,omitempty"`
// Indicates that before signing headers, the host header will be swapped with
// this value. If not set or empty, the original host header value
// will be used and no rewrite will happen.
//
// Note: this rewrite affects both signing and host header forwarding. However, this
// option shouldn't be used with
// :ref:`HCM host rewrite <envoy_api_field_route.RouteAction.host_rewrite>` given that the
// value set here would be used for signing whereas the value set in the HCM would be used
// for host header forwarding which is not the desired outcome.
HostRewrite string `protobuf:"bytes,3,opt,name=host_rewrite,json=hostRewrite,proto3" json:"host_rewrite,omitempty"`
// contains filtered or unexported fields
}
Top level configuration for the AWS request signing filter.
func (*AwsRequestSigning) GetHostRewrite ¶
func (x *AwsRequestSigning) GetHostRewrite() string
func (*AwsRequestSigning) GetRegion ¶
func (x *AwsRequestSigning) GetRegion() string
func (*AwsRequestSigning) GetServiceName ¶
func (x *AwsRequestSigning) GetServiceName() string
func (*AwsRequestSigning) ProtoMessage ¶
func (*AwsRequestSigning) ProtoMessage()
func (*AwsRequestSigning) ProtoReflect ¶
func (x *AwsRequestSigning) ProtoReflect() protoreflect.Message
func (*AwsRequestSigning) Reset ¶
func (x *AwsRequestSigning) Reset()
func (*AwsRequestSigning) SetHostRewrite ¶
func (x *AwsRequestSigning) SetHostRewrite(v string)
func (*AwsRequestSigning) SetRegion ¶
func (x *AwsRequestSigning) SetRegion(v string)
func (*AwsRequestSigning) SetServiceName ¶
func (x *AwsRequestSigning) SetServiceName(v string)
func (*AwsRequestSigning) String ¶
func (x *AwsRequestSigning) String() string
type AwsRequestSigning_builder ¶
type AwsRequestSigning_builder struct {
// The `service namespace
// <https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html#genref-aws-service-namespaces>`_
// of the HTTP endpoint.
//
// Example: s3
ServiceName string
// The `region <https://docs.aws.amazon.com/general/latest/gr/rande.html>`_ hosting the HTTP
// endpoint.
//
// Example: us-west-2
Region string
// Indicates that before signing headers, the host header will be swapped with
// this value. If not set or empty, the original host header value
// will be used and no rewrite will happen.
//
// Note: this rewrite affects both signing and host header forwarding. However, this
// option shouldn't be used with
// :ref:`HCM host rewrite <envoy_api_field_route.RouteAction.host_rewrite>` given that the
// value set here would be used for signing whereas the value set in the HCM would be used
// for host header forwarding which is not the desired outcome.
HostRewrite string
// contains filtered or unexported fields
}
func (AwsRequestSigning_builder) Build ¶
func (b0 AwsRequestSigning_builder) Build() *AwsRequestSigning
Source Files
¶
- aws_request_signing.pb.go
Click to show internal directories.
Click to hide internal directories.