bufferv2

package
v1.36.11-2026042420273... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

const BufferPerRoute_Buffer_case case_BufferPerRoute_Override = 2
const BufferPerRoute_Disabled_case case_BufferPerRoute_Override = 1
const BufferPerRoute_Override_not_set_case case_BufferPerRoute_Override = 0

Variables

var File_envoy_config_filter_http_buffer_v2_buffer_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type Buffer

type Buffer struct {

	// The maximum request size that the filter will buffer before the connection
	// manager will stop buffering and return a 413 response.
	MaxRequestBytes *wrapperspb.UInt32Value `protobuf:"bytes,1,opt,name=max_request_bytes,json=maxRequestBytes,proto3" json:"max_request_bytes,omitempty"`
	// contains filtered or unexported fields
}

func (*Buffer) ClearMaxRequestBytes

func (x *Buffer) ClearMaxRequestBytes()

func (*Buffer) GetMaxRequestBytes

func (x *Buffer) GetMaxRequestBytes() *wrapperspb.UInt32Value

func (*Buffer) HasMaxRequestBytes

func (x *Buffer) HasMaxRequestBytes() bool

func (*Buffer) ProtoMessage

func (*Buffer) ProtoMessage()

func (*Buffer) ProtoReflect

func (x *Buffer) ProtoReflect() protoreflect.Message

func (*Buffer) Reset

func (x *Buffer) Reset()

func (*Buffer) SetMaxRequestBytes

func (x *Buffer) SetMaxRequestBytes(v *wrapperspb.UInt32Value)

func (*Buffer) String

func (x *Buffer) String() string

type BufferPerRoute

type BufferPerRoute struct {

	// Types that are valid to be assigned to Override:
	//
	//	*BufferPerRoute_Disabled
	//	*BufferPerRoute_Buffer
	Override isBufferPerRoute_Override `protobuf_oneof:"override"`
	// contains filtered or unexported fields
}

func (*BufferPerRoute) ClearBuffer

func (x *BufferPerRoute) ClearBuffer()

func (*BufferPerRoute) ClearDisabled

func (x *BufferPerRoute) ClearDisabled()

func (*BufferPerRoute) ClearOverride

func (x *BufferPerRoute) ClearOverride()

func (*BufferPerRoute) GetBuffer

func (x *BufferPerRoute) GetBuffer() *Buffer

func (*BufferPerRoute) GetDisabled

func (x *BufferPerRoute) GetDisabled() bool

func (*BufferPerRoute) GetOverride

func (x *BufferPerRoute) GetOverride() isBufferPerRoute_Override

func (*BufferPerRoute) HasBuffer

func (x *BufferPerRoute) HasBuffer() bool

func (*BufferPerRoute) HasDisabled

func (x *BufferPerRoute) HasDisabled() bool

func (*BufferPerRoute) HasOverride

func (x *BufferPerRoute) HasOverride() bool

func (*BufferPerRoute) ProtoMessage

func (*BufferPerRoute) ProtoMessage()

func (*BufferPerRoute) ProtoReflect

func (x *BufferPerRoute) ProtoReflect() protoreflect.Message

func (*BufferPerRoute) Reset

func (x *BufferPerRoute) Reset()

func (*BufferPerRoute) SetBuffer

func (x *BufferPerRoute) SetBuffer(v *Buffer)

func (*BufferPerRoute) SetDisabled

func (x *BufferPerRoute) SetDisabled(v bool)

func (*BufferPerRoute) String

func (x *BufferPerRoute) String() string

func (*BufferPerRoute) WhichOverride

func (x *BufferPerRoute) WhichOverride() case_BufferPerRoute_Override

type BufferPerRoute_Buffer

type BufferPerRoute_Buffer struct {
	// Override the global configuration of the filter with this new config.
	Buffer *Buffer `protobuf:"bytes,2,opt,name=buffer,proto3,oneof"`
}

type BufferPerRoute_Disabled

type BufferPerRoute_Disabled struct {
	// Disable the buffer filter for this particular vhost or route.
	Disabled bool `protobuf:"varint,1,opt,name=disabled,proto3,oneof"`
}

type BufferPerRoute_builder

type BufferPerRoute_builder struct {

	// Fields of oneof Override:
	// Disable the buffer filter for this particular vhost or route.
	Disabled *bool
	// Override the global configuration of the filter with this new config.
	Buffer *Buffer
	// contains filtered or unexported fields
}

func (BufferPerRoute_builder) Build

type Buffer_builder

type Buffer_builder struct {

	// The maximum request size that the filter will buffer before the connection
	// manager will stop buffering and return a 413 response.
	MaxRequestBytes *wrapperspb.UInt32Value
	// contains filtered or unexported fields
}

func (Buffer_builder) Build

func (b0 Buffer_builder) Build() *Buffer

Source Files

  • buffer.pb.go

Jump to