Documentation
¶
Index ¶
- Variables
- type Compressor
- func (x *Compressor) ClearContentLength()
- func (x *Compressor) ClearRuntimeEnabled()
- func (x *Compressor) GetContentLength() *wrapperspb.UInt32Value
- func (x *Compressor) GetContentType() []string
- func (x *Compressor) GetDisableOnEtagHeader() bool
- func (x *Compressor) GetRemoveAcceptEncodingHeader() bool
- func (x *Compressor) GetRuntimeEnabled() *core.RuntimeFeatureFlag
- func (x *Compressor) HasContentLength() bool
- func (x *Compressor) HasRuntimeEnabled() bool
- func (*Compressor) ProtoMessage()
- func (x *Compressor) ProtoReflect() protoreflect.Message
- func (x *Compressor) Reset()
- func (x *Compressor) SetContentLength(v *wrapperspb.UInt32Value)
- func (x *Compressor) SetContentType(v []string)
- func (x *Compressor) SetDisableOnEtagHeader(v bool)
- func (x *Compressor) SetRemoveAcceptEncodingHeader(v bool)
- func (x *Compressor) SetRuntimeEnabled(v *core.RuntimeFeatureFlag)
- func (x *Compressor) String() string
- type Compressor_builder
Constants ¶
This section is empty.
Variables ¶
var File_envoy_config_filter_http_compressor_v2_compressor_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Compressor ¶
type Compressor struct {
// Minimum response length, in bytes, which will trigger compression. The default value is 30.
ContentLength *wrapperspb.UInt32Value `protobuf:"bytes,1,opt,name=content_length,json=contentLength,proto3" json:"content_length,omitempty"`
// Set of strings that allows specifying which mime-types yield compression; e.g.,
// application/json, text/html, etc. When this field is not defined, compression will be applied
// to the following mime-types: "application/javascript", "application/json",
// "application/xhtml+xml", "image/svg+xml", "text/css", "text/html", "text/plain", "text/xml"
// and their synonyms.
ContentType []string `protobuf:"bytes,2,rep,name=content_type,json=contentType,proto3" json:"content_type,omitempty"`
// If true, disables compression when the response contains an etag header. When it is false, the
// filter will preserve weak etags and remove the ones that require strong validation.
DisableOnEtagHeader bool `protobuf:"varint,3,opt,name=disable_on_etag_header,json=disableOnEtagHeader,proto3" json:"disable_on_etag_header,omitempty"`
// If true, removes accept-encoding from the request headers before dispatching it to the upstream
// so that responses do not get compressed before reaching the filter.
// .. attention:
//
// To avoid interfering with other compression filters in the same chain use this option in
// the filter closest to the upstream.
RemoveAcceptEncodingHeader bool `` /* 144-byte string literal not displayed */
// Runtime flag that controls whether the filter is enabled or not. If set to false, the
// filter will operate as a pass-through filter. If not specified, defaults to enabled.
RuntimeEnabled *core.RuntimeFeatureFlag `protobuf:"bytes,5,opt,name=runtime_enabled,json=runtimeEnabled,proto3" json:"runtime_enabled,omitempty"`
// contains filtered or unexported fields
}
[#next-free-field: 6]
func (*Compressor) ClearContentLength ¶
func (x *Compressor) ClearContentLength()
func (*Compressor) ClearRuntimeEnabled ¶
func (x *Compressor) ClearRuntimeEnabled()
func (*Compressor) GetContentLength ¶
func (x *Compressor) GetContentLength() *wrapperspb.UInt32Value
func (*Compressor) GetContentType ¶
func (x *Compressor) GetContentType() []string
func (*Compressor) GetDisableOnEtagHeader ¶
func (x *Compressor) GetDisableOnEtagHeader() bool
func (*Compressor) GetRemoveAcceptEncodingHeader ¶
func (x *Compressor) GetRemoveAcceptEncodingHeader() bool
func (*Compressor) GetRuntimeEnabled ¶
func (x *Compressor) GetRuntimeEnabled() *core.RuntimeFeatureFlag
func (*Compressor) HasContentLength ¶
func (x *Compressor) HasContentLength() bool
func (*Compressor) HasRuntimeEnabled ¶
func (x *Compressor) HasRuntimeEnabled() bool
func (*Compressor) ProtoMessage ¶
func (*Compressor) ProtoMessage()
func (*Compressor) ProtoReflect ¶
func (x *Compressor) ProtoReflect() protoreflect.Message
func (*Compressor) Reset ¶
func (x *Compressor) Reset()
func (*Compressor) SetContentLength ¶
func (x *Compressor) SetContentLength(v *wrapperspb.UInt32Value)
func (*Compressor) SetContentType ¶
func (x *Compressor) SetContentType(v []string)
func (*Compressor) SetDisableOnEtagHeader ¶
func (x *Compressor) SetDisableOnEtagHeader(v bool)
func (*Compressor) SetRemoveAcceptEncodingHeader ¶
func (x *Compressor) SetRemoveAcceptEncodingHeader(v bool)
func (*Compressor) SetRuntimeEnabled ¶
func (x *Compressor) SetRuntimeEnabled(v *core.RuntimeFeatureFlag)
func (*Compressor) String ¶
func (x *Compressor) String() string
type Compressor_builder ¶
type Compressor_builder struct {
// Minimum response length, in bytes, which will trigger compression. The default value is 30.
ContentLength *wrapperspb.UInt32Value
// Set of strings that allows specifying which mime-types yield compression; e.g.,
// application/json, text/html, etc. When this field is not defined, compression will be applied
// to the following mime-types: "application/javascript", "application/json",
// "application/xhtml+xml", "image/svg+xml", "text/css", "text/html", "text/plain", "text/xml"
// and their synonyms.
ContentType []string
// If true, disables compression when the response contains an etag header. When it is false, the
// filter will preserve weak etags and remove the ones that require strong validation.
DisableOnEtagHeader bool
// If true, removes accept-encoding from the request headers before dispatching it to the upstream
// so that responses do not get compressed before reaching the filter.
// .. attention:
//
// To avoid interfering with other compression filters in the same chain use this option in
// the filter closest to the upstream.
RemoveAcceptEncodingHeader bool
// Runtime flag that controls whether the filter is enabled or not. If set to false, the
// filter will operate as a pass-through filter. If not specified, defaults to enabled.
RuntimeEnabled *core.RuntimeFeatureFlag
// contains filtered or unexported fields
}
func (Compressor_builder) Build ¶
func (b0 Compressor_builder) Build() *Compressor
Source Files
¶
- compressor.pb.go
Click to show internal directories.
Click to hide internal directories.