Documentation
¶
Index ¶
- Constants
- Variables
- type FilterConfig
- func (x *FilterConfig) ClearDnsCacheConfig()
- func (x *FilterConfig) GetDnsCacheConfig() *v2alpha.DnsCacheConfig
- func (x *FilterConfig) HasDnsCacheConfig() bool
- func (*FilterConfig) ProtoMessage()
- func (x *FilterConfig) ProtoReflect() protoreflect.Message
- func (x *FilterConfig) Reset()
- func (x *FilterConfig) SetDnsCacheConfig(v *v2alpha.DnsCacheConfig)
- func (x *FilterConfig) String() string
- type FilterConfig_builder
- type PerRouteConfig
- func (x *PerRouteConfig) ClearAutoHostRewriteHeader()
- func (x *PerRouteConfig) ClearHostRewrite()
- func (x *PerRouteConfig) ClearHostRewriteSpecifier()
- func (x *PerRouteConfig) GetAutoHostRewriteHeader() string
- func (x *PerRouteConfig) GetHostRewrite() string
- func (x *PerRouteConfig) GetHostRewriteSpecifier() isPerRouteConfig_HostRewriteSpecifier
- func (x *PerRouteConfig) HasAutoHostRewriteHeader() bool
- func (x *PerRouteConfig) HasHostRewrite() bool
- func (x *PerRouteConfig) HasHostRewriteSpecifier() bool
- func (*PerRouteConfig) ProtoMessage()
- func (x *PerRouteConfig) ProtoReflect() protoreflect.Message
- func (x *PerRouteConfig) Reset()
- func (x *PerRouteConfig) SetAutoHostRewriteHeader(v string)
- func (x *PerRouteConfig) SetHostRewrite(v string)
- func (x *PerRouteConfig) String() string
- func (x *PerRouteConfig) WhichHostRewriteSpecifier() case_PerRouteConfig_HostRewriteSpecifier
- type PerRouteConfig_AutoHostRewriteHeader
- type PerRouteConfig_HostRewrite
- type PerRouteConfig_builder
Constants ¶
const PerRouteConfig_AutoHostRewriteHeader_case case_PerRouteConfig_HostRewriteSpecifier = 2
const PerRouteConfig_HostRewriteSpecifier_not_set_case case_PerRouteConfig_HostRewriteSpecifier = 0
const PerRouteConfig_HostRewrite_case case_PerRouteConfig_HostRewriteSpecifier = 1
Variables ¶
var File_envoy_config_filter_http_dynamic_forward_proxy_v2alpha_dynamic_forward_proxy_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type FilterConfig ¶
type FilterConfig struct {
// The DNS cache configuration that the filter will attach to. Note this configuration must
// match that of associated :ref:`dynamic forward proxy cluster configuration
// <envoy_api_field_config.cluster.dynamic_forward_proxy.v2alpha.ClusterConfig.dns_cache_config>`.
DnsCacheConfig *v2alpha.DnsCacheConfig `protobuf:"bytes,1,opt,name=dns_cache_config,json=dnsCacheConfig,proto3" json:"dns_cache_config,omitempty"`
// contains filtered or unexported fields
}
Configuration for the dynamic forward proxy HTTP filter. See the :ref:`architecture overview <arch_overview_http_dynamic_forward_proxy>` for more information. [#extension: envoy.filters.http.dynamic_forward_proxy]
func (*FilterConfig) ClearDnsCacheConfig ¶
func (x *FilterConfig) ClearDnsCacheConfig()
func (*FilterConfig) GetDnsCacheConfig ¶
func (x *FilterConfig) GetDnsCacheConfig() *v2alpha.DnsCacheConfig
func (*FilterConfig) HasDnsCacheConfig ¶
func (x *FilterConfig) HasDnsCacheConfig() bool
func (*FilterConfig) ProtoMessage ¶
func (*FilterConfig) ProtoMessage()
func (*FilterConfig) ProtoReflect ¶
func (x *FilterConfig) ProtoReflect() protoreflect.Message
func (*FilterConfig) Reset ¶
func (x *FilterConfig) Reset()
func (*FilterConfig) SetDnsCacheConfig ¶
func (x *FilterConfig) SetDnsCacheConfig(v *v2alpha.DnsCacheConfig)
func (*FilterConfig) String ¶
func (x *FilterConfig) String() string
type FilterConfig_builder ¶
type FilterConfig_builder struct {
// The DNS cache configuration that the filter will attach to. Note this configuration must
// match that of associated :ref:`dynamic forward proxy cluster configuration
// <envoy_api_field_config.cluster.dynamic_forward_proxy.v2alpha.ClusterConfig.dns_cache_config>`.
DnsCacheConfig *v2alpha.DnsCacheConfig
// contains filtered or unexported fields
}
func (FilterConfig_builder) Build ¶
func (b0 FilterConfig_builder) Build() *FilterConfig
type PerRouteConfig ¶
type PerRouteConfig struct {
// Types that are valid to be assigned to HostRewriteSpecifier:
//
// *PerRouteConfig_HostRewrite
// *PerRouteConfig_AutoHostRewriteHeader
HostRewriteSpecifier isPerRouteConfig_HostRewriteSpecifier `protobuf_oneof:"host_rewrite_specifier"`
// contains filtered or unexported fields
}
Per route Configuration for the dynamic forward proxy HTTP filter.
func (*PerRouteConfig) ClearAutoHostRewriteHeader ¶
func (x *PerRouteConfig) ClearAutoHostRewriteHeader()
func (*PerRouteConfig) ClearHostRewrite ¶
func (x *PerRouteConfig) ClearHostRewrite()
func (*PerRouteConfig) ClearHostRewriteSpecifier ¶
func (x *PerRouteConfig) ClearHostRewriteSpecifier()
func (*PerRouteConfig) GetAutoHostRewriteHeader ¶
func (x *PerRouteConfig) GetAutoHostRewriteHeader() string
func (*PerRouteConfig) GetHostRewrite ¶
func (x *PerRouteConfig) GetHostRewrite() string
func (*PerRouteConfig) GetHostRewriteSpecifier ¶
func (x *PerRouteConfig) GetHostRewriteSpecifier() isPerRouteConfig_HostRewriteSpecifier
func (*PerRouteConfig) HasAutoHostRewriteHeader ¶
func (x *PerRouteConfig) HasAutoHostRewriteHeader() bool
func (*PerRouteConfig) HasHostRewrite ¶
func (x *PerRouteConfig) HasHostRewrite() bool
func (*PerRouteConfig) HasHostRewriteSpecifier ¶
func (x *PerRouteConfig) HasHostRewriteSpecifier() bool
func (*PerRouteConfig) ProtoMessage ¶
func (*PerRouteConfig) ProtoMessage()
func (*PerRouteConfig) ProtoReflect ¶
func (x *PerRouteConfig) ProtoReflect() protoreflect.Message
func (*PerRouteConfig) Reset ¶
func (x *PerRouteConfig) Reset()
func (*PerRouteConfig) SetAutoHostRewriteHeader ¶
func (x *PerRouteConfig) SetAutoHostRewriteHeader(v string)
func (*PerRouteConfig) SetHostRewrite ¶
func (x *PerRouteConfig) SetHostRewrite(v string)
func (*PerRouteConfig) String ¶
func (x *PerRouteConfig) String() string
func (*PerRouteConfig) WhichHostRewriteSpecifier ¶
func (x *PerRouteConfig) WhichHostRewriteSpecifier() case_PerRouteConfig_HostRewriteSpecifier
type PerRouteConfig_AutoHostRewriteHeader ¶
type PerRouteConfig_AutoHostRewriteHeader struct {
// Indicates that before DNS lookup, the host header will be swapped with
// the value of this header. If not set or empty, the original host header
// value will be used and no rewrite will happen.
//
// Note: this rewrite affects both DNS lookup and host header forwarding. However, this
// option shouldn't be used with
// :ref:`HCM host rewrite header <envoy_api_field_route.RouteAction.auto_host_rewrite_header>`
// given that the value set here would be used for DNS lookups whereas the value set in the HCM
// would be used for host header forwarding which is not the desired outcome.
//
// .. note::
//
// If the header appears multiple times only the first value is used.
AutoHostRewriteHeader string `protobuf:"bytes,2,opt,name=auto_host_rewrite_header,json=autoHostRewriteHeader,proto3,oneof"`
}
type PerRouteConfig_HostRewrite ¶
type PerRouteConfig_HostRewrite struct {
// Indicates that before DNS lookup, the host header will be swapped with
// this value. If not set or empty, the original host header value
// will be used and no rewrite will happen.
//
// Note: this rewrite affects both DNS lookup and host header forwarding. However, this
// option shouldn't be used with
// :ref:`HCM host rewrite <envoy_api_field_route.RouteAction.host_rewrite>` given that the
// value set here would be used for DNS lookups whereas the value set in the HCM would be used
// for host header forwarding which is not the desired outcome.
HostRewrite string `protobuf:"bytes,1,opt,name=host_rewrite,json=hostRewrite,proto3,oneof"`
}
type PerRouteConfig_builder ¶
type PerRouteConfig_builder struct {
// Fields of oneof HostRewriteSpecifier:
// Indicates that before DNS lookup, the host header will be swapped with
// this value. If not set or empty, the original host header value
// will be used and no rewrite will happen.
//
// Note: this rewrite affects both DNS lookup and host header forwarding. However, this
// option shouldn't be used with
// :ref:`HCM host rewrite <envoy_api_field_route.RouteAction.host_rewrite>` given that the
// value set here would be used for DNS lookups whereas the value set in the HCM would be used
// for host header forwarding which is not the desired outcome.
HostRewrite *string
// Indicates that before DNS lookup, the host header will be swapped with
// the value of this header. If not set or empty, the original host header
// value will be used and no rewrite will happen.
//
// Note: this rewrite affects both DNS lookup and host header forwarding. However, this
// option shouldn't be used with
// :ref:`HCM host rewrite header <envoy_api_field_route.RouteAction.auto_host_rewrite_header>`
// given that the value set here would be used for DNS lookups whereas the value set in the HCM
// would be used for host header forwarding which is not the desired outcome.
//
// .. note::
//
// If the header appears multiple times only the first value is used.
AutoHostRewriteHeader *string
// contains filtered or unexported fields
}
func (PerRouteConfig_builder) Build ¶
func (b0 PerRouteConfig_builder) Build() *PerRouteConfig
Source Files
¶
- dynamic_forward_proxy.pb.go
Click to show internal directories.
Click to hide internal directories.