Documentation
¶
Index ¶
- Variables
- type Gzip
- func (x *Gzip) ClearCompressor()
- func (x *Gzip) ClearContentLength()deprecated
- func (x *Gzip) ClearMemoryLevel()
- func (x *Gzip) ClearWindowBits()
- func (x *Gzip) GetCompressionLevel() Gzip_CompressionLevel_Enum
- func (x *Gzip) GetCompressionStrategy() Gzip_CompressionStrategy
- func (x *Gzip) GetCompressor() *v2.Compressor
- func (x *Gzip) GetContentLength() *wrapperspb.UInt32Valuedeprecated
- func (x *Gzip) GetContentType() []stringdeprecated
- func (x *Gzip) GetDisableOnEtagHeader() booldeprecated
- func (x *Gzip) GetMemoryLevel() *wrapperspb.UInt32Value
- func (x *Gzip) GetRemoveAcceptEncodingHeader() booldeprecated
- func (x *Gzip) GetWindowBits() *wrapperspb.UInt32Value
- func (x *Gzip) HasCompressor() bool
- func (x *Gzip) HasContentLength() booldeprecated
- func (x *Gzip) HasMemoryLevel() bool
- func (x *Gzip) HasWindowBits() bool
- func (*Gzip) ProtoMessage()
- func (x *Gzip) ProtoReflect() protoreflect.Message
- func (x *Gzip) Reset()
- func (x *Gzip) SetCompressionLevel(v Gzip_CompressionLevel_Enum)
- func (x *Gzip) SetCompressionStrategy(v Gzip_CompressionStrategy)
- func (x *Gzip) SetCompressor(v *v2.Compressor)
- func (x *Gzip) SetContentLength(v *wrapperspb.UInt32Value)deprecated
- func (x *Gzip) SetContentType(v []string)deprecated
- func (x *Gzip) SetDisableOnEtagHeader(v bool)deprecated
- func (x *Gzip) SetMemoryLevel(v *wrapperspb.UInt32Value)
- func (x *Gzip) SetRemoveAcceptEncodingHeader(v bool)deprecated
- func (x *Gzip) SetWindowBits(v *wrapperspb.UInt32Value)
- func (x *Gzip) String() string
- type Gzip_CompressionLevel
- type Gzip_CompressionLevel_Enum
- func (Gzip_CompressionLevel_Enum) Descriptor() protoreflect.EnumDescriptor
- func (x Gzip_CompressionLevel_Enum) Enum() *Gzip_CompressionLevel_Enum
- func (x Gzip_CompressionLevel_Enum) Number() protoreflect.EnumNumber
- func (x Gzip_CompressionLevel_Enum) String() string
- func (Gzip_CompressionLevel_Enum) Type() protoreflect.EnumType
- type Gzip_CompressionLevel_builder
- type Gzip_CompressionStrategy
- func (Gzip_CompressionStrategy) Descriptor() protoreflect.EnumDescriptor
- func (x Gzip_CompressionStrategy) Enum() *Gzip_CompressionStrategy
- func (x Gzip_CompressionStrategy) Number() protoreflect.EnumNumber
- func (x Gzip_CompressionStrategy) String() string
- func (Gzip_CompressionStrategy) Type() protoreflect.EnumType
- type Gzip_builder
Constants ¶
This section is empty.
Variables ¶
var ( Gzip_CompressionStrategy_name = map[int32]string{ 0: "DEFAULT", 1: "FILTERED", 2: "HUFFMAN", 3: "RLE", } Gzip_CompressionStrategy_value = map[string]int32{ "DEFAULT": 0, "FILTERED": 1, "HUFFMAN": 2, "RLE": 3, } )
Enum value maps for Gzip_CompressionStrategy.
var ( Gzip_CompressionLevel_Enum_name = map[int32]string{ 0: "DEFAULT", 1: "BEST", 2: "SPEED", } Gzip_CompressionLevel_Enum_value = map[string]int32{ "DEFAULT": 0, "BEST": 1, "SPEED": 2, } )
Enum value maps for Gzip_CompressionLevel_Enum.
var File_envoy_config_filter_http_gzip_v2_gzip_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Gzip ¶
type Gzip struct {
// Value from 1 to 9 that controls the amount of internal memory used by zlib. Higher values
// use more memory, but are faster and produce better compression results. The default value is 5.
MemoryLevel *wrapperspb.UInt32Value `protobuf:"bytes,1,opt,name=memory_level,json=memoryLevel,proto3" json:"memory_level,omitempty"`
// Minimum response length, in bytes, which will trigger compression. The default value is 30.
// .. attention:
//
// **This field is deprecated**. Set the `compressor` field instead.
//
// Deprecated: Marked as deprecated in envoy/config/filter/http/gzip/v2/gzip.proto.
ContentLength *wrapperspb.UInt32Value `protobuf:"bytes,2,opt,name=content_length,json=contentLength,proto3" json:"content_length,omitempty"`
// A value used for selecting the zlib compression level. This setting will affect speed and
// amount of compression applied to the content. "BEST" provides higher compression at the cost of
// higher latency, "SPEED" provides lower compression with minimum impact on response time.
// "DEFAULT" provides an optimal result between speed and compression. This field will be set to
// "DEFAULT" if not specified.
CompressionLevel Gzip_CompressionLevel_Enum `` /* 175-byte string literal not displayed */
// A value used for selecting the zlib compression strategy which is directly related to the
// characteristics of the content. Most of the time "DEFAULT" will be the best choice, though
// there are situations which changing this parameter might produce better results. For example,
// run-length encoding (RLE) is typically used when the content is known for having sequences
// which same data occurs many consecutive times. For more information about each strategy, please
// refer to zlib manual.
CompressionStrategy Gzip_CompressionStrategy `` /* 182-byte string literal not displayed */
// Set of strings that allows specifying which mime-types yield compression; e.g.,
// application/json, text/html, etc. When this field is not defined, compression will be applied
// to the following mime-types: "application/javascript", "application/json",
// "application/xhtml+xml", "image/svg+xml", "text/css", "text/html", "text/plain", "text/xml".
// .. attention:
//
// **This field is deprecated**. Set the `compressor` field instead.
//
// Deprecated: Marked as deprecated in envoy/config/filter/http/gzip/v2/gzip.proto.
ContentType []string `protobuf:"bytes,6,rep,name=content_type,json=contentType,proto3" json:"content_type,omitempty"`
// If true, disables compression when the response contains an etag header. When it is false, the
// filter will preserve weak etags and remove the ones that require strong validation.
// .. attention:
//
// **This field is deprecated**. Set the `compressor` field instead.
//
// Deprecated: Marked as deprecated in envoy/config/filter/http/gzip/v2/gzip.proto.
DisableOnEtagHeader bool `protobuf:"varint,7,opt,name=disable_on_etag_header,json=disableOnEtagHeader,proto3" json:"disable_on_etag_header,omitempty"`
// If true, removes accept-encoding from the request headers before dispatching it to the upstream
// so that responses do not get compressed before reaching the filter.
// .. attention:
//
// **This field is deprecated**. Set the `compressor` field instead.
//
// Deprecated: Marked as deprecated in envoy/config/filter/http/gzip/v2/gzip.proto.
RemoveAcceptEncodingHeader bool `` /* 144-byte string literal not displayed */
// Value from 9 to 15 that represents the base two logarithmic of the compressor's window size.
// Larger window results in better compression at the expense of memory usage. The default is 12
// which will produce a 4096 bytes window. For more details about this parameter, please refer to
// zlib manual > deflateInit2.
WindowBits *wrapperspb.UInt32Value `protobuf:"bytes,9,opt,name=window_bits,json=windowBits,proto3" json:"window_bits,omitempty"`
// Set of configuration parameters common for all compression filters. If this field is set then
// the fields `content_length`, `content_type`, `disable_on_etag_header` and
// `remove_accept_encoding_header` are ignored.
Compressor *v2.Compressor `protobuf:"bytes,10,opt,name=compressor,proto3" json:"compressor,omitempty"`
// contains filtered or unexported fields
}
[#next-free-field: 11]
func (*Gzip) ClearContentLength
deprecated
func (x *Gzip) ClearContentLength()
Deprecated: Marked as deprecated in envoy/config/filter/http/gzip/v2/gzip.proto.
func (*Gzip) GetCompressionLevel ¶
func (x *Gzip) GetCompressionLevel() Gzip_CompressionLevel_Enum
func (*Gzip) GetCompressionStrategy ¶
func (x *Gzip) GetCompressionStrategy() Gzip_CompressionStrategy
func (*Gzip) GetCompressor ¶
func (x *Gzip) GetCompressor() *v2.Compressor
func (*Gzip) GetContentLength
deprecated
func (x *Gzip) GetContentLength() *wrapperspb.UInt32Value
Deprecated: Marked as deprecated in envoy/config/filter/http/gzip/v2/gzip.proto.
func (*Gzip) GetMemoryLevel ¶
func (x *Gzip) GetMemoryLevel() *wrapperspb.UInt32Value
func (*Gzip) GetWindowBits ¶
func (x *Gzip) GetWindowBits() *wrapperspb.UInt32Value
func (*Gzip) ProtoReflect ¶
func (x *Gzip) ProtoReflect() protoreflect.Message
func (*Gzip) SetCompressionLevel ¶
func (x *Gzip) SetCompressionLevel(v Gzip_CompressionLevel_Enum)
func (*Gzip) SetCompressionStrategy ¶
func (x *Gzip) SetCompressionStrategy(v Gzip_CompressionStrategy)
func (*Gzip) SetCompressor ¶
func (x *Gzip) SetCompressor(v *v2.Compressor)
func (*Gzip) SetContentLength
deprecated
func (x *Gzip) SetContentLength(v *wrapperspb.UInt32Value)
Deprecated: Marked as deprecated in envoy/config/filter/http/gzip/v2/gzip.proto.
func (*Gzip) SetMemoryLevel ¶
func (x *Gzip) SetMemoryLevel(v *wrapperspb.UInt32Value)
func (*Gzip) SetWindowBits ¶
func (x *Gzip) SetWindowBits(v *wrapperspb.UInt32Value)
type Gzip_CompressionLevel ¶
type Gzip_CompressionLevel struct {
// contains filtered or unexported fields
}
func (*Gzip_CompressionLevel) ProtoMessage ¶
func (*Gzip_CompressionLevel) ProtoMessage()
func (*Gzip_CompressionLevel) ProtoReflect ¶
func (x *Gzip_CompressionLevel) ProtoReflect() protoreflect.Message
func (*Gzip_CompressionLevel) Reset ¶
func (x *Gzip_CompressionLevel) Reset()
func (*Gzip_CompressionLevel) String ¶
func (x *Gzip_CompressionLevel) String() string
type Gzip_CompressionLevel_Enum ¶
type Gzip_CompressionLevel_Enum int32
const ( Gzip_CompressionLevel_DEFAULT Gzip_CompressionLevel_Enum = 0 Gzip_CompressionLevel_BEST Gzip_CompressionLevel_Enum = 1 Gzip_CompressionLevel_SPEED Gzip_CompressionLevel_Enum = 2 )
func (Gzip_CompressionLevel_Enum) Descriptor ¶
func (Gzip_CompressionLevel_Enum) Descriptor() protoreflect.EnumDescriptor
func (Gzip_CompressionLevel_Enum) Enum ¶
func (x Gzip_CompressionLevel_Enum) Enum() *Gzip_CompressionLevel_Enum
func (Gzip_CompressionLevel_Enum) Number ¶
func (x Gzip_CompressionLevel_Enum) Number() protoreflect.EnumNumber
func (Gzip_CompressionLevel_Enum) String ¶
func (x Gzip_CompressionLevel_Enum) String() string
func (Gzip_CompressionLevel_Enum) Type ¶
func (Gzip_CompressionLevel_Enum) Type() protoreflect.EnumType
type Gzip_CompressionLevel_builder ¶
type Gzip_CompressionLevel_builder struct {
// contains filtered or unexported fields
}
func (Gzip_CompressionLevel_builder) Build ¶
func (b0 Gzip_CompressionLevel_builder) Build() *Gzip_CompressionLevel
type Gzip_CompressionStrategy ¶
type Gzip_CompressionStrategy int32
const ( Gzip_DEFAULT Gzip_CompressionStrategy = 0 Gzip_FILTERED Gzip_CompressionStrategy = 1 Gzip_HUFFMAN Gzip_CompressionStrategy = 2 Gzip_RLE Gzip_CompressionStrategy = 3 )
func (Gzip_CompressionStrategy) Descriptor ¶
func (Gzip_CompressionStrategy) Descriptor() protoreflect.EnumDescriptor
func (Gzip_CompressionStrategy) Enum ¶
func (x Gzip_CompressionStrategy) Enum() *Gzip_CompressionStrategy
func (Gzip_CompressionStrategy) Number ¶
func (x Gzip_CompressionStrategy) Number() protoreflect.EnumNumber
func (Gzip_CompressionStrategy) String ¶
func (x Gzip_CompressionStrategy) String() string
func (Gzip_CompressionStrategy) Type ¶
func (Gzip_CompressionStrategy) Type() protoreflect.EnumType
type Gzip_builder ¶
type Gzip_builder struct {
// Value from 1 to 9 that controls the amount of internal memory used by zlib. Higher values
// use more memory, but are faster and produce better compression results. The default value is 5.
MemoryLevel *wrapperspb.UInt32Value
// Minimum response length, in bytes, which will trigger compression. The default value is 30.
// .. attention:
//
// **This field is deprecated**. Set the `compressor` field instead.
//
// Deprecated: Marked as deprecated in envoy/config/filter/http/gzip/v2/gzip.proto.
ContentLength *wrapperspb.UInt32Value
// A value used for selecting the zlib compression level. This setting will affect speed and
// amount of compression applied to the content. "BEST" provides higher compression at the cost of
// higher latency, "SPEED" provides lower compression with minimum impact on response time.
// "DEFAULT" provides an optimal result between speed and compression. This field will be set to
// "DEFAULT" if not specified.
CompressionLevel Gzip_CompressionLevel_Enum
// A value used for selecting the zlib compression strategy which is directly related to the
// characteristics of the content. Most of the time "DEFAULT" will be the best choice, though
// there are situations which changing this parameter might produce better results. For example,
// run-length encoding (RLE) is typically used when the content is known for having sequences
// which same data occurs many consecutive times. For more information about each strategy, please
// refer to zlib manual.
CompressionStrategy Gzip_CompressionStrategy
// Set of strings that allows specifying which mime-types yield compression; e.g.,
// application/json, text/html, etc. When this field is not defined, compression will be applied
// to the following mime-types: "application/javascript", "application/json",
// "application/xhtml+xml", "image/svg+xml", "text/css", "text/html", "text/plain", "text/xml".
// .. attention:
//
// **This field is deprecated**. Set the `compressor` field instead.
//
// Deprecated: Marked as deprecated in envoy/config/filter/http/gzip/v2/gzip.proto.
ContentType []string
// If true, disables compression when the response contains an etag header. When it is false, the
// filter will preserve weak etags and remove the ones that require strong validation.
// .. attention:
//
// **This field is deprecated**. Set the `compressor` field instead.
//
// Deprecated: Marked as deprecated in envoy/config/filter/http/gzip/v2/gzip.proto.
DisableOnEtagHeader bool
// If true, removes accept-encoding from the request headers before dispatching it to the upstream
// so that responses do not get compressed before reaching the filter.
// .. attention:
//
// **This field is deprecated**. Set the `compressor` field instead.
//
// Deprecated: Marked as deprecated in envoy/config/filter/http/gzip/v2/gzip.proto.
RemoveAcceptEncodingHeader bool
// Value from 9 to 15 that represents the base two logarithmic of the compressor's window size.
// Larger window results in better compression at the expense of memory usage. The default is 12
// which will produce a 4096 bytes window. For more details about this parameter, please refer to
// zlib manual > deflateInit2.
WindowBits *wrapperspb.UInt32Value
// Set of configuration parameters common for all compression filters. If this field is set then
// the fields `content_length`, `content_type`, `disable_on_etag_header` and
// `remove_accept_encoding_header` are ignored.
Compressor *v2.Compressor
// contains filtered or unexported fields
}
func (Gzip_builder) Build ¶
func (b0 Gzip_builder) Build() *Gzip
Source Files
¶
- gzip.pb.go
Click to show internal directories.
Click to hide internal directories.