Documentation
¶
Index ¶
- Variables
- type IPTagging
- func (x *IPTagging) GetIpTags() []*IPTagging_IPTag
- func (x *IPTagging) GetRequestType() IPTagging_RequestType
- func (*IPTagging) ProtoMessage()
- func (x *IPTagging) ProtoReflect() protoreflect.Message
- func (x *IPTagging) Reset()
- func (x *IPTagging) SetIpTags(v []*IPTagging_IPTag)
- func (x *IPTagging) SetRequestType(v IPTagging_RequestType)
- func (x *IPTagging) String() string
- type IPTagging_IPTag
- func (x *IPTagging_IPTag) GetIpList() []*core.CidrRange
- func (x *IPTagging_IPTag) GetIpTagName() string
- func (*IPTagging_IPTag) ProtoMessage()
- func (x *IPTagging_IPTag) ProtoReflect() protoreflect.Message
- func (x *IPTagging_IPTag) Reset()
- func (x *IPTagging_IPTag) SetIpList(v []*core.CidrRange)
- func (x *IPTagging_IPTag) SetIpTagName(v string)
- func (x *IPTagging_IPTag) String() string
- type IPTagging_IPTag_builder
- type IPTagging_RequestType
- type IPTagging_builder
Constants ¶
This section is empty.
Variables ¶
var ( IPTagging_RequestType_name = map[int32]string{ 0: "BOTH", 1: "INTERNAL", 2: "EXTERNAL", } IPTagging_RequestType_value = map[string]int32{ "BOTH": 0, "INTERNAL": 1, "EXTERNAL": 2, } )
Enum value maps for IPTagging_RequestType.
var File_envoy_config_filter_http_ip_tagging_v2_ip_tagging_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type IPTagging ¶
type IPTagging struct {
// The type of request the filter should apply to.
RequestType IPTagging_RequestType `` /* 161-byte string literal not displayed */
// [#comment:TODO(ccaraman): Extend functionality to load IP tags from file system.
// Tracked by issue https://github.com/envoyproxy/envoy/issues/2695]
// The set of IP tags for the filter.
IpTags []*IPTagging_IPTag `protobuf:"bytes,4,rep,name=ip_tags,json=ipTags,proto3" json:"ip_tags,omitempty"`
// contains filtered or unexported fields
}
func (*IPTagging) GetIpTags ¶
func (x *IPTagging) GetIpTags() []*IPTagging_IPTag
func (*IPTagging) GetRequestType ¶
func (x *IPTagging) GetRequestType() IPTagging_RequestType
func (*IPTagging) ProtoReflect ¶
func (x *IPTagging) ProtoReflect() protoreflect.Message
func (*IPTagging) SetIpTags ¶
func (x *IPTagging) SetIpTags(v []*IPTagging_IPTag)
func (*IPTagging) SetRequestType ¶
func (x *IPTagging) SetRequestType(v IPTagging_RequestType)
type IPTagging_IPTag ¶
type IPTagging_IPTag struct {
// Specifies the IP tag name to apply.
IpTagName string `protobuf:"bytes,1,opt,name=ip_tag_name,json=ipTagName,proto3" json:"ip_tag_name,omitempty"`
// A list of IP address subnets that will be tagged with
// ip_tag_name. Both IPv4 and IPv6 are supported.
IpList []*core.CidrRange `protobuf:"bytes,2,rep,name=ip_list,json=ipList,proto3" json:"ip_list,omitempty"`
// contains filtered or unexported fields
}
Supplies the IP tag name and the IP address subnets.
func (*IPTagging_IPTag) GetIpList ¶
func (x *IPTagging_IPTag) GetIpList() []*core.CidrRange
func (*IPTagging_IPTag) GetIpTagName ¶
func (x *IPTagging_IPTag) GetIpTagName() string
func (*IPTagging_IPTag) ProtoMessage ¶
func (*IPTagging_IPTag) ProtoMessage()
func (*IPTagging_IPTag) ProtoReflect ¶
func (x *IPTagging_IPTag) ProtoReflect() protoreflect.Message
func (*IPTagging_IPTag) Reset ¶
func (x *IPTagging_IPTag) Reset()
func (*IPTagging_IPTag) SetIpList ¶
func (x *IPTagging_IPTag) SetIpList(v []*core.CidrRange)
func (*IPTagging_IPTag) SetIpTagName ¶
func (x *IPTagging_IPTag) SetIpTagName(v string)
func (*IPTagging_IPTag) String ¶
func (x *IPTagging_IPTag) String() string
type IPTagging_IPTag_builder ¶
type IPTagging_IPTag_builder struct {
// Specifies the IP tag name to apply.
IpTagName string
// A list of IP address subnets that will be tagged with
// ip_tag_name. Both IPv4 and IPv6 are supported.
IpList []*core.CidrRange
// contains filtered or unexported fields
}
func (IPTagging_IPTag_builder) Build ¶
func (b0 IPTagging_IPTag_builder) Build() *IPTagging_IPTag
type IPTagging_RequestType ¶
type IPTagging_RequestType int32
The type of requests the filter should apply to. The supported types are internal, external or both. The :ref:`x-forwarded-for<config_http_conn_man_headers_x-forwarded-for_internal_origin>` header is used to determine if a request is internal and will result in :ref:`x-envoy-internal<config_http_conn_man_headers_x-envoy-internal>` being set. The filter defaults to both, and it will apply to all request types.
const ( // Both external and internal requests will be tagged. This is the default value. IPTagging_BOTH IPTagging_RequestType = 0 // Only internal requests will be tagged. IPTagging_INTERNAL IPTagging_RequestType = 1 // Only external requests will be tagged. IPTagging_EXTERNAL IPTagging_RequestType = 2 )
func (IPTagging_RequestType) Descriptor ¶
func (IPTagging_RequestType) Descriptor() protoreflect.EnumDescriptor
func (IPTagging_RequestType) Enum ¶
func (x IPTagging_RequestType) Enum() *IPTagging_RequestType
func (IPTagging_RequestType) Number ¶
func (x IPTagging_RequestType) Number() protoreflect.EnumNumber
func (IPTagging_RequestType) String ¶
func (x IPTagging_RequestType) String() string
func (IPTagging_RequestType) Type ¶
func (IPTagging_RequestType) Type() protoreflect.EnumType
type IPTagging_builder ¶
type IPTagging_builder struct {
// The type of request the filter should apply to.
RequestType IPTagging_RequestType
// [#comment:TODO(ccaraman): Extend functionality to load IP tags from file system.
// Tracked by issue https://github.com/envoyproxy/envoy/issues/2695]
// The set of IP tags for the filter.
IpTags []*IPTagging_IPTag
// contains filtered or unexported fields
}
func (IPTagging_builder) Build ¶
func (b0 IPTagging_builder) Build() *IPTagging
Source Files
¶
- ip_tagging.pb.go
Click to show internal directories.
Click to hide internal directories.