Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var File_envoy_config_filter_http_lua_v2_lua_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Lua ¶
type Lua struct {
// The Lua code that Envoy will execute. This can be a very small script that
// further loads code from disk if desired. Note that if JSON configuration is used, the code must
// be properly escaped. YAML configuration may be easier to read since YAML supports multi-line
// strings so complex scripts can be easily expressed inline in the configuration.
InlineCode string `protobuf:"bytes,1,opt,name=inline_code,json=inlineCode,proto3" json:"inline_code,omitempty"`
// contains filtered or unexported fields
}
func (*Lua) ProtoReflect ¶
func (x *Lua) ProtoReflect() protoreflect.Message
type Lua_builder ¶
type Lua_builder struct {
// The Lua code that Envoy will execute. This can be a very small script that
// further loads code from disk if desired. Note that if JSON configuration is used, the code must
// be properly escaped. YAML configuration may be easier to read since YAML supports multi-line
// strings so complex scripts can be easily expressed inline in the configuration.
InlineCode string
// contains filtered or unexported fields
}
func (Lua_builder) Build ¶
func (b0 Lua_builder) Build() *Lua
Source Files
¶
- lua.pb.go
Click to show internal directories.
Click to hide internal directories.