rbacv2

package
v1.36.11-2026011520535... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var File_envoy_config_filter_http_rbac_v2_rbac_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type RBAC

type RBAC struct {

	// Specify the RBAC rules to be applied globally.
	// If absent, no enforcing RBAC policy will be applied.
	Rules *v2.RBAC `protobuf:"bytes,1,opt,name=rules,proto3" json:"rules,omitempty"`
	// Shadow rules are not enforced by the filter (i.e., returning a 403)
	// but will emit stats and logs and can be used for rule testing.
	// If absent, no shadow RBAC policy will be applied.
	ShadowRules *v2.RBAC `protobuf:"bytes,2,opt,name=shadow_rules,json=shadowRules,proto3" json:"shadow_rules,omitempty"`
	// contains filtered or unexported fields
}

RBAC filter config.

func (*RBAC) ClearRules

func (x *RBAC) ClearRules()

func (*RBAC) ClearShadowRules

func (x *RBAC) ClearShadowRules()

func (*RBAC) GetRules

func (x *RBAC) GetRules() *v2.RBAC

func (*RBAC) GetShadowRules

func (x *RBAC) GetShadowRules() *v2.RBAC

func (*RBAC) HasRules

func (x *RBAC) HasRules() bool

func (*RBAC) HasShadowRules

func (x *RBAC) HasShadowRules() bool

func (*RBAC) ProtoMessage

func (*RBAC) ProtoMessage()

func (*RBAC) ProtoReflect

func (x *RBAC) ProtoReflect() protoreflect.Message

func (*RBAC) Reset

func (x *RBAC) Reset()

func (*RBAC) SetRules

func (x *RBAC) SetRules(v *v2.RBAC)

func (*RBAC) SetShadowRules

func (x *RBAC) SetShadowRules(v *v2.RBAC)

func (*RBAC) String

func (x *RBAC) String() string

type RBACPerRoute

type RBACPerRoute struct {

	// Override the global configuration of the filter with this new config.
	// If absent, the global RBAC policy will be disabled for this route.
	Rbac *RBAC `protobuf:"bytes,2,opt,name=rbac,proto3" json:"rbac,omitempty"`
	// contains filtered or unexported fields
}

func (*RBACPerRoute) ClearRbac

func (x *RBACPerRoute) ClearRbac()

func (*RBACPerRoute) GetRbac

func (x *RBACPerRoute) GetRbac() *RBAC

func (*RBACPerRoute) HasRbac

func (x *RBACPerRoute) HasRbac() bool

func (*RBACPerRoute) ProtoMessage

func (*RBACPerRoute) ProtoMessage()

func (*RBACPerRoute) ProtoReflect

func (x *RBACPerRoute) ProtoReflect() protoreflect.Message

func (*RBACPerRoute) Reset

func (x *RBACPerRoute) Reset()

func (*RBACPerRoute) SetRbac

func (x *RBACPerRoute) SetRbac(v *RBAC)

func (*RBACPerRoute) String

func (x *RBACPerRoute) String() string

type RBACPerRoute_builder

type RBACPerRoute_builder struct {

	// Override the global configuration of the filter with this new config.
	// If absent, the global RBAC policy will be disabled for this route.
	Rbac *RBAC
	// contains filtered or unexported fields
}

func (RBACPerRoute_builder) Build

func (b0 RBACPerRoute_builder) Build() *RBACPerRoute

type RBAC_builder

type RBAC_builder struct {

	// Specify the RBAC rules to be applied globally.
	// If absent, no enforcing RBAC policy will be applied.
	Rules *v2.RBAC
	// Shadow rules are not enforced by the filter (i.e., returning a 403)
	// but will emit stats and logs and can be used for rule testing.
	// If absent, no shadow RBAC policy will be applied.
	ShadowRules *v2.RBAC
	// contains filtered or unexported fields
}

func (RBAC_builder) Build

func (b0 RBAC_builder) Build() *RBAC

Source Files

  • rbac.pb.go

Jump to