Documentation
¶
Index ¶
- Variables
- type Router
- func (x *Router) ClearDynamicStats()
- func (x *Router) GetDynamicStats() *wrapperspb.BoolValue
- func (x *Router) GetRespectExpectedRqTimeout() bool
- func (x *Router) GetStartChildSpan() bool
- func (x *Router) GetStrictCheckHeaders() []string
- func (x *Router) GetSuppressEnvoyHeaders() bool
- func (x *Router) GetUpstreamLog() []*v2.AccessLog
- func (x *Router) HasDynamicStats() bool
- func (*Router) ProtoMessage()
- func (x *Router) ProtoReflect() protoreflect.Message
- func (x *Router) Reset()
- func (x *Router) SetDynamicStats(v *wrapperspb.BoolValue)
- func (x *Router) SetRespectExpectedRqTimeout(v bool)
- func (x *Router) SetStartChildSpan(v bool)
- func (x *Router) SetStrictCheckHeaders(v []string)
- func (x *Router) SetSuppressEnvoyHeaders(v bool)
- func (x *Router) SetUpstreamLog(v []*v2.AccessLog)
- func (x *Router) String() string
- type Router_builder
Constants ¶
This section is empty.
Variables ¶
var File_envoy_config_filter_http_router_v2_router_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Router ¶
type Router struct {
// Whether the router generates dynamic cluster statistics. Defaults to
// true. Can be disabled in high performance scenarios.
DynamicStats *wrapperspb.BoolValue `protobuf:"bytes,1,opt,name=dynamic_stats,json=dynamicStats,proto3" json:"dynamic_stats,omitempty"`
// Whether to start a child span for egress routed calls. This can be
// useful in scenarios where other filters (auth, ratelimit, etc.) make
// outbound calls and have child spans rooted at the same ingress
// parent. Defaults to false.
StartChildSpan bool `protobuf:"varint,2,opt,name=start_child_span,json=startChildSpan,proto3" json:"start_child_span,omitempty"`
// Configuration for HTTP upstream logs emitted by the router. Upstream logs
// are configured in the same way as access logs, but each log entry represents
// an upstream request. Presuming retries are configured, multiple upstream
// requests may be made for each downstream (inbound) request.
UpstreamLog []*v2.AccessLog `protobuf:"bytes,3,rep,name=upstream_log,json=upstreamLog,proto3" json:"upstream_log,omitempty"`
// Do not add any additional *x-envoy-* headers to requests or responses. This
// only affects the :ref:`router filter generated *x-envoy-* headers
// <config_http_filters_router_headers_set>`, other Envoy filters and the HTTP
// connection manager may continue to set *x-envoy-* headers.
SuppressEnvoyHeaders bool `protobuf:"varint,4,opt,name=suppress_envoy_headers,json=suppressEnvoyHeaders,proto3" json:"suppress_envoy_headers,omitempty"`
// Specifies a list of HTTP headers to strictly validate. Envoy will reject a
// request and respond with HTTP status 400 if the request contains an invalid
// value for any of the headers listed in this field. Strict header checking
// is only supported for the following headers:
//
// Value must be a ','-delimited list (i.e. no spaces) of supported retry
// policy values:
//
// * :ref:`config_http_filters_router_x-envoy-retry-grpc-on`
// * :ref:`config_http_filters_router_x-envoy-retry-on`
//
// Value must be an integer:
//
// * :ref:`config_http_filters_router_x-envoy-max-retries`
// * :ref:`config_http_filters_router_x-envoy-upstream-rq-timeout-ms`
// * :ref:`config_http_filters_router_x-envoy-upstream-rq-per-try-timeout-ms`
StrictCheckHeaders []string `protobuf:"bytes,5,rep,name=strict_check_headers,json=strictCheckHeaders,proto3" json:"strict_check_headers,omitempty"`
// If not set, ingress Envoy will ignore
// :ref:`config_http_filters_router_x-envoy-expected-rq-timeout-ms` header, populated by egress
// Envoy, when deriving timeout for upstream cluster.
RespectExpectedRqTimeout bool `` /* 138-byte string literal not displayed */
// contains filtered or unexported fields
}
[#next-free-field: 7]
func (*Router) GetDynamicStats ¶
func (x *Router) GetDynamicStats() *wrapperspb.BoolValue
func (*Router) ProtoReflect ¶
func (x *Router) ProtoReflect() protoreflect.Message
func (*Router) SetDynamicStats ¶
func (x *Router) SetDynamicStats(v *wrapperspb.BoolValue)
type Router_builder ¶
type Router_builder struct {
// Whether the router generates dynamic cluster statistics. Defaults to
// true. Can be disabled in high performance scenarios.
DynamicStats *wrapperspb.BoolValue
// Whether to start a child span for egress routed calls. This can be
// useful in scenarios where other filters (auth, ratelimit, etc.) make
// outbound calls and have child spans rooted at the same ingress
// parent. Defaults to false.
StartChildSpan bool
// Configuration for HTTP upstream logs emitted by the router. Upstream logs
// are configured in the same way as access logs, but each log entry represents
// an upstream request. Presuming retries are configured, multiple upstream
// requests may be made for each downstream (inbound) request.
UpstreamLog []*v2.AccessLog
// Do not add any additional *x-envoy-* headers to requests or responses. This
// only affects the :ref:`router filter generated *x-envoy-* headers
// <config_http_filters_router_headers_set>`, other Envoy filters and the HTTP
// connection manager may continue to set *x-envoy-* headers.
SuppressEnvoyHeaders bool
// Specifies a list of HTTP headers to strictly validate. Envoy will reject a
// request and respond with HTTP status 400 if the request contains an invalid
// value for any of the headers listed in this field. Strict header checking
// is only supported for the following headers:
//
// Value must be a ','-delimited list (i.e. no spaces) of supported retry
// policy values:
//
// * :ref:`config_http_filters_router_x-envoy-retry-grpc-on`
// * :ref:`config_http_filters_router_x-envoy-retry-on`
//
// Value must be an integer:
//
// * :ref:`config_http_filters_router_x-envoy-max-retries`
// * :ref:`config_http_filters_router_x-envoy-upstream-rq-timeout-ms`
// * :ref:`config_http_filters_router_x-envoy-upstream-rq-per-try-timeout-ms`
StrictCheckHeaders []string
// If not set, ingress Envoy will ignore
// :ref:`config_http_filters_router_x-envoy-expected-rq-timeout-ms` header, populated by egress
// Envoy, when deriving timeout for upstream cluster.
RespectExpectedRqTimeout bool
// contains filtered or unexported fields
}
func (Router_builder) Build ¶
func (b0 Router_builder) Build() *Router
Source Files
¶
- router.pb.go
Click to show internal directories.
Click to hide internal directories.