Documentation
¶
Index ¶
- Variables
- type Squash
- func (x *Squash) ClearAttachmentPollPeriod()
- func (x *Squash) ClearAttachmentTemplate()
- func (x *Squash) ClearAttachmentTimeout()
- func (x *Squash) ClearRequestTimeout()
- func (x *Squash) GetAttachmentPollPeriod() *durationpb.Duration
- func (x *Squash) GetAttachmentTemplate() *structpb.Struct
- func (x *Squash) GetAttachmentTimeout() *durationpb.Duration
- func (x *Squash) GetCluster() string
- func (x *Squash) GetRequestTimeout() *durationpb.Duration
- func (x *Squash) HasAttachmentPollPeriod() bool
- func (x *Squash) HasAttachmentTemplate() bool
- func (x *Squash) HasAttachmentTimeout() bool
- func (x *Squash) HasRequestTimeout() bool
- func (*Squash) ProtoMessage()
- func (x *Squash) ProtoReflect() protoreflect.Message
- func (x *Squash) Reset()
- func (x *Squash) SetAttachmentPollPeriod(v *durationpb.Duration)
- func (x *Squash) SetAttachmentTemplate(v *structpb.Struct)
- func (x *Squash) SetAttachmentTimeout(v *durationpb.Duration)
- func (x *Squash) SetCluster(v string)
- func (x *Squash) SetRequestTimeout(v *durationpb.Duration)
- func (x *Squash) String() string
- type Squash_builder
Constants ¶
This section is empty.
Variables ¶
var File_envoy_config_filter_http_squash_v2_squash_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Squash ¶
type Squash struct {
// The name of the cluster that hosts the Squash server.
Cluster string `protobuf:"bytes,1,opt,name=cluster,proto3" json:"cluster,omitempty"`
// When the filter requests the Squash server to create a DebugAttachment, it will use this
// structure as template for the body of the request. It can contain reference to environment
// variables in the form of '{{ ENV_VAR_NAME }}'. These can be used to provide the Squash server
// with more information to find the process to attach the debugger to. For example, in a
// Istio/k8s environment, this will contain information on the pod:
//
// .. code-block:: json
//
// {
// "spec": {
// "attachment": {
// "pod": "{{ POD_NAME }}",
// "namespace": "{{ POD_NAMESPACE }}"
// },
// "match_request": true
// }
// }
//
// (where POD_NAME, POD_NAMESPACE are configured in the pod via the Downward API)
AttachmentTemplate *structpb.Struct `protobuf:"bytes,2,opt,name=attachment_template,json=attachmentTemplate,proto3" json:"attachment_template,omitempty"`
// The timeout for individual requests sent to the Squash cluster. Defaults to 1 second.
RequestTimeout *durationpb.Duration `protobuf:"bytes,3,opt,name=request_timeout,json=requestTimeout,proto3" json:"request_timeout,omitempty"`
// The total timeout Squash will delay a request and wait for it to be attached. Defaults to 60
// seconds.
AttachmentTimeout *durationpb.Duration `protobuf:"bytes,4,opt,name=attachment_timeout,json=attachmentTimeout,proto3" json:"attachment_timeout,omitempty"`
// Amount of time to poll for the status of the attachment object in the Squash server
// (to check if has been attached). Defaults to 1 second.
AttachmentPollPeriod *durationpb.Duration `protobuf:"bytes,5,opt,name=attachment_poll_period,json=attachmentPollPeriod,proto3" json:"attachment_poll_period,omitempty"`
// contains filtered or unexported fields
}
[#next-free-field: 6]
func (*Squash) GetAttachmentPollPeriod ¶
func (x *Squash) GetAttachmentPollPeriod() *durationpb.Duration
func (*Squash) GetAttachmentTimeout ¶
func (x *Squash) GetAttachmentTimeout() *durationpb.Duration
func (*Squash) GetRequestTimeout ¶
func (x *Squash) GetRequestTimeout() *durationpb.Duration
func (*Squash) ProtoReflect ¶
func (x *Squash) ProtoReflect() protoreflect.Message
func (*Squash) SetAttachmentPollPeriod ¶
func (x *Squash) SetAttachmentPollPeriod(v *durationpb.Duration)
func (*Squash) SetAttachmentTimeout ¶
func (x *Squash) SetAttachmentTimeout(v *durationpb.Duration)
func (*Squash) SetRequestTimeout ¶
func (x *Squash) SetRequestTimeout(v *durationpb.Duration)
type Squash_builder ¶
type Squash_builder struct {
// The name of the cluster that hosts the Squash server.
Cluster string
// When the filter requests the Squash server to create a DebugAttachment, it will use this
// structure as template for the body of the request. It can contain reference to environment
// variables in the form of '{{ ENV_VAR_NAME }}'. These can be used to provide the Squash server
// with more information to find the process to attach the debugger to. For example, in a
// Istio/k8s environment, this will contain information on the pod:
//
// .. code-block:: json
//
// {
// "spec": {
// "attachment": {
// "pod": "{{ POD_NAME }}",
// "namespace": "{{ POD_NAMESPACE }}"
// },
// "match_request": true
// }
// }
//
// (where POD_NAME, POD_NAMESPACE are configured in the pod via the Downward API)
AttachmentTemplate *structpb.Struct
// The timeout for individual requests sent to the Squash cluster. Defaults to 1 second.
RequestTimeout *durationpb.Duration
// The total timeout Squash will delay a request and wait for it to be attached. Defaults to 60
// seconds.
AttachmentTimeout *durationpb.Duration
// Amount of time to poll for the status of the attachment object in the Squash server
// (to check if has been attached). Defaults to 1 second.
AttachmentPollPeriod *durationpb.Duration
// contains filtered or unexported fields
}
func (Squash_builder) Build ¶
func (b0 Squash_builder) Build() *Squash
Source Files
¶
- squash.pb.go
Click to show internal directories.
Click to hide internal directories.