Documentation
¶
Index ¶
- Constants
- Variables
- type GrpcJsonTranscoder
- func (x *GrpcJsonTranscoder) ClearDescriptorSet()
- func (x *GrpcJsonTranscoder) ClearPrintOptions()
- func (x *GrpcJsonTranscoder) ClearProtoDescriptor()
- func (x *GrpcJsonTranscoder) ClearProtoDescriptorBin()
- func (x *GrpcJsonTranscoder) GetAutoMapping() bool
- func (x *GrpcJsonTranscoder) GetConvertGrpcStatus() bool
- func (x *GrpcJsonTranscoder) GetDescriptorSet() isGrpcJsonTranscoder_DescriptorSet
- func (x *GrpcJsonTranscoder) GetIgnoreUnknownQueryParameters() bool
- func (x *GrpcJsonTranscoder) GetIgnoredQueryParameters() []string
- func (x *GrpcJsonTranscoder) GetMatchIncomingRequestRoute() bool
- func (x *GrpcJsonTranscoder) GetPrintOptions() *GrpcJsonTranscoder_PrintOptions
- func (x *GrpcJsonTranscoder) GetProtoDescriptor() string
- func (x *GrpcJsonTranscoder) GetProtoDescriptorBin() []byte
- func (x *GrpcJsonTranscoder) GetServices() []string
- func (x *GrpcJsonTranscoder) HasDescriptorSet() bool
- func (x *GrpcJsonTranscoder) HasPrintOptions() bool
- func (x *GrpcJsonTranscoder) HasProtoDescriptor() bool
- func (x *GrpcJsonTranscoder) HasProtoDescriptorBin() bool
- func (*GrpcJsonTranscoder) ProtoMessage()
- func (x *GrpcJsonTranscoder) ProtoReflect() protoreflect.Message
- func (x *GrpcJsonTranscoder) Reset()
- func (x *GrpcJsonTranscoder) SetAutoMapping(v bool)
- func (x *GrpcJsonTranscoder) SetConvertGrpcStatus(v bool)
- func (x *GrpcJsonTranscoder) SetIgnoreUnknownQueryParameters(v bool)
- func (x *GrpcJsonTranscoder) SetIgnoredQueryParameters(v []string)
- func (x *GrpcJsonTranscoder) SetMatchIncomingRequestRoute(v bool)
- func (x *GrpcJsonTranscoder) SetPrintOptions(v *GrpcJsonTranscoder_PrintOptions)
- func (x *GrpcJsonTranscoder) SetProtoDescriptor(v string)
- func (x *GrpcJsonTranscoder) SetProtoDescriptorBin(v []byte)
- func (x *GrpcJsonTranscoder) SetServices(v []string)
- func (x *GrpcJsonTranscoder) String() string
- func (x *GrpcJsonTranscoder) WhichDescriptorSet() case_GrpcJsonTranscoder_DescriptorSet
- type GrpcJsonTranscoder_PrintOptions
- func (x *GrpcJsonTranscoder_PrintOptions) GetAddWhitespace() bool
- func (x *GrpcJsonTranscoder_PrintOptions) GetAlwaysPrintEnumsAsInts() bool
- func (x *GrpcJsonTranscoder_PrintOptions) GetAlwaysPrintPrimitiveFields() bool
- func (x *GrpcJsonTranscoder_PrintOptions) GetPreserveProtoFieldNames() bool
- func (*GrpcJsonTranscoder_PrintOptions) ProtoMessage()
- func (x *GrpcJsonTranscoder_PrintOptions) ProtoReflect() protoreflect.Message
- func (x *GrpcJsonTranscoder_PrintOptions) Reset()
- func (x *GrpcJsonTranscoder_PrintOptions) SetAddWhitespace(v bool)
- func (x *GrpcJsonTranscoder_PrintOptions) SetAlwaysPrintEnumsAsInts(v bool)
- func (x *GrpcJsonTranscoder_PrintOptions) SetAlwaysPrintPrimitiveFields(v bool)
- func (x *GrpcJsonTranscoder_PrintOptions) SetPreserveProtoFieldNames(v bool)
- func (x *GrpcJsonTranscoder_PrintOptions) String() string
- type GrpcJsonTranscoder_PrintOptions_builder
- type GrpcJsonTranscoder_ProtoDescriptor
- type GrpcJsonTranscoder_ProtoDescriptorBin
- type GrpcJsonTranscoder_builder
Constants ¶
const GrpcJsonTranscoder_DescriptorSet_not_set_case case_GrpcJsonTranscoder_DescriptorSet = 0
const GrpcJsonTranscoder_ProtoDescriptorBin_case case_GrpcJsonTranscoder_DescriptorSet = 4
const GrpcJsonTranscoder_ProtoDescriptor_case case_GrpcJsonTranscoder_DescriptorSet = 1
Variables ¶
var File_envoy_config_filter_http_transcoder_v2_transcoder_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type GrpcJsonTranscoder ¶
type GrpcJsonTranscoder struct {
// Types that are valid to be assigned to DescriptorSet:
//
// *GrpcJsonTranscoder_ProtoDescriptor
// *GrpcJsonTranscoder_ProtoDescriptorBin
DescriptorSet isGrpcJsonTranscoder_DescriptorSet `protobuf_oneof:"descriptor_set"`
// A list of strings that
// supplies the fully qualified service names (i.e. "package_name.service_name") that
// the transcoder will translate. If the service name doesn't exist in “proto_descriptor“,
// Envoy will fail at startup. The “proto_descriptor“ may contain more services than
// the service names specified here, but they won't be translated.
Services []string `protobuf:"bytes,2,rep,name=services,proto3" json:"services,omitempty"`
// Control options for response JSON. These options are passed directly to
// `JsonPrintOptions <https://developers.google.com/protocol-buffers/docs/reference/cpp/
// google.protobuf.util.json_util#JsonPrintOptions>`_.
PrintOptions *GrpcJsonTranscoder_PrintOptions `protobuf:"bytes,3,opt,name=print_options,json=printOptions,proto3" json:"print_options,omitempty"`
// Whether to keep the incoming request route after the outgoing headers have been transformed to
// the match the upstream gRPC service. Note: This means that routes for gRPC services that are
// not transcoded cannot be used in combination with *match_incoming_request_route*.
MatchIncomingRequestRoute bool `` /* 141-byte string literal not displayed */
// A list of query parameters to be ignored for transcoding method mapping.
// By default, the transcoder filter will not transcode a request if there are any
// unknown/invalid query parameters.
//
// Example :
//
// .. code-block:: proto
//
// service Bookstore {
// rpc GetShelf(GetShelfRequest) returns (Shelf) {
// option (google.api.http) = {
// get: "/shelves/{shelf}"
// };
// }
// }
//
// message GetShelfRequest {
// int64 shelf = 1;
// }
//
// message Shelf {}
//
// The request “/shelves/100?foo=bar“ will not be mapped to “GetShelf“` because variable
// binding for “foo“ is not defined. Adding “foo“ to “ignored_query_parameters“ will allow
// the same request to be mapped to “GetShelf“.
IgnoredQueryParameters []string `` /* 129-byte string literal not displayed */
// Whether to route methods without the “google.api.http“ option.
//
// Example :
//
// .. code-block:: proto
//
// package bookstore;
//
// service Bookstore {
// rpc GetShelf(GetShelfRequest) returns (Shelf) {}
// }
//
// message GetShelfRequest {
// int64 shelf = 1;
// }
//
// message Shelf {}
//
// The client could “post“ a json body “{"shelf": 1234}“ with the path of
// “/bookstore.Bookstore/GetShelfRequest“ to call “GetShelfRequest“.
AutoMapping bool `protobuf:"varint,7,opt,name=auto_mapping,json=autoMapping,proto3" json:"auto_mapping,omitempty"`
// Whether to ignore query parameters that cannot be mapped to a corresponding
// protobuf field. Use this if you cannot control the query parameters and do
// not know them beforehand. Otherwise use “ignored_query_parameters“.
// Defaults to false.
IgnoreUnknownQueryParameters bool `` /* 150-byte string literal not displayed */
// Whether to convert gRPC status headers to JSON.
// When trailer indicates a gRPC error and there was no HTTP body, take “google.rpc.Status“
// from the “grpc-status-details-bin“ header and use it as JSON body.
// If there was no such header, make “google.rpc.Status“ out of the “grpc-status“ and
// “grpc-message“ headers.
// The error details types must be present in the “proto_descriptor“.
//
// For example, if an upstream server replies with headers:
//
// .. code-block:: none
//
// grpc-status: 5
// grpc-status-details-bin:
// CAUaMwoqdHlwZS5nb29nbGVhcGlzLmNvbS9nb29nbGUucnBjLlJlcXVlc3RJbmZvEgUKA3ItMQ
//
// The “grpc-status-details-bin“ header contains a base64-encoded protobuf message
// “google.rpc.Status“. It will be transcoded into:
//
// .. code-block:: none
//
// HTTP/1.1 404 Not Found
// content-type: application/json
//
// {"code":5,"details":[{"@type":"type.googleapis.com/google.rpc.RequestInfo","requestId":"r-1"}]}
//
// In order to transcode the message, the “google.rpc.RequestInfo“ type from
// the “google/rpc/error_details.proto“ should be included in the configured
// :ref:`proto descriptor set <config_grpc_json_generate_proto_descriptor_set>`.
ConvertGrpcStatus bool `protobuf:"varint,9,opt,name=convert_grpc_status,json=convertGrpcStatus,proto3" json:"convert_grpc_status,omitempty"`
// contains filtered or unexported fields
}
[#next-free-field: 10]
func (*GrpcJsonTranscoder) ClearDescriptorSet ¶
func (x *GrpcJsonTranscoder) ClearDescriptorSet()
func (*GrpcJsonTranscoder) ClearPrintOptions ¶
func (x *GrpcJsonTranscoder) ClearPrintOptions()
func (*GrpcJsonTranscoder) ClearProtoDescriptor ¶
func (x *GrpcJsonTranscoder) ClearProtoDescriptor()
func (*GrpcJsonTranscoder) ClearProtoDescriptorBin ¶
func (x *GrpcJsonTranscoder) ClearProtoDescriptorBin()
func (*GrpcJsonTranscoder) GetAutoMapping ¶
func (x *GrpcJsonTranscoder) GetAutoMapping() bool
func (*GrpcJsonTranscoder) GetConvertGrpcStatus ¶
func (x *GrpcJsonTranscoder) GetConvertGrpcStatus() bool
func (*GrpcJsonTranscoder) GetDescriptorSet ¶
func (x *GrpcJsonTranscoder) GetDescriptorSet() isGrpcJsonTranscoder_DescriptorSet
func (*GrpcJsonTranscoder) GetIgnoreUnknownQueryParameters ¶
func (x *GrpcJsonTranscoder) GetIgnoreUnknownQueryParameters() bool
func (*GrpcJsonTranscoder) GetIgnoredQueryParameters ¶
func (x *GrpcJsonTranscoder) GetIgnoredQueryParameters() []string
func (*GrpcJsonTranscoder) GetMatchIncomingRequestRoute ¶
func (x *GrpcJsonTranscoder) GetMatchIncomingRequestRoute() bool
func (*GrpcJsonTranscoder) GetPrintOptions ¶
func (x *GrpcJsonTranscoder) GetPrintOptions() *GrpcJsonTranscoder_PrintOptions
func (*GrpcJsonTranscoder) GetProtoDescriptor ¶
func (x *GrpcJsonTranscoder) GetProtoDescriptor() string
func (*GrpcJsonTranscoder) GetProtoDescriptorBin ¶
func (x *GrpcJsonTranscoder) GetProtoDescriptorBin() []byte
func (*GrpcJsonTranscoder) GetServices ¶
func (x *GrpcJsonTranscoder) GetServices() []string
func (*GrpcJsonTranscoder) HasDescriptorSet ¶
func (x *GrpcJsonTranscoder) HasDescriptorSet() bool
func (*GrpcJsonTranscoder) HasPrintOptions ¶
func (x *GrpcJsonTranscoder) HasPrintOptions() bool
func (*GrpcJsonTranscoder) HasProtoDescriptor ¶
func (x *GrpcJsonTranscoder) HasProtoDescriptor() bool
func (*GrpcJsonTranscoder) HasProtoDescriptorBin ¶
func (x *GrpcJsonTranscoder) HasProtoDescriptorBin() bool
func (*GrpcJsonTranscoder) ProtoMessage ¶
func (*GrpcJsonTranscoder) ProtoMessage()
func (*GrpcJsonTranscoder) ProtoReflect ¶
func (x *GrpcJsonTranscoder) ProtoReflect() protoreflect.Message
func (*GrpcJsonTranscoder) Reset ¶
func (x *GrpcJsonTranscoder) Reset()
func (*GrpcJsonTranscoder) SetAutoMapping ¶
func (x *GrpcJsonTranscoder) SetAutoMapping(v bool)
func (*GrpcJsonTranscoder) SetConvertGrpcStatus ¶
func (x *GrpcJsonTranscoder) SetConvertGrpcStatus(v bool)
func (*GrpcJsonTranscoder) SetIgnoreUnknownQueryParameters ¶
func (x *GrpcJsonTranscoder) SetIgnoreUnknownQueryParameters(v bool)
func (*GrpcJsonTranscoder) SetIgnoredQueryParameters ¶
func (x *GrpcJsonTranscoder) SetIgnoredQueryParameters(v []string)
func (*GrpcJsonTranscoder) SetMatchIncomingRequestRoute ¶
func (x *GrpcJsonTranscoder) SetMatchIncomingRequestRoute(v bool)
func (*GrpcJsonTranscoder) SetPrintOptions ¶
func (x *GrpcJsonTranscoder) SetPrintOptions(v *GrpcJsonTranscoder_PrintOptions)
func (*GrpcJsonTranscoder) SetProtoDescriptor ¶
func (x *GrpcJsonTranscoder) SetProtoDescriptor(v string)
func (*GrpcJsonTranscoder) SetProtoDescriptorBin ¶
func (x *GrpcJsonTranscoder) SetProtoDescriptorBin(v []byte)
func (*GrpcJsonTranscoder) SetServices ¶
func (x *GrpcJsonTranscoder) SetServices(v []string)
func (*GrpcJsonTranscoder) String ¶
func (x *GrpcJsonTranscoder) String() string
func (*GrpcJsonTranscoder) WhichDescriptorSet ¶
func (x *GrpcJsonTranscoder) WhichDescriptorSet() case_GrpcJsonTranscoder_DescriptorSet
type GrpcJsonTranscoder_PrintOptions ¶
type GrpcJsonTranscoder_PrintOptions struct {
// Whether to add spaces, line breaks and indentation to make the JSON
// output easy to read. Defaults to false.
AddWhitespace bool `protobuf:"varint,1,opt,name=add_whitespace,json=addWhitespace,proto3" json:"add_whitespace,omitempty"`
// Whether to always print primitive fields. By default primitive
// fields with default values will be omitted in JSON output. For
// example, an int32 field set to 0 will be omitted. Setting this flag to
// true will override the default behavior and print primitive fields
// regardless of their values. Defaults to false.
AlwaysPrintPrimitiveFields bool `` /* 144-byte string literal not displayed */
// Whether to always print enums as ints. By default they are rendered
// as strings. Defaults to false.
AlwaysPrintEnumsAsInts bool `` /* 134-byte string literal not displayed */
// Whether to preserve proto field names. By default protobuf will
// generate JSON field names using the “json_name“ option, or lower camel case,
// in that order. Setting this flag will preserve the original field names. Defaults to false.
PreserveProtoFieldNames bool `` /* 135-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*GrpcJsonTranscoder_PrintOptions) GetAddWhitespace ¶
func (x *GrpcJsonTranscoder_PrintOptions) GetAddWhitespace() bool
func (*GrpcJsonTranscoder_PrintOptions) GetAlwaysPrintEnumsAsInts ¶
func (x *GrpcJsonTranscoder_PrintOptions) GetAlwaysPrintEnumsAsInts() bool
func (*GrpcJsonTranscoder_PrintOptions) GetAlwaysPrintPrimitiveFields ¶
func (x *GrpcJsonTranscoder_PrintOptions) GetAlwaysPrintPrimitiveFields() bool
func (*GrpcJsonTranscoder_PrintOptions) GetPreserveProtoFieldNames ¶
func (x *GrpcJsonTranscoder_PrintOptions) GetPreserveProtoFieldNames() bool
func (*GrpcJsonTranscoder_PrintOptions) ProtoMessage ¶
func (*GrpcJsonTranscoder_PrintOptions) ProtoMessage()
func (*GrpcJsonTranscoder_PrintOptions) ProtoReflect ¶
func (x *GrpcJsonTranscoder_PrintOptions) ProtoReflect() protoreflect.Message
func (*GrpcJsonTranscoder_PrintOptions) Reset ¶
func (x *GrpcJsonTranscoder_PrintOptions) Reset()
func (*GrpcJsonTranscoder_PrintOptions) SetAddWhitespace ¶
func (x *GrpcJsonTranscoder_PrintOptions) SetAddWhitespace(v bool)
func (*GrpcJsonTranscoder_PrintOptions) SetAlwaysPrintEnumsAsInts ¶
func (x *GrpcJsonTranscoder_PrintOptions) SetAlwaysPrintEnumsAsInts(v bool)
func (*GrpcJsonTranscoder_PrintOptions) SetAlwaysPrintPrimitiveFields ¶
func (x *GrpcJsonTranscoder_PrintOptions) SetAlwaysPrintPrimitiveFields(v bool)
func (*GrpcJsonTranscoder_PrintOptions) SetPreserveProtoFieldNames ¶
func (x *GrpcJsonTranscoder_PrintOptions) SetPreserveProtoFieldNames(v bool)
func (*GrpcJsonTranscoder_PrintOptions) String ¶
func (x *GrpcJsonTranscoder_PrintOptions) String() string
type GrpcJsonTranscoder_PrintOptions_builder ¶
type GrpcJsonTranscoder_PrintOptions_builder struct {
// Whether to add spaces, line breaks and indentation to make the JSON
// output easy to read. Defaults to false.
AddWhitespace bool
// Whether to always print primitive fields. By default primitive
// fields with default values will be omitted in JSON output. For
// example, an int32 field set to 0 will be omitted. Setting this flag to
// true will override the default behavior and print primitive fields
// regardless of their values. Defaults to false.
AlwaysPrintPrimitiveFields bool
// Whether to always print enums as ints. By default they are rendered
// as strings. Defaults to false.
AlwaysPrintEnumsAsInts bool
// Whether to preserve proto field names. By default protobuf will
// generate JSON field names using the “json_name“ option, or lower camel case,
// in that order. Setting this flag will preserve the original field names. Defaults to false.
PreserveProtoFieldNames bool
// contains filtered or unexported fields
}
func (GrpcJsonTranscoder_PrintOptions_builder) Build ¶
func (b0 GrpcJsonTranscoder_PrintOptions_builder) Build() *GrpcJsonTranscoder_PrintOptions
type GrpcJsonTranscoder_ProtoDescriptor ¶
type GrpcJsonTranscoder_ProtoDescriptor struct {
// Supplies the filename of
// :ref:`the proto descriptor set <config_grpc_json_generate_proto_descriptor_set>` for the gRPC
// services.
ProtoDescriptor string `protobuf:"bytes,1,opt,name=proto_descriptor,json=protoDescriptor,proto3,oneof"`
}
type GrpcJsonTranscoder_ProtoDescriptorBin ¶
type GrpcJsonTranscoder_ProtoDescriptorBin struct {
// Supplies the binary content of
// :ref:`the proto descriptor set <config_grpc_json_generate_proto_descriptor_set>` for the gRPC
// services.
ProtoDescriptorBin []byte `protobuf:"bytes,4,opt,name=proto_descriptor_bin,json=protoDescriptorBin,proto3,oneof"`
}
type GrpcJsonTranscoder_builder ¶
type GrpcJsonTranscoder_builder struct {
// Fields of oneof DescriptorSet:
// Supplies the filename of
// :ref:`the proto descriptor set <config_grpc_json_generate_proto_descriptor_set>` for the gRPC
// services.
ProtoDescriptor *string
// Supplies the binary content of
// :ref:`the proto descriptor set <config_grpc_json_generate_proto_descriptor_set>` for the gRPC
// services.
ProtoDescriptorBin []byte
// -- end of DescriptorSet
// A list of strings that
// supplies the fully qualified service names (i.e. "package_name.service_name") that
// the transcoder will translate. If the service name doesn't exist in “proto_descriptor“,
// Envoy will fail at startup. The “proto_descriptor“ may contain more services than
// the service names specified here, but they won't be translated.
Services []string
// Control options for response JSON. These options are passed directly to
// `JsonPrintOptions <https://developers.google.com/protocol-buffers/docs/reference/cpp/
// google.protobuf.util.json_util#JsonPrintOptions>`_.
PrintOptions *GrpcJsonTranscoder_PrintOptions
// Whether to keep the incoming request route after the outgoing headers have been transformed to
// the match the upstream gRPC service. Note: This means that routes for gRPC services that are
// not transcoded cannot be used in combination with *match_incoming_request_route*.
MatchIncomingRequestRoute bool
// A list of query parameters to be ignored for transcoding method mapping.
// By default, the transcoder filter will not transcode a request if there are any
// unknown/invalid query parameters.
//
// Example :
//
// .. code-block:: proto
//
// service Bookstore {
// rpc GetShelf(GetShelfRequest) returns (Shelf) {
// option (google.api.http) = {
// get: "/shelves/{shelf}"
// };
// }
// }
//
// message GetShelfRequest {
// int64 shelf = 1;
// }
//
// message Shelf {}
//
// The request “/shelves/100?foo=bar“ will not be mapped to “GetShelf“` because variable
// binding for “foo“ is not defined. Adding “foo“ to “ignored_query_parameters“ will allow
// the same request to be mapped to “GetShelf“.
IgnoredQueryParameters []string
// Whether to route methods without the “google.api.http“ option.
//
// Example :
//
// .. code-block:: proto
//
// package bookstore;
//
// service Bookstore {
// rpc GetShelf(GetShelfRequest) returns (Shelf) {}
// }
//
// message GetShelfRequest {
// int64 shelf = 1;
// }
//
// message Shelf {}
//
// The client could “post“ a json body “{"shelf": 1234}“ with the path of
// “/bookstore.Bookstore/GetShelfRequest“ to call “GetShelfRequest“.
AutoMapping bool
// Whether to ignore query parameters that cannot be mapped to a corresponding
// protobuf field. Use this if you cannot control the query parameters and do
// not know them beforehand. Otherwise use “ignored_query_parameters“.
// Defaults to false.
IgnoreUnknownQueryParameters bool
// Whether to convert gRPC status headers to JSON.
// When trailer indicates a gRPC error and there was no HTTP body, take “google.rpc.Status“
// from the “grpc-status-details-bin“ header and use it as JSON body.
// If there was no such header, make “google.rpc.Status“ out of the “grpc-status“ and
// “grpc-message“ headers.
// The error details types must be present in the “proto_descriptor“.
//
// For example, if an upstream server replies with headers:
//
// .. code-block:: none
//
// grpc-status: 5
// grpc-status-details-bin:
// CAUaMwoqdHlwZS5nb29nbGVhcGlzLmNvbS9nb29nbGUucnBjLlJlcXVlc3RJbmZvEgUKA3ItMQ
//
// The “grpc-status-details-bin“ header contains a base64-encoded protobuf message
// “google.rpc.Status“. It will be transcoded into:
//
// .. code-block:: none
//
// HTTP/1.1 404 Not Found
// content-type: application/json
//
// {"code":5,"details":[{"@type":"type.googleapis.com/google.rpc.RequestInfo","requestId":"r-1"}]}
//
// In order to transcode the message, the “google.rpc.RequestInfo“ type from
// the “google/rpc/error_details.proto“ should be included in the configured
// :ref:`proto descriptor set <config_grpc_json_generate_proto_descriptor_set>`.
ConvertGrpcStatus bool
// contains filtered or unexported fields
}
func (GrpcJsonTranscoder_builder) Build ¶
func (b0 GrpcJsonTranscoder_builder) Build() *GrpcJsonTranscoder
Source Files
¶
- transcoder.pb.go
Click to show internal directories.
Click to hide internal directories.