Documentation
¶
Index ¶
- Variables
- type ClientSSLAuth
- func (x *ClientSSLAuth) ClearRefreshDelay()
- func (x *ClientSSLAuth) GetAuthApiCluster() string
- func (x *ClientSSLAuth) GetIpWhiteList() []*core.CidrRange
- func (x *ClientSSLAuth) GetRefreshDelay() *durationpb.Duration
- func (x *ClientSSLAuth) GetStatPrefix() string
- func (x *ClientSSLAuth) HasRefreshDelay() bool
- func (*ClientSSLAuth) ProtoMessage()
- func (x *ClientSSLAuth) ProtoReflect() protoreflect.Message
- func (x *ClientSSLAuth) Reset()
- func (x *ClientSSLAuth) SetAuthApiCluster(v string)
- func (x *ClientSSLAuth) SetIpWhiteList(v []*core.CidrRange)
- func (x *ClientSSLAuth) SetRefreshDelay(v *durationpb.Duration)
- func (x *ClientSSLAuth) SetStatPrefix(v string)
- func (x *ClientSSLAuth) String() string
- type ClientSSLAuth_builder
Constants ¶
This section is empty.
Variables ¶
var File_envoy_config_filter_network_client_ssl_auth_v2_client_ssl_auth_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type ClientSSLAuth ¶
type ClientSSLAuth struct {
// The :ref:`cluster manager <arch_overview_cluster_manager>` cluster that runs
// the authentication service. The filter will connect to the service every 60s to fetch the list
// of principals. The service must support the expected :ref:`REST API
// <config_network_filters_client_ssl_auth_rest_api>`.
AuthApiCluster string `protobuf:"bytes,1,opt,name=auth_api_cluster,json=authApiCluster,proto3" json:"auth_api_cluster,omitempty"`
// The prefix to use when emitting :ref:`statistics
// <config_network_filters_client_ssl_auth_stats>`.
StatPrefix string `protobuf:"bytes,2,opt,name=stat_prefix,json=statPrefix,proto3" json:"stat_prefix,omitempty"`
// Time in milliseconds between principal refreshes from the
// authentication service. Default is 60000 (60s). The actual fetch time
// will be this value plus a random jittered value between
// 0-refresh_delay_ms milliseconds.
RefreshDelay *durationpb.Duration `protobuf:"bytes,3,opt,name=refresh_delay,json=refreshDelay,proto3" json:"refresh_delay,omitempty"`
// An optional list of IP address and subnet masks that should be white
// listed for access by the filter. If no list is provided, there is no
// IP allowlist.
IpWhiteList []*core.CidrRange `protobuf:"bytes,4,rep,name=ip_white_list,json=ipWhiteList,proto3" json:"ip_white_list,omitempty"`
// contains filtered or unexported fields
}
func (*ClientSSLAuth) ClearRefreshDelay ¶
func (x *ClientSSLAuth) ClearRefreshDelay()
func (*ClientSSLAuth) GetAuthApiCluster ¶
func (x *ClientSSLAuth) GetAuthApiCluster() string
func (*ClientSSLAuth) GetIpWhiteList ¶
func (x *ClientSSLAuth) GetIpWhiteList() []*core.CidrRange
func (*ClientSSLAuth) GetRefreshDelay ¶
func (x *ClientSSLAuth) GetRefreshDelay() *durationpb.Duration
func (*ClientSSLAuth) GetStatPrefix ¶
func (x *ClientSSLAuth) GetStatPrefix() string
func (*ClientSSLAuth) HasRefreshDelay ¶
func (x *ClientSSLAuth) HasRefreshDelay() bool
func (*ClientSSLAuth) ProtoMessage ¶
func (*ClientSSLAuth) ProtoMessage()
func (*ClientSSLAuth) ProtoReflect ¶
func (x *ClientSSLAuth) ProtoReflect() protoreflect.Message
func (*ClientSSLAuth) Reset ¶
func (x *ClientSSLAuth) Reset()
func (*ClientSSLAuth) SetAuthApiCluster ¶
func (x *ClientSSLAuth) SetAuthApiCluster(v string)
func (*ClientSSLAuth) SetIpWhiteList ¶
func (x *ClientSSLAuth) SetIpWhiteList(v []*core.CidrRange)
func (*ClientSSLAuth) SetRefreshDelay ¶
func (x *ClientSSLAuth) SetRefreshDelay(v *durationpb.Duration)
func (*ClientSSLAuth) SetStatPrefix ¶
func (x *ClientSSLAuth) SetStatPrefix(v string)
func (*ClientSSLAuth) String ¶
func (x *ClientSSLAuth) String() string
type ClientSSLAuth_builder ¶
type ClientSSLAuth_builder struct {
// The :ref:`cluster manager <arch_overview_cluster_manager>` cluster that runs
// the authentication service. The filter will connect to the service every 60s to fetch the list
// of principals. The service must support the expected :ref:`REST API
// <config_network_filters_client_ssl_auth_rest_api>`.
AuthApiCluster string
// The prefix to use when emitting :ref:`statistics
// <config_network_filters_client_ssl_auth_stats>`.
StatPrefix string
// Time in milliseconds between principal refreshes from the
// authentication service. Default is 60000 (60s). The actual fetch time
// will be this value plus a random jittered value between
// 0-refresh_delay_ms milliseconds.
RefreshDelay *durationpb.Duration
// An optional list of IP address and subnet masks that should be white
// listed for access by the filter. If no list is provided, there is no
// IP allowlist.
IpWhiteList []*core.CidrRange
// contains filtered or unexported fields
}
func (ClientSSLAuth_builder) Build ¶
func (b0 ClientSSLAuth_builder) Build() *ClientSSLAuth
Source Files
¶
- client_ssl_auth.pb.go
Click to show internal directories.
Click to hide internal directories.