kafka_brokerv2alpha1

package
v1.36.11-2026011520535... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

const KafkaBroker_BrokerAddressRewriteSpec_not_set_case case_KafkaBroker_BrokerAddressRewriteSpec = 0
const KafkaBroker_IdBasedBrokerAddressRewriteSpec_case case_KafkaBroker_BrokerAddressRewriteSpec = 3

Variables

var File_envoy_config_filter_network_kafka_broker_v2alpha1_kafka_broker_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type IdBasedBrokerRewriteRule

type IdBasedBrokerRewriteRule struct {

	// Broker ID to match.
	Id uint32 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
	// The host value to use (resembling the host part of Kafka's advertised.listeners).
	// The value should point to the Envoy (not Kafka) listener, so that all client traffic goes
	// through Envoy.
	Host string `protobuf:"bytes,2,opt,name=host,proto3" json:"host,omitempty"`
	// The port value to use (resembling the port part of Kafka's advertised.listeners).
	// The value should point to the Envoy (not Kafka) listener, so that all client traffic goes
	// through Envoy.
	Port uint32 `protobuf:"varint,3,opt,name=port,proto3" json:"port,omitempty"`
	// contains filtered or unexported fields
}

Defines a rule to rewrite broker address data.

func (*IdBasedBrokerRewriteRule) GetHost

func (x *IdBasedBrokerRewriteRule) GetHost() string

func (*IdBasedBrokerRewriteRule) GetId

func (x *IdBasedBrokerRewriteRule) GetId() uint32

func (*IdBasedBrokerRewriteRule) GetPort

func (x *IdBasedBrokerRewriteRule) GetPort() uint32

func (*IdBasedBrokerRewriteRule) ProtoMessage

func (*IdBasedBrokerRewriteRule) ProtoMessage()

func (*IdBasedBrokerRewriteRule) ProtoReflect

func (x *IdBasedBrokerRewriteRule) ProtoReflect() protoreflect.Message

func (*IdBasedBrokerRewriteRule) Reset

func (x *IdBasedBrokerRewriteRule) Reset()

func (*IdBasedBrokerRewriteRule) SetHost

func (x *IdBasedBrokerRewriteRule) SetHost(v string)

func (*IdBasedBrokerRewriteRule) SetId

func (x *IdBasedBrokerRewriteRule) SetId(v uint32)

func (*IdBasedBrokerRewriteRule) SetPort

func (x *IdBasedBrokerRewriteRule) SetPort(v uint32)

func (*IdBasedBrokerRewriteRule) String

func (x *IdBasedBrokerRewriteRule) String() string

type IdBasedBrokerRewriteRule_builder

type IdBasedBrokerRewriteRule_builder struct {

	// Broker ID to match.
	Id uint32
	// The host value to use (resembling the host part of Kafka's advertised.listeners).
	// The value should point to the Envoy (not Kafka) listener, so that all client traffic goes
	// through Envoy.
	Host string
	// The port value to use (resembling the port part of Kafka's advertised.listeners).
	// The value should point to the Envoy (not Kafka) listener, so that all client traffic goes
	// through Envoy.
	Port uint32
	// contains filtered or unexported fields
}

func (IdBasedBrokerRewriteRule_builder) Build

type IdBasedBrokerRewriteSpec

type IdBasedBrokerRewriteSpec struct {
	Rules []*IdBasedBrokerRewriteRule `protobuf:"bytes,1,rep,name=rules,proto3" json:"rules,omitempty"`
	// contains filtered or unexported fields
}

Collection of rules matching by broker ID.

func (*IdBasedBrokerRewriteSpec) GetRules

func (*IdBasedBrokerRewriteSpec) ProtoMessage

func (*IdBasedBrokerRewriteSpec) ProtoMessage()

func (*IdBasedBrokerRewriteSpec) ProtoReflect

func (x *IdBasedBrokerRewriteSpec) ProtoReflect() protoreflect.Message

func (*IdBasedBrokerRewriteSpec) Reset

func (x *IdBasedBrokerRewriteSpec) Reset()

func (*IdBasedBrokerRewriteSpec) SetRules

func (*IdBasedBrokerRewriteSpec) String

func (x *IdBasedBrokerRewriteSpec) String() string

type IdBasedBrokerRewriteSpec_builder

type IdBasedBrokerRewriteSpec_builder struct {
	Rules []*IdBasedBrokerRewriteRule
	// contains filtered or unexported fields
}

func (IdBasedBrokerRewriteSpec_builder) Build

type KafkaBroker

type KafkaBroker struct {

	// The prefix to use when emitting :ref:`statistics <config_network_filters_kafka_broker_stats>`.
	StatPrefix string `protobuf:"bytes,1,opt,name=stat_prefix,json=statPrefix,proto3" json:"stat_prefix,omitempty"`
	// Set to true if broker filter should attempt to serialize the received responses from the
	// upstream broker instead of passing received bytes as is.
	// Disabled by default.
	ForceResponseRewrite bool `protobuf:"varint,2,opt,name=force_response_rewrite,json=forceResponseRewrite,proto3" json:"force_response_rewrite,omitempty"`
	// Optional broker address rewrite specification.
	// Allows the broker filter to rewrite Kafka responses so that all connections established by
	// the Kafka clients point to Envoy.
	// This allows Kafka cluster not to configure its 'advertised.listeners' property
	// (as the necessary re-pointing will be done by this filter).
	// This collection of rules should cover all brokers in the cluster that is being proxied,
	// otherwise some nodes' addresses might leak to the downstream clients.
	//
	// Types that are valid to be assigned to BrokerAddressRewriteSpec:
	//
	//	*KafkaBroker_IdBasedBrokerAddressRewriteSpec
	BrokerAddressRewriteSpec isKafkaBroker_BrokerAddressRewriteSpec `protobuf_oneof:"broker_address_rewrite_spec"`
	// Optional list of allowed Kafka API keys. Only requests with provided API keys will be
	// routed, otherwise the connection will be closed. No effect if empty.
	ApiKeysAllowed []uint32 `protobuf:"varint,4,rep,packed,name=api_keys_allowed,json=apiKeysAllowed,proto3" json:"api_keys_allowed,omitempty"`
	// Optional list of denied Kafka API keys. Requests with API keys matching this list will have
	// the connection closed. No effect if empty.
	ApiKeysDenied []uint32 `protobuf:"varint,5,rep,packed,name=api_keys_denied,json=apiKeysDenied,proto3" json:"api_keys_denied,omitempty"`
	// contains filtered or unexported fields
}

[#protodoc-title: Kafka Broker] Kafka Broker :ref:`configuration overview <config_network_filters_kafka_broker>`. [#extension: envoy.filters.network.kafka_broker] [#next-free-field: 6]

func (*KafkaBroker) ClearBrokerAddressRewriteSpec

func (x *KafkaBroker) ClearBrokerAddressRewriteSpec()

func (*KafkaBroker) ClearIdBasedBrokerAddressRewriteSpec

func (x *KafkaBroker) ClearIdBasedBrokerAddressRewriteSpec()

func (*KafkaBroker) GetApiKeysAllowed

func (x *KafkaBroker) GetApiKeysAllowed() []uint32

func (*KafkaBroker) GetApiKeysDenied

func (x *KafkaBroker) GetApiKeysDenied() []uint32

func (*KafkaBroker) GetBrokerAddressRewriteSpec

func (x *KafkaBroker) GetBrokerAddressRewriteSpec() isKafkaBroker_BrokerAddressRewriteSpec

func (*KafkaBroker) GetForceResponseRewrite

func (x *KafkaBroker) GetForceResponseRewrite() bool

func (*KafkaBroker) GetIdBasedBrokerAddressRewriteSpec

func (x *KafkaBroker) GetIdBasedBrokerAddressRewriteSpec() *IdBasedBrokerRewriteSpec

func (*KafkaBroker) GetStatPrefix

func (x *KafkaBroker) GetStatPrefix() string

func (*KafkaBroker) HasBrokerAddressRewriteSpec

func (x *KafkaBroker) HasBrokerAddressRewriteSpec() bool

func (*KafkaBroker) HasIdBasedBrokerAddressRewriteSpec

func (x *KafkaBroker) HasIdBasedBrokerAddressRewriteSpec() bool

func (*KafkaBroker) ProtoMessage

func (*KafkaBroker) ProtoMessage()

func (*KafkaBroker) ProtoReflect

func (x *KafkaBroker) ProtoReflect() protoreflect.Message

func (*KafkaBroker) Reset

func (x *KafkaBroker) Reset()

func (*KafkaBroker) SetApiKeysAllowed

func (x *KafkaBroker) SetApiKeysAllowed(v []uint32)

func (*KafkaBroker) SetApiKeysDenied

func (x *KafkaBroker) SetApiKeysDenied(v []uint32)

func (*KafkaBroker) SetForceResponseRewrite

func (x *KafkaBroker) SetForceResponseRewrite(v bool)

func (*KafkaBroker) SetIdBasedBrokerAddressRewriteSpec

func (x *KafkaBroker) SetIdBasedBrokerAddressRewriteSpec(v *IdBasedBrokerRewriteSpec)

func (*KafkaBroker) SetStatPrefix

func (x *KafkaBroker) SetStatPrefix(v string)

func (*KafkaBroker) String

func (x *KafkaBroker) String() string

func (*KafkaBroker) WhichBrokerAddressRewriteSpec

func (x *KafkaBroker) WhichBrokerAddressRewriteSpec() case_KafkaBroker_BrokerAddressRewriteSpec

type KafkaBroker_IdBasedBrokerAddressRewriteSpec

type KafkaBroker_IdBasedBrokerAddressRewriteSpec struct {
	// Broker address rewrite rules that match by broker ID.
	IdBasedBrokerAddressRewriteSpec *IdBasedBrokerRewriteSpec `protobuf:"bytes,3,opt,name=id_based_broker_address_rewrite_spec,json=idBasedBrokerAddressRewriteSpec,proto3,oneof"`
}

type KafkaBroker_builder

type KafkaBroker_builder struct {

	// The prefix to use when emitting :ref:`statistics <config_network_filters_kafka_broker_stats>`.
	StatPrefix string
	// Set to true if broker filter should attempt to serialize the received responses from the
	// upstream broker instead of passing received bytes as is.
	// Disabled by default.
	ForceResponseRewrite bool

	// Fields of oneof BrokerAddressRewriteSpec:
	// Broker address rewrite rules that match by broker ID.
	IdBasedBrokerAddressRewriteSpec *IdBasedBrokerRewriteSpec
	// -- end of BrokerAddressRewriteSpec
	// Optional list of allowed Kafka API keys. Only requests with provided API keys will be
	// routed, otherwise the connection will be closed. No effect if empty.
	ApiKeysAllowed []uint32
	// Optional list of denied Kafka API keys. Requests with API keys matching this list will have
	// the connection closed. No effect if empty.
	ApiKeysDenied []uint32
	// contains filtered or unexported fields
}

func (KafkaBroker_builder) Build

func (b0 KafkaBroker_builder) Build() *KafkaBroker

Source Files

  • kafka_broker.pb.go

Jump to