Documentation
¶
Index ¶
- Variables
- type MongoProxy
- func (x *MongoProxy) ClearDelay()
- func (x *MongoProxy) GetAccessLog() string
- func (x *MongoProxy) GetDelay() *v2.FaultDelay
- func (x *MongoProxy) GetEmitDynamicMetadata() bool
- func (x *MongoProxy) GetStatPrefix() string
- func (x *MongoProxy) HasDelay() bool
- func (*MongoProxy) ProtoMessage()
- func (x *MongoProxy) ProtoReflect() protoreflect.Message
- func (x *MongoProxy) Reset()
- func (x *MongoProxy) SetAccessLog(v string)
- func (x *MongoProxy) SetDelay(v *v2.FaultDelay)
- func (x *MongoProxy) SetEmitDynamicMetadata(v bool)
- func (x *MongoProxy) SetStatPrefix(v string)
- func (x *MongoProxy) String() string
- type MongoProxy_builder
Constants ¶
This section is empty.
Variables ¶
var File_envoy_config_filter_network_mongo_proxy_v2_mongo_proxy_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type MongoProxy ¶
type MongoProxy struct {
// The human readable prefix to use when emitting :ref:`statistics
// <config_network_filters_mongo_proxy_stats>`.
StatPrefix string `protobuf:"bytes,1,opt,name=stat_prefix,json=statPrefix,proto3" json:"stat_prefix,omitempty"`
// The optional path to use for writing Mongo access logs. If not access log
// path is specified no access logs will be written. Note that access log is
// also gated :ref:`runtime <config_network_filters_mongo_proxy_runtime>`.
AccessLog string `protobuf:"bytes,2,opt,name=access_log,json=accessLog,proto3" json:"access_log,omitempty"`
// Inject a fixed delay before proxying a Mongo operation. Delays are
// applied to the following MongoDB operations: Query, Insert, GetMore,
// and KillCursors. Once an active delay is in progress, all incoming
// data up until the timer event fires will be a part of the delay.
Delay *v2.FaultDelay `protobuf:"bytes,3,opt,name=delay,proto3" json:"delay,omitempty"`
// Flag to specify whether :ref:`dynamic metadata
// <config_network_filters_mongo_proxy_dynamic_metadata>` should be emitted. Defaults to false.
EmitDynamicMetadata bool `protobuf:"varint,4,opt,name=emit_dynamic_metadata,json=emitDynamicMetadata,proto3" json:"emit_dynamic_metadata,omitempty"`
// contains filtered or unexported fields
}
func (*MongoProxy) ClearDelay ¶
func (x *MongoProxy) ClearDelay()
func (*MongoProxy) GetAccessLog ¶
func (x *MongoProxy) GetAccessLog() string
func (*MongoProxy) GetDelay ¶
func (x *MongoProxy) GetDelay() *v2.FaultDelay
func (*MongoProxy) GetEmitDynamicMetadata ¶
func (x *MongoProxy) GetEmitDynamicMetadata() bool
func (*MongoProxy) GetStatPrefix ¶
func (x *MongoProxy) GetStatPrefix() string
func (*MongoProxy) HasDelay ¶
func (x *MongoProxy) HasDelay() bool
func (*MongoProxy) ProtoMessage ¶
func (*MongoProxy) ProtoMessage()
func (*MongoProxy) ProtoReflect ¶
func (x *MongoProxy) ProtoReflect() protoreflect.Message
func (*MongoProxy) Reset ¶
func (x *MongoProxy) Reset()
func (*MongoProxy) SetAccessLog ¶
func (x *MongoProxy) SetAccessLog(v string)
func (*MongoProxy) SetDelay ¶
func (x *MongoProxy) SetDelay(v *v2.FaultDelay)
func (*MongoProxy) SetEmitDynamicMetadata ¶
func (x *MongoProxy) SetEmitDynamicMetadata(v bool)
func (*MongoProxy) SetStatPrefix ¶
func (x *MongoProxy) SetStatPrefix(v string)
func (*MongoProxy) String ¶
func (x *MongoProxy) String() string
type MongoProxy_builder ¶
type MongoProxy_builder struct {
// The human readable prefix to use when emitting :ref:`statistics
// <config_network_filters_mongo_proxy_stats>`.
StatPrefix string
// The optional path to use for writing Mongo access logs. If not access log
// path is specified no access logs will be written. Note that access log is
// also gated :ref:`runtime <config_network_filters_mongo_proxy_runtime>`.
AccessLog string
// Inject a fixed delay before proxying a Mongo operation. Delays are
// applied to the following MongoDB operations: Query, Insert, GetMore,
// and KillCursors. Once an active delay is in progress, all incoming
// data up until the timer event fires will be a part of the delay.
Delay *v2.FaultDelay
// Flag to specify whether :ref:`dynamic metadata
// <config_network_filters_mongo_proxy_dynamic_metadata>` should be emitted. Defaults to false.
EmitDynamicMetadata bool
// contains filtered or unexported fields
}
func (MongoProxy_builder) Build ¶
func (b0 MongoProxy_builder) Build() *MongoProxy
Source Files
¶
- mongo_proxy.pb.go
Click to show internal directories.
Click to hide internal directories.