Documentation
¶
Index ¶
- Variables
- type ZooKeeperProxy
- func (x *ZooKeeperProxy) ClearMaxPacketBytes()
- func (x *ZooKeeperProxy) GetAccessLog() string
- func (x *ZooKeeperProxy) GetMaxPacketBytes() *wrapperspb.UInt32Value
- func (x *ZooKeeperProxy) GetStatPrefix() string
- func (x *ZooKeeperProxy) HasMaxPacketBytes() bool
- func (*ZooKeeperProxy) ProtoMessage()
- func (x *ZooKeeperProxy) ProtoReflect() protoreflect.Message
- func (x *ZooKeeperProxy) Reset()
- func (x *ZooKeeperProxy) SetAccessLog(v string)
- func (x *ZooKeeperProxy) SetMaxPacketBytes(v *wrapperspb.UInt32Value)
- func (x *ZooKeeperProxy) SetStatPrefix(v string)
- func (x *ZooKeeperProxy) String() string
- type ZooKeeperProxy_builder
Constants ¶
This section is empty.
Variables ¶
var File_envoy_config_filter_network_zookeeper_proxy_v1alpha1_zookeeper_proxy_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type ZooKeeperProxy ¶
type ZooKeeperProxy struct {
// The human readable prefix to use when emitting :ref:`statistics
// <config_network_filters_zookeeper_proxy_stats>`.
StatPrefix string `protobuf:"bytes,1,opt,name=stat_prefix,json=statPrefix,proto3" json:"stat_prefix,omitempty"`
// [#not-implemented-hide:] The optional path to use for writing ZooKeeper access logs.
// If the access log field is empty, access logs will not be written.
AccessLog string `protobuf:"bytes,2,opt,name=access_log,json=accessLog,proto3" json:"access_log,omitempty"`
// Messages — requests, responses and events — that are bigger than this value will
// be ignored. If it is not set, the default value is 1Mb.
//
// The value here should match the jute.maxbuffer property in your cluster configuration:
//
// https://zookeeper.apache.org/doc/r3.4.10/zookeeperAdmin.html#Unsafe+Options
//
// if that is set. If it isn't, ZooKeeper's default is also 1Mb.
MaxPacketBytes *wrapperspb.UInt32Value `protobuf:"bytes,3,opt,name=max_packet_bytes,json=maxPacketBytes,proto3" json:"max_packet_bytes,omitempty"`
// contains filtered or unexported fields
}
func (*ZooKeeperProxy) ClearMaxPacketBytes ¶
func (x *ZooKeeperProxy) ClearMaxPacketBytes()
func (*ZooKeeperProxy) GetAccessLog ¶
func (x *ZooKeeperProxy) GetAccessLog() string
func (*ZooKeeperProxy) GetMaxPacketBytes ¶
func (x *ZooKeeperProxy) GetMaxPacketBytes() *wrapperspb.UInt32Value
func (*ZooKeeperProxy) GetStatPrefix ¶
func (x *ZooKeeperProxy) GetStatPrefix() string
func (*ZooKeeperProxy) HasMaxPacketBytes ¶
func (x *ZooKeeperProxy) HasMaxPacketBytes() bool
func (*ZooKeeperProxy) ProtoMessage ¶
func (*ZooKeeperProxy) ProtoMessage()
func (*ZooKeeperProxy) ProtoReflect ¶
func (x *ZooKeeperProxy) ProtoReflect() protoreflect.Message
func (*ZooKeeperProxy) Reset ¶
func (x *ZooKeeperProxy) Reset()
func (*ZooKeeperProxy) SetAccessLog ¶
func (x *ZooKeeperProxy) SetAccessLog(v string)
func (*ZooKeeperProxy) SetMaxPacketBytes ¶
func (x *ZooKeeperProxy) SetMaxPacketBytes(v *wrapperspb.UInt32Value)
func (*ZooKeeperProxy) SetStatPrefix ¶
func (x *ZooKeeperProxy) SetStatPrefix(v string)
func (*ZooKeeperProxy) String ¶
func (x *ZooKeeperProxy) String() string
type ZooKeeperProxy_builder ¶
type ZooKeeperProxy_builder struct {
// The human readable prefix to use when emitting :ref:`statistics
// <config_network_filters_zookeeper_proxy_stats>`.
StatPrefix string
// [#not-implemented-hide:] The optional path to use for writing ZooKeeper access logs.
// If the access log field is empty, access logs will not be written.
AccessLog string
// Messages — requests, responses and events — that are bigger than this value will
// be ignored. If it is not set, the default value is 1Mb.
//
// The value here should match the jute.maxbuffer property in your cluster configuration:
//
// https://zookeeper.apache.org/doc/r3.4.10/zookeeperAdmin.html#Unsafe+Options
//
// if that is set. If it isn't, ZooKeeper's default is also 1Mb.
MaxPacketBytes *wrapperspb.UInt32Value
// contains filtered or unexported fields
}
func (ZooKeeperProxy_builder) Build ¶
func (b0 ZooKeeperProxy_builder) Build() *ZooKeeperProxy
Source Files
¶
- zookeeper_proxy.pb.go
Click to show internal directories.
Click to hide internal directories.