grpc_credentialv3

package
v1.36.11-2026011520535... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var File_envoy_config_grpc_credential_v3_file_based_metadata_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type FileBasedMetadataConfig

type FileBasedMetadataConfig struct {

	// Location or inline data of secret to use for authentication of the Google gRPC connection
	// this secret will be attached to a header of the gRPC connection
	SecretData *v3.DataSource `protobuf:"bytes,1,opt,name=secret_data,json=secretData,proto3" json:"secret_data,omitempty"`
	// Metadata header key to use for sending the secret data
	// if no header key is set, "authorization" header will be used
	HeaderKey string `protobuf:"bytes,2,opt,name=header_key,json=headerKey,proto3" json:"header_key,omitempty"`
	// Prefix to prepend to the secret in the metadata header
	// if no prefix is set, the default is to use no prefix
	HeaderPrefix string `protobuf:"bytes,3,opt,name=header_prefix,json=headerPrefix,proto3" json:"header_prefix,omitempty"`
	// contains filtered or unexported fields
}

func (*FileBasedMetadataConfig) ClearSecretData

func (x *FileBasedMetadataConfig) ClearSecretData()

func (*FileBasedMetadataConfig) GetHeaderKey

func (x *FileBasedMetadataConfig) GetHeaderKey() string

func (*FileBasedMetadataConfig) GetHeaderPrefix

func (x *FileBasedMetadataConfig) GetHeaderPrefix() string

func (*FileBasedMetadataConfig) GetSecretData

func (x *FileBasedMetadataConfig) GetSecretData() *v3.DataSource

func (*FileBasedMetadataConfig) HasSecretData

func (x *FileBasedMetadataConfig) HasSecretData() bool

func (*FileBasedMetadataConfig) ProtoMessage

func (*FileBasedMetadataConfig) ProtoMessage()

func (*FileBasedMetadataConfig) ProtoReflect

func (x *FileBasedMetadataConfig) ProtoReflect() protoreflect.Message

func (*FileBasedMetadataConfig) Reset

func (x *FileBasedMetadataConfig) Reset()

func (*FileBasedMetadataConfig) SetHeaderKey

func (x *FileBasedMetadataConfig) SetHeaderKey(v string)

func (*FileBasedMetadataConfig) SetHeaderPrefix

func (x *FileBasedMetadataConfig) SetHeaderPrefix(v string)

func (*FileBasedMetadataConfig) SetSecretData

func (x *FileBasedMetadataConfig) SetSecretData(v *v3.DataSource)

func (*FileBasedMetadataConfig) String

func (x *FileBasedMetadataConfig) String() string

type FileBasedMetadataConfig_builder

type FileBasedMetadataConfig_builder struct {

	// Location or inline data of secret to use for authentication of the Google gRPC connection
	// this secret will be attached to a header of the gRPC connection
	SecretData *v3.DataSource
	// Metadata header key to use for sending the secret data
	// if no header key is set, "authorization" header will be used
	HeaderKey string
	// Prefix to prepend to the secret in the metadata header
	// if no prefix is set, the default is to use no prefix
	HeaderPrefix string
	// contains filtered or unexported fields
}

func (FileBasedMetadataConfig_builder) Build

Source Files

  • file_based_metadata.pb.go

Jump to