Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var File_envoy_config_health_checker_redis_v2_redis_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Redis ¶
type Redis struct {
// If set, optionally perform “EXISTS <key>“ instead of “PING“. A return value
// from Redis of 0 (does not exist) is considered a passing healthcheck. A return value other
// than 0 is considered a failure. This allows the user to mark a Redis instance for maintenance
// by setting the specified key to any value and waiting for traffic to drain.
Key string `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
// contains filtered or unexported fields
}
func (*Redis) ProtoReflect ¶
func (x *Redis) ProtoReflect() protoreflect.Message
type Redis_builder ¶
type Redis_builder struct {
// If set, optionally perform “EXISTS <key>“ instead of “PING“. A return value
// from Redis of 0 (does not exist) is considered a passing healthcheck. A return value other
// than 0 is considered a failure. This allows the user to mark a Redis instance for maintenance
// by setting the specified key to any value and waiting for traffic to drain.
Key string
// contains filtered or unexported fields
}
func (Redis_builder) Build ¶
func (b0 Redis_builder) Build() *Redis
Source Files
¶
- redis.pb.go
Click to show internal directories.
Click to hide internal directories.