Documentation
¶
Index ¶
- Variables
- type ApiListener
- func (x *ApiListener) ClearApiListener()
- func (x *ApiListener) GetApiListener() *anypb.Any
- func (x *ApiListener) HasApiListener() bool
- func (*ApiListener) ProtoMessage()
- func (x *ApiListener) ProtoReflect() protoreflect.Message
- func (x *ApiListener) Reset()
- func (x *ApiListener) SetApiListener(v *anypb.Any)
- func (x *ApiListener) String() string
- type ApiListener_builder
Constants ¶
This section is empty.
Variables ¶
var File_envoy_config_listener_v2_api_listener_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type ApiListener ¶
type ApiListener struct {
// The type in this field determines the type of API listener. At present, the following
// types are supported:
// envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager (HTTP)
// [#next-major-version: In the v3 API, replace this Any field with a oneof containing the
// specific config message for each type of API listener. We could not do this in v2 because
// it would have caused circular dependencies for go protos: lds.proto depends on this file,
// and http_connection_manager.proto depends on rds.proto, which is in the same directory as
// lds.proto, so lds.proto cannot depend on this file.]
ApiListener *anypb.Any `protobuf:"bytes,1,opt,name=api_listener,json=apiListener,proto3" json:"api_listener,omitempty"`
// contains filtered or unexported fields
}
Describes a type of API listener, which is used in non-proxy clients. The type of API exposed to the non-proxy application depends on the type of API listener.
func (*ApiListener) ClearApiListener ¶
func (x *ApiListener) ClearApiListener()
func (*ApiListener) GetApiListener ¶
func (x *ApiListener) GetApiListener() *anypb.Any
func (*ApiListener) HasApiListener ¶
func (x *ApiListener) HasApiListener() bool
func (*ApiListener) ProtoMessage ¶
func (*ApiListener) ProtoMessage()
func (*ApiListener) ProtoReflect ¶
func (x *ApiListener) ProtoReflect() protoreflect.Message
func (*ApiListener) Reset ¶
func (x *ApiListener) Reset()
func (*ApiListener) SetApiListener ¶
func (x *ApiListener) SetApiListener(v *anypb.Any)
func (*ApiListener) String ¶
func (x *ApiListener) String() string
type ApiListener_builder ¶
type ApiListener_builder struct {
// The type in this field determines the type of API listener. At present, the following
// types are supported:
// envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager (HTTP)
// [#next-major-version: In the v3 API, replace this Any field with a oneof containing the
// specific config message for each type of API listener. We could not do this in v2 because
// it would have caused circular dependencies for go protos: lds.proto depends on this file,
// and http_connection_manager.proto depends on rds.proto, which is in the same directory as
// lds.proto, so lds.proto cannot depend on this file.]
ApiListener *anypb.Any
// contains filtered or unexported fields
}
func (ApiListener_builder) Build ¶
func (b0 ApiListener_builder) Build() *ApiListener
Source Files
¶
- api_listener.pb.go
Click to show internal directories.
Click to hide internal directories.