tracev2

package
v1.36.11-2026011520535... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 11 Imported by: 0

Documentation

Index

Constants

const Tracing_Http_ConfigType_not_set_case case_Tracing_Http_ConfigType = 0
const Tracing_Http_Config_case case_Tracing_Http_ConfigType = 2
const Tracing_Http_TypedConfig_case case_Tracing_Http_ConfigType = 3

Variables

var (
	LightstepConfig_PropagationMode_name = map[int32]string{
		0: "ENVOY",
		1: "LIGHTSTEP",
		2: "B3",
		3: "TRACE_CONTEXT",
	}
	LightstepConfig_PropagationMode_value = map[string]int32{
		"ENVOY":         0,
		"LIGHTSTEP":     1,
		"B3":            2,
		"TRACE_CONTEXT": 3,
	}
)

Enum value maps for LightstepConfig_PropagationMode.

var (
	ZipkinConfig_CollectorEndpointVersion_name = map[int32]string{
		0: "HTTP_JSON_V1",
		1: "HTTP_JSON",
		2: "HTTP_PROTO",
		3: "GRPC",
	}
	ZipkinConfig_CollectorEndpointVersion_value = map[string]int32{
		"HTTP_JSON_V1": 0,
		"HTTP_JSON":    1,
		"HTTP_PROTO":   2,
		"GRPC":         3,
	}
)

Enum value maps for ZipkinConfig_CollectorEndpointVersion.

var File_envoy_config_trace_v2_datadog_proto protoreflect.FileDescriptor
var File_envoy_config_trace_v2_dynamic_ot_proto protoreflect.FileDescriptor
var File_envoy_config_trace_v2_http_tracer_proto protoreflect.FileDescriptor
var File_envoy_config_trace_v2_lightstep_proto protoreflect.FileDescriptor
var File_envoy_config_trace_v2_service_proto protoreflect.FileDescriptor
var File_envoy_config_trace_v2_trace_proto protoreflect.FileDescriptor
var File_envoy_config_trace_v2_zipkin_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type DatadogConfig

type DatadogConfig struct {

	// The cluster to use for submitting traces to the Datadog agent.
	CollectorCluster string `protobuf:"bytes,1,opt,name=collector_cluster,json=collectorCluster,proto3" json:"collector_cluster,omitempty"`
	// The name used for the service when traces are generated by envoy.
	ServiceName string `protobuf:"bytes,2,opt,name=service_name,json=serviceName,proto3" json:"service_name,omitempty"`
	// contains filtered or unexported fields
}

Configuration for the Datadog tracer. [#extension: envoy.tracers.datadog]

func (*DatadogConfig) GetCollectorCluster

func (x *DatadogConfig) GetCollectorCluster() string

func (*DatadogConfig) GetServiceName

func (x *DatadogConfig) GetServiceName() string

func (*DatadogConfig) ProtoMessage

func (*DatadogConfig) ProtoMessage()

func (*DatadogConfig) ProtoReflect

func (x *DatadogConfig) ProtoReflect() protoreflect.Message

func (*DatadogConfig) Reset

func (x *DatadogConfig) Reset()

func (*DatadogConfig) SetCollectorCluster

func (x *DatadogConfig) SetCollectorCluster(v string)

func (*DatadogConfig) SetServiceName

func (x *DatadogConfig) SetServiceName(v string)

func (*DatadogConfig) String

func (x *DatadogConfig) String() string

type DatadogConfig_builder

type DatadogConfig_builder struct {

	// The cluster to use for submitting traces to the Datadog agent.
	CollectorCluster string
	// The name used for the service when traces are generated by envoy.
	ServiceName string
	// contains filtered or unexported fields
}

func (DatadogConfig_builder) Build

type DynamicOtConfig

type DynamicOtConfig struct {

	// Dynamic library implementing the `OpenTracing API
	// <https://github.com/opentracing/opentracing-cpp>`_.
	Library string `protobuf:"bytes,1,opt,name=library,proto3" json:"library,omitempty"`
	// The configuration to use when creating a tracer from the given dynamic
	// library.
	Config *structpb.Struct `protobuf:"bytes,2,opt,name=config,proto3" json:"config,omitempty"`
	// contains filtered or unexported fields
}

DynamicOtConfig is used to dynamically load a tracer from a shared library that implements the `OpenTracing dynamic loading API <https://github.com/opentracing/opentracing-cpp>`_. [#extension: envoy.tracers.dynamic_ot]

func (*DynamicOtConfig) ClearConfig

func (x *DynamicOtConfig) ClearConfig()

func (*DynamicOtConfig) GetConfig

func (x *DynamicOtConfig) GetConfig() *structpb.Struct

func (*DynamicOtConfig) GetLibrary

func (x *DynamicOtConfig) GetLibrary() string

func (*DynamicOtConfig) HasConfig

func (x *DynamicOtConfig) HasConfig() bool

func (*DynamicOtConfig) ProtoMessage

func (*DynamicOtConfig) ProtoMessage()

func (*DynamicOtConfig) ProtoReflect

func (x *DynamicOtConfig) ProtoReflect() protoreflect.Message

func (*DynamicOtConfig) Reset

func (x *DynamicOtConfig) Reset()

func (*DynamicOtConfig) SetConfig

func (x *DynamicOtConfig) SetConfig(v *structpb.Struct)

func (*DynamicOtConfig) SetLibrary

func (x *DynamicOtConfig) SetLibrary(v string)

func (*DynamicOtConfig) String

func (x *DynamicOtConfig) String() string

type DynamicOtConfig_builder

type DynamicOtConfig_builder struct {

	// Dynamic library implementing the `OpenTracing API
	// <https://github.com/opentracing/opentracing-cpp>`_.
	Library string
	// The configuration to use when creating a tracer from the given dynamic
	// library.
	Config *structpb.Struct
	// contains filtered or unexported fields
}

func (DynamicOtConfig_builder) Build

type LightstepConfig

type LightstepConfig struct {

	// The cluster manager cluster that hosts the LightStep collectors.
	CollectorCluster string `protobuf:"bytes,1,opt,name=collector_cluster,json=collectorCluster,proto3" json:"collector_cluster,omitempty"`
	// File containing the access token to the `LightStep
	// <https://lightstep.com/>`_ API.
	AccessTokenFile string `protobuf:"bytes,2,opt,name=access_token_file,json=accessTokenFile,proto3" json:"access_token_file,omitempty"`
	// Propagation modes to use by LightStep's tracer.
	PropagationModes []LightstepConfig_PropagationMode `` /* 176-byte string literal not displayed */
	// contains filtered or unexported fields
}

Configuration for the LightStep tracer. [#extension: envoy.tracers.lightstep]

func (*LightstepConfig) GetAccessTokenFile

func (x *LightstepConfig) GetAccessTokenFile() string

func (*LightstepConfig) GetCollectorCluster

func (x *LightstepConfig) GetCollectorCluster() string

func (*LightstepConfig) GetPropagationModes

func (x *LightstepConfig) GetPropagationModes() []LightstepConfig_PropagationMode

func (*LightstepConfig) ProtoMessage

func (*LightstepConfig) ProtoMessage()

func (*LightstepConfig) ProtoReflect

func (x *LightstepConfig) ProtoReflect() protoreflect.Message

func (*LightstepConfig) Reset

func (x *LightstepConfig) Reset()

func (*LightstepConfig) SetAccessTokenFile

func (x *LightstepConfig) SetAccessTokenFile(v string)

func (*LightstepConfig) SetCollectorCluster

func (x *LightstepConfig) SetCollectorCluster(v string)

func (*LightstepConfig) SetPropagationModes

func (x *LightstepConfig) SetPropagationModes(v []LightstepConfig_PropagationMode)

func (*LightstepConfig) String

func (x *LightstepConfig) String() string

type LightstepConfig_PropagationMode

type LightstepConfig_PropagationMode int32

Available propagation modes

const (
	// Propagate trace context in the single header x-ot-span-context.
	LightstepConfig_ENVOY LightstepConfig_PropagationMode = 0
	// Propagate trace context using LightStep's native format.
	LightstepConfig_LIGHTSTEP LightstepConfig_PropagationMode = 1
	// Propagate trace context using the b3 format.
	LightstepConfig_B3 LightstepConfig_PropagationMode = 2
	// Propagation trace context using the w3 trace-context standard.
	LightstepConfig_TRACE_CONTEXT LightstepConfig_PropagationMode = 3
)

func (LightstepConfig_PropagationMode) Descriptor

func (LightstepConfig_PropagationMode) Enum

func (LightstepConfig_PropagationMode) Number

func (LightstepConfig_PropagationMode) String

func (LightstepConfig_PropagationMode) Type

type LightstepConfig_builder

type LightstepConfig_builder struct {

	// The cluster manager cluster that hosts the LightStep collectors.
	CollectorCluster string
	// File containing the access token to the `LightStep
	// <https://lightstep.com/>`_ API.
	AccessTokenFile string
	// Propagation modes to use by LightStep's tracer.
	PropagationModes []LightstepConfig_PropagationMode
	// contains filtered or unexported fields
}

func (LightstepConfig_builder) Build

type TraceServiceConfig

type TraceServiceConfig struct {

	// The upstream gRPC cluster that hosts the metrics service.
	GrpcService *core.GrpcService `protobuf:"bytes,1,opt,name=grpc_service,json=grpcService,proto3" json:"grpc_service,omitempty"`
	// contains filtered or unexported fields
}

Configuration structure.

func (*TraceServiceConfig) ClearGrpcService

func (x *TraceServiceConfig) ClearGrpcService()

func (*TraceServiceConfig) GetGrpcService

func (x *TraceServiceConfig) GetGrpcService() *core.GrpcService

func (*TraceServiceConfig) HasGrpcService

func (x *TraceServiceConfig) HasGrpcService() bool

func (*TraceServiceConfig) ProtoMessage

func (*TraceServiceConfig) ProtoMessage()

func (*TraceServiceConfig) ProtoReflect

func (x *TraceServiceConfig) ProtoReflect() protoreflect.Message

func (*TraceServiceConfig) Reset

func (x *TraceServiceConfig) Reset()

func (*TraceServiceConfig) SetGrpcService

func (x *TraceServiceConfig) SetGrpcService(v *core.GrpcService)

func (*TraceServiceConfig) String

func (x *TraceServiceConfig) String() string

type TraceServiceConfig_builder

type TraceServiceConfig_builder struct {

	// The upstream gRPC cluster that hosts the metrics service.
	GrpcService *core.GrpcService
	// contains filtered or unexported fields
}

func (TraceServiceConfig_builder) Build

type Tracing

type Tracing struct {

	// Provides configuration for the HTTP tracer.
	Http *Tracing_Http `protobuf:"bytes,1,opt,name=http,proto3" json:"http,omitempty"`
	// contains filtered or unexported fields
}

The tracing configuration specifies settings for an HTTP tracer provider used by Envoy.

Envoy may support other tracers in the future, but right now the HTTP tracer is the only one supported.

.. attention::

Use of this message type has been deprecated in favor of direct use of
:ref:`Tracing.Http <envoy_api_msg_config.trace.v2.Tracing.Http>`.

func (*Tracing) ClearHttp

func (x *Tracing) ClearHttp()

func (*Tracing) GetHttp

func (x *Tracing) GetHttp() *Tracing_Http

func (*Tracing) HasHttp

func (x *Tracing) HasHttp() bool

func (*Tracing) ProtoMessage

func (*Tracing) ProtoMessage()

func (*Tracing) ProtoReflect

func (x *Tracing) ProtoReflect() protoreflect.Message

func (*Tracing) Reset

func (x *Tracing) Reset()

func (*Tracing) SetHttp

func (x *Tracing) SetHttp(v *Tracing_Http)

func (*Tracing) String

func (x *Tracing) String() string

type Tracing_Http

type Tracing_Http struct {

	// The name of the HTTP trace driver to instantiate. The name must match a
	// supported HTTP trace driver. Built-in trace drivers:
	//
	// - *envoy.tracers.lightstep*
	// - *envoy.tracers.zipkin*
	// - *envoy.tracers.dynamic_ot*
	// - *envoy.tracers.datadog*
	// - *envoy.tracers.xray*
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Trace driver specific configuration which depends on the driver being instantiated.
	// See the trace drivers for examples:
	//
	// - :ref:`LightstepConfig <envoy_api_msg_config.trace.v2.LightstepConfig>`
	// - :ref:`ZipkinConfig <envoy_api_msg_config.trace.v2.ZipkinConfig>`
	// - :ref:`DynamicOtConfig <envoy_api_msg_config.trace.v2.DynamicOtConfig>`
	// - :ref:`DatadogConfig <envoy_api_msg_config.trace.v2.DatadogConfig>`
	// - :ref:`AWS X-Ray <envoy_api_msg_config.trace.v2alpha.XRayConfig>`
	//
	// Types that are valid to be assigned to ConfigType:
	//
	//	*Tracing_Http_Config
	//	*Tracing_Http_TypedConfig
	ConfigType isTracing_Http_ConfigType `protobuf_oneof:"config_type"`
	// contains filtered or unexported fields
}

Configuration for an HTTP tracer provider used by Envoy.

The configuration is defined by the :ref:`HttpConnectionManager.Tracing <envoy_api_msg_config.filter.network.http_connection_manager.v2.HttpConnectionManager.Tracing>` :ref:`provider <envoy_api_field_config.filter.network.http_connection_manager.v2.HttpConnectionManager.Tracing.provider>` field.

func (*Tracing_Http) ClearConfig deprecated

func (x *Tracing_Http) ClearConfig()

Deprecated: Marked as deprecated in envoy/config/trace/v2/http_tracer.proto.

func (*Tracing_Http) ClearConfigType

func (x *Tracing_Http) ClearConfigType()

func (*Tracing_Http) ClearTypedConfig

func (x *Tracing_Http) ClearTypedConfig()

func (*Tracing_Http) GetConfig deprecated

func (x *Tracing_Http) GetConfig() *structpb.Struct

Deprecated: Marked as deprecated in envoy/config/trace/v2/http_tracer.proto.

func (*Tracing_Http) GetConfigType

func (x *Tracing_Http) GetConfigType() isTracing_Http_ConfigType

func (*Tracing_Http) GetName

func (x *Tracing_Http) GetName() string

func (*Tracing_Http) GetTypedConfig

func (x *Tracing_Http) GetTypedConfig() *anypb.Any

func (*Tracing_Http) HasConfig deprecated

func (x *Tracing_Http) HasConfig() bool

Deprecated: Marked as deprecated in envoy/config/trace/v2/http_tracer.proto.

func (*Tracing_Http) HasConfigType

func (x *Tracing_Http) HasConfigType() bool

func (*Tracing_Http) HasTypedConfig

func (x *Tracing_Http) HasTypedConfig() bool

func (*Tracing_Http) ProtoMessage

func (*Tracing_Http) ProtoMessage()

func (*Tracing_Http) ProtoReflect

func (x *Tracing_Http) ProtoReflect() protoreflect.Message

func (*Tracing_Http) Reset

func (x *Tracing_Http) Reset()

func (*Tracing_Http) SetConfig deprecated

func (x *Tracing_Http) SetConfig(v *structpb.Struct)

Deprecated: Marked as deprecated in envoy/config/trace/v2/http_tracer.proto.

func (*Tracing_Http) SetName

func (x *Tracing_Http) SetName(v string)

func (*Tracing_Http) SetTypedConfig

func (x *Tracing_Http) SetTypedConfig(v *anypb.Any)

func (*Tracing_Http) String

func (x *Tracing_Http) String() string

func (*Tracing_Http) WhichConfigType

func (x *Tracing_Http) WhichConfigType() case_Tracing_Http_ConfigType

type Tracing_Http_Config

type Tracing_Http_Config struct {
	// Deprecated: Marked as deprecated in envoy/config/trace/v2/http_tracer.proto.
	Config *structpb.Struct `protobuf:"bytes,2,opt,name=config,proto3,oneof"`
}

type Tracing_Http_TypedConfig

type Tracing_Http_TypedConfig struct {
	TypedConfig *anypb.Any `protobuf:"bytes,3,opt,name=typed_config,json=typedConfig,proto3,oneof"`
}

type Tracing_Http_builder

type Tracing_Http_builder struct {

	// The name of the HTTP trace driver to instantiate. The name must match a
	// supported HTTP trace driver. Built-in trace drivers:
	//
	// - *envoy.tracers.lightstep*
	// - *envoy.tracers.zipkin*
	// - *envoy.tracers.dynamic_ot*
	// - *envoy.tracers.datadog*
	// - *envoy.tracers.xray*
	Name string

	// Fields of oneof ConfigType:
	// Deprecated: Marked as deprecated in envoy/config/trace/v2/http_tracer.proto.
	Config      *structpb.Struct
	TypedConfig *anypb.Any
	// contains filtered or unexported fields
}

func (Tracing_Http_builder) Build

func (b0 Tracing_Http_builder) Build() *Tracing_Http

type Tracing_builder

type Tracing_builder struct {

	// Provides configuration for the HTTP tracer.
	Http *Tracing_Http
	// contains filtered or unexported fields
}

func (Tracing_builder) Build

func (b0 Tracing_builder) Build() *Tracing

type ZipkinConfig

type ZipkinConfig struct {

	// The cluster manager cluster that hosts the Zipkin collectors. Note that the
	// Zipkin cluster must be defined in the :ref:`Bootstrap static cluster
	// resources <envoy_api_field_config.bootstrap.v2.Bootstrap.StaticResources.clusters>`.
	CollectorCluster string `protobuf:"bytes,1,opt,name=collector_cluster,json=collectorCluster,proto3" json:"collector_cluster,omitempty"`
	// The API endpoint of the Zipkin service where the spans will be sent. When
	// using a standard Zipkin installation, the API endpoint is typically
	// /api/v1/spans, which is the default value.
	CollectorEndpoint string `protobuf:"bytes,2,opt,name=collector_endpoint,json=collectorEndpoint,proto3" json:"collector_endpoint,omitempty"`
	// Determines whether a 128bit trace id will be used when creating a new
	// trace instance. The default value is false, which will result in a 64 bit trace id being used.
	TraceId_128Bit bool `protobuf:"varint,3,opt,name=trace_id_128bit,json=traceId128bit,proto3" json:"trace_id_128bit,omitempty"`
	// Determines whether client and server spans will share the same span context.
	// The default value is true.
	SharedSpanContext *wrapperspb.BoolValue `protobuf:"bytes,4,opt,name=shared_span_context,json=sharedSpanContext,proto3" json:"shared_span_context,omitempty"`
	// Determines the selected collector endpoint version. By default, the “HTTP_JSON_V1“ will be
	// used.
	CollectorEndpointVersion ZipkinConfig_CollectorEndpointVersion `` /* 201-byte string literal not displayed */
	// contains filtered or unexported fields
}

Configuration for the Zipkin tracer. [#extension: envoy.tracers.zipkin] [#next-free-field: 6]

func (*ZipkinConfig) ClearSharedSpanContext

func (x *ZipkinConfig) ClearSharedSpanContext()

func (*ZipkinConfig) GetCollectorCluster

func (x *ZipkinConfig) GetCollectorCluster() string

func (*ZipkinConfig) GetCollectorEndpoint

func (x *ZipkinConfig) GetCollectorEndpoint() string

func (*ZipkinConfig) GetCollectorEndpointVersion

func (x *ZipkinConfig) GetCollectorEndpointVersion() ZipkinConfig_CollectorEndpointVersion

func (*ZipkinConfig) GetSharedSpanContext

func (x *ZipkinConfig) GetSharedSpanContext() *wrapperspb.BoolValue

func (*ZipkinConfig) GetTraceId_128Bit

func (x *ZipkinConfig) GetTraceId_128Bit() bool

func (*ZipkinConfig) HasSharedSpanContext

func (x *ZipkinConfig) HasSharedSpanContext() bool

func (*ZipkinConfig) ProtoMessage

func (*ZipkinConfig) ProtoMessage()

func (*ZipkinConfig) ProtoReflect

func (x *ZipkinConfig) ProtoReflect() protoreflect.Message

func (*ZipkinConfig) Reset

func (x *ZipkinConfig) Reset()

func (*ZipkinConfig) SetCollectorCluster

func (x *ZipkinConfig) SetCollectorCluster(v string)

func (*ZipkinConfig) SetCollectorEndpoint

func (x *ZipkinConfig) SetCollectorEndpoint(v string)

func (*ZipkinConfig) SetCollectorEndpointVersion

func (x *ZipkinConfig) SetCollectorEndpointVersion(v ZipkinConfig_CollectorEndpointVersion)

func (*ZipkinConfig) SetSharedSpanContext

func (x *ZipkinConfig) SetSharedSpanContext(v *wrapperspb.BoolValue)

func (*ZipkinConfig) SetTraceId_128Bit

func (x *ZipkinConfig) SetTraceId_128Bit(v bool)

func (*ZipkinConfig) String

func (x *ZipkinConfig) String() string

type ZipkinConfig_CollectorEndpointVersion

type ZipkinConfig_CollectorEndpointVersion int32

Available Zipkin collector endpoint versions.

const (
	// Zipkin API v1, JSON over HTTP.
	// [#comment: The default implementation of Zipkin client before this field is added was only v1
	// and the way user configure this was by not explicitly specifying the version. Consequently,
	// before this is added, the corresponding Zipkin collector expected to receive v1 payload.
	// Hence the motivation of adding HTTP_JSON_V1 as the default is to avoid a breaking change when
	// user upgrading Envoy with this change. Furthermore, we also immediately deprecate this field,
	// since in Zipkin realm this v1 version is considered to be not preferable anymore.]
	//
	// Deprecated: Marked as deprecated in envoy/config/trace/v2/zipkin.proto.
	ZipkinConfig_HTTP_JSON_V1 ZipkinConfig_CollectorEndpointVersion = 0
	// Zipkin API v2, JSON over HTTP.
	ZipkinConfig_HTTP_JSON ZipkinConfig_CollectorEndpointVersion = 1
	// Zipkin API v2, protobuf over HTTP.
	ZipkinConfig_HTTP_PROTO ZipkinConfig_CollectorEndpointVersion = 2
	// [#not-implemented-hide:]
	ZipkinConfig_GRPC ZipkinConfig_CollectorEndpointVersion = 3
)

func (ZipkinConfig_CollectorEndpointVersion) Descriptor

func (ZipkinConfig_CollectorEndpointVersion) Enum

func (ZipkinConfig_CollectorEndpointVersion) Number

func (ZipkinConfig_CollectorEndpointVersion) String

func (ZipkinConfig_CollectorEndpointVersion) Type

type ZipkinConfig_builder

type ZipkinConfig_builder struct {

	// The cluster manager cluster that hosts the Zipkin collectors. Note that the
	// Zipkin cluster must be defined in the :ref:`Bootstrap static cluster
	// resources <envoy_api_field_config.bootstrap.v2.Bootstrap.StaticResources.clusters>`.
	CollectorCluster string
	// The API endpoint of the Zipkin service where the spans will be sent. When
	// using a standard Zipkin installation, the API endpoint is typically
	// /api/v1/spans, which is the default value.
	CollectorEndpoint string
	// Determines whether a 128bit trace id will be used when creating a new
	// trace instance. The default value is false, which will result in a 64 bit trace id being used.
	TraceId_128Bit bool
	// Determines whether client and server spans will share the same span context.
	// The default value is true.
	SharedSpanContext *wrapperspb.BoolValue
	// Determines the selected collector endpoint version. By default, the “HTTP_JSON_V1“ will be
	// used.
	CollectorEndpointVersion ZipkinConfig_CollectorEndpointVersion
	// contains filtered or unexported fields
}

func (ZipkinConfig_builder) Build

func (b0 ZipkinConfig_builder) Build() *ZipkinConfig

Source Files

  • datadog.pb.go
  • dynamic_ot.pb.go
  • http_tracer.pb.go
  • lightstep.pb.go
  • service.pb.go
  • trace.pb.go
  • zipkin.pb.go

Jump to