Documentation
¶
Index ¶
- Constants
- Variables
- type DnsTable
- func (x *DnsTable) GetExternalRetryCount() uint32
- func (x *DnsTable) GetKnownSuffixes() []*v3.StringMatcherdeprecated
- func (x *DnsTable) GetVirtualDomains() []*DnsTable_DnsVirtualDomain
- func (*DnsTable) ProtoMessage()
- func (x *DnsTable) ProtoReflect() protoreflect.Message
- func (x *DnsTable) Reset()
- func (x *DnsTable) SetExternalRetryCount(v uint32)
- func (x *DnsTable) SetKnownSuffixes(v []*v3.StringMatcher)deprecated
- func (x *DnsTable) SetVirtualDomains(v []*DnsTable_DnsVirtualDomain)
- func (x *DnsTable) String() string
- type DnsTable_AddressList
- func (x *DnsTable_AddressList) GetAddress() []string
- func (*DnsTable_AddressList) ProtoMessage()
- func (x *DnsTable_AddressList) ProtoReflect() protoreflect.Message
- func (x *DnsTable_AddressList) Reset()
- func (x *DnsTable_AddressList) SetAddress(v []string)
- func (x *DnsTable_AddressList) String() string
- type DnsTable_AddressList_builder
- type DnsTable_DnsEndpoint
- func (x *DnsTable_DnsEndpoint) ClearAddressList()
- func (x *DnsTable_DnsEndpoint) ClearClusterName()
- func (x *DnsTable_DnsEndpoint) ClearEndpointConfig()
- func (x *DnsTable_DnsEndpoint) ClearServiceList()
- func (x *DnsTable_DnsEndpoint) GetAddressList() *DnsTable_AddressList
- func (x *DnsTable_DnsEndpoint) GetClusterName() string
- func (x *DnsTable_DnsEndpoint) GetEndpointConfig() isDnsTable_DnsEndpoint_EndpointConfig
- func (x *DnsTable_DnsEndpoint) GetServiceList() *DnsTable_DnsServiceList
- func (x *DnsTable_DnsEndpoint) HasAddressList() bool
- func (x *DnsTable_DnsEndpoint) HasClusterName() bool
- func (x *DnsTable_DnsEndpoint) HasEndpointConfig() bool
- func (x *DnsTable_DnsEndpoint) HasServiceList() bool
- func (*DnsTable_DnsEndpoint) ProtoMessage()
- func (x *DnsTable_DnsEndpoint) ProtoReflect() protoreflect.Message
- func (x *DnsTable_DnsEndpoint) Reset()
- func (x *DnsTable_DnsEndpoint) SetAddressList(v *DnsTable_AddressList)
- func (x *DnsTable_DnsEndpoint) SetClusterName(v string)
- func (x *DnsTable_DnsEndpoint) SetServiceList(v *DnsTable_DnsServiceList)
- func (x *DnsTable_DnsEndpoint) String() string
- func (x *DnsTable_DnsEndpoint) WhichEndpointConfig() case_DnsTable_DnsEndpoint_EndpointConfig
- type DnsTable_DnsEndpoint_AddressList
- type DnsTable_DnsEndpoint_ClusterName
- type DnsTable_DnsEndpoint_ServiceList
- type DnsTable_DnsEndpoint_builder
- type DnsTable_DnsService
- func (x *DnsTable_DnsService) ClearProtocol()
- func (x *DnsTable_DnsService) ClearTtl()
- func (x *DnsTable_DnsService) GetProtocol() *DnsTable_DnsServiceProtocol
- func (x *DnsTable_DnsService) GetServiceName() string
- func (x *DnsTable_DnsService) GetTargets() []*DnsTable_DnsServiceTarget
- func (x *DnsTable_DnsService) GetTtl() *durationpb.Duration
- func (x *DnsTable_DnsService) HasProtocol() bool
- func (x *DnsTable_DnsService) HasTtl() bool
- func (*DnsTable_DnsService) ProtoMessage()
- func (x *DnsTable_DnsService) ProtoReflect() protoreflect.Message
- func (x *DnsTable_DnsService) Reset()
- func (x *DnsTable_DnsService) SetProtocol(v *DnsTable_DnsServiceProtocol)
- func (x *DnsTable_DnsService) SetServiceName(v string)
- func (x *DnsTable_DnsService) SetTargets(v []*DnsTable_DnsServiceTarget)
- func (x *DnsTable_DnsService) SetTtl(v *durationpb.Duration)
- func (x *DnsTable_DnsService) String() string
- type DnsTable_DnsServiceList
- func (x *DnsTable_DnsServiceList) GetServices() []*DnsTable_DnsService
- func (*DnsTable_DnsServiceList) ProtoMessage()
- func (x *DnsTable_DnsServiceList) ProtoReflect() protoreflect.Message
- func (x *DnsTable_DnsServiceList) Reset()
- func (x *DnsTable_DnsServiceList) SetServices(v []*DnsTable_DnsService)
- func (x *DnsTable_DnsServiceList) String() string
- type DnsTable_DnsServiceList_builder
- type DnsTable_DnsServiceProtocol
- func (x *DnsTable_DnsServiceProtocol) ClearName()
- func (x *DnsTable_DnsServiceProtocol) ClearNumber()
- func (x *DnsTable_DnsServiceProtocol) ClearProtocolConfig()
- func (x *DnsTable_DnsServiceProtocol) GetName() string
- func (x *DnsTable_DnsServiceProtocol) GetNumber() uint32
- func (x *DnsTable_DnsServiceProtocol) GetProtocolConfig() isDnsTable_DnsServiceProtocol_ProtocolConfig
- func (x *DnsTable_DnsServiceProtocol) HasName() bool
- func (x *DnsTable_DnsServiceProtocol) HasNumber() bool
- func (x *DnsTable_DnsServiceProtocol) HasProtocolConfig() bool
- func (*DnsTable_DnsServiceProtocol) ProtoMessage()
- func (x *DnsTable_DnsServiceProtocol) ProtoReflect() protoreflect.Message
- func (x *DnsTable_DnsServiceProtocol) Reset()
- func (x *DnsTable_DnsServiceProtocol) SetName(v string)
- func (x *DnsTable_DnsServiceProtocol) SetNumber(v uint32)
- func (x *DnsTable_DnsServiceProtocol) String() string
- func (x *DnsTable_DnsServiceProtocol) WhichProtocolConfig() case_DnsTable_DnsServiceProtocol_ProtocolConfig
- type DnsTable_DnsServiceProtocol_Name
- type DnsTable_DnsServiceProtocol_Number
- type DnsTable_DnsServiceProtocol_builder
- type DnsTable_DnsServiceTarget
- func (x *DnsTable_DnsServiceTarget) ClearClusterName()
- func (x *DnsTable_DnsServiceTarget) ClearEndpointType()
- func (x *DnsTable_DnsServiceTarget) ClearHostName()
- func (x *DnsTable_DnsServiceTarget) GetClusterName() string
- func (x *DnsTable_DnsServiceTarget) GetEndpointType() isDnsTable_DnsServiceTarget_EndpointType
- func (x *DnsTable_DnsServiceTarget) GetHostName() string
- func (x *DnsTable_DnsServiceTarget) GetPort() uint32
- func (x *DnsTable_DnsServiceTarget) GetPriority() uint32
- func (x *DnsTable_DnsServiceTarget) GetWeight() uint32
- func (x *DnsTable_DnsServiceTarget) HasClusterName() bool
- func (x *DnsTable_DnsServiceTarget) HasEndpointType() bool
- func (x *DnsTable_DnsServiceTarget) HasHostName() bool
- func (*DnsTable_DnsServiceTarget) ProtoMessage()
- func (x *DnsTable_DnsServiceTarget) ProtoReflect() protoreflect.Message
- func (x *DnsTable_DnsServiceTarget) Reset()
- func (x *DnsTable_DnsServiceTarget) SetClusterName(v string)
- func (x *DnsTable_DnsServiceTarget) SetHostName(v string)
- func (x *DnsTable_DnsServiceTarget) SetPort(v uint32)
- func (x *DnsTable_DnsServiceTarget) SetPriority(v uint32)
- func (x *DnsTable_DnsServiceTarget) SetWeight(v uint32)
- func (x *DnsTable_DnsServiceTarget) String() string
- func (x *DnsTable_DnsServiceTarget) WhichEndpointType() case_DnsTable_DnsServiceTarget_EndpointType
- type DnsTable_DnsServiceTarget_ClusterName
- type DnsTable_DnsServiceTarget_HostName
- type DnsTable_DnsServiceTarget_builder
- type DnsTable_DnsService_builder
- type DnsTable_DnsVirtualDomain
- func (x *DnsTable_DnsVirtualDomain) ClearAnswerTtl()
- func (x *DnsTable_DnsVirtualDomain) ClearEndpoint()
- func (x *DnsTable_DnsVirtualDomain) GetAnswerTtl() *durationpb.Duration
- func (x *DnsTable_DnsVirtualDomain) GetEndpoint() *DnsTable_DnsEndpoint
- func (x *DnsTable_DnsVirtualDomain) GetName() string
- func (x *DnsTable_DnsVirtualDomain) HasAnswerTtl() bool
- func (x *DnsTable_DnsVirtualDomain) HasEndpoint() bool
- func (*DnsTable_DnsVirtualDomain) ProtoMessage()
- func (x *DnsTable_DnsVirtualDomain) ProtoReflect() protoreflect.Message
- func (x *DnsTable_DnsVirtualDomain) Reset()
- func (x *DnsTable_DnsVirtualDomain) SetAnswerTtl(v *durationpb.Duration)
- func (x *DnsTable_DnsVirtualDomain) SetEndpoint(v *DnsTable_DnsEndpoint)
- func (x *DnsTable_DnsVirtualDomain) SetName(v string)
- func (x *DnsTable_DnsVirtualDomain) String() string
- type DnsTable_DnsVirtualDomain_builder
- type DnsTable_builder
Constants ¶
const DnsTable_DnsEndpoint_AddressList_case case_DnsTable_DnsEndpoint_EndpointConfig = 1
const DnsTable_DnsEndpoint_ClusterName_case case_DnsTable_DnsEndpoint_EndpointConfig = 2
const DnsTable_DnsEndpoint_EndpointConfig_not_set_case case_DnsTable_DnsEndpoint_EndpointConfig = 0
const DnsTable_DnsEndpoint_ServiceList_case case_DnsTable_DnsEndpoint_EndpointConfig = 3
const DnsTable_DnsServiceProtocol_Name_case case_DnsTable_DnsServiceProtocol_ProtocolConfig = 2
const DnsTable_DnsServiceProtocol_Number_case case_DnsTable_DnsServiceProtocol_ProtocolConfig = 1
const DnsTable_DnsServiceProtocol_ProtocolConfig_not_set_case case_DnsTable_DnsServiceProtocol_ProtocolConfig = 0
const DnsTable_DnsServiceTarget_ClusterName_case case_DnsTable_DnsServiceTarget_EndpointType = 2
const DnsTable_DnsServiceTarget_EndpointType_not_set_case case_DnsTable_DnsServiceTarget_EndpointType = 0
const DnsTable_DnsServiceTarget_HostName_case case_DnsTable_DnsServiceTarget_EndpointType = 1
Variables ¶
var File_envoy_data_dns_v3_dns_table_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type DnsTable ¶
type DnsTable struct {
// Control how many times Envoy makes an attempt to forward a query to an external DNS server
ExternalRetryCount uint32 `protobuf:"varint,1,opt,name=external_retry_count,json=externalRetryCount,proto3" json:"external_retry_count,omitempty"`
// Fully qualified domain names for which Envoy will respond to DNS queries. By leaving this
// list empty, Envoy will forward all queries to external resolvers
VirtualDomains []*DnsTable_DnsVirtualDomain `protobuf:"bytes,2,rep,name=virtual_domains,json=virtualDomains,proto3" json:"virtual_domains,omitempty"`
// This field is deprecated and no longer used in Envoy. The filter's behavior has changed
// internally to use a different data structure allowing the filter to determine whether a
// query is for known domain without the use of this field.
//
// This field serves to help Envoy determine whether it can authoritatively answer a query
// for a name matching a suffix in this list. If the query name does not match a suffix in
// this list, Envoy will forward the query to an upstream DNS server
//
// Deprecated: Marked as deprecated in envoy/data/dns/v3/dns_table.proto.
KnownSuffixes []*v3.StringMatcher `protobuf:"bytes,3,rep,name=known_suffixes,json=knownSuffixes,proto3" json:"known_suffixes,omitempty"`
// contains filtered or unexported fields
}
This message contains the configuration for the DNS Filter if populated from the control plane
func (*DnsTable) GetKnownSuffixes
deprecated
func (x *DnsTable) GetKnownSuffixes() []*v3.StringMatcher
Deprecated: Marked as deprecated in envoy/data/dns/v3/dns_table.proto.
func (*DnsTable) GetVirtualDomains ¶
func (x *DnsTable) GetVirtualDomains() []*DnsTable_DnsVirtualDomain
func (*DnsTable) ProtoReflect ¶
func (x *DnsTable) ProtoReflect() protoreflect.Message
func (*DnsTable) SetKnownSuffixes
deprecated
func (x *DnsTable) SetKnownSuffixes(v []*v3.StringMatcher)
Deprecated: Marked as deprecated in envoy/data/dns/v3/dns_table.proto.
func (*DnsTable) SetVirtualDomains ¶
func (x *DnsTable) SetVirtualDomains(v []*DnsTable_DnsVirtualDomain)
type DnsTable_AddressList ¶
type DnsTable_AddressList struct {
// This field contains a well formed IP address that is returned in the answer for a
// name query. The address field can be an IPv4 or IPv6 address. Address family
// detection is done automatically when Envoy parses the string. Since this field is
// repeated, Envoy will return as many entries from this list in the DNS response while
// keeping the response under 512 bytes
Address []string `protobuf:"bytes,1,rep,name=address,proto3" json:"address,omitempty"`
// contains filtered or unexported fields
}
This message contains a list of IP addresses returned for a query for a known name
func (*DnsTable_AddressList) GetAddress ¶
func (x *DnsTable_AddressList) GetAddress() []string
func (*DnsTable_AddressList) ProtoMessage ¶
func (*DnsTable_AddressList) ProtoMessage()
func (*DnsTable_AddressList) ProtoReflect ¶
func (x *DnsTable_AddressList) ProtoReflect() protoreflect.Message
func (*DnsTable_AddressList) Reset ¶
func (x *DnsTable_AddressList) Reset()
func (*DnsTable_AddressList) SetAddress ¶
func (x *DnsTable_AddressList) SetAddress(v []string)
func (*DnsTable_AddressList) String ¶
func (x *DnsTable_AddressList) String() string
type DnsTable_AddressList_builder ¶
type DnsTable_AddressList_builder struct {
// This field contains a well formed IP address that is returned in the answer for a
// name query. The address field can be an IPv4 or IPv6 address. Address family
// detection is done automatically when Envoy parses the string. Since this field is
// repeated, Envoy will return as many entries from this list in the DNS response while
// keeping the response under 512 bytes
Address []string
// contains filtered or unexported fields
}
func (DnsTable_AddressList_builder) Build ¶
func (b0 DnsTable_AddressList_builder) Build() *DnsTable_AddressList
type DnsTable_DnsEndpoint ¶
type DnsTable_DnsEndpoint struct {
// Types that are valid to be assigned to EndpointConfig:
//
// *DnsTable_DnsEndpoint_AddressList
// *DnsTable_DnsEndpoint_ClusterName
// *DnsTable_DnsEndpoint_ServiceList
EndpointConfig isDnsTable_DnsEndpoint_EndpointConfig `protobuf_oneof:"endpoint_config"`
// contains filtered or unexported fields
}
func (*DnsTable_DnsEndpoint) ClearAddressList ¶
func (x *DnsTable_DnsEndpoint) ClearAddressList()
func (*DnsTable_DnsEndpoint) ClearClusterName ¶
func (x *DnsTable_DnsEndpoint) ClearClusterName()
func (*DnsTable_DnsEndpoint) ClearEndpointConfig ¶
func (x *DnsTable_DnsEndpoint) ClearEndpointConfig()
func (*DnsTable_DnsEndpoint) ClearServiceList ¶
func (x *DnsTable_DnsEndpoint) ClearServiceList()
func (*DnsTable_DnsEndpoint) GetAddressList ¶
func (x *DnsTable_DnsEndpoint) GetAddressList() *DnsTable_AddressList
func (*DnsTable_DnsEndpoint) GetClusterName ¶
func (x *DnsTable_DnsEndpoint) GetClusterName() string
func (*DnsTable_DnsEndpoint) GetEndpointConfig ¶
func (x *DnsTable_DnsEndpoint) GetEndpointConfig() isDnsTable_DnsEndpoint_EndpointConfig
func (*DnsTable_DnsEndpoint) GetServiceList ¶
func (x *DnsTable_DnsEndpoint) GetServiceList() *DnsTable_DnsServiceList
func (*DnsTable_DnsEndpoint) HasAddressList ¶
func (x *DnsTable_DnsEndpoint) HasAddressList() bool
func (*DnsTable_DnsEndpoint) HasClusterName ¶
func (x *DnsTable_DnsEndpoint) HasClusterName() bool
func (*DnsTable_DnsEndpoint) HasEndpointConfig ¶
func (x *DnsTable_DnsEndpoint) HasEndpointConfig() bool
func (*DnsTable_DnsEndpoint) HasServiceList ¶
func (x *DnsTable_DnsEndpoint) HasServiceList() bool
func (*DnsTable_DnsEndpoint) ProtoMessage ¶
func (*DnsTable_DnsEndpoint) ProtoMessage()
func (*DnsTable_DnsEndpoint) ProtoReflect ¶
func (x *DnsTable_DnsEndpoint) ProtoReflect() protoreflect.Message
func (*DnsTable_DnsEndpoint) Reset ¶
func (x *DnsTable_DnsEndpoint) Reset()
func (*DnsTable_DnsEndpoint) SetAddressList ¶
func (x *DnsTable_DnsEndpoint) SetAddressList(v *DnsTable_AddressList)
func (*DnsTable_DnsEndpoint) SetClusterName ¶
func (x *DnsTable_DnsEndpoint) SetClusterName(v string)
func (*DnsTable_DnsEndpoint) SetServiceList ¶
func (x *DnsTable_DnsEndpoint) SetServiceList(v *DnsTable_DnsServiceList)
func (*DnsTable_DnsEndpoint) String ¶
func (x *DnsTable_DnsEndpoint) String() string
func (*DnsTable_DnsEndpoint) WhichEndpointConfig ¶
func (x *DnsTable_DnsEndpoint) WhichEndpointConfig() case_DnsTable_DnsEndpoint_EndpointConfig
type DnsTable_DnsEndpoint_AddressList ¶
type DnsTable_DnsEndpoint_AddressList struct {
// Define a list of addresses to return for the specified endpoint
AddressList *DnsTable_AddressList `protobuf:"bytes,1,opt,name=address_list,json=addressList,proto3,oneof"`
}
type DnsTable_DnsEndpoint_ClusterName ¶
type DnsTable_DnsEndpoint_ClusterName struct {
// Define a cluster whose addresses are returned for the specified endpoint
ClusterName string `protobuf:"bytes,2,opt,name=cluster_name,json=clusterName,proto3,oneof"`
}
type DnsTable_DnsEndpoint_ServiceList ¶
type DnsTable_DnsEndpoint_ServiceList struct {
// Define a DNS Service List for the specified endpoint
ServiceList *DnsTable_DnsServiceList `protobuf:"bytes,3,opt,name=service_list,json=serviceList,proto3,oneof"`
}
type DnsTable_DnsEndpoint_builder ¶
type DnsTable_DnsEndpoint_builder struct {
// Fields of oneof EndpointConfig:
// Define a list of addresses to return for the specified endpoint
AddressList *DnsTable_AddressList
// Define a cluster whose addresses are returned for the specified endpoint
ClusterName *string
// Define a DNS Service List for the specified endpoint
ServiceList *DnsTable_DnsServiceList
// contains filtered or unexported fields
}
func (DnsTable_DnsEndpoint_builder) Build ¶
func (b0 DnsTable_DnsEndpoint_builder) Build() *DnsTable_DnsEndpoint
type DnsTable_DnsService ¶
type DnsTable_DnsService struct {
// The name of the service without the protocol or domain name
ServiceName string `protobuf:"bytes,1,opt,name=service_name,json=serviceName,proto3" json:"service_name,omitempty"`
// The service protocol. This can be specified as a string or the numeric value of the protocol
Protocol *DnsTable_DnsServiceProtocol `protobuf:"bytes,2,opt,name=protocol,proto3" json:"protocol,omitempty"`
// The service entry time to live. This is independent from the DNS Answer record TTL
Ttl *durationpb.Duration `protobuf:"bytes,3,opt,name=ttl,proto3" json:"ttl,omitempty"`
// The list of targets hosting the service
Targets []*DnsTable_DnsServiceTarget `protobuf:"bytes,4,rep,name=targets,proto3" json:"targets,omitempty"`
// contains filtered or unexported fields
}
This message defines a service selection record returned for a service query in a domain
func (*DnsTable_DnsService) ClearProtocol ¶
func (x *DnsTable_DnsService) ClearProtocol()
func (*DnsTable_DnsService) ClearTtl ¶
func (x *DnsTable_DnsService) ClearTtl()
func (*DnsTable_DnsService) GetProtocol ¶
func (x *DnsTable_DnsService) GetProtocol() *DnsTable_DnsServiceProtocol
func (*DnsTable_DnsService) GetServiceName ¶
func (x *DnsTable_DnsService) GetServiceName() string
func (*DnsTable_DnsService) GetTargets ¶
func (x *DnsTable_DnsService) GetTargets() []*DnsTable_DnsServiceTarget
func (*DnsTable_DnsService) GetTtl ¶
func (x *DnsTable_DnsService) GetTtl() *durationpb.Duration
func (*DnsTable_DnsService) HasProtocol ¶
func (x *DnsTable_DnsService) HasProtocol() bool
func (*DnsTable_DnsService) HasTtl ¶
func (x *DnsTable_DnsService) HasTtl() bool
func (*DnsTable_DnsService) ProtoMessage ¶
func (*DnsTable_DnsService) ProtoMessage()
func (*DnsTable_DnsService) ProtoReflect ¶
func (x *DnsTable_DnsService) ProtoReflect() protoreflect.Message
func (*DnsTable_DnsService) Reset ¶
func (x *DnsTable_DnsService) Reset()
func (*DnsTable_DnsService) SetProtocol ¶
func (x *DnsTable_DnsService) SetProtocol(v *DnsTable_DnsServiceProtocol)
func (*DnsTable_DnsService) SetServiceName ¶
func (x *DnsTable_DnsService) SetServiceName(v string)
func (*DnsTable_DnsService) SetTargets ¶
func (x *DnsTable_DnsService) SetTargets(v []*DnsTable_DnsServiceTarget)
func (*DnsTable_DnsService) SetTtl ¶
func (x *DnsTable_DnsService) SetTtl(v *durationpb.Duration)
func (*DnsTable_DnsService) String ¶
func (x *DnsTable_DnsService) String() string
type DnsTable_DnsServiceList ¶
type DnsTable_DnsServiceList struct {
Services []*DnsTable_DnsService `protobuf:"bytes,1,rep,name=services,proto3" json:"services,omitempty"`
// contains filtered or unexported fields
}
Define a list of service records for a given service
func (*DnsTable_DnsServiceList) GetServices ¶
func (x *DnsTable_DnsServiceList) GetServices() []*DnsTable_DnsService
func (*DnsTable_DnsServiceList) ProtoMessage ¶
func (*DnsTable_DnsServiceList) ProtoMessage()
func (*DnsTable_DnsServiceList) ProtoReflect ¶
func (x *DnsTable_DnsServiceList) ProtoReflect() protoreflect.Message
func (*DnsTable_DnsServiceList) Reset ¶
func (x *DnsTable_DnsServiceList) Reset()
func (*DnsTable_DnsServiceList) SetServices ¶
func (x *DnsTable_DnsServiceList) SetServices(v []*DnsTable_DnsService)
func (*DnsTable_DnsServiceList) String ¶
func (x *DnsTable_DnsServiceList) String() string
type DnsTable_DnsServiceList_builder ¶
type DnsTable_DnsServiceList_builder struct {
Services []*DnsTable_DnsService
// contains filtered or unexported fields
}
func (DnsTable_DnsServiceList_builder) Build ¶
func (b0 DnsTable_DnsServiceList_builder) Build() *DnsTable_DnsServiceList
type DnsTable_DnsServiceProtocol ¶
type DnsTable_DnsServiceProtocol struct {
// Types that are valid to be assigned to ProtocolConfig:
//
// *DnsTable_DnsServiceProtocol_Number
// *DnsTable_DnsServiceProtocol_Name
ProtocolConfig isDnsTable_DnsServiceProtocol_ProtocolConfig `protobuf_oneof:"protocol_config"`
// contains filtered or unexported fields
}
Specify the service protocol using a numeric or string value
func (*DnsTable_DnsServiceProtocol) ClearName ¶
func (x *DnsTable_DnsServiceProtocol) ClearName()
func (*DnsTable_DnsServiceProtocol) ClearNumber ¶
func (x *DnsTable_DnsServiceProtocol) ClearNumber()
func (*DnsTable_DnsServiceProtocol) ClearProtocolConfig ¶
func (x *DnsTable_DnsServiceProtocol) ClearProtocolConfig()
func (*DnsTable_DnsServiceProtocol) GetName ¶
func (x *DnsTable_DnsServiceProtocol) GetName() string
func (*DnsTable_DnsServiceProtocol) GetNumber ¶
func (x *DnsTable_DnsServiceProtocol) GetNumber() uint32
func (*DnsTable_DnsServiceProtocol) GetProtocolConfig ¶
func (x *DnsTable_DnsServiceProtocol) GetProtocolConfig() isDnsTable_DnsServiceProtocol_ProtocolConfig
func (*DnsTable_DnsServiceProtocol) HasName ¶
func (x *DnsTable_DnsServiceProtocol) HasName() bool
func (*DnsTable_DnsServiceProtocol) HasNumber ¶
func (x *DnsTable_DnsServiceProtocol) HasNumber() bool
func (*DnsTable_DnsServiceProtocol) HasProtocolConfig ¶
func (x *DnsTable_DnsServiceProtocol) HasProtocolConfig() bool
func (*DnsTable_DnsServiceProtocol) ProtoMessage ¶
func (*DnsTable_DnsServiceProtocol) ProtoMessage()
func (*DnsTable_DnsServiceProtocol) ProtoReflect ¶
func (x *DnsTable_DnsServiceProtocol) ProtoReflect() protoreflect.Message
func (*DnsTable_DnsServiceProtocol) Reset ¶
func (x *DnsTable_DnsServiceProtocol) Reset()
func (*DnsTable_DnsServiceProtocol) SetName ¶
func (x *DnsTable_DnsServiceProtocol) SetName(v string)
func (*DnsTable_DnsServiceProtocol) SetNumber ¶
func (x *DnsTable_DnsServiceProtocol) SetNumber(v uint32)
func (*DnsTable_DnsServiceProtocol) String ¶
func (x *DnsTable_DnsServiceProtocol) String() string
func (*DnsTable_DnsServiceProtocol) WhichProtocolConfig ¶
func (x *DnsTable_DnsServiceProtocol) WhichProtocolConfig() case_DnsTable_DnsServiceProtocol_ProtocolConfig
type DnsTable_DnsServiceProtocol_Name ¶
type DnsTable_DnsServiceProtocol_Name struct {
// Specify the protocol name for the service.
Name string `protobuf:"bytes,2,opt,name=name,proto3,oneof"`
}
type DnsTable_DnsServiceProtocol_Number ¶
type DnsTable_DnsServiceProtocol_Number struct {
// Specify the protocol number for the service. Envoy will try to resolve the number to
// the protocol name. For example, 6 will resolve to "tcp". Refer to:
// https://www.iana.org/assignments/protocol-numbers/protocol-numbers.xhtml
// for protocol names and numbers
Number uint32 `protobuf:"varint,1,opt,name=number,proto3,oneof"`
}
type DnsTable_DnsServiceProtocol_builder ¶
type DnsTable_DnsServiceProtocol_builder struct {
// Fields of oneof ProtocolConfig:
// Specify the protocol number for the service. Envoy will try to resolve the number to
// the protocol name. For example, 6 will resolve to "tcp". Refer to:
// https://www.iana.org/assignments/protocol-numbers/protocol-numbers.xhtml
// for protocol names and numbers
Number *uint32
// Specify the protocol name for the service.
Name *string
// contains filtered or unexported fields
}
func (DnsTable_DnsServiceProtocol_builder) Build ¶
func (b0 DnsTable_DnsServiceProtocol_builder) Build() *DnsTable_DnsServiceProtocol
type DnsTable_DnsServiceTarget ¶
type DnsTable_DnsServiceTarget struct {
// Specify the name of the endpoint for the Service. The name is a hostname or a cluster
//
// Types that are valid to be assigned to EndpointType:
//
// *DnsTable_DnsServiceTarget_HostName
// *DnsTable_DnsServiceTarget_ClusterName
EndpointType isDnsTable_DnsServiceTarget_EndpointType `protobuf_oneof:"endpoint_type"`
// The priority of the service record target
Priority uint32 `protobuf:"varint,3,opt,name=priority,proto3" json:"priority,omitempty"`
// The weight of the service record target
Weight uint32 `protobuf:"varint,4,opt,name=weight,proto3" json:"weight,omitempty"`
// The port to which the service is bound. This value is optional if the target is a
// cluster. Setting port to zero in this case makes the filter use the port value
// from the cluster host
Port uint32 `protobuf:"varint,5,opt,name=port,proto3" json:"port,omitempty"`
// contains filtered or unexported fields
}
Specify the target for a given DNS service [#next-free-field: 6]
func (*DnsTable_DnsServiceTarget) ClearClusterName ¶
func (x *DnsTable_DnsServiceTarget) ClearClusterName()
func (*DnsTable_DnsServiceTarget) ClearEndpointType ¶
func (x *DnsTable_DnsServiceTarget) ClearEndpointType()
func (*DnsTable_DnsServiceTarget) ClearHostName ¶
func (x *DnsTable_DnsServiceTarget) ClearHostName()
func (*DnsTable_DnsServiceTarget) GetClusterName ¶
func (x *DnsTable_DnsServiceTarget) GetClusterName() string
func (*DnsTable_DnsServiceTarget) GetEndpointType ¶
func (x *DnsTable_DnsServiceTarget) GetEndpointType() isDnsTable_DnsServiceTarget_EndpointType
func (*DnsTable_DnsServiceTarget) GetHostName ¶
func (x *DnsTable_DnsServiceTarget) GetHostName() string
func (*DnsTable_DnsServiceTarget) GetPort ¶
func (x *DnsTable_DnsServiceTarget) GetPort() uint32
func (*DnsTable_DnsServiceTarget) GetPriority ¶
func (x *DnsTable_DnsServiceTarget) GetPriority() uint32
func (*DnsTable_DnsServiceTarget) GetWeight ¶
func (x *DnsTable_DnsServiceTarget) GetWeight() uint32
func (*DnsTable_DnsServiceTarget) HasClusterName ¶
func (x *DnsTable_DnsServiceTarget) HasClusterName() bool
func (*DnsTable_DnsServiceTarget) HasEndpointType ¶
func (x *DnsTable_DnsServiceTarget) HasEndpointType() bool
func (*DnsTable_DnsServiceTarget) HasHostName ¶
func (x *DnsTable_DnsServiceTarget) HasHostName() bool
func (*DnsTable_DnsServiceTarget) ProtoMessage ¶
func (*DnsTable_DnsServiceTarget) ProtoMessage()
func (*DnsTable_DnsServiceTarget) ProtoReflect ¶
func (x *DnsTable_DnsServiceTarget) ProtoReflect() protoreflect.Message
func (*DnsTable_DnsServiceTarget) Reset ¶
func (x *DnsTable_DnsServiceTarget) Reset()
func (*DnsTable_DnsServiceTarget) SetClusterName ¶
func (x *DnsTable_DnsServiceTarget) SetClusterName(v string)
func (*DnsTable_DnsServiceTarget) SetHostName ¶
func (x *DnsTable_DnsServiceTarget) SetHostName(v string)
func (*DnsTable_DnsServiceTarget) SetPort ¶
func (x *DnsTable_DnsServiceTarget) SetPort(v uint32)
func (*DnsTable_DnsServiceTarget) SetPriority ¶
func (x *DnsTable_DnsServiceTarget) SetPriority(v uint32)
func (*DnsTable_DnsServiceTarget) SetWeight ¶
func (x *DnsTable_DnsServiceTarget) SetWeight(v uint32)
func (*DnsTable_DnsServiceTarget) String ¶
func (x *DnsTable_DnsServiceTarget) String() string
func (*DnsTable_DnsServiceTarget) WhichEndpointType ¶
func (x *DnsTable_DnsServiceTarget) WhichEndpointType() case_DnsTable_DnsServiceTarget_EndpointType
type DnsTable_DnsServiceTarget_ClusterName ¶
type DnsTable_DnsServiceTarget_ClusterName struct {
// Use a cluster name as the endpoint for a service.
ClusterName string `protobuf:"bytes,2,opt,name=cluster_name,json=clusterName,proto3,oneof"`
}
type DnsTable_DnsServiceTarget_HostName ¶
type DnsTable_DnsServiceTarget_HostName struct {
// Use a resolvable hostname as the endpoint for a service.
HostName string `protobuf:"bytes,1,opt,name=host_name,json=hostName,proto3,oneof"`
}
type DnsTable_DnsServiceTarget_builder ¶
type DnsTable_DnsServiceTarget_builder struct {
// Fields of oneof EndpointType:
// Use a resolvable hostname as the endpoint for a service.
HostName *string
// Use a cluster name as the endpoint for a service.
ClusterName *string
// -- end of EndpointType
// The priority of the service record target
Priority uint32
// The weight of the service record target
Weight uint32
// The port to which the service is bound. This value is optional if the target is a
// cluster. Setting port to zero in this case makes the filter use the port value
// from the cluster host
Port uint32
// contains filtered or unexported fields
}
func (DnsTable_DnsServiceTarget_builder) Build ¶
func (b0 DnsTable_DnsServiceTarget_builder) Build() *DnsTable_DnsServiceTarget
type DnsTable_DnsService_builder ¶
type DnsTable_DnsService_builder struct {
// The name of the service without the protocol or domain name
ServiceName string
// The service protocol. This can be specified as a string or the numeric value of the protocol
Protocol *DnsTable_DnsServiceProtocol
// The service entry time to live. This is independent from the DNS Answer record TTL
Ttl *durationpb.Duration
// The list of targets hosting the service
Targets []*DnsTable_DnsServiceTarget
// contains filtered or unexported fields
}
func (DnsTable_DnsService_builder) Build ¶
func (b0 DnsTable_DnsService_builder) Build() *DnsTable_DnsService
type DnsTable_DnsVirtualDomain ¶
type DnsTable_DnsVirtualDomain struct {
// A domain name for which Envoy will respond to query requests.
// Wildcard records are supported on the first label only, e.g. “*.example.com“ or “*.subdomain.example.com“.
// Names such as “*example.com“, “subdomain.*.example.com“, “*subdomain.example.com“, etc
// are not valid wildcard names and asterisk will be interpreted as a literal “*“ character.
// Wildcard records match subdomains on any levels, e.g. “*.example.com“ will match
// “foo.example.com“, “bar.foo.example.com“, “baz.bar.foo.example.com“, etc. In case there are multiple
// wildcard records, the longest wildcard match will be used, e.g. if there are wildcard records for
// “*.example.com“ and “*.foo.example.com“ and the query is for “bar.foo.example.com“, the latter will be used.
// Specific records will always take precedence over wildcard records.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// The configuration containing the method to determine the address of this endpoint
Endpoint *DnsTable_DnsEndpoint `protobuf:"bytes,2,opt,name=endpoint,proto3" json:"endpoint,omitempty"`
// Sets the TTL in DNS answers from Envoy returned to the client. The default TTL is 300s
AnswerTtl *durationpb.Duration `protobuf:"bytes,3,opt,name=answer_ttl,json=answerTtl,proto3" json:"answer_ttl,omitempty"`
// contains filtered or unexported fields
}
func (*DnsTable_DnsVirtualDomain) ClearAnswerTtl ¶
func (x *DnsTable_DnsVirtualDomain) ClearAnswerTtl()
func (*DnsTable_DnsVirtualDomain) ClearEndpoint ¶
func (x *DnsTable_DnsVirtualDomain) ClearEndpoint()
func (*DnsTable_DnsVirtualDomain) GetAnswerTtl ¶
func (x *DnsTable_DnsVirtualDomain) GetAnswerTtl() *durationpb.Duration
func (*DnsTable_DnsVirtualDomain) GetEndpoint ¶
func (x *DnsTable_DnsVirtualDomain) GetEndpoint() *DnsTable_DnsEndpoint
func (*DnsTable_DnsVirtualDomain) GetName ¶
func (x *DnsTable_DnsVirtualDomain) GetName() string
func (*DnsTable_DnsVirtualDomain) HasAnswerTtl ¶
func (x *DnsTable_DnsVirtualDomain) HasAnswerTtl() bool
func (*DnsTable_DnsVirtualDomain) HasEndpoint ¶
func (x *DnsTable_DnsVirtualDomain) HasEndpoint() bool
func (*DnsTable_DnsVirtualDomain) ProtoMessage ¶
func (*DnsTable_DnsVirtualDomain) ProtoMessage()
func (*DnsTable_DnsVirtualDomain) ProtoReflect ¶
func (x *DnsTable_DnsVirtualDomain) ProtoReflect() protoreflect.Message
func (*DnsTable_DnsVirtualDomain) Reset ¶
func (x *DnsTable_DnsVirtualDomain) Reset()
func (*DnsTable_DnsVirtualDomain) SetAnswerTtl ¶
func (x *DnsTable_DnsVirtualDomain) SetAnswerTtl(v *durationpb.Duration)
func (*DnsTable_DnsVirtualDomain) SetEndpoint ¶
func (x *DnsTable_DnsVirtualDomain) SetEndpoint(v *DnsTable_DnsEndpoint)
func (*DnsTable_DnsVirtualDomain) SetName ¶
func (x *DnsTable_DnsVirtualDomain) SetName(v string)
func (*DnsTable_DnsVirtualDomain) String ¶
func (x *DnsTable_DnsVirtualDomain) String() string
type DnsTable_DnsVirtualDomain_builder ¶
type DnsTable_DnsVirtualDomain_builder struct {
// A domain name for which Envoy will respond to query requests.
// Wildcard records are supported on the first label only, e.g. “*.example.com“ or “*.subdomain.example.com“.
// Names such as “*example.com“, “subdomain.*.example.com“, “*subdomain.example.com“, etc
// are not valid wildcard names and asterisk will be interpreted as a literal “*“ character.
// Wildcard records match subdomains on any levels, e.g. “*.example.com“ will match
// “foo.example.com“, “bar.foo.example.com“, “baz.bar.foo.example.com“, etc. In case there are multiple
// wildcard records, the longest wildcard match will be used, e.g. if there are wildcard records for
// “*.example.com“ and “*.foo.example.com“ and the query is for “bar.foo.example.com“, the latter will be used.
// Specific records will always take precedence over wildcard records.
Name string
// The configuration containing the method to determine the address of this endpoint
Endpoint *DnsTable_DnsEndpoint
// Sets the TTL in DNS answers from Envoy returned to the client. The default TTL is 300s
AnswerTtl *durationpb.Duration
// contains filtered or unexported fields
}
func (DnsTable_DnsVirtualDomain_builder) Build ¶
func (b0 DnsTable_DnsVirtualDomain_builder) Build() *DnsTable_DnsVirtualDomain
type DnsTable_builder ¶
type DnsTable_builder struct {
// Control how many times Envoy makes an attempt to forward a query to an external DNS server
ExternalRetryCount uint32
// Fully qualified domain names for which Envoy will respond to DNS queries. By leaving this
// list empty, Envoy will forward all queries to external resolvers
VirtualDomains []*DnsTable_DnsVirtualDomain
// This field is deprecated and no longer used in Envoy. The filter's behavior has changed
// internally to use a different data structure allowing the filter to determine whether a
// query is for known domain without the use of this field.
//
// This field serves to help Envoy determine whether it can authoritatively answer a query
// for a name matching a suffix in this list. If the query name does not match a suffix in
// this list, Envoy will forward the query to an upstream DNS server
//
// Deprecated: Marked as deprecated in envoy/data/dns/v3/dns_table.proto.
KnownSuffixes []*v3.StringMatcher
// contains filtered or unexported fields
}
func (DnsTable_builder) Build ¶
func (b0 DnsTable_builder) Build() *DnsTable
Source Files
¶
- dns_table.pb.go
Click to show internal directories.
Click to hide internal directories.