open_telemetryv3

package
v1.36.11-2026011520535... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 12 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var File_envoy_extensions_access_loggers_open_telemetry_v3_logs_service_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type OpenTelemetryAccessLogConfig

type OpenTelemetryAccessLogConfig struct {

	// [#comment:TODO(itamarkam): add 'filter_state_objects_to_log' to logs.]
	// Deprecated. Use “grpc_service“ or “http_service“ instead.
	//
	// Deprecated: Marked as deprecated in envoy/extensions/access_loggers/open_telemetry/v3/logs_service.proto.
	CommonConfig *v3.CommonGrpcAccessLogConfig `protobuf:"bytes,1,opt,name=common_config,json=commonConfig,proto3" json:"common_config,omitempty"`
	// The upstream HTTP cluster that will receive OTLP logs via
	// `OTLP/HTTP <https://opentelemetry.io/docs/specs/otlp/#otlphttp>`_.
	// Note: Only one of “common_config“, “grpc_service“, or “http_service“ may be used.
	//
	// .. note::
	//
	//	The “request_headers_to_add“ property in the OTLP HTTP exporter service
	//	does not support the :ref:`format specifier <config_access_log_format>` as used for
	//	:ref:`HTTP access logging <config_access_log>`.
	//	The values configured are added as HTTP headers on the OTLP export request
	//	without any formatting applied.
	HttpService *v31.HttpService `protobuf:"bytes,8,opt,name=http_service,json=httpService,proto3" json:"http_service,omitempty"`
	// The upstream gRPC cluster that will receive OTLP logs.
	// Note: Only one of “common_config“, “grpc_service“, or “http_service“ may be used.
	// This field is preferred over “common_config.grpc_service“.
	GrpcService *v31.GrpcService `protobuf:"bytes,9,opt,name=grpc_service,json=grpcService,proto3" json:"grpc_service,omitempty"`
	// If specified, Envoy will not generate built-in resource labels
	// like “log_name“, “zone_name“, “cluster_name“, “node_name“.
	DisableBuiltinLabels bool `protobuf:"varint,5,opt,name=disable_builtin_labels,json=disableBuiltinLabels,proto3" json:"disable_builtin_labels,omitempty"`
	// OpenTelemetry `Resource <https://github.com/open-telemetry/opentelemetry-proto/blob/main/opentelemetry/proto/logs/v1/logs.proto#L51>`_
	// attributes are filled with Envoy node info.
	// Example: “resource_attributes { values { key: "region" value { string_value: "cn-north-7" } } }“.
	ResourceAttributes *v1.KeyValueList `protobuf:"bytes,4,opt,name=resource_attributes,json=resourceAttributes,proto3" json:"resource_attributes,omitempty"`
	// OpenTelemetry `LogResource <https://github.com/open-telemetry/opentelemetry-proto/blob/main/opentelemetry/proto/logs/v1/logs.proto>`_
	// fields, following `Envoy access logging formatting <https://www.envoyproxy.io/docs/envoy/latest/configuration/observability/access_log/usage>`_.
	//
	// See 'body' in the LogResource proto for more details.
	// Example: “body { string_value: "%PROTOCOL%" }“.
	Body *v1.AnyValue `protobuf:"bytes,2,opt,name=body,proto3" json:"body,omitempty"`
	// See 'attributes' in the LogResource proto for more details.
	// Example: “attributes { values { key: "user_agent" value { string_value: "%REQ(USER-AGENT)%" } } }“.
	Attributes *v1.KeyValueList `protobuf:"bytes,3,opt,name=attributes,proto3" json:"attributes,omitempty"`
	// Optional. Additional prefix to use on OpenTelemetry access logger stats. If empty, the stats will be rooted at
	// “access_logs.open_telemetry_access_log.“. If non-empty, stats will be rooted at
	// “access_logs.open_telemetry_access_log.<stat_prefix>.“.
	StatPrefix string `protobuf:"bytes,6,opt,name=stat_prefix,json=statPrefix,proto3" json:"stat_prefix,omitempty"`
	// Specifies a collection of Formatter plugins that can be called from the access log configuration.
	// See the formatters extensions documentation for details.
	// [#extension-category: envoy.formatter]
	Formatters []*v31.TypedExtensionConfig `protobuf:"bytes,7,rep,name=formatters,proto3" json:"formatters,omitempty"`
	LogName    string                      `protobuf:"bytes,10,opt,name=log_name,json=logName,proto3" json:"log_name,omitempty"`
	// The interval for flushing access logs to the transport. Default: 1 second.
	BufferFlushInterval *durationpb.Duration `protobuf:"bytes,11,opt,name=buffer_flush_interval,json=bufferFlushInterval,proto3" json:"buffer_flush_interval,omitempty"`
	// Soft size limit in bytes for the access log buffer. When the buffer exceeds
	// this limit, logs will be flushed. Default: 16KB.
	BufferSizeBytes *wrapperspb.UInt32Value `protobuf:"bytes,12,opt,name=buffer_size_bytes,json=bufferSizeBytes,proto3" json:"buffer_size_bytes,omitempty"`
	// Additional filter state objects to log as attributes.
	FilterStateObjectsToLog []string `` /* 137-byte string literal not displayed */
	// Custom tags to include as log attributes.
	CustomTags []*v32.CustomTag `protobuf:"bytes,14,rep,name=custom_tags,json=customTags,proto3" json:"custom_tags,omitempty"`
	// contains filtered or unexported fields
}

Configuration for the built-in “envoy.access_loggers.open_telemetry“ :ref:`AccessLog <envoy_v3_api_msg_config.accesslog.v3.AccessLog>`. This configuration will populate `opentelemetry.proto.collector.v1.logs.ExportLogsServiceRequest.resource_logs <https://github.com/open-telemetry/opentelemetry-proto/blob/main/opentelemetry/proto/collector/logs/v1/logs_service.proto>`_. In addition, the request start time is set in the dedicated field. [#extension: envoy.access_loggers.open_telemetry] [#next-free-field: 15]

func (*OpenTelemetryAccessLogConfig) ClearAttributes

func (x *OpenTelemetryAccessLogConfig) ClearAttributes()

func (*OpenTelemetryAccessLogConfig) ClearBody

func (x *OpenTelemetryAccessLogConfig) ClearBody()

func (*OpenTelemetryAccessLogConfig) ClearBufferFlushInterval

func (x *OpenTelemetryAccessLogConfig) ClearBufferFlushInterval()

func (*OpenTelemetryAccessLogConfig) ClearBufferSizeBytes

func (x *OpenTelemetryAccessLogConfig) ClearBufferSizeBytes()

func (*OpenTelemetryAccessLogConfig) ClearCommonConfig deprecated

func (x *OpenTelemetryAccessLogConfig) ClearCommonConfig()

Deprecated: Marked as deprecated in envoy/extensions/access_loggers/open_telemetry/v3/logs_service.proto.

func (*OpenTelemetryAccessLogConfig) ClearGrpcService

func (x *OpenTelemetryAccessLogConfig) ClearGrpcService()

func (*OpenTelemetryAccessLogConfig) ClearHttpService

func (x *OpenTelemetryAccessLogConfig) ClearHttpService()

func (*OpenTelemetryAccessLogConfig) ClearResourceAttributes

func (x *OpenTelemetryAccessLogConfig) ClearResourceAttributes()

func (*OpenTelemetryAccessLogConfig) GetAttributes

func (x *OpenTelemetryAccessLogConfig) GetAttributes() *v1.KeyValueList

func (*OpenTelemetryAccessLogConfig) GetBody

func (*OpenTelemetryAccessLogConfig) GetBufferFlushInterval

func (x *OpenTelemetryAccessLogConfig) GetBufferFlushInterval() *durationpb.Duration

func (*OpenTelemetryAccessLogConfig) GetBufferSizeBytes

func (x *OpenTelemetryAccessLogConfig) GetBufferSizeBytes() *wrapperspb.UInt32Value

func (*OpenTelemetryAccessLogConfig) GetCommonConfig deprecated

Deprecated: Marked as deprecated in envoy/extensions/access_loggers/open_telemetry/v3/logs_service.proto.

func (*OpenTelemetryAccessLogConfig) GetCustomTags

func (x *OpenTelemetryAccessLogConfig) GetCustomTags() []*v32.CustomTag

func (*OpenTelemetryAccessLogConfig) GetDisableBuiltinLabels

func (x *OpenTelemetryAccessLogConfig) GetDisableBuiltinLabels() bool

func (*OpenTelemetryAccessLogConfig) GetFilterStateObjectsToLog

func (x *OpenTelemetryAccessLogConfig) GetFilterStateObjectsToLog() []string

func (*OpenTelemetryAccessLogConfig) GetFormatters

func (*OpenTelemetryAccessLogConfig) GetGrpcService

func (x *OpenTelemetryAccessLogConfig) GetGrpcService() *v31.GrpcService

func (*OpenTelemetryAccessLogConfig) GetHttpService

func (x *OpenTelemetryAccessLogConfig) GetHttpService() *v31.HttpService

func (*OpenTelemetryAccessLogConfig) GetLogName

func (x *OpenTelemetryAccessLogConfig) GetLogName() string

func (*OpenTelemetryAccessLogConfig) GetResourceAttributes

func (x *OpenTelemetryAccessLogConfig) GetResourceAttributes() *v1.KeyValueList

func (*OpenTelemetryAccessLogConfig) GetStatPrefix

func (x *OpenTelemetryAccessLogConfig) GetStatPrefix() string

func (*OpenTelemetryAccessLogConfig) HasAttributes

func (x *OpenTelemetryAccessLogConfig) HasAttributes() bool

func (*OpenTelemetryAccessLogConfig) HasBody

func (x *OpenTelemetryAccessLogConfig) HasBody() bool

func (*OpenTelemetryAccessLogConfig) HasBufferFlushInterval

func (x *OpenTelemetryAccessLogConfig) HasBufferFlushInterval() bool

func (*OpenTelemetryAccessLogConfig) HasBufferSizeBytes

func (x *OpenTelemetryAccessLogConfig) HasBufferSizeBytes() bool

func (*OpenTelemetryAccessLogConfig) HasCommonConfig deprecated

func (x *OpenTelemetryAccessLogConfig) HasCommonConfig() bool

Deprecated: Marked as deprecated in envoy/extensions/access_loggers/open_telemetry/v3/logs_service.proto.

func (*OpenTelemetryAccessLogConfig) HasGrpcService

func (x *OpenTelemetryAccessLogConfig) HasGrpcService() bool

func (*OpenTelemetryAccessLogConfig) HasHttpService

func (x *OpenTelemetryAccessLogConfig) HasHttpService() bool

func (*OpenTelemetryAccessLogConfig) HasResourceAttributes

func (x *OpenTelemetryAccessLogConfig) HasResourceAttributes() bool

func (*OpenTelemetryAccessLogConfig) ProtoMessage

func (*OpenTelemetryAccessLogConfig) ProtoMessage()

func (*OpenTelemetryAccessLogConfig) ProtoReflect

func (*OpenTelemetryAccessLogConfig) Reset

func (x *OpenTelemetryAccessLogConfig) Reset()

func (*OpenTelemetryAccessLogConfig) SetAttributes

func (x *OpenTelemetryAccessLogConfig) SetAttributes(v *v1.KeyValueList)

func (*OpenTelemetryAccessLogConfig) SetBody

func (x *OpenTelemetryAccessLogConfig) SetBody(v *v1.AnyValue)

func (*OpenTelemetryAccessLogConfig) SetBufferFlushInterval

func (x *OpenTelemetryAccessLogConfig) SetBufferFlushInterval(v *durationpb.Duration)

func (*OpenTelemetryAccessLogConfig) SetBufferSizeBytes

func (x *OpenTelemetryAccessLogConfig) SetBufferSizeBytes(v *wrapperspb.UInt32Value)

func (*OpenTelemetryAccessLogConfig) SetCommonConfig deprecated

Deprecated: Marked as deprecated in envoy/extensions/access_loggers/open_telemetry/v3/logs_service.proto.

func (*OpenTelemetryAccessLogConfig) SetCustomTags

func (x *OpenTelemetryAccessLogConfig) SetCustomTags(v []*v32.CustomTag)

func (*OpenTelemetryAccessLogConfig) SetDisableBuiltinLabels

func (x *OpenTelemetryAccessLogConfig) SetDisableBuiltinLabels(v bool)

func (*OpenTelemetryAccessLogConfig) SetFilterStateObjectsToLog

func (x *OpenTelemetryAccessLogConfig) SetFilterStateObjectsToLog(v []string)

func (*OpenTelemetryAccessLogConfig) SetFormatters

func (x *OpenTelemetryAccessLogConfig) SetFormatters(v []*v31.TypedExtensionConfig)

func (*OpenTelemetryAccessLogConfig) SetGrpcService

func (x *OpenTelemetryAccessLogConfig) SetGrpcService(v *v31.GrpcService)

func (*OpenTelemetryAccessLogConfig) SetHttpService

func (x *OpenTelemetryAccessLogConfig) SetHttpService(v *v31.HttpService)

func (*OpenTelemetryAccessLogConfig) SetLogName

func (x *OpenTelemetryAccessLogConfig) SetLogName(v string)

func (*OpenTelemetryAccessLogConfig) SetResourceAttributes

func (x *OpenTelemetryAccessLogConfig) SetResourceAttributes(v *v1.KeyValueList)

func (*OpenTelemetryAccessLogConfig) SetStatPrefix

func (x *OpenTelemetryAccessLogConfig) SetStatPrefix(v string)

func (*OpenTelemetryAccessLogConfig) String

type OpenTelemetryAccessLogConfig_builder

type OpenTelemetryAccessLogConfig_builder struct {

	// [#comment:TODO(itamarkam): add 'filter_state_objects_to_log' to logs.]
	// Deprecated. Use “grpc_service“ or “http_service“ instead.
	//
	// Deprecated: Marked as deprecated in envoy/extensions/access_loggers/open_telemetry/v3/logs_service.proto.
	CommonConfig *v3.CommonGrpcAccessLogConfig
	// The upstream HTTP cluster that will receive OTLP logs via
	// `OTLP/HTTP <https://opentelemetry.io/docs/specs/otlp/#otlphttp>`_.
	// Note: Only one of “common_config“, “grpc_service“, or “http_service“ may be used.
	//
	// .. note::
	//
	//	The “request_headers_to_add“ property in the OTLP HTTP exporter service
	//	does not support the :ref:`format specifier <config_access_log_format>` as used for
	//	:ref:`HTTP access logging <config_access_log>`.
	//	The values configured are added as HTTP headers on the OTLP export request
	//	without any formatting applied.
	HttpService *v31.HttpService
	// The upstream gRPC cluster that will receive OTLP logs.
	// Note: Only one of “common_config“, “grpc_service“, or “http_service“ may be used.
	// This field is preferred over “common_config.grpc_service“.
	GrpcService *v31.GrpcService
	// If specified, Envoy will not generate built-in resource labels
	// like “log_name“, “zone_name“, “cluster_name“, “node_name“.
	DisableBuiltinLabels bool
	// OpenTelemetry `Resource <https://github.com/open-telemetry/opentelemetry-proto/blob/main/opentelemetry/proto/logs/v1/logs.proto#L51>`_
	// attributes are filled with Envoy node info.
	// Example: “resource_attributes { values { key: "region" value { string_value: "cn-north-7" } } }“.
	ResourceAttributes *v1.KeyValueList
	// OpenTelemetry `LogResource <https://github.com/open-telemetry/opentelemetry-proto/blob/main/opentelemetry/proto/logs/v1/logs.proto>`_
	// fields, following `Envoy access logging formatting <https://www.envoyproxy.io/docs/envoy/latest/configuration/observability/access_log/usage>`_.
	//
	// See 'body' in the LogResource proto for more details.
	// Example: “body { string_value: "%PROTOCOL%" }“.
	Body *v1.AnyValue
	// See 'attributes' in the LogResource proto for more details.
	// Example: “attributes { values { key: "user_agent" value { string_value: "%REQ(USER-AGENT)%" } } }“.
	Attributes *v1.KeyValueList
	// Optional. Additional prefix to use on OpenTelemetry access logger stats. If empty, the stats will be rooted at
	// “access_logs.open_telemetry_access_log.“. If non-empty, stats will be rooted at
	// “access_logs.open_telemetry_access_log.<stat_prefix>.“.
	StatPrefix string
	// Specifies a collection of Formatter plugins that can be called from the access log configuration.
	// See the formatters extensions documentation for details.
	// [#extension-category: envoy.formatter]
	Formatters []*v31.TypedExtensionConfig
	LogName    string
	// The interval for flushing access logs to the transport. Default: 1 second.
	BufferFlushInterval *durationpb.Duration
	// Soft size limit in bytes for the access log buffer. When the buffer exceeds
	// this limit, logs will be flushed. Default: 16KB.
	BufferSizeBytes *wrapperspb.UInt32Value
	// Additional filter state objects to log as attributes.
	FilterStateObjectsToLog []string
	// Custom tags to include as log attributes.
	CustomTags []*v32.CustomTag
	// contains filtered or unexported fields
}

func (OpenTelemetryAccessLogConfig_builder) Build

Source Files

  • logs_service.pb.go

Jump to