Documentation
¶
Index ¶
- Constants
- Variables
- type StderrAccessLog
- func (x *StderrAccessLog) ClearAccessLogFormat()
- func (x *StderrAccessLog) ClearLogFormat()
- func (x *StderrAccessLog) GetAccessLogFormat() isStderrAccessLog_AccessLogFormat
- func (x *StderrAccessLog) GetLogFormat() *v3.SubstitutionFormatString
- func (x *StderrAccessLog) HasAccessLogFormat() bool
- func (x *StderrAccessLog) HasLogFormat() bool
- func (*StderrAccessLog) ProtoMessage()
- func (x *StderrAccessLog) ProtoReflect() protoreflect.Message
- func (x *StderrAccessLog) Reset()
- func (x *StderrAccessLog) SetLogFormat(v *v3.SubstitutionFormatString)
- func (x *StderrAccessLog) String() string
- func (x *StderrAccessLog) WhichAccessLogFormat() case_StderrAccessLog_AccessLogFormat
- type StderrAccessLog_LogFormat
- type StderrAccessLog_builder
- type StdoutAccessLog
- func (x *StdoutAccessLog) ClearAccessLogFormat()
- func (x *StdoutAccessLog) ClearLogFormat()
- func (x *StdoutAccessLog) GetAccessLogFormat() isStdoutAccessLog_AccessLogFormat
- func (x *StdoutAccessLog) GetLogFormat() *v3.SubstitutionFormatString
- func (x *StdoutAccessLog) HasAccessLogFormat() bool
- func (x *StdoutAccessLog) HasLogFormat() bool
- func (*StdoutAccessLog) ProtoMessage()
- func (x *StdoutAccessLog) ProtoReflect() protoreflect.Message
- func (x *StdoutAccessLog) Reset()
- func (x *StdoutAccessLog) SetLogFormat(v *v3.SubstitutionFormatString)
- func (x *StdoutAccessLog) String() string
- func (x *StdoutAccessLog) WhichAccessLogFormat() case_StdoutAccessLog_AccessLogFormat
- type StdoutAccessLog_LogFormat
- type StdoutAccessLog_builder
Constants ¶
const StderrAccessLog_AccessLogFormat_not_set_case case_StderrAccessLog_AccessLogFormat = 0
const StderrAccessLog_LogFormat_case case_StderrAccessLog_AccessLogFormat = 1
const StdoutAccessLog_AccessLogFormat_not_set_case case_StdoutAccessLog_AccessLogFormat = 0
const StdoutAccessLog_LogFormat_case case_StdoutAccessLog_AccessLogFormat = 1
Variables ¶
var File_envoy_extensions_access_loggers_stream_v3_stream_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type StderrAccessLog ¶
type StderrAccessLog struct {
// Types that are valid to be assigned to AccessLogFormat:
//
// *StderrAccessLog_LogFormat
AccessLogFormat isStderrAccessLog_AccessLogFormat `protobuf_oneof:"access_log_format"`
// contains filtered or unexported fields
}
Custom configuration for an :ref:`AccessLog <envoy_v3_api_msg_config.accesslog.v3.AccessLog>` that writes log entries directly to the operating system's standard error. [#extension: envoy.access_loggers.stderr]
func (*StderrAccessLog) ClearAccessLogFormat ¶
func (x *StderrAccessLog) ClearAccessLogFormat()
func (*StderrAccessLog) ClearLogFormat ¶
func (x *StderrAccessLog) ClearLogFormat()
func (*StderrAccessLog) GetAccessLogFormat ¶
func (x *StderrAccessLog) GetAccessLogFormat() isStderrAccessLog_AccessLogFormat
func (*StderrAccessLog) GetLogFormat ¶
func (x *StderrAccessLog) GetLogFormat() *v3.SubstitutionFormatString
func (*StderrAccessLog) HasAccessLogFormat ¶
func (x *StderrAccessLog) HasAccessLogFormat() bool
func (*StderrAccessLog) HasLogFormat ¶
func (x *StderrAccessLog) HasLogFormat() bool
func (*StderrAccessLog) ProtoMessage ¶
func (*StderrAccessLog) ProtoMessage()
func (*StderrAccessLog) ProtoReflect ¶
func (x *StderrAccessLog) ProtoReflect() protoreflect.Message
func (*StderrAccessLog) Reset ¶
func (x *StderrAccessLog) Reset()
func (*StderrAccessLog) SetLogFormat ¶
func (x *StderrAccessLog) SetLogFormat(v *v3.SubstitutionFormatString)
func (*StderrAccessLog) String ¶
func (x *StderrAccessLog) String() string
func (*StderrAccessLog) WhichAccessLogFormat ¶
func (x *StderrAccessLog) WhichAccessLogFormat() case_StderrAccessLog_AccessLogFormat
type StderrAccessLog_LogFormat ¶
type StderrAccessLog_LogFormat struct {
// Configuration to form access log data and format.
// If not specified, use :ref:`default format <config_access_log_default_format>`.
LogFormat *v3.SubstitutionFormatString `protobuf:"bytes,1,opt,name=log_format,json=logFormat,proto3,oneof"`
}
type StderrAccessLog_builder ¶
type StderrAccessLog_builder struct {
// Fields of oneof AccessLogFormat:
// Configuration to form access log data and format.
// If not specified, use :ref:`default format <config_access_log_default_format>`.
LogFormat *v3.SubstitutionFormatString
// contains filtered or unexported fields
}
func (StderrAccessLog_builder) Build ¶
func (b0 StderrAccessLog_builder) Build() *StderrAccessLog
type StdoutAccessLog ¶
type StdoutAccessLog struct {
// Types that are valid to be assigned to AccessLogFormat:
//
// *StdoutAccessLog_LogFormat
AccessLogFormat isStdoutAccessLog_AccessLogFormat `protobuf_oneof:"access_log_format"`
// contains filtered or unexported fields
}
Custom configuration for an :ref:`AccessLog <envoy_v3_api_msg_config.accesslog.v3.AccessLog>` that writes log entries directly to the operating system's standard output. [#extension: envoy.access_loggers.stdout]
func (*StdoutAccessLog) ClearAccessLogFormat ¶
func (x *StdoutAccessLog) ClearAccessLogFormat()
func (*StdoutAccessLog) ClearLogFormat ¶
func (x *StdoutAccessLog) ClearLogFormat()
func (*StdoutAccessLog) GetAccessLogFormat ¶
func (x *StdoutAccessLog) GetAccessLogFormat() isStdoutAccessLog_AccessLogFormat
func (*StdoutAccessLog) GetLogFormat ¶
func (x *StdoutAccessLog) GetLogFormat() *v3.SubstitutionFormatString
func (*StdoutAccessLog) HasAccessLogFormat ¶
func (x *StdoutAccessLog) HasAccessLogFormat() bool
func (*StdoutAccessLog) HasLogFormat ¶
func (x *StdoutAccessLog) HasLogFormat() bool
func (*StdoutAccessLog) ProtoMessage ¶
func (*StdoutAccessLog) ProtoMessage()
func (*StdoutAccessLog) ProtoReflect ¶
func (x *StdoutAccessLog) ProtoReflect() protoreflect.Message
func (*StdoutAccessLog) Reset ¶
func (x *StdoutAccessLog) Reset()
func (*StdoutAccessLog) SetLogFormat ¶
func (x *StdoutAccessLog) SetLogFormat(v *v3.SubstitutionFormatString)
func (*StdoutAccessLog) String ¶
func (x *StdoutAccessLog) String() string
func (*StdoutAccessLog) WhichAccessLogFormat ¶
func (x *StdoutAccessLog) WhichAccessLogFormat() case_StdoutAccessLog_AccessLogFormat
type StdoutAccessLog_LogFormat ¶
type StdoutAccessLog_LogFormat struct {
// Configuration to form access log data and format.
// If not specified, use :ref:`default format <config_access_log_default_format>`.
LogFormat *v3.SubstitutionFormatString `protobuf:"bytes,1,opt,name=log_format,json=logFormat,proto3,oneof"`
}
type StdoutAccessLog_builder ¶
type StdoutAccessLog_builder struct {
// Fields of oneof AccessLogFormat:
// Configuration to form access log data and format.
// If not specified, use :ref:`default format <config_access_log_default_format>`.
LogFormat *v3.SubstitutionFormatString
// contains filtered or unexported fields
}
func (StdoutAccessLog_builder) Build ¶
func (b0 StdoutAccessLog_builder) Build() *StdoutAccessLog
Source Files
¶
- stream.pb.go
Click to show internal directories.
Click to hide internal directories.