dynamic_forward_proxyv3

package
v1.36.11-2026011520535... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 11 Imported by: 0

Documentation

Index

Constants

const ClusterConfig_ClusterImplementationSpecifier_not_set_case case_ClusterConfig_ClusterImplementationSpecifier = 0
const ClusterConfig_DnsCacheConfig_case case_ClusterConfig_ClusterImplementationSpecifier = 1
const ClusterConfig_SubClustersConfig_case case_ClusterConfig_ClusterImplementationSpecifier = 4

Variables

var File_envoy_extensions_clusters_dynamic_forward_proxy_v3_cluster_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type ClusterConfig

type ClusterConfig struct {

	// Types that are valid to be assigned to ClusterImplementationSpecifier:
	//
	//	*ClusterConfig_DnsCacheConfig
	//	*ClusterConfig_SubClustersConfig
	ClusterImplementationSpecifier isClusterConfig_ClusterImplementationSpecifier `protobuf_oneof:"cluster_implementation_specifier"`
	// If true allow the cluster configuration to disable the auto_sni and auto_san_validation options
	// in the :ref:`cluster's upstream_http_protocol_options
	// <envoy_v3_api_field_config.cluster.v3.Cluster.upstream_http_protocol_options>`
	AllowInsecureClusterOptions bool `` /* 147-byte string literal not displayed */
	// If true allow HTTP/2 and HTTP/3 connections to be reused for requests to different
	// origins than the connection was initially created for. This will only happen when the
	// resolved address for the new connection matches the peer address of the connection and
	// the TLS certificate is also valid for the new hostname. For example, if a connection
	// has previously been established to foo.example.com at IP 1.2.3.4 with a certificate
	// that is valid for “*.example.com“, then this connection could be used for requests to
	// bar.example.com if that also resolved to 1.2.3.4.
	//
	// .. note::
	//
	//	By design, this feature will maximize reuse of connections. This means that instead
	//	opening a new connection when an existing connection reaches the maximum number of
	//	concurrent streams, requests will instead be sent to the existing connection.
	//
	// .. note::
	//
	//	The coalesced connections might be to upstreams that would not be otherwise
	//	selected by Envoy. See the section `Connection Reuse in RFC 7540
	//	<https://datatracker.ietf.org/doc/html/rfc7540#section-9.1.1>`_
	AllowCoalescedConnections bool `` /* 139-byte string literal not displayed */
	// contains filtered or unexported fields
}

Configuration for the dynamic forward proxy cluster. See the :ref:`architecture overview <arch_overview_http_dynamic_forward_proxy>` for more information. [#extension: envoy.clusters.dynamic_forward_proxy]

func (*ClusterConfig) ClearClusterImplementationSpecifier

func (x *ClusterConfig) ClearClusterImplementationSpecifier()

func (*ClusterConfig) ClearDnsCacheConfig

func (x *ClusterConfig) ClearDnsCacheConfig()

func (*ClusterConfig) ClearSubClustersConfig

func (x *ClusterConfig) ClearSubClustersConfig()

func (*ClusterConfig) GetAllowCoalescedConnections

func (x *ClusterConfig) GetAllowCoalescedConnections() bool

func (*ClusterConfig) GetAllowInsecureClusterOptions

func (x *ClusterConfig) GetAllowInsecureClusterOptions() bool

func (*ClusterConfig) GetClusterImplementationSpecifier

func (x *ClusterConfig) GetClusterImplementationSpecifier() isClusterConfig_ClusterImplementationSpecifier

func (*ClusterConfig) GetDnsCacheConfig

func (x *ClusterConfig) GetDnsCacheConfig() *v3.DnsCacheConfig

func (*ClusterConfig) GetSubClustersConfig

func (x *ClusterConfig) GetSubClustersConfig() *SubClustersConfig

func (*ClusterConfig) HasClusterImplementationSpecifier

func (x *ClusterConfig) HasClusterImplementationSpecifier() bool

func (*ClusterConfig) HasDnsCacheConfig

func (x *ClusterConfig) HasDnsCacheConfig() bool

func (*ClusterConfig) HasSubClustersConfig

func (x *ClusterConfig) HasSubClustersConfig() bool

func (*ClusterConfig) ProtoMessage

func (*ClusterConfig) ProtoMessage()

func (*ClusterConfig) ProtoReflect

func (x *ClusterConfig) ProtoReflect() protoreflect.Message

func (*ClusterConfig) Reset

func (x *ClusterConfig) Reset()

func (*ClusterConfig) SetAllowCoalescedConnections

func (x *ClusterConfig) SetAllowCoalescedConnections(v bool)

func (*ClusterConfig) SetAllowInsecureClusterOptions

func (x *ClusterConfig) SetAllowInsecureClusterOptions(v bool)

func (*ClusterConfig) SetDnsCacheConfig

func (x *ClusterConfig) SetDnsCacheConfig(v *v3.DnsCacheConfig)

func (*ClusterConfig) SetSubClustersConfig

func (x *ClusterConfig) SetSubClustersConfig(v *SubClustersConfig)

func (*ClusterConfig) String

func (x *ClusterConfig) String() string

func (*ClusterConfig) WhichClusterImplementationSpecifier

func (x *ClusterConfig) WhichClusterImplementationSpecifier() case_ClusterConfig_ClusterImplementationSpecifier

type ClusterConfig_DnsCacheConfig

type ClusterConfig_DnsCacheConfig struct {
	// The DNS cache configuration that the cluster will attach to. Note this configuration must
	// match that of associated :ref:`dynamic forward proxy HTTP filter configuration
	// <envoy_v3_api_field_extensions.filters.http.dynamic_forward_proxy.v3.FilterConfig.dns_cache_config>`.
	DnsCacheConfig *v3.DnsCacheConfig `protobuf:"bytes,1,opt,name=dns_cache_config,json=dnsCacheConfig,proto3,oneof"`
}

type ClusterConfig_SubClustersConfig

type ClusterConfig_SubClustersConfig struct {
	// Configuration for sub clusters, when this configuration is enabled,
	// Envoy will create an independent sub cluster dynamically for each host:port.
	// Most of the configuration of a sub cluster is inherited from the current cluster,
	// i.e. health_checks, dns_resolvers and etc.
	// And the load_assignment will be set to the only one endpoint, host:port.
	//
	// Compared to the dns_cache_config, it has the following advantages:
	//
	//  1. sub clusters will be created with the STRICT_DNS DiscoveryType,
	//     so that Envoy will use all of the IPs resolved from the host.
	//
	// 2. each sub cluster is full featured cluster, with lb_policy and health check and etc enabled.
	SubClustersConfig *SubClustersConfig `protobuf:"bytes,4,opt,name=sub_clusters_config,json=subClustersConfig,proto3,oneof"`
}

type ClusterConfig_builder

type ClusterConfig_builder struct {

	// Fields of oneof ClusterImplementationSpecifier:
	// The DNS cache configuration that the cluster will attach to. Note this configuration must
	// match that of associated :ref:`dynamic forward proxy HTTP filter configuration
	// <envoy_v3_api_field_extensions.filters.http.dynamic_forward_proxy.v3.FilterConfig.dns_cache_config>`.
	DnsCacheConfig *v3.DnsCacheConfig
	// Configuration for sub clusters, when this configuration is enabled,
	// Envoy will create an independent sub cluster dynamically for each host:port.
	// Most of the configuration of a sub cluster is inherited from the current cluster,
	// i.e. health_checks, dns_resolvers and etc.
	// And the load_assignment will be set to the only one endpoint, host:port.
	//
	// Compared to the dns_cache_config, it has the following advantages:
	//
	//  1. sub clusters will be created with the STRICT_DNS DiscoveryType,
	//     so that Envoy will use all of the IPs resolved from the host.
	//
	// 2. each sub cluster is full featured cluster, with lb_policy and health check and etc enabled.
	SubClustersConfig *SubClustersConfig
	// -- end of ClusterImplementationSpecifier
	// If true allow the cluster configuration to disable the auto_sni and auto_san_validation options
	// in the :ref:`cluster's upstream_http_protocol_options
	// <envoy_v3_api_field_config.cluster.v3.Cluster.upstream_http_protocol_options>`
	AllowInsecureClusterOptions bool
	// If true allow HTTP/2 and HTTP/3 connections to be reused for requests to different
	// origins than the connection was initially created for. This will only happen when the
	// resolved address for the new connection matches the peer address of the connection and
	// the TLS certificate is also valid for the new hostname. For example, if a connection
	// has previously been established to foo.example.com at IP 1.2.3.4 with a certificate
	// that is valid for “*.example.com“, then this connection could be used for requests to
	// bar.example.com if that also resolved to 1.2.3.4.
	//
	// .. note::
	//
	//	By design, this feature will maximize reuse of connections. This means that instead
	//	opening a new connection when an existing connection reaches the maximum number of
	//	concurrent streams, requests will instead be sent to the existing connection.
	//
	// .. note::
	//
	//	The coalesced connections might be to upstreams that would not be otherwise
	//	selected by Envoy. See the section `Connection Reuse in RFC 7540
	//	<https://datatracker.ietf.org/doc/html/rfc7540#section-9.1.1>`_
	AllowCoalescedConnections bool
	// contains filtered or unexported fields
}

func (ClusterConfig_builder) Build

type SubClustersConfig

type SubClustersConfig struct {

	// The :ref:`load balancer type <arch_overview_load_balancing_types>` to use
	// when picking a host in a sub cluster. Note that CLUSTER_PROVIDED is not allowed here.
	LbPolicy v31.Cluster_LbPolicy `` /* 132-byte string literal not displayed */
	// The maximum number of sub clusters that the DFP cluster will hold. If not specified defaults to 1024.
	MaxSubClusters *wrapperspb.UInt32Value `protobuf:"bytes,2,opt,name=max_sub_clusters,json=maxSubClusters,proto3" json:"max_sub_clusters,omitempty"`
	// The TTL for sub clusters that are unused. Sub clusters that have not been used in the configured time
	// interval will be purged. If not specified defaults to 5m.
	SubClusterTtl *durationpb.Duration `protobuf:"bytes,3,opt,name=sub_cluster_ttl,json=subClusterTtl,proto3" json:"sub_cluster_ttl,omitempty"`
	// Sub clusters that should be created & warmed upon creation. This might provide a
	// performance improvement, in the form of cache hits, for sub clusters that are going to be
	// warmed during steady state and are known at config load time.
	PreresolveClusters []*v32.SocketAddress `protobuf:"bytes,4,rep,name=preresolve_clusters,json=preresolveClusters,proto3" json:"preresolve_clusters,omitempty"`
	// contains filtered or unexported fields
}

Configuration for sub clusters. Hard code STRICT_DNS cluster type now.

func (*SubClustersConfig) ClearMaxSubClusters

func (x *SubClustersConfig) ClearMaxSubClusters()

func (*SubClustersConfig) ClearSubClusterTtl

func (x *SubClustersConfig) ClearSubClusterTtl()

func (*SubClustersConfig) GetLbPolicy

func (x *SubClustersConfig) GetLbPolicy() v31.Cluster_LbPolicy

func (*SubClustersConfig) GetMaxSubClusters

func (x *SubClustersConfig) GetMaxSubClusters() *wrapperspb.UInt32Value

func (*SubClustersConfig) GetPreresolveClusters

func (x *SubClustersConfig) GetPreresolveClusters() []*v32.SocketAddress

func (*SubClustersConfig) GetSubClusterTtl

func (x *SubClustersConfig) GetSubClusterTtl() *durationpb.Duration

func (*SubClustersConfig) HasMaxSubClusters

func (x *SubClustersConfig) HasMaxSubClusters() bool

func (*SubClustersConfig) HasSubClusterTtl

func (x *SubClustersConfig) HasSubClusterTtl() bool

func (*SubClustersConfig) ProtoMessage

func (*SubClustersConfig) ProtoMessage()

func (*SubClustersConfig) ProtoReflect

func (x *SubClustersConfig) ProtoReflect() protoreflect.Message

func (*SubClustersConfig) Reset

func (x *SubClustersConfig) Reset()

func (*SubClustersConfig) SetLbPolicy

func (x *SubClustersConfig) SetLbPolicy(v v31.Cluster_LbPolicy)

func (*SubClustersConfig) SetMaxSubClusters

func (x *SubClustersConfig) SetMaxSubClusters(v *wrapperspb.UInt32Value)

func (*SubClustersConfig) SetPreresolveClusters

func (x *SubClustersConfig) SetPreresolveClusters(v []*v32.SocketAddress)

func (*SubClustersConfig) SetSubClusterTtl

func (x *SubClustersConfig) SetSubClusterTtl(v *durationpb.Duration)

func (*SubClustersConfig) String

func (x *SubClustersConfig) String() string

type SubClustersConfig_builder

type SubClustersConfig_builder struct {

	// The :ref:`load balancer type <arch_overview_load_balancing_types>` to use
	// when picking a host in a sub cluster. Note that CLUSTER_PROVIDED is not allowed here.
	LbPolicy v31.Cluster_LbPolicy
	// The maximum number of sub clusters that the DFP cluster will hold. If not specified defaults to 1024.
	MaxSubClusters *wrapperspb.UInt32Value
	// The TTL for sub clusters that are unused. Sub clusters that have not been used in the configured time
	// interval will be purged. If not specified defaults to 5m.
	SubClusterTtl *durationpb.Duration
	// Sub clusters that should be created & warmed upon creation. This might provide a
	// performance improvement, in the form of cache hits, for sub clusters that are going to be
	// warmed during steady state and are known at config load time.
	PreresolveClusters []*v32.SocketAddress
	// contains filtered or unexported fields
}

func (SubClustersConfig_builder) Build

Source Files

  • cluster.pb.go

Jump to