Documentation
¶
Index ¶
- Variables
- type AssumeRoleCredentialProvider
- func (x *AssumeRoleCredentialProvider) ClearCredentialProvider()
- func (x *AssumeRoleCredentialProvider) ClearSessionDuration()
- func (x *AssumeRoleCredentialProvider) GetCredentialProvider() *AwsCredentialProvider
- func (x *AssumeRoleCredentialProvider) GetExternalId() string
- func (x *AssumeRoleCredentialProvider) GetRoleArn() string
- func (x *AssumeRoleCredentialProvider) GetRoleSessionName() string
- func (x *AssumeRoleCredentialProvider) GetSessionDuration() *durationpb.Duration
- func (x *AssumeRoleCredentialProvider) HasCredentialProvider() bool
- func (x *AssumeRoleCredentialProvider) HasSessionDuration() bool
- func (*AssumeRoleCredentialProvider) ProtoMessage()
- func (x *AssumeRoleCredentialProvider) ProtoReflect() protoreflect.Message
- func (x *AssumeRoleCredentialProvider) Reset()
- func (x *AssumeRoleCredentialProvider) SetCredentialProvider(v *AwsCredentialProvider)
- func (x *AssumeRoleCredentialProvider) SetExternalId(v string)
- func (x *AssumeRoleCredentialProvider) SetRoleArn(v string)
- func (x *AssumeRoleCredentialProvider) SetRoleSessionName(v string)
- func (x *AssumeRoleCredentialProvider) SetSessionDuration(v *durationpb.Duration)
- func (x *AssumeRoleCredentialProvider) String() string
- type AssumeRoleCredentialProvider_builder
- type AssumeRoleWithWebIdentityCredentialProvider
- func (x *AssumeRoleWithWebIdentityCredentialProvider) ClearWebIdentityTokenDataSource()
- func (x *AssumeRoleWithWebIdentityCredentialProvider) GetRoleArn() string
- func (x *AssumeRoleWithWebIdentityCredentialProvider) GetRoleSessionName() string
- func (x *AssumeRoleWithWebIdentityCredentialProvider) GetWebIdentityTokenDataSource() *v3.DataSource
- func (x *AssumeRoleWithWebIdentityCredentialProvider) HasWebIdentityTokenDataSource() bool
- func (*AssumeRoleWithWebIdentityCredentialProvider) ProtoMessage()
- func (x *AssumeRoleWithWebIdentityCredentialProvider) ProtoReflect() protoreflect.Message
- func (x *AssumeRoleWithWebIdentityCredentialProvider) Reset()
- func (x *AssumeRoleWithWebIdentityCredentialProvider) SetRoleArn(v string)
- func (x *AssumeRoleWithWebIdentityCredentialProvider) SetRoleSessionName(v string)
- func (x *AssumeRoleWithWebIdentityCredentialProvider) SetWebIdentityTokenDataSource(v *v3.DataSource)
- func (x *AssumeRoleWithWebIdentityCredentialProvider) String() string
- type AssumeRoleWithWebIdentityCredentialProvider_builder
- type AwsCredentialProvider
- func (x *AwsCredentialProvider) ClearAssumeRoleCredentialProvider()
- func (x *AwsCredentialProvider) ClearAssumeRoleWithWebIdentityProvider()
- func (x *AwsCredentialProvider) ClearConfigCredentialProvider()
- func (x *AwsCredentialProvider) ClearContainerCredentialProvider()
- func (x *AwsCredentialProvider) ClearCredentialsFileProvider()
- func (x *AwsCredentialProvider) ClearEnvironmentCredentialProvider()
- func (x *AwsCredentialProvider) ClearIamRolesAnywhereCredentialProvider()
- func (x *AwsCredentialProvider) ClearInlineCredential()
- func (x *AwsCredentialProvider) ClearInstanceProfileCredentialProvider()
- func (x *AwsCredentialProvider) GetAssumeRoleCredentialProvider() *AssumeRoleCredentialProvider
- func (x *AwsCredentialProvider) GetAssumeRoleWithWebIdentityProvider() *AssumeRoleWithWebIdentityCredentialProvider
- func (x *AwsCredentialProvider) GetConfigCredentialProvider() *ConfigCredentialProvider
- func (x *AwsCredentialProvider) GetContainerCredentialProvider() *ContainerCredentialProvider
- func (x *AwsCredentialProvider) GetCredentialsFileProvider() *CredentialsFileCredentialProvider
- func (x *AwsCredentialProvider) GetCustomCredentialProviderChain() bool
- func (x *AwsCredentialProvider) GetEnvironmentCredentialProvider() *EnvironmentCredentialProvider
- func (x *AwsCredentialProvider) GetIamRolesAnywhereCredentialProvider() *IAMRolesAnywhereCredentialProvider
- func (x *AwsCredentialProvider) GetInlineCredential() *InlineCredentialProvider
- func (x *AwsCredentialProvider) GetInstanceProfileCredentialProvider() *InstanceProfileCredentialProvider
- func (x *AwsCredentialProvider) HasAssumeRoleCredentialProvider() bool
- func (x *AwsCredentialProvider) HasAssumeRoleWithWebIdentityProvider() bool
- func (x *AwsCredentialProvider) HasConfigCredentialProvider() bool
- func (x *AwsCredentialProvider) HasContainerCredentialProvider() bool
- func (x *AwsCredentialProvider) HasCredentialsFileProvider() bool
- func (x *AwsCredentialProvider) HasEnvironmentCredentialProvider() bool
- func (x *AwsCredentialProvider) HasIamRolesAnywhereCredentialProvider() bool
- func (x *AwsCredentialProvider) HasInlineCredential() bool
- func (x *AwsCredentialProvider) HasInstanceProfileCredentialProvider() bool
- func (*AwsCredentialProvider) ProtoMessage()
- func (x *AwsCredentialProvider) ProtoReflect() protoreflect.Message
- func (x *AwsCredentialProvider) Reset()
- func (x *AwsCredentialProvider) SetAssumeRoleCredentialProvider(v *AssumeRoleCredentialProvider)
- func (x *AwsCredentialProvider) SetAssumeRoleWithWebIdentityProvider(v *AssumeRoleWithWebIdentityCredentialProvider)
- func (x *AwsCredentialProvider) SetConfigCredentialProvider(v *ConfigCredentialProvider)
- func (x *AwsCredentialProvider) SetContainerCredentialProvider(v *ContainerCredentialProvider)
- func (x *AwsCredentialProvider) SetCredentialsFileProvider(v *CredentialsFileCredentialProvider)
- func (x *AwsCredentialProvider) SetCustomCredentialProviderChain(v bool)
- func (x *AwsCredentialProvider) SetEnvironmentCredentialProvider(v *EnvironmentCredentialProvider)
- func (x *AwsCredentialProvider) SetIamRolesAnywhereCredentialProvider(v *IAMRolesAnywhereCredentialProvider)
- func (x *AwsCredentialProvider) SetInlineCredential(v *InlineCredentialProvider)
- func (x *AwsCredentialProvider) SetInstanceProfileCredentialProvider(v *InstanceProfileCredentialProvider)
- func (x *AwsCredentialProvider) String() string
- type AwsCredentialProvider_builder
- type ConfigCredentialProvider
- type ConfigCredentialProvider_builder
- type ContainerCredentialProvider
- type ContainerCredentialProvider_builder
- type CredentialsFileCredentialProvider
- func (x *CredentialsFileCredentialProvider) ClearCredentialsDataSource()
- func (x *CredentialsFileCredentialProvider) GetCredentialsDataSource() *v3.DataSource
- func (x *CredentialsFileCredentialProvider) GetProfile() string
- func (x *CredentialsFileCredentialProvider) HasCredentialsDataSource() bool
- func (*CredentialsFileCredentialProvider) ProtoMessage()
- func (x *CredentialsFileCredentialProvider) ProtoReflect() protoreflect.Message
- func (x *CredentialsFileCredentialProvider) Reset()
- func (x *CredentialsFileCredentialProvider) SetCredentialsDataSource(v *v3.DataSource)
- func (x *CredentialsFileCredentialProvider) SetProfile(v string)
- func (x *CredentialsFileCredentialProvider) String() string
- type CredentialsFileCredentialProvider_builder
- type EnvironmentCredentialProvider
- type EnvironmentCredentialProvider_builder
- type IAMRolesAnywhereCredentialProvider
- func (x *IAMRolesAnywhereCredentialProvider) ClearCertificate()
- func (x *IAMRolesAnywhereCredentialProvider) ClearCertificateChain()
- func (x *IAMRolesAnywhereCredentialProvider) ClearPrivateKey()
- func (x *IAMRolesAnywhereCredentialProvider) ClearSessionDuration()
- func (x *IAMRolesAnywhereCredentialProvider) GetCertificate() *v3.DataSource
- func (x *IAMRolesAnywhereCredentialProvider) GetCertificateChain() *v3.DataSource
- func (x *IAMRolesAnywhereCredentialProvider) GetPrivateKey() *v3.DataSource
- func (x *IAMRolesAnywhereCredentialProvider) GetProfileArn() string
- func (x *IAMRolesAnywhereCredentialProvider) GetRoleArn() string
- func (x *IAMRolesAnywhereCredentialProvider) GetRoleSessionName() string
- func (x *IAMRolesAnywhereCredentialProvider) GetSessionDuration() *durationpb.Duration
- func (x *IAMRolesAnywhereCredentialProvider) GetTrustAnchorArn() string
- func (x *IAMRolesAnywhereCredentialProvider) HasCertificate() bool
- func (x *IAMRolesAnywhereCredentialProvider) HasCertificateChain() bool
- func (x *IAMRolesAnywhereCredentialProvider) HasPrivateKey() bool
- func (x *IAMRolesAnywhereCredentialProvider) HasSessionDuration() bool
- func (*IAMRolesAnywhereCredentialProvider) ProtoMessage()
- func (x *IAMRolesAnywhereCredentialProvider) ProtoReflect() protoreflect.Message
- func (x *IAMRolesAnywhereCredentialProvider) Reset()
- func (x *IAMRolesAnywhereCredentialProvider) SetCertificate(v *v3.DataSource)
- func (x *IAMRolesAnywhereCredentialProvider) SetCertificateChain(v *v3.DataSource)
- func (x *IAMRolesAnywhereCredentialProvider) SetPrivateKey(v *v3.DataSource)
- func (x *IAMRolesAnywhereCredentialProvider) SetProfileArn(v string)
- func (x *IAMRolesAnywhereCredentialProvider) SetRoleArn(v string)
- func (x *IAMRolesAnywhereCredentialProvider) SetRoleSessionName(v string)
- func (x *IAMRolesAnywhereCredentialProvider) SetSessionDuration(v *durationpb.Duration)
- func (x *IAMRolesAnywhereCredentialProvider) SetTrustAnchorArn(v string)
- func (x *IAMRolesAnywhereCredentialProvider) String() string
- type IAMRolesAnywhereCredentialProvider_builder
- type InlineCredentialProvider
- func (x *InlineCredentialProvider) GetAccessKeyId() string
- func (x *InlineCredentialProvider) GetSecretAccessKey() string
- func (x *InlineCredentialProvider) GetSessionToken() string
- func (*InlineCredentialProvider) ProtoMessage()
- func (x *InlineCredentialProvider) ProtoReflect() protoreflect.Message
- func (x *InlineCredentialProvider) Reset()
- func (x *InlineCredentialProvider) SetAccessKeyId(v string)
- func (x *InlineCredentialProvider) SetSecretAccessKey(v string)
- func (x *InlineCredentialProvider) SetSessionToken(v string)
- func (x *InlineCredentialProvider) String() string
- type InlineCredentialProvider_builder
- type InstanceProfileCredentialProvider
- type InstanceProfileCredentialProvider_builder
Constants ¶
This section is empty.
Variables ¶
var File_envoy_extensions_common_aws_v3_credential_provider_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type AssumeRoleCredentialProvider ¶
type AssumeRoleCredentialProvider struct {
// The ARN of the role to assume.
RoleArn string `protobuf:"bytes,1,opt,name=role_arn,json=roleArn,proto3" json:"role_arn,omitempty"`
// An optional role session name, used when identifying the role in subsequent AWS API calls. If not provided, the role session name will default
// to the current timestamp.
RoleSessionName string `protobuf:"bytes,2,opt,name=role_session_name,json=roleSessionName,proto3" json:"role_session_name,omitempty"`
// Optional string value to use as the externalId
ExternalId string `protobuf:"bytes,3,opt,name=external_id,json=externalId,proto3" json:"external_id,omitempty"`
// An optional duration, in seconds, of the role session. Minimum role duration is 900s (5 minutes) and maximum is 43200s (12 hours).
// If the session duration is not provided, the default will be determined using the `table described here <https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_manage-assume.html>`_.
SessionDuration *durationpb.Duration `protobuf:"bytes,4,opt,name=session_duration,json=sessionDuration,proto3" json:"session_duration,omitempty"`
// The credential provider for signing the AssumeRole request. This is optional and if not set,
// it will be retrieved from the procedure described in :ref:`config_http_filters_aws_request_signing`.
// This list of credential providers cannot include an AssumeRole credential provider and if one is provided
// it will be ignored.
CredentialProvider *AwsCredentialProvider `protobuf:"bytes,5,opt,name=credential_provider,json=credentialProvider,proto3" json:"credential_provider,omitempty"`
// contains filtered or unexported fields
}
Configuration to use `AssumeRole <https://docs.aws.amazon.com/STS/latest/APIReference/API_AssumeRole.html>`_ for retrieving new credentials, via role chaining. [#next-free-field: 6]
func (*AssumeRoleCredentialProvider) ClearCredentialProvider ¶
func (x *AssumeRoleCredentialProvider) ClearCredentialProvider()
func (*AssumeRoleCredentialProvider) ClearSessionDuration ¶
func (x *AssumeRoleCredentialProvider) ClearSessionDuration()
func (*AssumeRoleCredentialProvider) GetCredentialProvider ¶
func (x *AssumeRoleCredentialProvider) GetCredentialProvider() *AwsCredentialProvider
func (*AssumeRoleCredentialProvider) GetExternalId ¶
func (x *AssumeRoleCredentialProvider) GetExternalId() string
func (*AssumeRoleCredentialProvider) GetRoleArn ¶
func (x *AssumeRoleCredentialProvider) GetRoleArn() string
func (*AssumeRoleCredentialProvider) GetRoleSessionName ¶
func (x *AssumeRoleCredentialProvider) GetRoleSessionName() string
func (*AssumeRoleCredentialProvider) GetSessionDuration ¶
func (x *AssumeRoleCredentialProvider) GetSessionDuration() *durationpb.Duration
func (*AssumeRoleCredentialProvider) HasCredentialProvider ¶
func (x *AssumeRoleCredentialProvider) HasCredentialProvider() bool
func (*AssumeRoleCredentialProvider) HasSessionDuration ¶
func (x *AssumeRoleCredentialProvider) HasSessionDuration() bool
func (*AssumeRoleCredentialProvider) ProtoMessage ¶
func (*AssumeRoleCredentialProvider) ProtoMessage()
func (*AssumeRoleCredentialProvider) ProtoReflect ¶
func (x *AssumeRoleCredentialProvider) ProtoReflect() protoreflect.Message
func (*AssumeRoleCredentialProvider) Reset ¶
func (x *AssumeRoleCredentialProvider) Reset()
func (*AssumeRoleCredentialProvider) SetCredentialProvider ¶
func (x *AssumeRoleCredentialProvider) SetCredentialProvider(v *AwsCredentialProvider)
func (*AssumeRoleCredentialProvider) SetExternalId ¶
func (x *AssumeRoleCredentialProvider) SetExternalId(v string)
func (*AssumeRoleCredentialProvider) SetRoleArn ¶
func (x *AssumeRoleCredentialProvider) SetRoleArn(v string)
func (*AssumeRoleCredentialProvider) SetRoleSessionName ¶
func (x *AssumeRoleCredentialProvider) SetRoleSessionName(v string)
func (*AssumeRoleCredentialProvider) SetSessionDuration ¶
func (x *AssumeRoleCredentialProvider) SetSessionDuration(v *durationpb.Duration)
func (*AssumeRoleCredentialProvider) String ¶
func (x *AssumeRoleCredentialProvider) String() string
type AssumeRoleCredentialProvider_builder ¶
type AssumeRoleCredentialProvider_builder struct {
// The ARN of the role to assume.
RoleArn string
// An optional role session name, used when identifying the role in subsequent AWS API calls. If not provided, the role session name will default
// to the current timestamp.
RoleSessionName string
// Optional string value to use as the externalId
ExternalId string
// An optional duration, in seconds, of the role session. Minimum role duration is 900s (5 minutes) and maximum is 43200s (12 hours).
// If the session duration is not provided, the default will be determined using the `table described here <https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_manage-assume.html>`_.
SessionDuration *durationpb.Duration
// The credential provider for signing the AssumeRole request. This is optional and if not set,
// it will be retrieved from the procedure described in :ref:`config_http_filters_aws_request_signing`.
// This list of credential providers cannot include an AssumeRole credential provider and if one is provided
// it will be ignored.
CredentialProvider *AwsCredentialProvider
// contains filtered or unexported fields
}
func (AssumeRoleCredentialProvider_builder) Build ¶
func (b0 AssumeRoleCredentialProvider_builder) Build() *AssumeRoleCredentialProvider
type AssumeRoleWithWebIdentityCredentialProvider ¶
type AssumeRoleWithWebIdentityCredentialProvider struct {
// Data source for a web identity token that is provided by the identity provider to assume the role.
// If a “watched_directory“ is not provided, one will be automatically inferred from the directory of the token file. This is to ensure
// that if the token file is rotated, the new token will be picked up. This behaviour differs from the standard envoy data source behavior, which does not
// automatically watch the directory of a file data source.
// Even when file rotation occurs, current credentials will continue to be used until they expire, at which point new credentials will be retrieved using the new token.
WebIdentityTokenDataSource *v3.DataSource `` /* 145-byte string literal not displayed */
// The ARN of the role to assume.
RoleArn string `protobuf:"bytes,2,opt,name=role_arn,json=roleArn,proto3" json:"role_arn,omitempty"`
// Optional role session name to use in AssumeRoleWithWebIdentity API call.
RoleSessionName string `protobuf:"bytes,3,opt,name=role_session_name,json=roleSessionName,proto3" json:"role_session_name,omitempty"`
// contains filtered or unexported fields
}
Configuration to use `AssumeRoleWithWebIdentity <https://docs.aws.amazon.com/STS/latest/APIReference/API_AssumeRoleWithWebIdentity.html>`_ to retrieve AWS credentials.
func (*AssumeRoleWithWebIdentityCredentialProvider) ClearWebIdentityTokenDataSource ¶
func (x *AssumeRoleWithWebIdentityCredentialProvider) ClearWebIdentityTokenDataSource()
func (*AssumeRoleWithWebIdentityCredentialProvider) GetRoleArn ¶
func (x *AssumeRoleWithWebIdentityCredentialProvider) GetRoleArn() string
func (*AssumeRoleWithWebIdentityCredentialProvider) GetRoleSessionName ¶
func (x *AssumeRoleWithWebIdentityCredentialProvider) GetRoleSessionName() string
func (*AssumeRoleWithWebIdentityCredentialProvider) GetWebIdentityTokenDataSource ¶
func (x *AssumeRoleWithWebIdentityCredentialProvider) GetWebIdentityTokenDataSource() *v3.DataSource
func (*AssumeRoleWithWebIdentityCredentialProvider) HasWebIdentityTokenDataSource ¶
func (x *AssumeRoleWithWebIdentityCredentialProvider) HasWebIdentityTokenDataSource() bool
func (*AssumeRoleWithWebIdentityCredentialProvider) ProtoMessage ¶
func (*AssumeRoleWithWebIdentityCredentialProvider) ProtoMessage()
func (*AssumeRoleWithWebIdentityCredentialProvider) ProtoReflect ¶
func (x *AssumeRoleWithWebIdentityCredentialProvider) ProtoReflect() protoreflect.Message
func (*AssumeRoleWithWebIdentityCredentialProvider) Reset ¶
func (x *AssumeRoleWithWebIdentityCredentialProvider) Reset()
func (*AssumeRoleWithWebIdentityCredentialProvider) SetRoleArn ¶
func (x *AssumeRoleWithWebIdentityCredentialProvider) SetRoleArn(v string)
func (*AssumeRoleWithWebIdentityCredentialProvider) SetRoleSessionName ¶
func (x *AssumeRoleWithWebIdentityCredentialProvider) SetRoleSessionName(v string)
func (*AssumeRoleWithWebIdentityCredentialProvider) SetWebIdentityTokenDataSource ¶
func (x *AssumeRoleWithWebIdentityCredentialProvider) SetWebIdentityTokenDataSource(v *v3.DataSource)
func (*AssumeRoleWithWebIdentityCredentialProvider) String ¶
func (x *AssumeRoleWithWebIdentityCredentialProvider) String() string
type AssumeRoleWithWebIdentityCredentialProvider_builder ¶
type AssumeRoleWithWebIdentityCredentialProvider_builder struct {
// Data source for a web identity token that is provided by the identity provider to assume the role.
// If a “watched_directory“ is not provided, one will be automatically inferred from the directory of the token file. This is to ensure
// that if the token file is rotated, the new token will be picked up. This behaviour differs from the standard envoy data source behavior, which does not
// automatically watch the directory of a file data source.
// Even when file rotation occurs, current credentials will continue to be used until they expire, at which point new credentials will be retrieved using the new token.
WebIdentityTokenDataSource *v3.DataSource
// The ARN of the role to assume.
RoleArn string
// Optional role session name to use in AssumeRoleWithWebIdentity API call.
RoleSessionName string
// contains filtered or unexported fields
}
func (AssumeRoleWithWebIdentityCredentialProvider_builder) Build ¶
type AwsCredentialProvider ¶
type AwsCredentialProvider struct {
// The option to use `AssumeRoleWithWebIdentity <https://docs.aws.amazon.com/STS/latest/APIReference/API_AssumeRoleWithWebIdentity.html>`_.
AssumeRoleWithWebIdentityProvider *AssumeRoleWithWebIdentityCredentialProvider `` /* 168-byte string literal not displayed */
// The option to use an inline credential. If inline credential is provided, no chain will be created and only the inline credential will be used.
InlineCredential *InlineCredentialProvider `protobuf:"bytes,2,opt,name=inline_credential,json=inlineCredential,proto3" json:"inline_credential,omitempty"`
// The option to specify parameters for credential retrieval from an envoy data source, such as a file in AWS credential format.
CredentialsFileProvider *CredentialsFileCredentialProvider `` /* 132-byte string literal not displayed */
// Create a custom credential provider chain instead of the default credential provider chain.
// If set to TRUE, the credential provider chain that is created contains only those set in this credential provider message.
// If set to FALSE, the settings provided here will act as modifiers to the default credential provider chain.
// Defaults to FALSE.
//
// This has no effect if inline_credential is provided.
CustomCredentialProviderChain bool `` /* 153-byte string literal not displayed */
// The option to use `IAM Roles Anywhere <https://docs.aws.amazon.com/rolesanywhere/latest/userguide/introduction.html>`_.
IamRolesAnywhereCredentialProvider *IAMRolesAnywhereCredentialProvider `` /* 169-byte string literal not displayed */
// The option to use credentials sourced from standard `AWS configuration files <https://docs.aws.amazon.com/cli/latest/userguide/cli-configure-files.html>`_.
ConfigCredentialProvider *ConfigCredentialProvider `` /* 135-byte string literal not displayed */
// The option to use credentials sourced from `container environment variables <https://docs.aws.amazon.com/sdkref/latest/guide/feature-container-credentials.html>`_.
ContainerCredentialProvider *ContainerCredentialProvider `` /* 144-byte string literal not displayed */
// The option to use credentials sourced from `environment variables <https://docs.aws.amazon.com/cli/latest/userguide/cli-configure-envvars.html>`_.
EnvironmentCredentialProvider *EnvironmentCredentialProvider `` /* 150-byte string literal not displayed */
// The option to use credentials sourced from an EC2 `Instance Profile <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-roles-for-amazon-ec2.html>`_.
InstanceProfileCredentialProvider *InstanceProfileCredentialProvider `` /* 164-byte string literal not displayed */
// The option to use `STS:AssumeRole aka Role Chaining <https://docs.aws.amazon.com/STS/latest/APIReference/API_AssumeRole.html>`_.
AssumeRoleCredentialProvider *AssumeRoleCredentialProvider `` /* 150-byte string literal not displayed */
// contains filtered or unexported fields
}
Configuration for AWS credential provider. This is optional and the credentials are normally retrieved from the environment or AWS configuration files by following the default credential provider chain. However, this configuration can be used to override the default behavior. [#next-free-field: 11]
func (*AwsCredentialProvider) ClearAssumeRoleCredentialProvider ¶
func (x *AwsCredentialProvider) ClearAssumeRoleCredentialProvider()
func (*AwsCredentialProvider) ClearAssumeRoleWithWebIdentityProvider ¶
func (x *AwsCredentialProvider) ClearAssumeRoleWithWebIdentityProvider()
func (*AwsCredentialProvider) ClearConfigCredentialProvider ¶
func (x *AwsCredentialProvider) ClearConfigCredentialProvider()
func (*AwsCredentialProvider) ClearContainerCredentialProvider ¶
func (x *AwsCredentialProvider) ClearContainerCredentialProvider()
func (*AwsCredentialProvider) ClearCredentialsFileProvider ¶
func (x *AwsCredentialProvider) ClearCredentialsFileProvider()
func (*AwsCredentialProvider) ClearEnvironmentCredentialProvider ¶
func (x *AwsCredentialProvider) ClearEnvironmentCredentialProvider()
func (*AwsCredentialProvider) ClearIamRolesAnywhereCredentialProvider ¶
func (x *AwsCredentialProvider) ClearIamRolesAnywhereCredentialProvider()
func (*AwsCredentialProvider) ClearInlineCredential ¶
func (x *AwsCredentialProvider) ClearInlineCredential()
func (*AwsCredentialProvider) ClearInstanceProfileCredentialProvider ¶
func (x *AwsCredentialProvider) ClearInstanceProfileCredentialProvider()
func (*AwsCredentialProvider) GetAssumeRoleCredentialProvider ¶
func (x *AwsCredentialProvider) GetAssumeRoleCredentialProvider() *AssumeRoleCredentialProvider
func (*AwsCredentialProvider) GetAssumeRoleWithWebIdentityProvider ¶
func (x *AwsCredentialProvider) GetAssumeRoleWithWebIdentityProvider() *AssumeRoleWithWebIdentityCredentialProvider
func (*AwsCredentialProvider) GetConfigCredentialProvider ¶
func (x *AwsCredentialProvider) GetConfigCredentialProvider() *ConfigCredentialProvider
func (*AwsCredentialProvider) GetContainerCredentialProvider ¶
func (x *AwsCredentialProvider) GetContainerCredentialProvider() *ContainerCredentialProvider
func (*AwsCredentialProvider) GetCredentialsFileProvider ¶
func (x *AwsCredentialProvider) GetCredentialsFileProvider() *CredentialsFileCredentialProvider
func (*AwsCredentialProvider) GetCustomCredentialProviderChain ¶
func (x *AwsCredentialProvider) GetCustomCredentialProviderChain() bool
func (*AwsCredentialProvider) GetEnvironmentCredentialProvider ¶
func (x *AwsCredentialProvider) GetEnvironmentCredentialProvider() *EnvironmentCredentialProvider
func (*AwsCredentialProvider) GetIamRolesAnywhereCredentialProvider ¶
func (x *AwsCredentialProvider) GetIamRolesAnywhereCredentialProvider() *IAMRolesAnywhereCredentialProvider
func (*AwsCredentialProvider) GetInlineCredential ¶
func (x *AwsCredentialProvider) GetInlineCredential() *InlineCredentialProvider
func (*AwsCredentialProvider) GetInstanceProfileCredentialProvider ¶
func (x *AwsCredentialProvider) GetInstanceProfileCredentialProvider() *InstanceProfileCredentialProvider
func (*AwsCredentialProvider) HasAssumeRoleCredentialProvider ¶
func (x *AwsCredentialProvider) HasAssumeRoleCredentialProvider() bool
func (*AwsCredentialProvider) HasAssumeRoleWithWebIdentityProvider ¶
func (x *AwsCredentialProvider) HasAssumeRoleWithWebIdentityProvider() bool
func (*AwsCredentialProvider) HasConfigCredentialProvider ¶
func (x *AwsCredentialProvider) HasConfigCredentialProvider() bool
func (*AwsCredentialProvider) HasContainerCredentialProvider ¶
func (x *AwsCredentialProvider) HasContainerCredentialProvider() bool
func (*AwsCredentialProvider) HasCredentialsFileProvider ¶
func (x *AwsCredentialProvider) HasCredentialsFileProvider() bool
func (*AwsCredentialProvider) HasEnvironmentCredentialProvider ¶
func (x *AwsCredentialProvider) HasEnvironmentCredentialProvider() bool
func (*AwsCredentialProvider) HasIamRolesAnywhereCredentialProvider ¶
func (x *AwsCredentialProvider) HasIamRolesAnywhereCredentialProvider() bool
func (*AwsCredentialProvider) HasInlineCredential ¶
func (x *AwsCredentialProvider) HasInlineCredential() bool
func (*AwsCredentialProvider) HasInstanceProfileCredentialProvider ¶
func (x *AwsCredentialProvider) HasInstanceProfileCredentialProvider() bool
func (*AwsCredentialProvider) ProtoMessage ¶
func (*AwsCredentialProvider) ProtoMessage()
func (*AwsCredentialProvider) ProtoReflect ¶
func (x *AwsCredentialProvider) ProtoReflect() protoreflect.Message
func (*AwsCredentialProvider) Reset ¶
func (x *AwsCredentialProvider) Reset()
func (*AwsCredentialProvider) SetAssumeRoleCredentialProvider ¶
func (x *AwsCredentialProvider) SetAssumeRoleCredentialProvider(v *AssumeRoleCredentialProvider)
func (*AwsCredentialProvider) SetAssumeRoleWithWebIdentityProvider ¶
func (x *AwsCredentialProvider) SetAssumeRoleWithWebIdentityProvider(v *AssumeRoleWithWebIdentityCredentialProvider)
func (*AwsCredentialProvider) SetConfigCredentialProvider ¶
func (x *AwsCredentialProvider) SetConfigCredentialProvider(v *ConfigCredentialProvider)
func (*AwsCredentialProvider) SetContainerCredentialProvider ¶
func (x *AwsCredentialProvider) SetContainerCredentialProvider(v *ContainerCredentialProvider)
func (*AwsCredentialProvider) SetCredentialsFileProvider ¶
func (x *AwsCredentialProvider) SetCredentialsFileProvider(v *CredentialsFileCredentialProvider)
func (*AwsCredentialProvider) SetCustomCredentialProviderChain ¶
func (x *AwsCredentialProvider) SetCustomCredentialProviderChain(v bool)
func (*AwsCredentialProvider) SetEnvironmentCredentialProvider ¶
func (x *AwsCredentialProvider) SetEnvironmentCredentialProvider(v *EnvironmentCredentialProvider)
func (*AwsCredentialProvider) SetIamRolesAnywhereCredentialProvider ¶
func (x *AwsCredentialProvider) SetIamRolesAnywhereCredentialProvider(v *IAMRolesAnywhereCredentialProvider)
func (*AwsCredentialProvider) SetInlineCredential ¶
func (x *AwsCredentialProvider) SetInlineCredential(v *InlineCredentialProvider)
func (*AwsCredentialProvider) SetInstanceProfileCredentialProvider ¶
func (x *AwsCredentialProvider) SetInstanceProfileCredentialProvider(v *InstanceProfileCredentialProvider)
func (*AwsCredentialProvider) String ¶
func (x *AwsCredentialProvider) String() string
type AwsCredentialProvider_builder ¶
type AwsCredentialProvider_builder struct {
// The option to use `AssumeRoleWithWebIdentity <https://docs.aws.amazon.com/STS/latest/APIReference/API_AssumeRoleWithWebIdentity.html>`_.
AssumeRoleWithWebIdentityProvider *AssumeRoleWithWebIdentityCredentialProvider
// The option to use an inline credential. If inline credential is provided, no chain will be created and only the inline credential will be used.
InlineCredential *InlineCredentialProvider
// The option to specify parameters for credential retrieval from an envoy data source, such as a file in AWS credential format.
CredentialsFileProvider *CredentialsFileCredentialProvider
// Create a custom credential provider chain instead of the default credential provider chain.
// If set to TRUE, the credential provider chain that is created contains only those set in this credential provider message.
// If set to FALSE, the settings provided here will act as modifiers to the default credential provider chain.
// Defaults to FALSE.
//
// This has no effect if inline_credential is provided.
CustomCredentialProviderChain bool
// The option to use `IAM Roles Anywhere <https://docs.aws.amazon.com/rolesanywhere/latest/userguide/introduction.html>`_.
IamRolesAnywhereCredentialProvider *IAMRolesAnywhereCredentialProvider
// The option to use credentials sourced from standard `AWS configuration files <https://docs.aws.amazon.com/cli/latest/userguide/cli-configure-files.html>`_.
ConfigCredentialProvider *ConfigCredentialProvider
// The option to use credentials sourced from `container environment variables <https://docs.aws.amazon.com/sdkref/latest/guide/feature-container-credentials.html>`_.
ContainerCredentialProvider *ContainerCredentialProvider
// The option to use credentials sourced from `environment variables <https://docs.aws.amazon.com/cli/latest/userguide/cli-configure-envvars.html>`_.
EnvironmentCredentialProvider *EnvironmentCredentialProvider
// The option to use credentials sourced from an EC2 `Instance Profile <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-roles-for-amazon-ec2.html>`_.
InstanceProfileCredentialProvider *InstanceProfileCredentialProvider
// The option to use `STS:AssumeRole aka Role Chaining <https://docs.aws.amazon.com/STS/latest/APIReference/API_AssumeRole.html>`_.
AssumeRoleCredentialProvider *AssumeRoleCredentialProvider
// contains filtered or unexported fields
}
func (AwsCredentialProvider_builder) Build ¶
func (b0 AwsCredentialProvider_builder) Build() *AwsCredentialProvider
type ConfigCredentialProvider ¶
type ConfigCredentialProvider struct {
// contains filtered or unexported fields
}
The Config Credential Provider has no configurable parameters, but listing it in a custom credential provider chain will enable this credential provider.
func (*ConfigCredentialProvider) ProtoMessage ¶
func (*ConfigCredentialProvider) ProtoMessage()
func (*ConfigCredentialProvider) ProtoReflect ¶
func (x *ConfigCredentialProvider) ProtoReflect() protoreflect.Message
func (*ConfigCredentialProvider) Reset ¶
func (x *ConfigCredentialProvider) Reset()
func (*ConfigCredentialProvider) String ¶
func (x *ConfigCredentialProvider) String() string
type ConfigCredentialProvider_builder ¶
type ConfigCredentialProvider_builder struct {
// contains filtered or unexported fields
}
func (ConfigCredentialProvider_builder) Build ¶
func (b0 ConfigCredentialProvider_builder) Build() *ConfigCredentialProvider
type ContainerCredentialProvider ¶
type ContainerCredentialProvider struct {
// contains filtered or unexported fields
}
The Container Credential Provider has no configurable parameters, but listing it in a custom credential provider chain will enable this credential provider.
func (*ContainerCredentialProvider) ProtoMessage ¶
func (*ContainerCredentialProvider) ProtoMessage()
func (*ContainerCredentialProvider) ProtoReflect ¶
func (x *ContainerCredentialProvider) ProtoReflect() protoreflect.Message
func (*ContainerCredentialProvider) Reset ¶
func (x *ContainerCredentialProvider) Reset()
func (*ContainerCredentialProvider) String ¶
func (x *ContainerCredentialProvider) String() string
type ContainerCredentialProvider_builder ¶
type ContainerCredentialProvider_builder struct {
// contains filtered or unexported fields
}
func (ContainerCredentialProvider_builder) Build ¶
func (b0 ContainerCredentialProvider_builder) Build() *ContainerCredentialProvider
type CredentialsFileCredentialProvider ¶
type CredentialsFileCredentialProvider struct {
// Data source from which to retrieve AWS credentials
// When using this data source, if a “watched_directory“ is provided, the credential file will be re-read when a file move is detected.
// See :ref:`watched_directory <envoy_v3_api_msg_config.core.v3.DataSource>` for more information about the “watched_directory“ field.
CredentialsDataSource *v3.DataSource `` /* 126-byte string literal not displayed */
// The profile within the credentials_file data source. If not provided, the default profile will be used.
Profile string `protobuf:"bytes,2,opt,name=profile,proto3" json:"profile,omitempty"`
// contains filtered or unexported fields
}
func (*CredentialsFileCredentialProvider) ClearCredentialsDataSource ¶
func (x *CredentialsFileCredentialProvider) ClearCredentialsDataSource()
func (*CredentialsFileCredentialProvider) GetCredentialsDataSource ¶
func (x *CredentialsFileCredentialProvider) GetCredentialsDataSource() *v3.DataSource
func (*CredentialsFileCredentialProvider) GetProfile ¶
func (x *CredentialsFileCredentialProvider) GetProfile() string
func (*CredentialsFileCredentialProvider) HasCredentialsDataSource ¶
func (x *CredentialsFileCredentialProvider) HasCredentialsDataSource() bool
func (*CredentialsFileCredentialProvider) ProtoMessage ¶
func (*CredentialsFileCredentialProvider) ProtoMessage()
func (*CredentialsFileCredentialProvider) ProtoReflect ¶
func (x *CredentialsFileCredentialProvider) ProtoReflect() protoreflect.Message
func (*CredentialsFileCredentialProvider) Reset ¶
func (x *CredentialsFileCredentialProvider) Reset()
func (*CredentialsFileCredentialProvider) SetCredentialsDataSource ¶
func (x *CredentialsFileCredentialProvider) SetCredentialsDataSource(v *v3.DataSource)
func (*CredentialsFileCredentialProvider) SetProfile ¶
func (x *CredentialsFileCredentialProvider) SetProfile(v string)
func (*CredentialsFileCredentialProvider) String ¶
func (x *CredentialsFileCredentialProvider) String() string
type CredentialsFileCredentialProvider_builder ¶
type CredentialsFileCredentialProvider_builder struct {
// Data source from which to retrieve AWS credentials
// When using this data source, if a “watched_directory“ is provided, the credential file will be re-read when a file move is detected.
// See :ref:`watched_directory <envoy_v3_api_msg_config.core.v3.DataSource>` for more information about the “watched_directory“ field.
CredentialsDataSource *v3.DataSource
// The profile within the credentials_file data source. If not provided, the default profile will be used.
Profile string
// contains filtered or unexported fields
}
func (CredentialsFileCredentialProvider_builder) Build ¶
func (b0 CredentialsFileCredentialProvider_builder) Build() *CredentialsFileCredentialProvider
type EnvironmentCredentialProvider ¶
type EnvironmentCredentialProvider struct {
// contains filtered or unexported fields
}
The Environment Credential Provider has no configurable parameters, but listing it in a custom credential provider chain will enable this credential provider.
func (*EnvironmentCredentialProvider) ProtoMessage ¶
func (*EnvironmentCredentialProvider) ProtoMessage()
func (*EnvironmentCredentialProvider) ProtoReflect ¶
func (x *EnvironmentCredentialProvider) ProtoReflect() protoreflect.Message
func (*EnvironmentCredentialProvider) Reset ¶
func (x *EnvironmentCredentialProvider) Reset()
func (*EnvironmentCredentialProvider) String ¶
func (x *EnvironmentCredentialProvider) String() string
type EnvironmentCredentialProvider_builder ¶
type EnvironmentCredentialProvider_builder struct {
// contains filtered or unexported fields
}
func (EnvironmentCredentialProvider_builder) Build ¶
func (b0 EnvironmentCredentialProvider_builder) Build() *EnvironmentCredentialProvider
type IAMRolesAnywhereCredentialProvider ¶
type IAMRolesAnywhereCredentialProvider struct {
// The ARN of the role to assume via the IAM Roles Anywhere sessions API. See `Configure Roles <https://docs.aws.amazon.com/rolesanywhere/latest/userguide/getting-started.html#getting-started-step2>`_ for more details.
RoleArn string `protobuf:"bytes,1,opt,name=role_arn,json=roleArn,proto3" json:"role_arn,omitempty"`
// The certificate used for authenticating to the IAM Roles Anywhere service.
// This certificate must match one configured in the IAM Roles Anywhere profile. See `Configure Roles <https://docs.aws.amazon.com/rolesanywhere/latest/userguide/getting-started.html#getting-started-step2>`_ for more details.
Certificate *v3.DataSource `protobuf:"bytes,2,opt,name=certificate,proto3" json:"certificate,omitempty"`
// The optional certificate chain, required when you are using a subordinate certificate authority for certificate issuance.
// A certificate chain can contain a maximum of 5 elements, see `The IAM Roles Anywhere authentication process <https://docs.aws.amazon.com/rolesanywhere/latest/userguide/authentication.html>`_ for more details.
CertificateChain *v3.DataSource `protobuf:"bytes,3,opt,name=certificate_chain,json=certificateChain,proto3" json:"certificate_chain,omitempty"`
// The TLS private key matching the certificate provided.
PrivateKey *v3.DataSource `protobuf:"bytes,4,opt,name=private_key,json=privateKey,proto3" json:"private_key,omitempty"`
// The arn of the IAM Roles Anywhere trust anchor configured in your AWS account. A trust anchor in IAM Roles anywhere establishes
// trust between your certificate authority (CA) and AWS. See `Establish trust <https://docs.aws.amazon.com/rolesanywhere/latest/userguide/getting-started.html#getting-started-step1>`_ for more details.
TrustAnchorArn string `protobuf:"bytes,5,opt,name=trust_anchor_arn,json=trustAnchorArn,proto3" json:"trust_anchor_arn,omitempty"`
// The IAM Roles Anywhere profile ARN configured in your AWS account.
ProfileArn string `protobuf:"bytes,6,opt,name=profile_arn,json=profileArn,proto3" json:"profile_arn,omitempty"`
// An optional role session name, used when identifying the role in subsequent AWS API calls.
RoleSessionName string `protobuf:"bytes,7,opt,name=role_session_name,json=roleSessionName,proto3" json:"role_session_name,omitempty"`
// An optional session duration, used when calculating the maximum time before vended credentials expire. This value cannot exceed the value configured
// in the IAM Roles Anywhere profile and the resultant session duration is calculate by the formula `here <https://docs.aws.amazon.com/rolesanywhere/latest/userguide/authentication-create-session.html#credentials-object>`_.
// If no session duration is provided here, the session duration is sourced from the IAM Roles Anywhere profile.
SessionDuration *durationpb.Duration `protobuf:"bytes,8,opt,name=session_duration,json=sessionDuration,proto3" json:"session_duration,omitempty"`
// contains filtered or unexported fields
}
Configuration to use `IAM Roles Anywhere <https://docs.aws.amazon.com/rolesanywhere/latest/userguide/introduction.html>`_ to retrieve AWS credentials. [#next-free-field: 9]
func (*IAMRolesAnywhereCredentialProvider) ClearCertificate ¶
func (x *IAMRolesAnywhereCredentialProvider) ClearCertificate()
func (*IAMRolesAnywhereCredentialProvider) ClearCertificateChain ¶
func (x *IAMRolesAnywhereCredentialProvider) ClearCertificateChain()
func (*IAMRolesAnywhereCredentialProvider) ClearPrivateKey ¶
func (x *IAMRolesAnywhereCredentialProvider) ClearPrivateKey()
func (*IAMRolesAnywhereCredentialProvider) ClearSessionDuration ¶
func (x *IAMRolesAnywhereCredentialProvider) ClearSessionDuration()
func (*IAMRolesAnywhereCredentialProvider) GetCertificate ¶
func (x *IAMRolesAnywhereCredentialProvider) GetCertificate() *v3.DataSource
func (*IAMRolesAnywhereCredentialProvider) GetCertificateChain ¶
func (x *IAMRolesAnywhereCredentialProvider) GetCertificateChain() *v3.DataSource
func (*IAMRolesAnywhereCredentialProvider) GetPrivateKey ¶
func (x *IAMRolesAnywhereCredentialProvider) GetPrivateKey() *v3.DataSource
func (*IAMRolesAnywhereCredentialProvider) GetProfileArn ¶
func (x *IAMRolesAnywhereCredentialProvider) GetProfileArn() string
func (*IAMRolesAnywhereCredentialProvider) GetRoleArn ¶
func (x *IAMRolesAnywhereCredentialProvider) GetRoleArn() string
func (*IAMRolesAnywhereCredentialProvider) GetRoleSessionName ¶
func (x *IAMRolesAnywhereCredentialProvider) GetRoleSessionName() string
func (*IAMRolesAnywhereCredentialProvider) GetSessionDuration ¶
func (x *IAMRolesAnywhereCredentialProvider) GetSessionDuration() *durationpb.Duration
func (*IAMRolesAnywhereCredentialProvider) GetTrustAnchorArn ¶
func (x *IAMRolesAnywhereCredentialProvider) GetTrustAnchorArn() string
func (*IAMRolesAnywhereCredentialProvider) HasCertificate ¶
func (x *IAMRolesAnywhereCredentialProvider) HasCertificate() bool
func (*IAMRolesAnywhereCredentialProvider) HasCertificateChain ¶
func (x *IAMRolesAnywhereCredentialProvider) HasCertificateChain() bool
func (*IAMRolesAnywhereCredentialProvider) HasPrivateKey ¶
func (x *IAMRolesAnywhereCredentialProvider) HasPrivateKey() bool
func (*IAMRolesAnywhereCredentialProvider) HasSessionDuration ¶
func (x *IAMRolesAnywhereCredentialProvider) HasSessionDuration() bool
func (*IAMRolesAnywhereCredentialProvider) ProtoMessage ¶
func (*IAMRolesAnywhereCredentialProvider) ProtoMessage()
func (*IAMRolesAnywhereCredentialProvider) ProtoReflect ¶
func (x *IAMRolesAnywhereCredentialProvider) ProtoReflect() protoreflect.Message
func (*IAMRolesAnywhereCredentialProvider) Reset ¶
func (x *IAMRolesAnywhereCredentialProvider) Reset()
func (*IAMRolesAnywhereCredentialProvider) SetCertificate ¶
func (x *IAMRolesAnywhereCredentialProvider) SetCertificate(v *v3.DataSource)
func (*IAMRolesAnywhereCredentialProvider) SetCertificateChain ¶
func (x *IAMRolesAnywhereCredentialProvider) SetCertificateChain(v *v3.DataSource)
func (*IAMRolesAnywhereCredentialProvider) SetPrivateKey ¶
func (x *IAMRolesAnywhereCredentialProvider) SetPrivateKey(v *v3.DataSource)
func (*IAMRolesAnywhereCredentialProvider) SetProfileArn ¶
func (x *IAMRolesAnywhereCredentialProvider) SetProfileArn(v string)
func (*IAMRolesAnywhereCredentialProvider) SetRoleArn ¶
func (x *IAMRolesAnywhereCredentialProvider) SetRoleArn(v string)
func (*IAMRolesAnywhereCredentialProvider) SetRoleSessionName ¶
func (x *IAMRolesAnywhereCredentialProvider) SetRoleSessionName(v string)
func (*IAMRolesAnywhereCredentialProvider) SetSessionDuration ¶
func (x *IAMRolesAnywhereCredentialProvider) SetSessionDuration(v *durationpb.Duration)
func (*IAMRolesAnywhereCredentialProvider) SetTrustAnchorArn ¶
func (x *IAMRolesAnywhereCredentialProvider) SetTrustAnchorArn(v string)
func (*IAMRolesAnywhereCredentialProvider) String ¶
func (x *IAMRolesAnywhereCredentialProvider) String() string
type IAMRolesAnywhereCredentialProvider_builder ¶
type IAMRolesAnywhereCredentialProvider_builder struct {
// The ARN of the role to assume via the IAM Roles Anywhere sessions API. See `Configure Roles <https://docs.aws.amazon.com/rolesanywhere/latest/userguide/getting-started.html#getting-started-step2>`_ for more details.
RoleArn string
// The certificate used for authenticating to the IAM Roles Anywhere service.
// This certificate must match one configured in the IAM Roles Anywhere profile. See `Configure Roles <https://docs.aws.amazon.com/rolesanywhere/latest/userguide/getting-started.html#getting-started-step2>`_ for more details.
Certificate *v3.DataSource
// The optional certificate chain, required when you are using a subordinate certificate authority for certificate issuance.
// A certificate chain can contain a maximum of 5 elements, see `The IAM Roles Anywhere authentication process <https://docs.aws.amazon.com/rolesanywhere/latest/userguide/authentication.html>`_ for more details.
CertificateChain *v3.DataSource
// The TLS private key matching the certificate provided.
PrivateKey *v3.DataSource
// The arn of the IAM Roles Anywhere trust anchor configured in your AWS account. A trust anchor in IAM Roles anywhere establishes
// trust between your certificate authority (CA) and AWS. See `Establish trust <https://docs.aws.amazon.com/rolesanywhere/latest/userguide/getting-started.html#getting-started-step1>`_ for more details.
TrustAnchorArn string
// The IAM Roles Anywhere profile ARN configured in your AWS account.
ProfileArn string
// An optional role session name, used when identifying the role in subsequent AWS API calls.
RoleSessionName string
// An optional session duration, used when calculating the maximum time before vended credentials expire. This value cannot exceed the value configured
// in the IAM Roles Anywhere profile and the resultant session duration is calculate by the formula `here <https://docs.aws.amazon.com/rolesanywhere/latest/userguide/authentication-create-session.html#credentials-object>`_.
// If no session duration is provided here, the session duration is sourced from the IAM Roles Anywhere profile.
SessionDuration *durationpb.Duration
// contains filtered or unexported fields
}
func (IAMRolesAnywhereCredentialProvider_builder) Build ¶
func (b0 IAMRolesAnywhereCredentialProvider_builder) Build() *IAMRolesAnywhereCredentialProvider
type InlineCredentialProvider ¶
type InlineCredentialProvider struct {
// The AWS access key ID.
AccessKeyId string `protobuf:"bytes,1,opt,name=access_key_id,json=accessKeyId,proto3" json:"access_key_id,omitempty"`
// The AWS secret access key.
SecretAccessKey string `protobuf:"bytes,2,opt,name=secret_access_key,json=secretAccessKey,proto3" json:"secret_access_key,omitempty"`
// The AWS session token. This is optional.
SessionToken string `protobuf:"bytes,3,opt,name=session_token,json=sessionToken,proto3" json:"session_token,omitempty"`
// contains filtered or unexported fields
}
Configuration to use an inline AWS credential. This is an equivalent to setting the well-known environment variables “AWS_ACCESS_KEY_ID“, “AWS_SECRET_ACCESS_KEY“, and the optional “AWS_SESSION_TOKEN“.
func (*InlineCredentialProvider) GetAccessKeyId ¶
func (x *InlineCredentialProvider) GetAccessKeyId() string
func (*InlineCredentialProvider) GetSecretAccessKey ¶
func (x *InlineCredentialProvider) GetSecretAccessKey() string
func (*InlineCredentialProvider) GetSessionToken ¶
func (x *InlineCredentialProvider) GetSessionToken() string
func (*InlineCredentialProvider) ProtoMessage ¶
func (*InlineCredentialProvider) ProtoMessage()
func (*InlineCredentialProvider) ProtoReflect ¶
func (x *InlineCredentialProvider) ProtoReflect() protoreflect.Message
func (*InlineCredentialProvider) Reset ¶
func (x *InlineCredentialProvider) Reset()
func (*InlineCredentialProvider) SetAccessKeyId ¶
func (x *InlineCredentialProvider) SetAccessKeyId(v string)
func (*InlineCredentialProvider) SetSecretAccessKey ¶
func (x *InlineCredentialProvider) SetSecretAccessKey(v string)
func (*InlineCredentialProvider) SetSessionToken ¶
func (x *InlineCredentialProvider) SetSessionToken(v string)
func (*InlineCredentialProvider) String ¶
func (x *InlineCredentialProvider) String() string
type InlineCredentialProvider_builder ¶
type InlineCredentialProvider_builder struct {
// The AWS access key ID.
AccessKeyId string
// The AWS secret access key.
SecretAccessKey string
// The AWS session token. This is optional.
SessionToken string
// contains filtered or unexported fields
}
func (InlineCredentialProvider_builder) Build ¶
func (b0 InlineCredentialProvider_builder) Build() *InlineCredentialProvider
type InstanceProfileCredentialProvider ¶
type InstanceProfileCredentialProvider struct {
// contains filtered or unexported fields
}
The Instance Profile Credential Provider has no configurable parameters, but listing it in a custom credential provider chain will enable this credential provider.
func (*InstanceProfileCredentialProvider) ProtoMessage ¶
func (*InstanceProfileCredentialProvider) ProtoMessage()
func (*InstanceProfileCredentialProvider) ProtoReflect ¶
func (x *InstanceProfileCredentialProvider) ProtoReflect() protoreflect.Message
func (*InstanceProfileCredentialProvider) Reset ¶
func (x *InstanceProfileCredentialProvider) Reset()
func (*InstanceProfileCredentialProvider) String ¶
func (x *InstanceProfileCredentialProvider) String() string
type InstanceProfileCredentialProvider_builder ¶
type InstanceProfileCredentialProvider_builder struct {
// contains filtered or unexported fields
}
func (InstanceProfileCredentialProvider_builder) Build ¶
func (b0 InstanceProfileCredentialProvider_builder) Build() *InstanceProfileCredentialProvider
Source Files
¶
- credential_provider.pb.go