Documentation
¶
Index ¶
- Variables
- type DnsCacheCircuitBreakers
- func (x *DnsCacheCircuitBreakers) ClearMaxPendingRequests()
- func (x *DnsCacheCircuitBreakers) GetMaxPendingRequests() *wrapperspb.UInt32Value
- func (x *DnsCacheCircuitBreakers) HasMaxPendingRequests() bool
- func (*DnsCacheCircuitBreakers) ProtoMessage()
- func (x *DnsCacheCircuitBreakers) ProtoReflect() protoreflect.Message
- func (x *DnsCacheCircuitBreakers) Reset()
- func (x *DnsCacheCircuitBreakers) SetMaxPendingRequests(v *wrapperspb.UInt32Value)
- func (x *DnsCacheCircuitBreakers) String() string
- type DnsCacheCircuitBreakers_builder
- type DnsCacheConfig
- func (x *DnsCacheConfig) ClearDnsCacheCircuitBreaker()
- func (x *DnsCacheConfig) ClearDnsFailureRefreshRate()
- func (x *DnsCacheConfig) ClearDnsMinRefreshRate()
- func (x *DnsCacheConfig) ClearDnsQueryTimeout()
- func (x *DnsCacheConfig) ClearDnsRefreshRate()
- func (x *DnsCacheConfig) ClearDnsResolutionConfig()deprecated
- func (x *DnsCacheConfig) ClearHostTtl()
- func (x *DnsCacheConfig) ClearKeyValueConfig()
- func (x *DnsCacheConfig) ClearMaxHosts()
- func (x *DnsCacheConfig) ClearTypedDnsResolverConfig()
- func (x *DnsCacheConfig) GetDisableDnsRefreshOnFailure() bool
- func (x *DnsCacheConfig) GetDnsCacheCircuitBreaker() *DnsCacheCircuitBreakers
- func (x *DnsCacheConfig) GetDnsFailureRefreshRate() *v3.Cluster_RefreshRate
- func (x *DnsCacheConfig) GetDnsLookupFamily() v3.Cluster_DnsLookupFamily
- func (x *DnsCacheConfig) GetDnsMinRefreshRate() *durationpb.Duration
- func (x *DnsCacheConfig) GetDnsQueryTimeout() *durationpb.Duration
- func (x *DnsCacheConfig) GetDnsRefreshRate() *durationpb.Duration
- func (x *DnsCacheConfig) GetDnsResolutionConfig() *v31.DnsResolutionConfigdeprecated
- func (x *DnsCacheConfig) GetHostTtl() *durationpb.Duration
- func (x *DnsCacheConfig) GetKeyValueConfig() *v32.KeyValueStoreConfig
- func (x *DnsCacheConfig) GetMaxHosts() *wrapperspb.UInt32Value
- func (x *DnsCacheConfig) GetName() string
- func (x *DnsCacheConfig) GetPreresolveHostnames() []*v31.SocketAddress
- func (x *DnsCacheConfig) GetTypedDnsResolverConfig() *v31.TypedExtensionConfig
- func (x *DnsCacheConfig) GetUseTcpForDnsLookups() booldeprecated
- func (x *DnsCacheConfig) HasDnsCacheCircuitBreaker() bool
- func (x *DnsCacheConfig) HasDnsFailureRefreshRate() bool
- func (x *DnsCacheConfig) HasDnsMinRefreshRate() bool
- func (x *DnsCacheConfig) HasDnsQueryTimeout() bool
- func (x *DnsCacheConfig) HasDnsRefreshRate() bool
- func (x *DnsCacheConfig) HasDnsResolutionConfig() booldeprecated
- func (x *DnsCacheConfig) HasHostTtl() bool
- func (x *DnsCacheConfig) HasKeyValueConfig() bool
- func (x *DnsCacheConfig) HasMaxHosts() bool
- func (x *DnsCacheConfig) HasTypedDnsResolverConfig() bool
- func (*DnsCacheConfig) ProtoMessage()
- func (x *DnsCacheConfig) ProtoReflect() protoreflect.Message
- func (x *DnsCacheConfig) Reset()
- func (x *DnsCacheConfig) SetDisableDnsRefreshOnFailure(v bool)
- func (x *DnsCacheConfig) SetDnsCacheCircuitBreaker(v *DnsCacheCircuitBreakers)
- func (x *DnsCacheConfig) SetDnsFailureRefreshRate(v *v3.Cluster_RefreshRate)
- func (x *DnsCacheConfig) SetDnsLookupFamily(v v3.Cluster_DnsLookupFamily)
- func (x *DnsCacheConfig) SetDnsMinRefreshRate(v *durationpb.Duration)
- func (x *DnsCacheConfig) SetDnsQueryTimeout(v *durationpb.Duration)
- func (x *DnsCacheConfig) SetDnsRefreshRate(v *durationpb.Duration)
- func (x *DnsCacheConfig) SetDnsResolutionConfig(v *v31.DnsResolutionConfig)deprecated
- func (x *DnsCacheConfig) SetHostTtl(v *durationpb.Duration)
- func (x *DnsCacheConfig) SetKeyValueConfig(v *v32.KeyValueStoreConfig)
- func (x *DnsCacheConfig) SetMaxHosts(v *wrapperspb.UInt32Value)
- func (x *DnsCacheConfig) SetName(v string)
- func (x *DnsCacheConfig) SetPreresolveHostnames(v []*v31.SocketAddress)
- func (x *DnsCacheConfig) SetTypedDnsResolverConfig(v *v31.TypedExtensionConfig)
- func (x *DnsCacheConfig) SetUseTcpForDnsLookups(v bool)deprecated
- func (x *DnsCacheConfig) String() string
- type DnsCacheConfig_builder
Constants ¶
This section is empty.
Variables ¶
var File_envoy_extensions_common_dynamic_forward_proxy_v3_dns_cache_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type DnsCacheCircuitBreakers ¶
type DnsCacheCircuitBreakers struct {
// The maximum number of pending requests that Envoy will allow to the
// resolver. If not specified, the default is 1024.
MaxPendingRequests *wrapperspb.UInt32Value `protobuf:"bytes,1,opt,name=max_pending_requests,json=maxPendingRequests,proto3" json:"max_pending_requests,omitempty"`
// contains filtered or unexported fields
}
Configuration of circuit breakers for resolver.
func (*DnsCacheCircuitBreakers) ClearMaxPendingRequests ¶
func (x *DnsCacheCircuitBreakers) ClearMaxPendingRequests()
func (*DnsCacheCircuitBreakers) GetMaxPendingRequests ¶
func (x *DnsCacheCircuitBreakers) GetMaxPendingRequests() *wrapperspb.UInt32Value
func (*DnsCacheCircuitBreakers) HasMaxPendingRequests ¶
func (x *DnsCacheCircuitBreakers) HasMaxPendingRequests() bool
func (*DnsCacheCircuitBreakers) ProtoMessage ¶
func (*DnsCacheCircuitBreakers) ProtoMessage()
func (*DnsCacheCircuitBreakers) ProtoReflect ¶
func (x *DnsCacheCircuitBreakers) ProtoReflect() protoreflect.Message
func (*DnsCacheCircuitBreakers) Reset ¶
func (x *DnsCacheCircuitBreakers) Reset()
func (*DnsCacheCircuitBreakers) SetMaxPendingRequests ¶
func (x *DnsCacheCircuitBreakers) SetMaxPendingRequests(v *wrapperspb.UInt32Value)
func (*DnsCacheCircuitBreakers) String ¶
func (x *DnsCacheCircuitBreakers) String() string
type DnsCacheCircuitBreakers_builder ¶
type DnsCacheCircuitBreakers_builder struct {
// The maximum number of pending requests that Envoy will allow to the
// resolver. If not specified, the default is 1024.
MaxPendingRequests *wrapperspb.UInt32Value
// contains filtered or unexported fields
}
func (DnsCacheCircuitBreakers_builder) Build ¶
func (b0 DnsCacheCircuitBreakers_builder) Build() *DnsCacheCircuitBreakers
type DnsCacheConfig ¶
type DnsCacheConfig struct {
// The name of the cache. Multiple named caches allow independent dynamic forward proxy
// configurations to operate within a single Envoy process using different configurations. All
// configurations with the same name *must* otherwise have the same settings when referenced
// from different configuration components. Configuration will fail to load if this is not
// the case.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// The DNS lookup family to use during resolution.
//
// [#comment:TODO(mattklein123): Figure out how to support IPv4/IPv6 "happy eyeballs" mode. The
// way this might work is a new lookup family which returns both IPv4 and IPv6 addresses, and
// then configures a host to have a primary and fall back address. With this, we could very
// likely build a "happy eyeballs" connection pool which would race the primary / fall back
// address and return the one that wins. This same method could potentially also be used for
// QUIC to TCP fall back.]
DnsLookupFamily v3.Cluster_DnsLookupFamily `` /* 162-byte string literal not displayed */
// The DNS refresh rate for unresolved DNS hosts. If not specified defaults to 60s.
//
// The refresh rate is rounded to the closest millisecond, and must be at least 1ms.
//
// Once a host has been resolved, the refresh rate will be the DNS TTL, capped
// at a minimum of “dns_min_refresh_rate“.
DnsRefreshRate *durationpb.Duration `protobuf:"bytes,3,opt,name=dns_refresh_rate,json=dnsRefreshRate,proto3" json:"dns_refresh_rate,omitempty"`
// The minimum rate that DNS resolution will occur. Per “dns_refresh_rate“, once a host is
// resolved, the DNS TTL will be used, with a minimum set by “dns_min_refresh_rate“.
// “dns_min_refresh_rate“ defaults to 5s and must also be >= 1s.
DnsMinRefreshRate *durationpb.Duration `protobuf:"bytes,14,opt,name=dns_min_refresh_rate,json=dnsMinRefreshRate,proto3" json:"dns_min_refresh_rate,omitempty"`
// The TTL for hosts that are unused. Hosts that have not been used in the configured time
// interval will be purged. If not specified defaults to 5m.
//
// .. note:
//
// The TTL is only checked at the time of DNS refresh, as specified by “dns_refresh_rate“. This
// means that if the configured TTL is shorter than the refresh rate the host may not be removed
// immediately.
//
// .. note:
//
// The TTL has no relation to DNS TTL and is only used to control Envoy's resource usage.
HostTtl *durationpb.Duration `protobuf:"bytes,4,opt,name=host_ttl,json=hostTtl,proto3" json:"host_ttl,omitempty"`
// The maximum number of hosts that the cache will hold. If not specified defaults to 1024.
//
// .. note:
//
// The implementation is approximate and enforced independently on each worker thread, thus
// it is possible for the maximum hosts in the cache to go slightly above the configured
// value depending on timing. This is similar to how other circuit breakers work.
MaxHosts *wrapperspb.UInt32Value `protobuf:"bytes,5,opt,name=max_hosts,json=maxHosts,proto3" json:"max_hosts,omitempty"`
// Disable the DNS refresh on failure. If this field is set to true, it will ignore the
// :ref:`typed_dns_resolver_config <envoy_v3_api_field_extensions.common.dynamic_forward_proxy.v3.DnsCacheConfig.dns_failure_refresh_rate>`.
// If not specified, it defaults to false. By enabling this feature, the failed hosts will now be treated as a cache miss,
// allowing the failed hosts to be resolved on demand.
DisableDnsRefreshOnFailure bool `` /* 147-byte string literal not displayed */
// If the DNS failure refresh rate is specified,
// this is used as the cache's DNS refresh rate when DNS requests are failing. If this setting is
// not specified, the failure refresh rate defaults to the dns_refresh_rate.
DnsFailureRefreshRate *v3.Cluster_RefreshRate `` /* 128-byte string literal not displayed */
// The config of circuit breakers for resolver. It provides a configurable threshold.
// Envoy will use dns cache circuit breakers with default settings even if this value is not set.
DnsCacheCircuitBreaker *DnsCacheCircuitBreakers `` /* 131-byte string literal not displayed */
// Always use TCP queries instead of UDP queries for DNS lookups.
// This field is deprecated in favor of “dns_resolution_config“
// which aggregates all of the DNS resolver configuration in a single message.
//
// Deprecated: Marked as deprecated in envoy/extensions/common/dynamic_forward_proxy/v3/dns_cache.proto.
UseTcpForDnsLookups bool `protobuf:"varint,8,opt,name=use_tcp_for_dns_lookups,json=useTcpForDnsLookups,proto3" json:"use_tcp_for_dns_lookups,omitempty"`
// DNS resolution configuration which includes the underlying dns resolver addresses and options.
// This field is deprecated in favor of
// :ref:`typed_dns_resolver_config <envoy_v3_api_field_extensions.common.dynamic_forward_proxy.v3.DnsCacheConfig.typed_dns_resolver_config>`.
//
// Deprecated: Marked as deprecated in envoy/extensions/common/dynamic_forward_proxy/v3/dns_cache.proto.
DnsResolutionConfig *v31.DnsResolutionConfig `protobuf:"bytes,9,opt,name=dns_resolution_config,json=dnsResolutionConfig,proto3" json:"dns_resolution_config,omitempty"`
// DNS resolver type configuration extension. This extension can be used to configure c-ares, apple,
// or any other DNS resolver types and the related parameters.
// For example, an object of
// :ref:`CaresDnsResolverConfig <envoy_v3_api_msg_extensions.network.dns_resolver.cares.v3.CaresDnsResolverConfig>`
// can be packed into this “typed_dns_resolver_config“. This configuration replaces the
// :ref:`dns_resolution_config <envoy_v3_api_field_extensions.common.dynamic_forward_proxy.v3.DnsCacheConfig.dns_resolution_config>`
// configuration.
// During the transition period when both “dns_resolution_config“ and “typed_dns_resolver_config“ exists,
// when “typed_dns_resolver_config“ is in place, Envoy will use it and ignore “dns_resolution_config“.
// When “typed_dns_resolver_config“ is missing, the default behavior is in place.
// [#extension-category: envoy.network.dns_resolver]
TypedDnsResolverConfig *v31.TypedExtensionConfig `` /* 132-byte string literal not displayed */
// Hostnames that should be preresolved into the cache upon creation. This might provide a
// performance improvement, in the form of cache hits, for hostnames that are going to be
// resolved during steady state and are known at config load time.
PreresolveHostnames []*v31.SocketAddress `protobuf:"bytes,10,rep,name=preresolve_hostnames,json=preresolveHostnames,proto3" json:"preresolve_hostnames,omitempty"`
// The timeout used for DNS queries. This timeout is independent of any timeout and retry policy
// used by the underlying DNS implementation (e.g., c-areas and Apple DNS) which are opaque.
// Setting this timeout will ensure that queries succeed or fail within the specified time frame
// and are then retried using the standard refresh rates. Setting it to 0 will disable the Envoy DNS
// query timeout and use the underlying DNS implementation timeout. Defaults to 5s if not set.
DnsQueryTimeout *durationpb.Duration `protobuf:"bytes,11,opt,name=dns_query_timeout,json=dnsQueryTimeout,proto3" json:"dns_query_timeout,omitempty"`
// Configuration to flush the DNS cache to long term storage.
KeyValueConfig *v32.KeyValueStoreConfig `protobuf:"bytes,13,opt,name=key_value_config,json=keyValueConfig,proto3" json:"key_value_config,omitempty"`
// contains filtered or unexported fields
}
Configuration for the dynamic forward proxy DNS cache. See the :ref:`architecture overview <arch_overview_http_dynamic_forward_proxy>` for more information. [#next-free-field: 16]
func (*DnsCacheConfig) ClearDnsCacheCircuitBreaker ¶
func (x *DnsCacheConfig) ClearDnsCacheCircuitBreaker()
func (*DnsCacheConfig) ClearDnsFailureRefreshRate ¶
func (x *DnsCacheConfig) ClearDnsFailureRefreshRate()
func (*DnsCacheConfig) ClearDnsMinRefreshRate ¶
func (x *DnsCacheConfig) ClearDnsMinRefreshRate()
func (*DnsCacheConfig) ClearDnsQueryTimeout ¶
func (x *DnsCacheConfig) ClearDnsQueryTimeout()
func (*DnsCacheConfig) ClearDnsRefreshRate ¶
func (x *DnsCacheConfig) ClearDnsRefreshRate()
func (*DnsCacheConfig) ClearDnsResolutionConfig
deprecated
func (x *DnsCacheConfig) ClearDnsResolutionConfig()
Deprecated: Marked as deprecated in envoy/extensions/common/dynamic_forward_proxy/v3/dns_cache.proto.
func (*DnsCacheConfig) ClearHostTtl ¶
func (x *DnsCacheConfig) ClearHostTtl()
func (*DnsCacheConfig) ClearKeyValueConfig ¶
func (x *DnsCacheConfig) ClearKeyValueConfig()
func (*DnsCacheConfig) ClearMaxHosts ¶
func (x *DnsCacheConfig) ClearMaxHosts()
func (*DnsCacheConfig) ClearTypedDnsResolverConfig ¶
func (x *DnsCacheConfig) ClearTypedDnsResolverConfig()
func (*DnsCacheConfig) GetDisableDnsRefreshOnFailure ¶
func (x *DnsCacheConfig) GetDisableDnsRefreshOnFailure() bool
func (*DnsCacheConfig) GetDnsCacheCircuitBreaker ¶
func (x *DnsCacheConfig) GetDnsCacheCircuitBreaker() *DnsCacheCircuitBreakers
func (*DnsCacheConfig) GetDnsFailureRefreshRate ¶
func (x *DnsCacheConfig) GetDnsFailureRefreshRate() *v3.Cluster_RefreshRate
func (*DnsCacheConfig) GetDnsLookupFamily ¶
func (x *DnsCacheConfig) GetDnsLookupFamily() v3.Cluster_DnsLookupFamily
func (*DnsCacheConfig) GetDnsMinRefreshRate ¶
func (x *DnsCacheConfig) GetDnsMinRefreshRate() *durationpb.Duration
func (*DnsCacheConfig) GetDnsQueryTimeout ¶
func (x *DnsCacheConfig) GetDnsQueryTimeout() *durationpb.Duration
func (*DnsCacheConfig) GetDnsRefreshRate ¶
func (x *DnsCacheConfig) GetDnsRefreshRate() *durationpb.Duration
func (*DnsCacheConfig) GetDnsResolutionConfig
deprecated
func (x *DnsCacheConfig) GetDnsResolutionConfig() *v31.DnsResolutionConfig
Deprecated: Marked as deprecated in envoy/extensions/common/dynamic_forward_proxy/v3/dns_cache.proto.
func (*DnsCacheConfig) GetHostTtl ¶
func (x *DnsCacheConfig) GetHostTtl() *durationpb.Duration
func (*DnsCacheConfig) GetKeyValueConfig ¶
func (x *DnsCacheConfig) GetKeyValueConfig() *v32.KeyValueStoreConfig
func (*DnsCacheConfig) GetMaxHosts ¶
func (x *DnsCacheConfig) GetMaxHosts() *wrapperspb.UInt32Value
func (*DnsCacheConfig) GetName ¶
func (x *DnsCacheConfig) GetName() string
func (*DnsCacheConfig) GetPreresolveHostnames ¶
func (x *DnsCacheConfig) GetPreresolveHostnames() []*v31.SocketAddress
func (*DnsCacheConfig) GetTypedDnsResolverConfig ¶
func (x *DnsCacheConfig) GetTypedDnsResolverConfig() *v31.TypedExtensionConfig
func (*DnsCacheConfig) GetUseTcpForDnsLookups
deprecated
func (x *DnsCacheConfig) GetUseTcpForDnsLookups() bool
Deprecated: Marked as deprecated in envoy/extensions/common/dynamic_forward_proxy/v3/dns_cache.proto.
func (*DnsCacheConfig) HasDnsCacheCircuitBreaker ¶
func (x *DnsCacheConfig) HasDnsCacheCircuitBreaker() bool
func (*DnsCacheConfig) HasDnsFailureRefreshRate ¶
func (x *DnsCacheConfig) HasDnsFailureRefreshRate() bool
func (*DnsCacheConfig) HasDnsMinRefreshRate ¶
func (x *DnsCacheConfig) HasDnsMinRefreshRate() bool
func (*DnsCacheConfig) HasDnsQueryTimeout ¶
func (x *DnsCacheConfig) HasDnsQueryTimeout() bool
func (*DnsCacheConfig) HasDnsRefreshRate ¶
func (x *DnsCacheConfig) HasDnsRefreshRate() bool
func (*DnsCacheConfig) HasDnsResolutionConfig
deprecated
func (x *DnsCacheConfig) HasDnsResolutionConfig() bool
Deprecated: Marked as deprecated in envoy/extensions/common/dynamic_forward_proxy/v3/dns_cache.proto.
func (*DnsCacheConfig) HasHostTtl ¶
func (x *DnsCacheConfig) HasHostTtl() bool
func (*DnsCacheConfig) HasKeyValueConfig ¶
func (x *DnsCacheConfig) HasKeyValueConfig() bool
func (*DnsCacheConfig) HasMaxHosts ¶
func (x *DnsCacheConfig) HasMaxHosts() bool
func (*DnsCacheConfig) HasTypedDnsResolverConfig ¶
func (x *DnsCacheConfig) HasTypedDnsResolverConfig() bool
func (*DnsCacheConfig) ProtoMessage ¶
func (*DnsCacheConfig) ProtoMessage()
func (*DnsCacheConfig) ProtoReflect ¶
func (x *DnsCacheConfig) ProtoReflect() protoreflect.Message
func (*DnsCacheConfig) Reset ¶
func (x *DnsCacheConfig) Reset()
func (*DnsCacheConfig) SetDisableDnsRefreshOnFailure ¶
func (x *DnsCacheConfig) SetDisableDnsRefreshOnFailure(v bool)
func (*DnsCacheConfig) SetDnsCacheCircuitBreaker ¶
func (x *DnsCacheConfig) SetDnsCacheCircuitBreaker(v *DnsCacheCircuitBreakers)
func (*DnsCacheConfig) SetDnsFailureRefreshRate ¶
func (x *DnsCacheConfig) SetDnsFailureRefreshRate(v *v3.Cluster_RefreshRate)
func (*DnsCacheConfig) SetDnsLookupFamily ¶
func (x *DnsCacheConfig) SetDnsLookupFamily(v v3.Cluster_DnsLookupFamily)
func (*DnsCacheConfig) SetDnsMinRefreshRate ¶
func (x *DnsCacheConfig) SetDnsMinRefreshRate(v *durationpb.Duration)
func (*DnsCacheConfig) SetDnsQueryTimeout ¶
func (x *DnsCacheConfig) SetDnsQueryTimeout(v *durationpb.Duration)
func (*DnsCacheConfig) SetDnsRefreshRate ¶
func (x *DnsCacheConfig) SetDnsRefreshRate(v *durationpb.Duration)
func (*DnsCacheConfig) SetDnsResolutionConfig
deprecated
func (x *DnsCacheConfig) SetDnsResolutionConfig(v *v31.DnsResolutionConfig)
Deprecated: Marked as deprecated in envoy/extensions/common/dynamic_forward_proxy/v3/dns_cache.proto.
func (*DnsCacheConfig) SetHostTtl ¶
func (x *DnsCacheConfig) SetHostTtl(v *durationpb.Duration)
func (*DnsCacheConfig) SetKeyValueConfig ¶
func (x *DnsCacheConfig) SetKeyValueConfig(v *v32.KeyValueStoreConfig)
func (*DnsCacheConfig) SetMaxHosts ¶
func (x *DnsCacheConfig) SetMaxHosts(v *wrapperspb.UInt32Value)
func (*DnsCacheConfig) SetName ¶
func (x *DnsCacheConfig) SetName(v string)
func (*DnsCacheConfig) SetPreresolveHostnames ¶
func (x *DnsCacheConfig) SetPreresolveHostnames(v []*v31.SocketAddress)
func (*DnsCacheConfig) SetTypedDnsResolverConfig ¶
func (x *DnsCacheConfig) SetTypedDnsResolverConfig(v *v31.TypedExtensionConfig)
func (*DnsCacheConfig) SetUseTcpForDnsLookups
deprecated
func (x *DnsCacheConfig) SetUseTcpForDnsLookups(v bool)
Deprecated: Marked as deprecated in envoy/extensions/common/dynamic_forward_proxy/v3/dns_cache.proto.
func (*DnsCacheConfig) String ¶
func (x *DnsCacheConfig) String() string
type DnsCacheConfig_builder ¶
type DnsCacheConfig_builder struct {
// The name of the cache. Multiple named caches allow independent dynamic forward proxy
// configurations to operate within a single Envoy process using different configurations. All
// configurations with the same name *must* otherwise have the same settings when referenced
// from different configuration components. Configuration will fail to load if this is not
// the case.
Name string
// The DNS lookup family to use during resolution.
//
// [#comment:TODO(mattklein123): Figure out how to support IPv4/IPv6 "happy eyeballs" mode. The
// way this might work is a new lookup family which returns both IPv4 and IPv6 addresses, and
// then configures a host to have a primary and fall back address. With this, we could very
// likely build a "happy eyeballs" connection pool which would race the primary / fall back
// address and return the one that wins. This same method could potentially also be used for
// QUIC to TCP fall back.]
DnsLookupFamily v3.Cluster_DnsLookupFamily
// The DNS refresh rate for unresolved DNS hosts. If not specified defaults to 60s.
//
// The refresh rate is rounded to the closest millisecond, and must be at least 1ms.
//
// Once a host has been resolved, the refresh rate will be the DNS TTL, capped
// at a minimum of “dns_min_refresh_rate“.
DnsRefreshRate *durationpb.Duration
// The minimum rate that DNS resolution will occur. Per “dns_refresh_rate“, once a host is
// resolved, the DNS TTL will be used, with a minimum set by “dns_min_refresh_rate“.
// “dns_min_refresh_rate“ defaults to 5s and must also be >= 1s.
DnsMinRefreshRate *durationpb.Duration
// The TTL for hosts that are unused. Hosts that have not been used in the configured time
// interval will be purged. If not specified defaults to 5m.
//
// .. note:
//
// The TTL is only checked at the time of DNS refresh, as specified by “dns_refresh_rate“. This
// means that if the configured TTL is shorter than the refresh rate the host may not be removed
// immediately.
//
// .. note:
//
// The TTL has no relation to DNS TTL and is only used to control Envoy's resource usage.
HostTtl *durationpb.Duration
// The maximum number of hosts that the cache will hold. If not specified defaults to 1024.
//
// .. note:
//
// The implementation is approximate and enforced independently on each worker thread, thus
// it is possible for the maximum hosts in the cache to go slightly above the configured
// value depending on timing. This is similar to how other circuit breakers work.
MaxHosts *wrapperspb.UInt32Value
// Disable the DNS refresh on failure. If this field is set to true, it will ignore the
// :ref:`typed_dns_resolver_config <envoy_v3_api_field_extensions.common.dynamic_forward_proxy.v3.DnsCacheConfig.dns_failure_refresh_rate>`.
// If not specified, it defaults to false. By enabling this feature, the failed hosts will now be treated as a cache miss,
// allowing the failed hosts to be resolved on demand.
DisableDnsRefreshOnFailure bool
// If the DNS failure refresh rate is specified,
// this is used as the cache's DNS refresh rate when DNS requests are failing. If this setting is
// not specified, the failure refresh rate defaults to the dns_refresh_rate.
DnsFailureRefreshRate *v3.Cluster_RefreshRate
// The config of circuit breakers for resolver. It provides a configurable threshold.
// Envoy will use dns cache circuit breakers with default settings even if this value is not set.
DnsCacheCircuitBreaker *DnsCacheCircuitBreakers
// Always use TCP queries instead of UDP queries for DNS lookups.
// This field is deprecated in favor of “dns_resolution_config“
// which aggregates all of the DNS resolver configuration in a single message.
//
// Deprecated: Marked as deprecated in envoy/extensions/common/dynamic_forward_proxy/v3/dns_cache.proto.
UseTcpForDnsLookups bool
// DNS resolution configuration which includes the underlying dns resolver addresses and options.
// This field is deprecated in favor of
// :ref:`typed_dns_resolver_config <envoy_v3_api_field_extensions.common.dynamic_forward_proxy.v3.DnsCacheConfig.typed_dns_resolver_config>`.
//
// Deprecated: Marked as deprecated in envoy/extensions/common/dynamic_forward_proxy/v3/dns_cache.proto.
DnsResolutionConfig *v31.DnsResolutionConfig
// DNS resolver type configuration extension. This extension can be used to configure c-ares, apple,
// or any other DNS resolver types and the related parameters.
// For example, an object of
// :ref:`CaresDnsResolverConfig <envoy_v3_api_msg_extensions.network.dns_resolver.cares.v3.CaresDnsResolverConfig>`
// can be packed into this “typed_dns_resolver_config“. This configuration replaces the
// :ref:`dns_resolution_config <envoy_v3_api_field_extensions.common.dynamic_forward_proxy.v3.DnsCacheConfig.dns_resolution_config>`
// configuration.
// During the transition period when both “dns_resolution_config“ and “typed_dns_resolver_config“ exists,
// when “typed_dns_resolver_config“ is in place, Envoy will use it and ignore “dns_resolution_config“.
// When “typed_dns_resolver_config“ is missing, the default behavior is in place.
// [#extension-category: envoy.network.dns_resolver]
TypedDnsResolverConfig *v31.TypedExtensionConfig
// Hostnames that should be preresolved into the cache upon creation. This might provide a
// performance improvement, in the form of cache hits, for hostnames that are going to be
// resolved during steady state and are known at config load time.
PreresolveHostnames []*v31.SocketAddress
// The timeout used for DNS queries. This timeout is independent of any timeout and retry policy
// used by the underlying DNS implementation (e.g., c-areas and Apple DNS) which are opaque.
// Setting this timeout will ensure that queries succeed or fail within the specified time frame
// and are then retried using the standard refresh rates. Setting it to 0 will disable the Envoy DNS
// query timeout and use the underlying DNS implementation timeout. Defaults to 5s if not set.
DnsQueryTimeout *durationpb.Duration
// Configuration to flush the DNS cache to long term storage.
KeyValueConfig *v32.KeyValueStoreConfig
// contains filtered or unexported fields
}
func (DnsCacheConfig_builder) Build ¶
func (b0 DnsCacheConfig_builder) Build() *DnsCacheConfig
Source Files
¶
- dns_cache.pb.go