Documentation
¶
Index ¶
- Variables
- type Gzip
- func (x *Gzip) ClearChunkSize()
- func (x *Gzip) ClearMaxInflateRatio()
- func (x *Gzip) ClearWindowBits()
- func (x *Gzip) GetChunkSize() *wrapperspb.UInt32Value
- func (x *Gzip) GetMaxInflateRatio() *wrapperspb.UInt32Value
- func (x *Gzip) GetWindowBits() *wrapperspb.UInt32Value
- func (x *Gzip) HasChunkSize() bool
- func (x *Gzip) HasMaxInflateRatio() bool
- func (x *Gzip) HasWindowBits() bool
- func (*Gzip) ProtoMessage()
- func (x *Gzip) ProtoReflect() protoreflect.Message
- func (x *Gzip) Reset()
- func (x *Gzip) SetChunkSize(v *wrapperspb.UInt32Value)
- func (x *Gzip) SetMaxInflateRatio(v *wrapperspb.UInt32Value)
- func (x *Gzip) SetWindowBits(v *wrapperspb.UInt32Value)
- func (x *Gzip) String() string
- type Gzip_builder
Constants ¶
This section is empty.
Variables ¶
var File_envoy_extensions_compression_gzip_decompressor_v3_gzip_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Gzip ¶
type Gzip struct {
// Value from 9 to 15 that represents the base two logarithmic of the decompressor's window size.
// The decompression window size needs to be equal or larger than the compression window size.
// The default window size is 15.
// This is so that the decompressor can decompress a response compressed by a compressor with any compression window size.
// For more details about this parameter, please refer to `zlib manual <https://www.zlib.net/manual.html>`_ > inflateInit2.
WindowBits *wrapperspb.UInt32Value `protobuf:"bytes,1,opt,name=window_bits,json=windowBits,proto3" json:"window_bits,omitempty"`
// Value for zlib's decompressor output buffer. If not set, defaults to 4096.
// See https://www.zlib.net/manual.html for more details.
ChunkSize *wrapperspb.UInt32Value `protobuf:"bytes,2,opt,name=chunk_size,json=chunkSize,proto3" json:"chunk_size,omitempty"`
// An upper bound to the number of times the output buffer is allowed to be bigger than the size of
// the accumulated input. This value is used to prevent decompression bombs. If not set, defaults to 100.
// [#comment:TODO(rojkov): Re-design the Decompressor interface to handle compression bombs gracefully instead of this quick solution.
// See https://github.com/envoyproxy/envoy/commit/d4c39e635603e2f23e1e08ddecf5a5fb5a706338 for details.]
MaxInflateRatio *wrapperspb.UInt32Value `protobuf:"bytes,3,opt,name=max_inflate_ratio,json=maxInflateRatio,proto3" json:"max_inflate_ratio,omitempty"`
// contains filtered or unexported fields
}
func (*Gzip) GetChunkSize ¶
func (x *Gzip) GetChunkSize() *wrapperspb.UInt32Value
func (*Gzip) GetMaxInflateRatio ¶
func (x *Gzip) GetMaxInflateRatio() *wrapperspb.UInt32Value
func (*Gzip) GetWindowBits ¶
func (x *Gzip) GetWindowBits() *wrapperspb.UInt32Value
func (*Gzip) ProtoReflect ¶
func (x *Gzip) ProtoReflect() protoreflect.Message
func (*Gzip) SetChunkSize ¶
func (x *Gzip) SetChunkSize(v *wrapperspb.UInt32Value)
func (*Gzip) SetMaxInflateRatio ¶
func (x *Gzip) SetMaxInflateRatio(v *wrapperspb.UInt32Value)
func (*Gzip) SetWindowBits ¶
func (x *Gzip) SetWindowBits(v *wrapperspb.UInt32Value)
type Gzip_builder ¶
type Gzip_builder struct {
// Value from 9 to 15 that represents the base two logarithmic of the decompressor's window size.
// The decompression window size needs to be equal or larger than the compression window size.
// The default window size is 15.
// This is so that the decompressor can decompress a response compressed by a compressor with any compression window size.
// For more details about this parameter, please refer to `zlib manual <https://www.zlib.net/manual.html>`_ > inflateInit2.
WindowBits *wrapperspb.UInt32Value
// Value for zlib's decompressor output buffer. If not set, defaults to 4096.
// See https://www.zlib.net/manual.html for more details.
ChunkSize *wrapperspb.UInt32Value
// An upper bound to the number of times the output buffer is allowed to be bigger than the size of
// the accumulated input. This value is used to prevent decompression bombs. If not set, defaults to 100.
// [#comment:TODO(rojkov): Re-design the Decompressor interface to handle compression bombs gracefully instead of this quick solution.
// See https://github.com/envoyproxy/envoy/commit/d4c39e635603e2f23e1e08ddecf5a5fb5a706338 for details.]
MaxInflateRatio *wrapperspb.UInt32Value
// contains filtered or unexported fields
}
func (Gzip_builder) Build ¶
func (b0 Gzip_builder) Build() *Gzip
Source Files
¶
- gzip.pb.go
Click to show internal directories.
Click to hide internal directories.