Documentation
¶
Index ¶
- Variables
- type Zstd
- func (x *Zstd) ClearChunkSize()
- func (x *Zstd) GetChunkSize() *wrapperspb.UInt32Value
- func (x *Zstd) GetDictionaries() []*v3.DataSource
- func (x *Zstd) HasChunkSize() bool
- func (*Zstd) ProtoMessage()
- func (x *Zstd) ProtoReflect() protoreflect.Message
- func (x *Zstd) Reset()
- func (x *Zstd) SetChunkSize(v *wrapperspb.UInt32Value)
- func (x *Zstd) SetDictionaries(v []*v3.DataSource)
- func (x *Zstd) String() string
- type Zstd_builder
Constants ¶
This section is empty.
Variables ¶
var File_envoy_extensions_compression_zstd_decompressor_v3_zstd_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Zstd ¶
type Zstd struct {
// Dictionaries for decompression. Zstd offers dictionary compression, which greatly improves
// efficiency on small files and messages. It is necessary to ensure that the dictionary used for
// decompression is the same as the compression dictionary. Multiple dictionaries can be set, and the
// dictionary will be automatically selected for decompression according to the dictionary ID in the
// source content.
// Please refer to `zstd manual <https://github.com/facebook/zstd/blob/dev/programs/zstd.1.md#dictionary-builder>`_
// to train specific dictionaries for decompression.
Dictionaries []*v3.DataSource `protobuf:"bytes,1,rep,name=dictionaries,proto3" json:"dictionaries,omitempty"`
// Value for decompressor's next output buffer. If not set, defaults to 4096.
ChunkSize *wrapperspb.UInt32Value `protobuf:"bytes,2,opt,name=chunk_size,json=chunkSize,proto3" json:"chunk_size,omitempty"`
// contains filtered or unexported fields
}
func (*Zstd) GetChunkSize ¶
func (x *Zstd) GetChunkSize() *wrapperspb.UInt32Value
func (*Zstd) GetDictionaries ¶
func (x *Zstd) GetDictionaries() []*v3.DataSource
func (*Zstd) ProtoReflect ¶
func (x *Zstd) ProtoReflect() protoreflect.Message
func (*Zstd) SetChunkSize ¶
func (x *Zstd) SetChunkSize(v *wrapperspb.UInt32Value)
func (*Zstd) SetDictionaries ¶
func (x *Zstd) SetDictionaries(v []*v3.DataSource)
type Zstd_builder ¶
type Zstd_builder struct {
// Dictionaries for decompression. Zstd offers dictionary compression, which greatly improves
// efficiency on small files and messages. It is necessary to ensure that the dictionary used for
// decompression is the same as the compression dictionary. Multiple dictionaries can be set, and the
// dictionary will be automatically selected for decompression according to the dictionary ID in the
// source content.
// Please refer to `zstd manual <https://github.com/facebook/zstd/blob/dev/programs/zstd.1.md#dictionary-builder>`_
// to train specific dictionaries for decompression.
Dictionaries []*v3.DataSource
// Value for decompressor's next output buffer. If not set, defaults to 4096.
ChunkSize *wrapperspb.UInt32Value
// contains filtered or unexported fields
}
func (Zstd_builder) Build ¶
func (b0 Zstd_builder) Build() *Zstd
Source Files
¶
- zstd.pb.go
Click to show internal directories.
Click to hide internal directories.