Documentation
¶
Index ¶
- Variables
- type FilterConfig
- func (x *FilterConfig) ClearAlternateProtocolsCacheOptions()deprecated
- func (x *FilterConfig) GetAlternateProtocolsCacheOptions() *v3.AlternateProtocolsCacheOptionsdeprecated
- func (x *FilterConfig) HasAlternateProtocolsCacheOptions() booldeprecated
- func (*FilterConfig) ProtoMessage()
- func (x *FilterConfig) ProtoReflect() protoreflect.Message
- func (x *FilterConfig) Reset()
- func (x *FilterConfig) SetAlternateProtocolsCacheOptions(v *v3.AlternateProtocolsCacheOptions)deprecated
- func (x *FilterConfig) String() string
- type FilterConfig_builder
Constants ¶
This section is empty.
Variables ¶
var File_envoy_extensions_filters_http_alternate_protocols_cache_v3_alternate_protocols_cache_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type FilterConfig ¶
type FilterConfig struct {
// This field is ignored: the alternate protocols cache filter will use the
// cache for the cluster the request is routed to.
//
// Deprecated: Marked as deprecated in envoy/extensions/filters/http/alternate_protocols_cache/v3/alternate_protocols_cache.proto.
AlternateProtocolsCacheOptions *v3.AlternateProtocolsCacheOptions `` /* 155-byte string literal not displayed */
// contains filtered or unexported fields
}
Configuration for the alternate protocols cache HTTP filter. [#extension: envoy.filters.http.alternate_protocols_cache]
func (*FilterConfig) ClearAlternateProtocolsCacheOptions
deprecated
func (x *FilterConfig) ClearAlternateProtocolsCacheOptions()
Deprecated: Marked as deprecated in envoy/extensions/filters/http/alternate_protocols_cache/v3/alternate_protocols_cache.proto.
func (*FilterConfig) GetAlternateProtocolsCacheOptions
deprecated
func (x *FilterConfig) GetAlternateProtocolsCacheOptions() *v3.AlternateProtocolsCacheOptions
Deprecated: Marked as deprecated in envoy/extensions/filters/http/alternate_protocols_cache/v3/alternate_protocols_cache.proto.
func (*FilterConfig) HasAlternateProtocolsCacheOptions
deprecated
func (x *FilterConfig) HasAlternateProtocolsCacheOptions() bool
Deprecated: Marked as deprecated in envoy/extensions/filters/http/alternate_protocols_cache/v3/alternate_protocols_cache.proto.
func (*FilterConfig) ProtoMessage ¶
func (*FilterConfig) ProtoMessage()
func (*FilterConfig) ProtoReflect ¶
func (x *FilterConfig) ProtoReflect() protoreflect.Message
func (*FilterConfig) Reset ¶
func (x *FilterConfig) Reset()
func (*FilterConfig) SetAlternateProtocolsCacheOptions
deprecated
func (x *FilterConfig) SetAlternateProtocolsCacheOptions(v *v3.AlternateProtocolsCacheOptions)
Deprecated: Marked as deprecated in envoy/extensions/filters/http/alternate_protocols_cache/v3/alternate_protocols_cache.proto.
func (*FilterConfig) String ¶
func (x *FilterConfig) String() string
type FilterConfig_builder ¶
type FilterConfig_builder struct {
// This field is ignored: the alternate protocols cache filter will use the
// cache for the cluster the request is routed to.
//
// Deprecated: Marked as deprecated in envoy/extensions/filters/http/alternate_protocols_cache/v3/alternate_protocols_cache.proto.
AlternateProtocolsCacheOptions *v3.AlternateProtocolsCacheOptions
// contains filtered or unexported fields
}
func (FilterConfig_builder) Build ¶
func (b0 FilterConfig_builder) Build() *FilterConfig
Source Files
¶
- alternate_protocols_cache.pb.go
Click to show internal directories.
Click to hide internal directories.