Documentation
¶
Index ¶
- Variables
- type BandwidthLimit
- func (x *BandwidthLimit) ClearFillInterval()
- func (x *BandwidthLimit) ClearLimitKbps()
- func (x *BandwidthLimit) ClearRuntimeEnabled()
- func (x *BandwidthLimit) GetEnableMode() BandwidthLimit_EnableMode
- func (x *BandwidthLimit) GetEnableResponseTrailers() bool
- func (x *BandwidthLimit) GetFillInterval() *durationpb.Duration
- func (x *BandwidthLimit) GetLimitKbps() *wrapperspb.UInt64Value
- func (x *BandwidthLimit) GetResponseTrailerPrefix() string
- func (x *BandwidthLimit) GetRuntimeEnabled() *v3.RuntimeFeatureFlag
- func (x *BandwidthLimit) GetStatPrefix() string
- func (x *BandwidthLimit) HasFillInterval() bool
- func (x *BandwidthLimit) HasLimitKbps() bool
- func (x *BandwidthLimit) HasRuntimeEnabled() bool
- func (*BandwidthLimit) ProtoMessage()
- func (x *BandwidthLimit) ProtoReflect() protoreflect.Message
- func (x *BandwidthLimit) Reset()
- func (x *BandwidthLimit) SetEnableMode(v BandwidthLimit_EnableMode)
- func (x *BandwidthLimit) SetEnableResponseTrailers(v bool)
- func (x *BandwidthLimit) SetFillInterval(v *durationpb.Duration)
- func (x *BandwidthLimit) SetLimitKbps(v *wrapperspb.UInt64Value)
- func (x *BandwidthLimit) SetResponseTrailerPrefix(v string)
- func (x *BandwidthLimit) SetRuntimeEnabled(v *v3.RuntimeFeatureFlag)
- func (x *BandwidthLimit) SetStatPrefix(v string)
- func (x *BandwidthLimit) String() string
- type BandwidthLimit_EnableMode
- func (BandwidthLimit_EnableMode) Descriptor() protoreflect.EnumDescriptor
- func (x BandwidthLimit_EnableMode) Enum() *BandwidthLimit_EnableMode
- func (x BandwidthLimit_EnableMode) Number() protoreflect.EnumNumber
- func (x BandwidthLimit_EnableMode) String() string
- func (BandwidthLimit_EnableMode) Type() protoreflect.EnumType
- type BandwidthLimit_builder
Constants ¶
This section is empty.
Variables ¶
var ( BandwidthLimit_EnableMode_name = map[int32]string{ 0: "DISABLED", 1: "REQUEST", 2: "RESPONSE", 3: "REQUEST_AND_RESPONSE", } BandwidthLimit_EnableMode_value = map[string]int32{ "DISABLED": 0, "REQUEST": 1, "RESPONSE": 2, "REQUEST_AND_RESPONSE": 3, } )
Enum value maps for BandwidthLimit_EnableMode.
var File_envoy_extensions_filters_http_bandwidth_limit_v3_bandwidth_limit_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type BandwidthLimit ¶
type BandwidthLimit struct {
// The human readable prefix to use when emitting stats.
StatPrefix string `protobuf:"bytes,1,opt,name=stat_prefix,json=statPrefix,proto3" json:"stat_prefix,omitempty"`
// The enable mode for the bandwidth limit filter.
// Default is Disabled.
EnableMode BandwidthLimit_EnableMode `` /* 172-byte string literal not displayed */
// The limit supplied in KiB/s.
//
// .. note::
//
// It's fine for the limit to be unset for the global configuration since the bandwidth limit
// can be applied at a the virtual host or route level. Thus, the limit must be set for the
// per route configuration otherwise the config will be rejected.
//
// .. note::
//
// When using per route configuration, the limit becomes unique to that route.
LimitKbps *wrapperspb.UInt64Value `protobuf:"bytes,3,opt,name=limit_kbps,json=limitKbps,proto3" json:"limit_kbps,omitempty"`
// Optional Fill interval in milliseconds for the token refills. Defaults to 50ms.
// It must be at least 20ms to avoid too aggressive refills.
FillInterval *durationpb.Duration `protobuf:"bytes,4,opt,name=fill_interval,json=fillInterval,proto3" json:"fill_interval,omitempty"`
// Runtime flag that controls whether the filter is enabled or not. If not specified, defaults
// to enabled.
RuntimeEnabled *v3.RuntimeFeatureFlag `protobuf:"bytes,5,opt,name=runtime_enabled,json=runtimeEnabled,proto3" json:"runtime_enabled,omitempty"`
// Enable response trailers.
//
// .. note::
//
// If set true, the following 4 trailers will be added, prefixed by “response_trailer_prefix“:
// * bandwidth-request-delay-ms: delay time in milliseconds it took for the request stream transfer including request body transfer time and the time added by the filter.
// * bandwidth-response-delay-ms: delay time in milliseconds it took for the response stream transfer including response body transfer time and the time added by the filter.
// * bandwidth-request-filter-delay-ms: delay time in milliseconds in request stream transfer added by the filter.
// * bandwidth-response-filter-delay-ms: delay time in milliseconds that added by the filter.
// If :ref:`enable_mode <envoy_v3_api_field_extensions.filters.http.bandwidth_limit.v3.BandwidthLimit.enable_mode>` is “DISABLED“ or “REQUEST“, the trailers will not be set.
// If both the request and response delay time is 0, the trailers will not be set.
EnableResponseTrailers bool `` /* 130-byte string literal not displayed */
// Optional The prefix for the response trailers.
ResponseTrailerPrefix string `` /* 126-byte string literal not displayed */
// contains filtered or unexported fields
}
[#next-free-field: 8]
func (*BandwidthLimit) ClearFillInterval ¶
func (x *BandwidthLimit) ClearFillInterval()
func (*BandwidthLimit) ClearLimitKbps ¶
func (x *BandwidthLimit) ClearLimitKbps()
func (*BandwidthLimit) ClearRuntimeEnabled ¶
func (x *BandwidthLimit) ClearRuntimeEnabled()
func (*BandwidthLimit) GetEnableMode ¶
func (x *BandwidthLimit) GetEnableMode() BandwidthLimit_EnableMode
func (*BandwidthLimit) GetEnableResponseTrailers ¶
func (x *BandwidthLimit) GetEnableResponseTrailers() bool
func (*BandwidthLimit) GetFillInterval ¶
func (x *BandwidthLimit) GetFillInterval() *durationpb.Duration
func (*BandwidthLimit) GetLimitKbps ¶
func (x *BandwidthLimit) GetLimitKbps() *wrapperspb.UInt64Value
func (*BandwidthLimit) GetResponseTrailerPrefix ¶
func (x *BandwidthLimit) GetResponseTrailerPrefix() string
func (*BandwidthLimit) GetRuntimeEnabled ¶
func (x *BandwidthLimit) GetRuntimeEnabled() *v3.RuntimeFeatureFlag
func (*BandwidthLimit) GetStatPrefix ¶
func (x *BandwidthLimit) GetStatPrefix() string
func (*BandwidthLimit) HasFillInterval ¶
func (x *BandwidthLimit) HasFillInterval() bool
func (*BandwidthLimit) HasLimitKbps ¶
func (x *BandwidthLimit) HasLimitKbps() bool
func (*BandwidthLimit) HasRuntimeEnabled ¶
func (x *BandwidthLimit) HasRuntimeEnabled() bool
func (*BandwidthLimit) ProtoMessage ¶
func (*BandwidthLimit) ProtoMessage()
func (*BandwidthLimit) ProtoReflect ¶
func (x *BandwidthLimit) ProtoReflect() protoreflect.Message
func (*BandwidthLimit) Reset ¶
func (x *BandwidthLimit) Reset()
func (*BandwidthLimit) SetEnableMode ¶
func (x *BandwidthLimit) SetEnableMode(v BandwidthLimit_EnableMode)
func (*BandwidthLimit) SetEnableResponseTrailers ¶
func (x *BandwidthLimit) SetEnableResponseTrailers(v bool)
func (*BandwidthLimit) SetFillInterval ¶
func (x *BandwidthLimit) SetFillInterval(v *durationpb.Duration)
func (*BandwidthLimit) SetLimitKbps ¶
func (x *BandwidthLimit) SetLimitKbps(v *wrapperspb.UInt64Value)
func (*BandwidthLimit) SetResponseTrailerPrefix ¶
func (x *BandwidthLimit) SetResponseTrailerPrefix(v string)
func (*BandwidthLimit) SetRuntimeEnabled ¶
func (x *BandwidthLimit) SetRuntimeEnabled(v *v3.RuntimeFeatureFlag)
func (*BandwidthLimit) SetStatPrefix ¶
func (x *BandwidthLimit) SetStatPrefix(v string)
func (*BandwidthLimit) String ¶
func (x *BandwidthLimit) String() string
type BandwidthLimit_EnableMode ¶
type BandwidthLimit_EnableMode int32
Defines the mode for the bandwidth limit filter. Values represent bitmask.
const ( // Filter is disabled. BandwidthLimit_DISABLED BandwidthLimit_EnableMode = 0 // Filter enabled only for incoming traffic. BandwidthLimit_REQUEST BandwidthLimit_EnableMode = 1 // Filter enabled only for outgoing traffic. BandwidthLimit_RESPONSE BandwidthLimit_EnableMode = 2 // Filter enabled for both incoming and outgoing traffic. BandwidthLimit_REQUEST_AND_RESPONSE BandwidthLimit_EnableMode = 3 )
func (BandwidthLimit_EnableMode) Descriptor ¶
func (BandwidthLimit_EnableMode) Descriptor() protoreflect.EnumDescriptor
func (BandwidthLimit_EnableMode) Enum ¶
func (x BandwidthLimit_EnableMode) Enum() *BandwidthLimit_EnableMode
func (BandwidthLimit_EnableMode) Number ¶
func (x BandwidthLimit_EnableMode) Number() protoreflect.EnumNumber
func (BandwidthLimit_EnableMode) String ¶
func (x BandwidthLimit_EnableMode) String() string
func (BandwidthLimit_EnableMode) Type ¶
func (BandwidthLimit_EnableMode) Type() protoreflect.EnumType
type BandwidthLimit_builder ¶
type BandwidthLimit_builder struct {
// The human readable prefix to use when emitting stats.
StatPrefix string
// The enable mode for the bandwidth limit filter.
// Default is Disabled.
EnableMode BandwidthLimit_EnableMode
// The limit supplied in KiB/s.
//
// .. note::
//
// It's fine for the limit to be unset for the global configuration since the bandwidth limit
// can be applied at a the virtual host or route level. Thus, the limit must be set for the
// per route configuration otherwise the config will be rejected.
//
// .. note::
//
// When using per route configuration, the limit becomes unique to that route.
LimitKbps *wrapperspb.UInt64Value
// Optional Fill interval in milliseconds for the token refills. Defaults to 50ms.
// It must be at least 20ms to avoid too aggressive refills.
FillInterval *durationpb.Duration
// Runtime flag that controls whether the filter is enabled or not. If not specified, defaults
// to enabled.
RuntimeEnabled *v3.RuntimeFeatureFlag
// Enable response trailers.
//
// .. note::
//
// If set true, the following 4 trailers will be added, prefixed by “response_trailer_prefix“:
// * bandwidth-request-delay-ms: delay time in milliseconds it took for the request stream transfer including request body transfer time and the time added by the filter.
// * bandwidth-response-delay-ms: delay time in milliseconds it took for the response stream transfer including response body transfer time and the time added by the filter.
// * bandwidth-request-filter-delay-ms: delay time in milliseconds in request stream transfer added by the filter.
// * bandwidth-response-filter-delay-ms: delay time in milliseconds that added by the filter.
// If :ref:`enable_mode <envoy_v3_api_field_extensions.filters.http.bandwidth_limit.v3.BandwidthLimit.enable_mode>` is “DISABLED“ or “REQUEST“, the trailers will not be set.
// If both the request and response delay time is 0, the trailers will not be set.
EnableResponseTrailers bool
// Optional The prefix for the response trailers.
ResponseTrailerPrefix string
// contains filtered or unexported fields
}
func (BandwidthLimit_builder) Build ¶
func (b0 BandwidthLimit_builder) Build() *BandwidthLimit
Source Files
¶
- bandwidth_limit.pb.go
Click to show internal directories.
Click to hide internal directories.