Documentation
¶
Index ¶
- Variables
- type CdnLoopConfig
- func (x *CdnLoopConfig) GetCdnId() string
- func (x *CdnLoopConfig) GetMaxAllowedOccurrences() uint32
- func (*CdnLoopConfig) ProtoMessage()
- func (x *CdnLoopConfig) ProtoReflect() protoreflect.Message
- func (x *CdnLoopConfig) Reset()
- func (x *CdnLoopConfig) SetCdnId(v string)
- func (x *CdnLoopConfig) SetMaxAllowedOccurrences(v uint32)
- func (x *CdnLoopConfig) String() string
- type CdnLoopConfig_builder
Constants ¶
This section is empty.
Variables ¶
var File_envoy_extensions_filters_http_cdn_loop_v3_cdn_loop_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type CdnLoopConfig ¶
type CdnLoopConfig struct {
// The CDN identifier to use for loop checks and to append to the
// CDN-Loop header.
//
// RFC 8586 calls this the cdn-id. The cdn-id can either be a
// pseudonym or hostname the CDN is in control of.
//
// cdn_id must not be empty.
CdnId string `protobuf:"bytes,1,opt,name=cdn_id,json=cdnId,proto3" json:"cdn_id,omitempty"`
// The maximum allowed count of cdn_id in the downstream CDN-Loop
// request header.
//
// The default of 0 means a request can transit the CdnLoopFilter
// once. A value of 1 means that a request can transit the
// CdnLoopFilter twice and so on.
MaxAllowedOccurrences uint32 `` /* 127-byte string literal not displayed */
// contains filtered or unexported fields
}
CDN-Loop Header filter config. See the :ref:`configuration overview <config_http_filters_cdn_loop>` for more information.
func (*CdnLoopConfig) GetCdnId ¶
func (x *CdnLoopConfig) GetCdnId() string
func (*CdnLoopConfig) GetMaxAllowedOccurrences ¶
func (x *CdnLoopConfig) GetMaxAllowedOccurrences() uint32
func (*CdnLoopConfig) ProtoMessage ¶
func (*CdnLoopConfig) ProtoMessage()
func (*CdnLoopConfig) ProtoReflect ¶
func (x *CdnLoopConfig) ProtoReflect() protoreflect.Message
func (*CdnLoopConfig) Reset ¶
func (x *CdnLoopConfig) Reset()
func (*CdnLoopConfig) SetCdnId ¶
func (x *CdnLoopConfig) SetCdnId(v string)
func (*CdnLoopConfig) SetMaxAllowedOccurrences ¶
func (x *CdnLoopConfig) SetMaxAllowedOccurrences(v uint32)
func (*CdnLoopConfig) String ¶
func (x *CdnLoopConfig) String() string
type CdnLoopConfig_builder ¶
type CdnLoopConfig_builder struct {
// The CDN identifier to use for loop checks and to append to the
// CDN-Loop header.
//
// RFC 8586 calls this the cdn-id. The cdn-id can either be a
// pseudonym or hostname the CDN is in control of.
//
// cdn_id must not be empty.
CdnId string
// The maximum allowed count of cdn_id in the downstream CDN-Loop
// request header.
//
// The default of 0 means a request can transit the CdnLoopFilter
// once. A value of 1 means that a request can transit the
// CdnLoopFilter twice and so on.
MaxAllowedOccurrences uint32
// contains filtered or unexported fields
}
func (CdnLoopConfig_builder) Build ¶
func (b0 CdnLoopConfig_builder) Build() *CdnLoopConfig
Source Files
¶
- cdn_loop.pb.go
Click to show internal directories.
Click to hide internal directories.