Documentation
¶
Index ¶
- Variables
- type CsrfPolicy
- func (x *CsrfPolicy) ClearFilterEnabled()
- func (x *CsrfPolicy) ClearShadowEnabled()
- func (x *CsrfPolicy) GetAdditionalOrigins() []*v31.StringMatcher
- func (x *CsrfPolicy) GetFilterEnabled() *v3.RuntimeFractionalPercent
- func (x *CsrfPolicy) GetShadowEnabled() *v3.RuntimeFractionalPercent
- func (x *CsrfPolicy) HasFilterEnabled() bool
- func (x *CsrfPolicy) HasShadowEnabled() bool
- func (*CsrfPolicy) ProtoMessage()
- func (x *CsrfPolicy) ProtoReflect() protoreflect.Message
- func (x *CsrfPolicy) Reset()
- func (x *CsrfPolicy) SetAdditionalOrigins(v []*v31.StringMatcher)
- func (x *CsrfPolicy) SetFilterEnabled(v *v3.RuntimeFractionalPercent)
- func (x *CsrfPolicy) SetShadowEnabled(v *v3.RuntimeFractionalPercent)
- func (x *CsrfPolicy) String() string
- type CsrfPolicy_builder
Constants ¶
This section is empty.
Variables ¶
var File_envoy_extensions_filters_http_csrf_v3_csrf_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type CsrfPolicy ¶
type CsrfPolicy struct {
// Specifies the % of requests for which the CSRF filter is enabled.
//
// If :ref:`runtime_key <envoy_v3_api_field_config.core.v3.RuntimeFractionalPercent.runtime_key>` is specified,
// Envoy will lookup the runtime key to get the percentage of requests to filter.
//
// .. note::
//
// This field defaults to 100/:ref:`HUNDRED
// <envoy_v3_api_enum_type.v3.FractionalPercent.DenominatorType>`.
FilterEnabled *v3.RuntimeFractionalPercent `protobuf:"bytes,1,opt,name=filter_enabled,json=filterEnabled,proto3" json:"filter_enabled,omitempty"`
// Specifies that CSRF policies will be evaluated and tracked, but not enforced.
//
// This is intended to be used when “filter_enabled“ is off and will be ignored otherwise.
//
// If :ref:`runtime_key <envoy_v3_api_field_config.core.v3.RuntimeFractionalPercent.runtime_key>` is specified,
// Envoy will lookup the runtime key to get the percentage of requests for which it will evaluate
// and track the request's “Origin“ and “Destination“ to determine if it's valid, but will not
// enforce any policies.
ShadowEnabled *v3.RuntimeFractionalPercent `protobuf:"bytes,2,opt,name=shadow_enabled,json=shadowEnabled,proto3" json:"shadow_enabled,omitempty"`
// Specifies additional source origins that will be allowed in addition to
// the destination origin.
//
// More information on how this can be configured via runtime can be found
// :ref:`here <csrf-configuration>`.
AdditionalOrigins []*v31.StringMatcher `protobuf:"bytes,3,rep,name=additional_origins,json=additionalOrigins,proto3" json:"additional_origins,omitempty"`
// contains filtered or unexported fields
}
CSRF filter config.
func (*CsrfPolicy) ClearFilterEnabled ¶
func (x *CsrfPolicy) ClearFilterEnabled()
func (*CsrfPolicy) ClearShadowEnabled ¶
func (x *CsrfPolicy) ClearShadowEnabled()
func (*CsrfPolicy) GetAdditionalOrigins ¶
func (x *CsrfPolicy) GetAdditionalOrigins() []*v31.StringMatcher
func (*CsrfPolicy) GetFilterEnabled ¶
func (x *CsrfPolicy) GetFilterEnabled() *v3.RuntimeFractionalPercent
func (*CsrfPolicy) GetShadowEnabled ¶
func (x *CsrfPolicy) GetShadowEnabled() *v3.RuntimeFractionalPercent
func (*CsrfPolicy) HasFilterEnabled ¶
func (x *CsrfPolicy) HasFilterEnabled() bool
func (*CsrfPolicy) HasShadowEnabled ¶
func (x *CsrfPolicy) HasShadowEnabled() bool
func (*CsrfPolicy) ProtoMessage ¶
func (*CsrfPolicy) ProtoMessage()
func (*CsrfPolicy) ProtoReflect ¶
func (x *CsrfPolicy) ProtoReflect() protoreflect.Message
func (*CsrfPolicy) Reset ¶
func (x *CsrfPolicy) Reset()
func (*CsrfPolicy) SetAdditionalOrigins ¶
func (x *CsrfPolicy) SetAdditionalOrigins(v []*v31.StringMatcher)
func (*CsrfPolicy) SetFilterEnabled ¶
func (x *CsrfPolicy) SetFilterEnabled(v *v3.RuntimeFractionalPercent)
func (*CsrfPolicy) SetShadowEnabled ¶
func (x *CsrfPolicy) SetShadowEnabled(v *v3.RuntimeFractionalPercent)
func (*CsrfPolicy) String ¶
func (x *CsrfPolicy) String() string
type CsrfPolicy_builder ¶
type CsrfPolicy_builder struct {
// Specifies the % of requests for which the CSRF filter is enabled.
//
// If :ref:`runtime_key <envoy_v3_api_field_config.core.v3.RuntimeFractionalPercent.runtime_key>` is specified,
// Envoy will lookup the runtime key to get the percentage of requests to filter.
//
// .. note::
//
// This field defaults to 100/:ref:`HUNDRED
// <envoy_v3_api_enum_type.v3.FractionalPercent.DenominatorType>`.
FilterEnabled *v3.RuntimeFractionalPercent
// Specifies that CSRF policies will be evaluated and tracked, but not enforced.
//
// This is intended to be used when “filter_enabled“ is off and will be ignored otherwise.
//
// If :ref:`runtime_key <envoy_v3_api_field_config.core.v3.RuntimeFractionalPercent.runtime_key>` is specified,
// Envoy will lookup the runtime key to get the percentage of requests for which it will evaluate
// and track the request's “Origin“ and “Destination“ to determine if it's valid, but will not
// enforce any policies.
ShadowEnabled *v3.RuntimeFractionalPercent
// Specifies additional source origins that will be allowed in addition to
// the destination origin.
//
// More information on how this can be configured via runtime can be found
// :ref:`here <csrf-configuration>`.
AdditionalOrigins []*v31.StringMatcher
// contains filtered or unexported fields
}
func (CsrfPolicy_builder) Build ¶
func (b0 CsrfPolicy_builder) Build() *CsrfPolicy
Source Files
¶
- csrf.pb.go
Click to show internal directories.
Click to hide internal directories.