Documentation
¶
Index ¶
- Constants
- Variables
- type FilterConfig
- func (x *FilterConfig) ClearDnsCacheConfig()
- func (x *FilterConfig) ClearImplementationSpecifier()
- func (x *FilterConfig) ClearSubClusterConfig()
- func (x *FilterConfig) GetAllowDynamicHostFromFilterState() bool
- func (x *FilterConfig) GetDnsCacheConfig() *v3.DnsCacheConfig
- func (x *FilterConfig) GetImplementationSpecifier() isFilterConfig_ImplementationSpecifier
- func (x *FilterConfig) GetSaveUpstreamAddress() bool
- func (x *FilterConfig) GetSubClusterConfig() *SubClusterConfig
- func (x *FilterConfig) HasDnsCacheConfig() bool
- func (x *FilterConfig) HasImplementationSpecifier() bool
- func (x *FilterConfig) HasSubClusterConfig() bool
- func (*FilterConfig) ProtoMessage()
- func (x *FilterConfig) ProtoReflect() protoreflect.Message
- func (x *FilterConfig) Reset()
- func (x *FilterConfig) SetAllowDynamicHostFromFilterState(v bool)
- func (x *FilterConfig) SetDnsCacheConfig(v *v3.DnsCacheConfig)
- func (x *FilterConfig) SetSaveUpstreamAddress(v bool)
- func (x *FilterConfig) SetSubClusterConfig(v *SubClusterConfig)
- func (x *FilterConfig) String() string
- func (x *FilterConfig) WhichImplementationSpecifier() case_FilterConfig_ImplementationSpecifier
- type FilterConfig_DnsCacheConfig
- type FilterConfig_SubClusterConfig
- type FilterConfig_builder
- type PerRouteConfig
- func (x *PerRouteConfig) ClearHostRewriteHeader()
- func (x *PerRouteConfig) ClearHostRewriteLiteral()
- func (x *PerRouteConfig) ClearHostRewriteSpecifier()
- func (x *PerRouteConfig) GetHostRewriteHeader() string
- func (x *PerRouteConfig) GetHostRewriteLiteral() string
- func (x *PerRouteConfig) GetHostRewriteSpecifier() isPerRouteConfig_HostRewriteSpecifier
- func (x *PerRouteConfig) HasHostRewriteHeader() bool
- func (x *PerRouteConfig) HasHostRewriteLiteral() bool
- func (x *PerRouteConfig) HasHostRewriteSpecifier() bool
- func (*PerRouteConfig) ProtoMessage()
- func (x *PerRouteConfig) ProtoReflect() protoreflect.Message
- func (x *PerRouteConfig) Reset()
- func (x *PerRouteConfig) SetHostRewriteHeader(v string)
- func (x *PerRouteConfig) SetHostRewriteLiteral(v string)
- func (x *PerRouteConfig) String() string
- func (x *PerRouteConfig) WhichHostRewriteSpecifier() case_PerRouteConfig_HostRewriteSpecifier
- type PerRouteConfig_HostRewriteHeader
- type PerRouteConfig_HostRewriteLiteral
- type PerRouteConfig_builder
- type SubClusterConfig
- func (x *SubClusterConfig) ClearClusterInitTimeout()
- func (x *SubClusterConfig) GetClusterInitTimeout() *durationpb.Duration
- func (x *SubClusterConfig) HasClusterInitTimeout() bool
- func (*SubClusterConfig) ProtoMessage()
- func (x *SubClusterConfig) ProtoReflect() protoreflect.Message
- func (x *SubClusterConfig) Reset()
- func (x *SubClusterConfig) SetClusterInitTimeout(v *durationpb.Duration)
- func (x *SubClusterConfig) String() string
- type SubClusterConfig_builder
Constants ¶
const FilterConfig_DnsCacheConfig_case case_FilterConfig_ImplementationSpecifier = 1
const FilterConfig_ImplementationSpecifier_not_set_case case_FilterConfig_ImplementationSpecifier = 0
const FilterConfig_SubClusterConfig_case case_FilterConfig_ImplementationSpecifier = 3
const PerRouteConfig_HostRewriteHeader_case case_PerRouteConfig_HostRewriteSpecifier = 2
const PerRouteConfig_HostRewriteLiteral_case case_PerRouteConfig_HostRewriteSpecifier = 1
const PerRouteConfig_HostRewriteSpecifier_not_set_case case_PerRouteConfig_HostRewriteSpecifier = 0
Variables ¶
var File_envoy_extensions_filters_http_dynamic_forward_proxy_v3_dynamic_forward_proxy_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type FilterConfig ¶
type FilterConfig struct {
// Types that are valid to be assigned to ImplementationSpecifier:
//
// *FilterConfig_DnsCacheConfig
// *FilterConfig_SubClusterConfig
ImplementationSpecifier isFilterConfig_ImplementationSpecifier `protobuf_oneof:"implementation_specifier"`
// When this flag is set, the filter will add the resolved upstream address in the filter
// state. The state should be saved with key
// “envoy.stream.upstream_address“ (See
// :repo:`upstream_address.h<source/common/stream_info/upstream_address.h>`).
SaveUpstreamAddress bool `protobuf:"varint,2,opt,name=save_upstream_address,json=saveUpstreamAddress,proto3" json:"save_upstream_address,omitempty"`
// When this flag is set, the filter will check for the “envoy.upstream.dynamic_host“
// and/or “envoy.upstream.dynamic_port“ filter state values before using the HTTP
// Host header for DNS resolution. This provides consistency with the
// :ref:`SNI dynamic forward proxy <envoy_v3_api_msg_extensions.filters.network.sni_dynamic_forward_proxy.v3.FilterConfig>` and
// :ref:`UDP dynamic forward proxy <envoy_v3_api_msg_extensions.filters.udp.udp_proxy.session.dynamic_forward_proxy.v3.FilterConfig>`
// filters behavior when enabled.
//
// If the flag is not set (default), the filter will use the HTTP Host header
// for DNS resolution, maintaining backward compatibility.
AllowDynamicHostFromFilterState bool `` /* 163-byte string literal not displayed */
// contains filtered or unexported fields
}
Configuration for the dynamic forward proxy HTTP filter. See the :ref:`architecture overview <arch_overview_http_dynamic_forward_proxy>` for more information. [#extension: envoy.filters.http.dynamic_forward_proxy]
func (*FilterConfig) ClearDnsCacheConfig ¶
func (x *FilterConfig) ClearDnsCacheConfig()
func (*FilterConfig) ClearImplementationSpecifier ¶
func (x *FilterConfig) ClearImplementationSpecifier()
func (*FilterConfig) ClearSubClusterConfig ¶
func (x *FilterConfig) ClearSubClusterConfig()
func (*FilterConfig) GetAllowDynamicHostFromFilterState ¶
func (x *FilterConfig) GetAllowDynamicHostFromFilterState() bool
func (*FilterConfig) GetDnsCacheConfig ¶
func (x *FilterConfig) GetDnsCacheConfig() *v3.DnsCacheConfig
func (*FilterConfig) GetImplementationSpecifier ¶
func (x *FilterConfig) GetImplementationSpecifier() isFilterConfig_ImplementationSpecifier
func (*FilterConfig) GetSaveUpstreamAddress ¶
func (x *FilterConfig) GetSaveUpstreamAddress() bool
func (*FilterConfig) GetSubClusterConfig ¶
func (x *FilterConfig) GetSubClusterConfig() *SubClusterConfig
func (*FilterConfig) HasDnsCacheConfig ¶
func (x *FilterConfig) HasDnsCacheConfig() bool
func (*FilterConfig) HasImplementationSpecifier ¶
func (x *FilterConfig) HasImplementationSpecifier() bool
func (*FilterConfig) HasSubClusterConfig ¶
func (x *FilterConfig) HasSubClusterConfig() bool
func (*FilterConfig) ProtoMessage ¶
func (*FilterConfig) ProtoMessage()
func (*FilterConfig) ProtoReflect ¶
func (x *FilterConfig) ProtoReflect() protoreflect.Message
func (*FilterConfig) Reset ¶
func (x *FilterConfig) Reset()
func (*FilterConfig) SetAllowDynamicHostFromFilterState ¶
func (x *FilterConfig) SetAllowDynamicHostFromFilterState(v bool)
func (*FilterConfig) SetDnsCacheConfig ¶
func (x *FilterConfig) SetDnsCacheConfig(v *v3.DnsCacheConfig)
func (*FilterConfig) SetSaveUpstreamAddress ¶
func (x *FilterConfig) SetSaveUpstreamAddress(v bool)
func (*FilterConfig) SetSubClusterConfig ¶
func (x *FilterConfig) SetSubClusterConfig(v *SubClusterConfig)
func (*FilterConfig) String ¶
func (x *FilterConfig) String() string
func (*FilterConfig) WhichImplementationSpecifier ¶
func (x *FilterConfig) WhichImplementationSpecifier() case_FilterConfig_ImplementationSpecifier
type FilterConfig_DnsCacheConfig ¶
type FilterConfig_DnsCacheConfig struct {
// The DNS cache configuration that the filter will attach to. Note this configuration must
// match that of associated :ref:`dynamic forward proxy cluster configuration
// <envoy_v3_api_field_extensions.clusters.dynamic_forward_proxy.v3.ClusterConfig.dns_cache_config>`.
DnsCacheConfig *v3.DnsCacheConfig `protobuf:"bytes,1,opt,name=dns_cache_config,json=dnsCacheConfig,proto3,oneof"`
}
type FilterConfig_SubClusterConfig ¶
type FilterConfig_SubClusterConfig struct {
// The configuration that the filter will use, when the related dynamic forward proxy cluster enabled
// sub clusters.
SubClusterConfig *SubClusterConfig `protobuf:"bytes,3,opt,name=sub_cluster_config,json=subClusterConfig,proto3,oneof"`
}
type FilterConfig_builder ¶
type FilterConfig_builder struct {
// Fields of oneof ImplementationSpecifier:
// The DNS cache configuration that the filter will attach to. Note this configuration must
// match that of associated :ref:`dynamic forward proxy cluster configuration
// <envoy_v3_api_field_extensions.clusters.dynamic_forward_proxy.v3.ClusterConfig.dns_cache_config>`.
DnsCacheConfig *v3.DnsCacheConfig
// The configuration that the filter will use, when the related dynamic forward proxy cluster enabled
// sub clusters.
SubClusterConfig *SubClusterConfig
// -- end of ImplementationSpecifier
// When this flag is set, the filter will add the resolved upstream address in the filter
// state. The state should be saved with key
// “envoy.stream.upstream_address“ (See
// :repo:`upstream_address.h<source/common/stream_info/upstream_address.h>`).
SaveUpstreamAddress bool
// When this flag is set, the filter will check for the “envoy.upstream.dynamic_host“
// and/or “envoy.upstream.dynamic_port“ filter state values before using the HTTP
// Host header for DNS resolution. This provides consistency with the
// :ref:`SNI dynamic forward proxy <envoy_v3_api_msg_extensions.filters.network.sni_dynamic_forward_proxy.v3.FilterConfig>` and
// :ref:`UDP dynamic forward proxy <envoy_v3_api_msg_extensions.filters.udp.udp_proxy.session.dynamic_forward_proxy.v3.FilterConfig>`
// filters behavior when enabled.
//
// If the flag is not set (default), the filter will use the HTTP Host header
// for DNS resolution, maintaining backward compatibility.
AllowDynamicHostFromFilterState bool
// contains filtered or unexported fields
}
func (FilterConfig_builder) Build ¶
func (b0 FilterConfig_builder) Build() *FilterConfig
type PerRouteConfig ¶
type PerRouteConfig struct {
// Types that are valid to be assigned to HostRewriteSpecifier:
//
// *PerRouteConfig_HostRewriteLiteral
// *PerRouteConfig_HostRewriteHeader
HostRewriteSpecifier isPerRouteConfig_HostRewriteSpecifier `protobuf_oneof:"host_rewrite_specifier"`
// contains filtered or unexported fields
}
Per route Configuration for the dynamic forward proxy HTTP filter.
func (*PerRouteConfig) ClearHostRewriteHeader ¶
func (x *PerRouteConfig) ClearHostRewriteHeader()
func (*PerRouteConfig) ClearHostRewriteLiteral ¶
func (x *PerRouteConfig) ClearHostRewriteLiteral()
func (*PerRouteConfig) ClearHostRewriteSpecifier ¶
func (x *PerRouteConfig) ClearHostRewriteSpecifier()
func (*PerRouteConfig) GetHostRewriteHeader ¶
func (x *PerRouteConfig) GetHostRewriteHeader() string
func (*PerRouteConfig) GetHostRewriteLiteral ¶
func (x *PerRouteConfig) GetHostRewriteLiteral() string
func (*PerRouteConfig) GetHostRewriteSpecifier ¶
func (x *PerRouteConfig) GetHostRewriteSpecifier() isPerRouteConfig_HostRewriteSpecifier
func (*PerRouteConfig) HasHostRewriteHeader ¶
func (x *PerRouteConfig) HasHostRewriteHeader() bool
func (*PerRouteConfig) HasHostRewriteLiteral ¶
func (x *PerRouteConfig) HasHostRewriteLiteral() bool
func (*PerRouteConfig) HasHostRewriteSpecifier ¶
func (x *PerRouteConfig) HasHostRewriteSpecifier() bool
func (*PerRouteConfig) ProtoMessage ¶
func (*PerRouteConfig) ProtoMessage()
func (*PerRouteConfig) ProtoReflect ¶
func (x *PerRouteConfig) ProtoReflect() protoreflect.Message
func (*PerRouteConfig) Reset ¶
func (x *PerRouteConfig) Reset()
func (*PerRouteConfig) SetHostRewriteHeader ¶
func (x *PerRouteConfig) SetHostRewriteHeader(v string)
func (*PerRouteConfig) SetHostRewriteLiteral ¶
func (x *PerRouteConfig) SetHostRewriteLiteral(v string)
func (*PerRouteConfig) String ¶
func (x *PerRouteConfig) String() string
func (*PerRouteConfig) WhichHostRewriteSpecifier ¶
func (x *PerRouteConfig) WhichHostRewriteSpecifier() case_PerRouteConfig_HostRewriteSpecifier
type PerRouteConfig_HostRewriteHeader ¶
type PerRouteConfig_HostRewriteHeader struct {
// Indicates that before DNS lookup, the host header will be swapped with
// the value of this header. If not set or empty, the original host header
// value will be used and no rewrite will happen.
//
// .. note::
//
// This rewrite affects both DNS lookup and host header forwarding. However, this option shouldn't be used with
// :ref:`HCM host rewrite header <envoy_v3_api_field_config.route.v3.RouteAction.auto_host_rewrite>` given that
// the value set here would be used for DNS lookups whereas the value set in the HCM would be used for host
// header forwarding which might not be the desired outcome.
//
// .. note::
//
// If the header appears multiple times only the first value is used.
HostRewriteHeader string `protobuf:"bytes,2,opt,name=host_rewrite_header,json=hostRewriteHeader,proto3,oneof"`
}
type PerRouteConfig_HostRewriteLiteral ¶
type PerRouteConfig_HostRewriteLiteral struct {
// Indicates that before DNS lookup, the host header will be swapped with
// this value. If not set or empty, the original host header value
// will be used and no rewrite will happen.
//
// .. note::
//
// This rewrite affects both DNS lookup and host header forwarding. However, this option shouldn't be used with
// :ref:`HCM host rewrite header <envoy_v3_api_field_config.route.v3.RouteAction.auto_host_rewrite>` given that
// the value set here would be used for DNS lookups whereas the value set in the HCM would be used for host
// header forwarding which might not be the desired outcome.
HostRewriteLiteral string `protobuf:"bytes,1,opt,name=host_rewrite_literal,json=hostRewriteLiteral,proto3,oneof"`
}
type PerRouteConfig_builder ¶
type PerRouteConfig_builder struct {
// Fields of oneof HostRewriteSpecifier:
// Indicates that before DNS lookup, the host header will be swapped with
// this value. If not set or empty, the original host header value
// will be used and no rewrite will happen.
//
// .. note::
//
// This rewrite affects both DNS lookup and host header forwarding. However, this option shouldn't be used with
// :ref:`HCM host rewrite header <envoy_v3_api_field_config.route.v3.RouteAction.auto_host_rewrite>` given that
// the value set here would be used for DNS lookups whereas the value set in the HCM would be used for host
// header forwarding which might not be the desired outcome.
HostRewriteLiteral *string
// Indicates that before DNS lookup, the host header will be swapped with
// the value of this header. If not set or empty, the original host header
// value will be used and no rewrite will happen.
//
// .. note::
//
// This rewrite affects both DNS lookup and host header forwarding. However, this option shouldn't be used with
// :ref:`HCM host rewrite header <envoy_v3_api_field_config.route.v3.RouteAction.auto_host_rewrite>` given that
// the value set here would be used for DNS lookups whereas the value set in the HCM would be used for host
// header forwarding which might not be the desired outcome.
//
// .. note::
//
// If the header appears multiple times only the first value is used.
HostRewriteHeader *string
// contains filtered or unexported fields
}
func (PerRouteConfig_builder) Build ¶
func (b0 PerRouteConfig_builder) Build() *PerRouteConfig
type SubClusterConfig ¶
type SubClusterConfig struct {
// The timeout used for sub cluster initialization. Defaults to **5s** if not set.
ClusterInitTimeout *durationpb.Duration `protobuf:"bytes,3,opt,name=cluster_init_timeout,json=clusterInitTimeout,proto3" json:"cluster_init_timeout,omitempty"`
// contains filtered or unexported fields
}
func (*SubClusterConfig) ClearClusterInitTimeout ¶
func (x *SubClusterConfig) ClearClusterInitTimeout()
func (*SubClusterConfig) GetClusterInitTimeout ¶
func (x *SubClusterConfig) GetClusterInitTimeout() *durationpb.Duration
func (*SubClusterConfig) HasClusterInitTimeout ¶
func (x *SubClusterConfig) HasClusterInitTimeout() bool
func (*SubClusterConfig) ProtoMessage ¶
func (*SubClusterConfig) ProtoMessage()
func (*SubClusterConfig) ProtoReflect ¶
func (x *SubClusterConfig) ProtoReflect() protoreflect.Message
func (*SubClusterConfig) Reset ¶
func (x *SubClusterConfig) Reset()
func (*SubClusterConfig) SetClusterInitTimeout ¶
func (x *SubClusterConfig) SetClusterInitTimeout(v *durationpb.Duration)
func (*SubClusterConfig) String ¶
func (x *SubClusterConfig) String() string
type SubClusterConfig_builder ¶
type SubClusterConfig_builder struct {
// The timeout used for sub cluster initialization. Defaults to **5s** if not set.
ClusterInitTimeout *durationpb.Duration
// contains filtered or unexported fields
}
func (SubClusterConfig_builder) Build ¶
func (b0 SubClusterConfig_builder) Build() *SubClusterConfig
Source Files
¶
- dynamic_forward_proxy.pb.go
Click to show internal directories.
Click to hide internal directories.