Documentation
¶
Index ¶
- Variables
- type FilterConfig
- func (x *FilterConfig) GetContentType() string
- func (x *FilterConfig) GetResponseSizeHeader() string
- func (x *FilterConfig) GetWithholdGrpcFrames() bool
- func (*FilterConfig) ProtoMessage()
- func (x *FilterConfig) ProtoReflect() protoreflect.Message
- func (x *FilterConfig) Reset()
- func (x *FilterConfig) SetContentType(v string)
- func (x *FilterConfig) SetResponseSizeHeader(v string)
- func (x *FilterConfig) SetWithholdGrpcFrames(v bool)
- func (x *FilterConfig) String() string
- type FilterConfigPerRoute
- type FilterConfigPerRoute_builder
- type FilterConfig_builder
Constants ¶
This section is empty.
Variables ¶
var File_envoy_extensions_filters_http_grpc_http1_reverse_bridge_v3_config_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type FilterConfig ¶
type FilterConfig struct {
// The content-type to pass to the upstream when the gRPC bridge filter is applied.
// The filter will also validate that the upstream responds with the same content type.
ContentType string `protobuf:"bytes,1,opt,name=content_type,json=contentType,proto3" json:"content_type,omitempty"`
// If true, Envoy will assume that the upstream doesn't understand gRPC frames and
// strip the gRPC frame from the request, and add it back in to the response. This will
// hide the gRPC semantics from the upstream, allowing it to receive and respond with a
// simple binary encoded protobuf. In order to calculate the “Content-Length“ header value, Envoy
// will buffer the upstream response unless :ref:`response_size_header
// <envoy_v3_api_field_extensions.filters.http.grpc_http1_reverse_bridge.v3.FilterConfig.response_size_header>`
// is set, in which case Envoy will use the value of an upstream header to calculate the content
// length.
WithholdGrpcFrames bool `protobuf:"varint,2,opt,name=withhold_grpc_frames,json=withholdGrpcFrames,proto3" json:"withhold_grpc_frames,omitempty"`
// When :ref:`withhold_grpc_frames
// <envoy_v3_api_field_extensions.filters.http.grpc_http1_reverse_bridge.v3.FilterConfig.withhold_grpc_frames>`
// is true, this option controls how Envoy calculates the “Content-Length“. When
// “response_size_header“ is empty, Envoy will buffer the upstream response to calculate its
// size. When “response_size_header“ is set to a non-empty string, Envoy will stream the response
// to the downstream and it will use the value of the response header with this name to set the
// “Content-Length“ header and gRPC frame size. If the header with this name is repeated, only
// the first value will be used.
//
// Envoy will treat the upstream response as an error if this option is specified and the header
// is missing or if the value does not match the actual response body size.
ResponseSizeHeader string `protobuf:"bytes,3,opt,name=response_size_header,json=responseSizeHeader,proto3" json:"response_size_header,omitempty"`
// contains filtered or unexported fields
}
gRPC reverse bridge filter configuration
func (*FilterConfig) GetContentType ¶
func (x *FilterConfig) GetContentType() string
func (*FilterConfig) GetResponseSizeHeader ¶
func (x *FilterConfig) GetResponseSizeHeader() string
func (*FilterConfig) GetWithholdGrpcFrames ¶
func (x *FilterConfig) GetWithholdGrpcFrames() bool
func (*FilterConfig) ProtoMessage ¶
func (*FilterConfig) ProtoMessage()
func (*FilterConfig) ProtoReflect ¶
func (x *FilterConfig) ProtoReflect() protoreflect.Message
func (*FilterConfig) Reset ¶
func (x *FilterConfig) Reset()
func (*FilterConfig) SetContentType ¶
func (x *FilterConfig) SetContentType(v string)
func (*FilterConfig) SetResponseSizeHeader ¶
func (x *FilterConfig) SetResponseSizeHeader(v string)
func (*FilterConfig) SetWithholdGrpcFrames ¶
func (x *FilterConfig) SetWithholdGrpcFrames(v bool)
func (*FilterConfig) String ¶
func (x *FilterConfig) String() string
type FilterConfigPerRoute ¶
type FilterConfigPerRoute struct {
// If true, disables gRPC reverse bridge filter for this particular vhost or route.
// If disabled is specified in multiple per-filter-configs, the most specific one will be used.
Disabled bool `protobuf:"varint,1,opt,name=disabled,proto3" json:"disabled,omitempty"`
// contains filtered or unexported fields
}
gRPC reverse bridge filter configuration per virtualhost/route/weighted-cluster level.
func (*FilterConfigPerRoute) GetDisabled ¶
func (x *FilterConfigPerRoute) GetDisabled() bool
func (*FilterConfigPerRoute) ProtoMessage ¶
func (*FilterConfigPerRoute) ProtoMessage()
func (*FilterConfigPerRoute) ProtoReflect ¶
func (x *FilterConfigPerRoute) ProtoReflect() protoreflect.Message
func (*FilterConfigPerRoute) Reset ¶
func (x *FilterConfigPerRoute) Reset()
func (*FilterConfigPerRoute) SetDisabled ¶
func (x *FilterConfigPerRoute) SetDisabled(v bool)
func (*FilterConfigPerRoute) String ¶
func (x *FilterConfigPerRoute) String() string
type FilterConfigPerRoute_builder ¶
type FilterConfigPerRoute_builder struct {
// If true, disables gRPC reverse bridge filter for this particular vhost or route.
// If disabled is specified in multiple per-filter-configs, the most specific one will be used.
Disabled bool
// contains filtered or unexported fields
}
func (FilterConfigPerRoute_builder) Build ¶
func (b0 FilterConfigPerRoute_builder) Build() *FilterConfigPerRoute
type FilterConfig_builder ¶
type FilterConfig_builder struct {
// The content-type to pass to the upstream when the gRPC bridge filter is applied.
// The filter will also validate that the upstream responds with the same content type.
ContentType string
// If true, Envoy will assume that the upstream doesn't understand gRPC frames and
// strip the gRPC frame from the request, and add it back in to the response. This will
// hide the gRPC semantics from the upstream, allowing it to receive and respond with a
// simple binary encoded protobuf. In order to calculate the “Content-Length“ header value, Envoy
// will buffer the upstream response unless :ref:`response_size_header
// <envoy_v3_api_field_extensions.filters.http.grpc_http1_reverse_bridge.v3.FilterConfig.response_size_header>`
// is set, in which case Envoy will use the value of an upstream header to calculate the content
// length.
WithholdGrpcFrames bool
// When :ref:`withhold_grpc_frames
// <envoy_v3_api_field_extensions.filters.http.grpc_http1_reverse_bridge.v3.FilterConfig.withhold_grpc_frames>`
// is true, this option controls how Envoy calculates the “Content-Length“. When
// “response_size_header“ is empty, Envoy will buffer the upstream response to calculate its
// size. When “response_size_header“ is set to a non-empty string, Envoy will stream the response
// to the downstream and it will use the value of the response header with this name to set the
// “Content-Length“ header and gRPC frame size. If the header with this name is repeated, only
// the first value will be used.
//
// Envoy will treat the upstream response as an error if this option is specified and the header
// is missing or if the value does not match the actual response body size.
ResponseSizeHeader string
// contains filtered or unexported fields
}
func (FilterConfig_builder) Build ¶
func (b0 FilterConfig_builder) Build() *FilterConfig
Source Files
¶
- config.pb.go
Click to show internal directories.
Click to hide internal directories.