header_mutationv3

package
v1.36.11-2026011520535... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var File_envoy_extensions_filters_http_header_mutation_v3_header_mutation_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type HeaderMutation

type HeaderMutation struct {
	Mutations *Mutations `protobuf:"bytes,1,opt,name=mutations,proto3" json:"mutations,omitempty"`
	// If per route HeaderMutationPerRoute config is configured at multiple route levels, header mutations
	// at all specified levels are evaluated. By default, the order is from most specific (i.e. route entry level)
	// to least specific (i.e. route configuration level). Later header mutations may override earlier mutations.
	//
	// This order can be reversed by setting this field to true. In other words, most specific level mutation
	// is evaluated last.
	MostSpecificHeaderMutationsWins bool `` /* 161-byte string literal not displayed */
	// contains filtered or unexported fields
}

Configuration for the header mutation filter. The mutation rules in the filter configuration will always be applied first and then the per-route mutation rules, if both are specified.

func (*HeaderMutation) ClearMutations

func (x *HeaderMutation) ClearMutations()

func (*HeaderMutation) GetMostSpecificHeaderMutationsWins

func (x *HeaderMutation) GetMostSpecificHeaderMutationsWins() bool

func (*HeaderMutation) GetMutations

func (x *HeaderMutation) GetMutations() *Mutations

func (*HeaderMutation) HasMutations

func (x *HeaderMutation) HasMutations() bool

func (*HeaderMutation) ProtoMessage

func (*HeaderMutation) ProtoMessage()

func (*HeaderMutation) ProtoReflect

func (x *HeaderMutation) ProtoReflect() protoreflect.Message

func (*HeaderMutation) Reset

func (x *HeaderMutation) Reset()

func (*HeaderMutation) SetMostSpecificHeaderMutationsWins

func (x *HeaderMutation) SetMostSpecificHeaderMutationsWins(v bool)

func (*HeaderMutation) SetMutations

func (x *HeaderMutation) SetMutations(v *Mutations)

func (*HeaderMutation) String

func (x *HeaderMutation) String() string

type HeaderMutationPerRoute

type HeaderMutationPerRoute struct {
	Mutations *Mutations `protobuf:"bytes,1,opt,name=mutations,proto3" json:"mutations,omitempty"`
	// contains filtered or unexported fields
}

Per route configuration for the header mutation filter.

func (*HeaderMutationPerRoute) ClearMutations

func (x *HeaderMutationPerRoute) ClearMutations()

func (*HeaderMutationPerRoute) GetMutations

func (x *HeaderMutationPerRoute) GetMutations() *Mutations

func (*HeaderMutationPerRoute) HasMutations

func (x *HeaderMutationPerRoute) HasMutations() bool

func (*HeaderMutationPerRoute) ProtoMessage

func (*HeaderMutationPerRoute) ProtoMessage()

func (*HeaderMutationPerRoute) ProtoReflect

func (x *HeaderMutationPerRoute) ProtoReflect() protoreflect.Message

func (*HeaderMutationPerRoute) Reset

func (x *HeaderMutationPerRoute) Reset()

func (*HeaderMutationPerRoute) SetMutations

func (x *HeaderMutationPerRoute) SetMutations(v *Mutations)

func (*HeaderMutationPerRoute) String

func (x *HeaderMutationPerRoute) String() string

type HeaderMutationPerRoute_builder

type HeaderMutationPerRoute_builder struct {
	Mutations *Mutations
	// contains filtered or unexported fields
}

func (HeaderMutationPerRoute_builder) Build

type HeaderMutation_builder

type HeaderMutation_builder struct {
	Mutations *Mutations
	// If per route HeaderMutationPerRoute config is configured at multiple route levels, header mutations
	// at all specified levels are evaluated. By default, the order is from most specific (i.e. route entry level)
	// to least specific (i.e. route configuration level). Later header mutations may override earlier mutations.
	//
	// This order can be reversed by setting this field to true. In other words, most specific level mutation
	// is evaluated last.
	MostSpecificHeaderMutationsWins bool
	// contains filtered or unexported fields
}

func (HeaderMutation_builder) Build

type Mutations

type Mutations struct {

	// The request mutations are applied before the request is forwarded to the upstream cluster.
	RequestMutations []*v3.HeaderMutation `protobuf:"bytes,1,rep,name=request_mutations,json=requestMutations,proto3" json:"request_mutations,omitempty"`
	// The “path“ header query parameter mutations are applied after “request_mutations“ and before the request
	// is forwarded to the next filter in the filter chain.
	QueryParameterMutations []*v31.KeyValueMutation `` /* 132-byte string literal not displayed */
	// The response mutations are applied before the response is sent to the downstream client.
	ResponseMutations []*v3.HeaderMutation `protobuf:"bytes,2,rep,name=response_mutations,json=responseMutations,proto3" json:"response_mutations,omitempty"`
	// The response trailer mutations are applied before the response is sent to the downstream client.
	ResponseTrailersMutations []*v3.HeaderMutation `` /* 138-byte string literal not displayed */
	// The request trailer mutations are applied before the request is sent to the upstream cluster.
	RequestTrailersMutations []*v3.HeaderMutation `` /* 135-byte string literal not displayed */
	// contains filtered or unexported fields
}

[#next-free-field: 6]

func (*Mutations) GetQueryParameterMutations

func (x *Mutations) GetQueryParameterMutations() []*v31.KeyValueMutation

func (*Mutations) GetRequestMutations

func (x *Mutations) GetRequestMutations() []*v3.HeaderMutation

func (*Mutations) GetRequestTrailersMutations

func (x *Mutations) GetRequestTrailersMutations() []*v3.HeaderMutation

func (*Mutations) GetResponseMutations

func (x *Mutations) GetResponseMutations() []*v3.HeaderMutation

func (*Mutations) GetResponseTrailersMutations

func (x *Mutations) GetResponseTrailersMutations() []*v3.HeaderMutation

func (*Mutations) ProtoMessage

func (*Mutations) ProtoMessage()

func (*Mutations) ProtoReflect

func (x *Mutations) ProtoReflect() protoreflect.Message

func (*Mutations) Reset

func (x *Mutations) Reset()

func (*Mutations) SetQueryParameterMutations

func (x *Mutations) SetQueryParameterMutations(v []*v31.KeyValueMutation)

func (*Mutations) SetRequestMutations

func (x *Mutations) SetRequestMutations(v []*v3.HeaderMutation)

func (*Mutations) SetRequestTrailersMutations

func (x *Mutations) SetRequestTrailersMutations(v []*v3.HeaderMutation)

func (*Mutations) SetResponseMutations

func (x *Mutations) SetResponseMutations(v []*v3.HeaderMutation)

func (*Mutations) SetResponseTrailersMutations

func (x *Mutations) SetResponseTrailersMutations(v []*v3.HeaderMutation)

func (*Mutations) String

func (x *Mutations) String() string

type Mutations_builder

type Mutations_builder struct {

	// The request mutations are applied before the request is forwarded to the upstream cluster.
	RequestMutations []*v3.HeaderMutation
	// The “path“ header query parameter mutations are applied after “request_mutations“ and before the request
	// is forwarded to the next filter in the filter chain.
	QueryParameterMutations []*v31.KeyValueMutation
	// The response mutations are applied before the response is sent to the downstream client.
	ResponseMutations []*v3.HeaderMutation
	// The response trailer mutations are applied before the response is sent to the downstream client.
	ResponseTrailersMutations []*v3.HeaderMutation
	// The request trailer mutations are applied before the request is sent to the upstream cluster.
	RequestTrailersMutations []*v3.HeaderMutation
	// contains filtered or unexported fields
}

func (Mutations_builder) Build

func (b0 Mutations_builder) Build() *Mutations

Source Files

  • header_mutation.pb.go

Jump to