health_checkv3

package
v1.36.11-2026011520535... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var File_envoy_extensions_filters_http_health_check_v3_health_check_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type HealthCheck

type HealthCheck struct {

	// Specifies whether the filter operates in pass through mode or not.
	PassThroughMode *wrapperspb.BoolValue `protobuf:"bytes,1,opt,name=pass_through_mode,json=passThroughMode,proto3" json:"pass_through_mode,omitempty"`
	// If operating in pass through mode, the amount of time in milliseconds
	// that the filter should cache the upstream response.
	CacheTime *durationpb.Duration `protobuf:"bytes,3,opt,name=cache_time,json=cacheTime,proto3" json:"cache_time,omitempty"`
	// If operating in non-pass-through mode, specifies a set of upstream cluster
	// names and the minimum percentage of servers in each of those clusters that
	// must be healthy or degraded in order for the filter to return a 200. If any of
	// the clusters configured here does not exist, the filter will not return a 200.
	//
	// .. note::
	//
	//	This value is interpreted as an integer by truncating, so 12.50% will be calculated
	//	as if it were 12%.
	ClusterMinHealthyPercentages map[string]*v3.Percent `` /* 223-byte string literal not displayed */
	// Specifies a set of health check request headers to match on. The health check filter will
	// check a request’s headers against all the specified headers. To specify the health check
	// endpoint, set the “:path“ header to match on.
	Headers []*v31.HeaderMatcher `protobuf:"bytes,5,rep,name=headers,proto3" json:"headers,omitempty"`
	// contains filtered or unexported fields
}

[#next-free-field: 6]

func (*HealthCheck) ClearCacheTime

func (x *HealthCheck) ClearCacheTime()

func (*HealthCheck) ClearPassThroughMode

func (x *HealthCheck) ClearPassThroughMode()

func (*HealthCheck) GetCacheTime

func (x *HealthCheck) GetCacheTime() *durationpb.Duration

func (*HealthCheck) GetClusterMinHealthyPercentages

func (x *HealthCheck) GetClusterMinHealthyPercentages() map[string]*v3.Percent

func (*HealthCheck) GetHeaders

func (x *HealthCheck) GetHeaders() []*v31.HeaderMatcher

func (*HealthCheck) GetPassThroughMode

func (x *HealthCheck) GetPassThroughMode() *wrapperspb.BoolValue

func (*HealthCheck) HasCacheTime

func (x *HealthCheck) HasCacheTime() bool

func (*HealthCheck) HasPassThroughMode

func (x *HealthCheck) HasPassThroughMode() bool

func (*HealthCheck) ProtoMessage

func (*HealthCheck) ProtoMessage()

func (*HealthCheck) ProtoReflect

func (x *HealthCheck) ProtoReflect() protoreflect.Message

func (*HealthCheck) Reset

func (x *HealthCheck) Reset()

func (*HealthCheck) SetCacheTime

func (x *HealthCheck) SetCacheTime(v *durationpb.Duration)

func (*HealthCheck) SetClusterMinHealthyPercentages

func (x *HealthCheck) SetClusterMinHealthyPercentages(v map[string]*v3.Percent)

func (*HealthCheck) SetHeaders

func (x *HealthCheck) SetHeaders(v []*v31.HeaderMatcher)

func (*HealthCheck) SetPassThroughMode

func (x *HealthCheck) SetPassThroughMode(v *wrapperspb.BoolValue)

func (*HealthCheck) String

func (x *HealthCheck) String() string

type HealthCheck_builder

type HealthCheck_builder struct {

	// Specifies whether the filter operates in pass through mode or not.
	PassThroughMode *wrapperspb.BoolValue
	// If operating in pass through mode, the amount of time in milliseconds
	// that the filter should cache the upstream response.
	CacheTime *durationpb.Duration
	// If operating in non-pass-through mode, specifies a set of upstream cluster
	// names and the minimum percentage of servers in each of those clusters that
	// must be healthy or degraded in order for the filter to return a 200. If any of
	// the clusters configured here does not exist, the filter will not return a 200.
	//
	// .. note::
	//
	//	This value is interpreted as an integer by truncating, so 12.50% will be calculated
	//	as if it were 12%.
	ClusterMinHealthyPercentages map[string]*v3.Percent
	// Specifies a set of health check request headers to match on. The health check filter will
	// check a request’s headers against all the specified headers. To specify the health check
	// endpoint, set the “:path“ header to match on.
	Headers []*v31.HeaderMatcher
	// contains filtered or unexported fields
}

func (HealthCheck_builder) Build

func (b0 HealthCheck_builder) Build() *HealthCheck

Source Files

  • health_check.pb.go

Jump to