ip_taggingv3

package
v1.36.11-2026041321000... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	IPTagging_RequestType_name = map[int32]string{
		0: "BOTH",
		1: "INTERNAL",
		2: "EXTERNAL",
	}
	IPTagging_RequestType_value = map[string]int32{
		"BOTH":     0,
		"INTERNAL": 1,
		"EXTERNAL": 2,
	}
)

Enum value maps for IPTagging_RequestType.

var (
	IPTagging_IpTagHeader_HeaderAction_name = map[int32]string{
		0: "SANITIZE",
		1: "APPEND_IF_EXISTS_OR_ADD",
	}
	IPTagging_IpTagHeader_HeaderAction_value = map[string]int32{
		"SANITIZE":                0,
		"APPEND_IF_EXISTS_OR_ADD": 1,
	}
)

Enum value maps for IPTagging_IpTagHeader_HeaderAction.

var File_envoy_extensions_filters_http_ip_tagging_v3_ip_tagging_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type IPTagging

type IPTagging struct {

	// The type of request the filter should apply to.
	RequestType IPTagging_RequestType `` /* 166-byte string literal not displayed */
	// [#comment:TODO(ccaraman): Extend functionality to load IP tags from file system.
	// Tracked by issue https://github.com/envoyproxy/envoy/issues/2695]
	// The set of IP tags for the filter.
	IpTags []*IPTagging_IPTag `protobuf:"bytes,4,rep,name=ip_tags,json=ipTags,proto3" json:"ip_tags,omitempty"`
	// Specify to which header the tags will be written.
	//
	// If left unspecified, the tags will be appended to the “x-envoy-ip-tags“ header.
	IpTagHeader *IPTagging_IpTagHeader `protobuf:"bytes,5,opt,name=ip_tag_header,json=ipTagHeader,proto3" json:"ip_tag_header,omitempty"`
	// contains filtered or unexported fields
}

[#next-free-field: 6]

func (*IPTagging) ClearIpTagHeader

func (x *IPTagging) ClearIpTagHeader()

func (*IPTagging) GetIpTagHeader

func (x *IPTagging) GetIpTagHeader() *IPTagging_IpTagHeader

func (*IPTagging) GetIpTags

func (x *IPTagging) GetIpTags() []*IPTagging_IPTag

func (*IPTagging) GetRequestType

func (x *IPTagging) GetRequestType() IPTagging_RequestType

func (*IPTagging) HasIpTagHeader

func (x *IPTagging) HasIpTagHeader() bool

func (*IPTagging) ProtoMessage

func (*IPTagging) ProtoMessage()

func (*IPTagging) ProtoReflect

func (x *IPTagging) ProtoReflect() protoreflect.Message

func (*IPTagging) Reset

func (x *IPTagging) Reset()

func (*IPTagging) SetIpTagHeader

func (x *IPTagging) SetIpTagHeader(v *IPTagging_IpTagHeader)

func (*IPTagging) SetIpTags

func (x *IPTagging) SetIpTags(v []*IPTagging_IPTag)

func (*IPTagging) SetRequestType

func (x *IPTagging) SetRequestType(v IPTagging_RequestType)

func (*IPTagging) String

func (x *IPTagging) String() string

type IPTagging_IPTag

type IPTagging_IPTag struct {

	// Specifies the IP tag name to apply.
	IpTagName string `protobuf:"bytes,1,opt,name=ip_tag_name,json=ipTagName,proto3" json:"ip_tag_name,omitempty"`
	// A list of IP address subnets that will be tagged with
	// ip_tag_name. Both IPv4 and IPv6 are supported.
	IpList []*v3.CidrRange `protobuf:"bytes,2,rep,name=ip_list,json=ipList,proto3" json:"ip_list,omitempty"`
	// contains filtered or unexported fields
}

Supplies the IP tag name and the IP address subnets.

func (*IPTagging_IPTag) GetIpList

func (x *IPTagging_IPTag) GetIpList() []*v3.CidrRange

func (*IPTagging_IPTag) GetIpTagName

func (x *IPTagging_IPTag) GetIpTagName() string

func (*IPTagging_IPTag) ProtoMessage

func (*IPTagging_IPTag) ProtoMessage()

func (*IPTagging_IPTag) ProtoReflect

func (x *IPTagging_IPTag) ProtoReflect() protoreflect.Message

func (*IPTagging_IPTag) Reset

func (x *IPTagging_IPTag) Reset()

func (*IPTagging_IPTag) SetIpList

func (x *IPTagging_IPTag) SetIpList(v []*v3.CidrRange)

func (*IPTagging_IPTag) SetIpTagName

func (x *IPTagging_IPTag) SetIpTagName(v string)

func (*IPTagging_IPTag) String

func (x *IPTagging_IPTag) String() string

type IPTagging_IPTag_builder

type IPTagging_IPTag_builder struct {

	// Specifies the IP tag name to apply.
	IpTagName string
	// A list of IP address subnets that will be tagged with
	// ip_tag_name. Both IPv4 and IPv6 are supported.
	IpList []*v3.CidrRange
	// contains filtered or unexported fields
}

func (IPTagging_IPTag_builder) Build

type IPTagging_IpTagHeader

type IPTagging_IpTagHeader struct {

	// Header to use for ip-tagging.
	//
	// This header will be sanitized based on the config in
	// :ref:`action <envoy_v3_api_field_extensions.filters.http.ip_tagging.v3.IPTagging.IpTagHeader.action>`
	// rather than the defaults for x-envoy prefixed headers.
	Header string `protobuf:"bytes,1,opt,name=header,proto3" json:"header,omitempty"`
	// Control if the :ref:`header <envoy_v3_api_field_extensions.filters.http.ip_tagging.v3.IPTagging.IpTagHeader.header>`
	// will be sanitized, or be appended to.
	//
	// Default: *SANITIZE*.
	Action IPTagging_IpTagHeader_HeaderAction `` /* 150-byte string literal not displayed */
	// contains filtered or unexported fields
}

Specify to which header the tags will be written.

func (*IPTagging_IpTagHeader) GetAction

func (*IPTagging_IpTagHeader) GetHeader

func (x *IPTagging_IpTagHeader) GetHeader() string

func (*IPTagging_IpTagHeader) ProtoMessage

func (*IPTagging_IpTagHeader) ProtoMessage()

func (*IPTagging_IpTagHeader) ProtoReflect

func (x *IPTagging_IpTagHeader) ProtoReflect() protoreflect.Message

func (*IPTagging_IpTagHeader) Reset

func (x *IPTagging_IpTagHeader) Reset()

func (*IPTagging_IpTagHeader) SetAction

func (*IPTagging_IpTagHeader) SetHeader

func (x *IPTagging_IpTagHeader) SetHeader(v string)

func (*IPTagging_IpTagHeader) String

func (x *IPTagging_IpTagHeader) String() string

type IPTagging_IpTagHeader_HeaderAction

type IPTagging_IpTagHeader_HeaderAction int32

Describes how to apply the tags to the headers.

const (
	// (DEFAULT) The header specified in :ref:`ip_tag_header <envoy_v3_api_field_extensions.filters.http.ip_tagging.v3.IPTagging.ip_tag_header>`
	// will be dropped, before the tags are applied. The incoming header will be "sanitized" regardless of whether the request is internal or external.
	//
	// Note that the header will be visible unsanitized to any filters that are invoked before the ip-tag-header filter, unless it has an *x-envoy* prefix.
	IPTagging_IpTagHeader_SANITIZE IPTagging_IpTagHeader_HeaderAction = 0
	// Tags will be appended to the header specified in
	// :ref:`ip_tag_header <envoy_v3_api_field_extensions.filters.http.ip_tagging.v3.IPTagging.ip_tag_header>`.
	//
	// Please note that this could cause the header to retain values set by the http client regardless of whether the request is internal or external.
	IPTagging_IpTagHeader_APPEND_IF_EXISTS_OR_ADD IPTagging_IpTagHeader_HeaderAction = 1
)

func (IPTagging_IpTagHeader_HeaderAction) Descriptor

func (IPTagging_IpTagHeader_HeaderAction) Enum

func (IPTagging_IpTagHeader_HeaderAction) Number

func (IPTagging_IpTagHeader_HeaderAction) String

func (IPTagging_IpTagHeader_HeaderAction) Type

type IPTagging_IpTagHeader_builder

type IPTagging_IpTagHeader_builder struct {

	// Header to use for ip-tagging.
	//
	// This header will be sanitized based on the config in
	// :ref:`action <envoy_v3_api_field_extensions.filters.http.ip_tagging.v3.IPTagging.IpTagHeader.action>`
	// rather than the defaults for x-envoy prefixed headers.
	Header string
	// Control if the :ref:`header <envoy_v3_api_field_extensions.filters.http.ip_tagging.v3.IPTagging.IpTagHeader.header>`
	// will be sanitized, or be appended to.
	//
	// Default: *SANITIZE*.
	Action IPTagging_IpTagHeader_HeaderAction
	// contains filtered or unexported fields
}

func (IPTagging_IpTagHeader_builder) Build

type IPTagging_RequestType

type IPTagging_RequestType int32

The type of requests the filter should apply to. The supported types are internal, external or both. The :ref:`x-forwarded-for<config_http_conn_man_headers_x-forwarded-for_internal_origin>` header is used to determine if a request is internal and will result in :ref:`x-envoy-internal<config_http_conn_man_headers_x-envoy-internal>` being set. The filter defaults to both, and it will apply to all request types.

const (
	// Both external and internal requests will be tagged. This is the default value.
	IPTagging_BOTH IPTagging_RequestType = 0
	// Only internal requests will be tagged.
	IPTagging_INTERNAL IPTagging_RequestType = 1
	// Only external requests will be tagged.
	IPTagging_EXTERNAL IPTagging_RequestType = 2
)

func (IPTagging_RequestType) Descriptor

func (IPTagging_RequestType) Enum

func (IPTagging_RequestType) Number

func (IPTagging_RequestType) String

func (x IPTagging_RequestType) String() string

func (IPTagging_RequestType) Type

type IPTagging_builder

type IPTagging_builder struct {

	// The type of request the filter should apply to.
	RequestType IPTagging_RequestType
	// [#comment:TODO(ccaraman): Extend functionality to load IP tags from file system.
	// Tracked by issue https://github.com/envoyproxy/envoy/issues/2695]
	// The set of IP tags for the filter.
	IpTags []*IPTagging_IPTag
	// Specify to which header the tags will be written.
	//
	// If left unspecified, the tags will be appended to the “x-envoy-ip-tags“ header.
	IpTagHeader *IPTagging_IpTagHeader
	// contains filtered or unexported fields
}

func (IPTagging_builder) Build

func (b0 IPTagging_builder) Build() *IPTagging

Source Files

  • ip_tagging.pb.go

Jump to