tapv3

package
v1.36.11-2026042420273... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var File_envoy_extensions_filters_http_tap_v3_tap_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type Tap

type Tap struct {

	// Common configuration for the HTTP tap filter.
	CommonConfig *v3.CommonExtensionConfig `protobuf:"bytes,1,opt,name=common_config,json=commonConfig,proto3" json:"common_config,omitempty"`
	// Indicates whether HTTP tap filter records the time stamp for request/response headers.
	// Request headers time stamp is stored after receiving request headers.
	// Response headers time stamp is stored after receiving response headers.
	RecordHeadersReceivedTime bool `` /* 141-byte string literal not displayed */
	// Indicates whether report downstream connection info
	RecordDownstreamConnection bool `` /* 142-byte string literal not displayed */
	// If enabled, upstream connection information will be reported.
	RecordUpstreamConnection bool `` /* 136-byte string literal not displayed */
	// contains filtered or unexported fields
}

Top level configuration for the tap filter.

func (*Tap) ClearCommonConfig

func (x *Tap) ClearCommonConfig()

func (*Tap) GetCommonConfig

func (x *Tap) GetCommonConfig() *v3.CommonExtensionConfig

func (*Tap) GetRecordDownstreamConnection

func (x *Tap) GetRecordDownstreamConnection() bool

func (*Tap) GetRecordHeadersReceivedTime

func (x *Tap) GetRecordHeadersReceivedTime() bool

func (*Tap) GetRecordUpstreamConnection

func (x *Tap) GetRecordUpstreamConnection() bool

func (*Tap) HasCommonConfig

func (x *Tap) HasCommonConfig() bool

func (*Tap) ProtoMessage

func (*Tap) ProtoMessage()

func (*Tap) ProtoReflect

func (x *Tap) ProtoReflect() protoreflect.Message

func (*Tap) Reset

func (x *Tap) Reset()

func (*Tap) SetCommonConfig

func (x *Tap) SetCommonConfig(v *v3.CommonExtensionConfig)

func (*Tap) SetRecordDownstreamConnection

func (x *Tap) SetRecordDownstreamConnection(v bool)

func (*Tap) SetRecordHeadersReceivedTime

func (x *Tap) SetRecordHeadersReceivedTime(v bool)

func (*Tap) SetRecordUpstreamConnection

func (x *Tap) SetRecordUpstreamConnection(v bool)

func (*Tap) String

func (x *Tap) String() string

type Tap_builder

type Tap_builder struct {

	// Common configuration for the HTTP tap filter.
	CommonConfig *v3.CommonExtensionConfig
	// Indicates whether HTTP tap filter records the time stamp for request/response headers.
	// Request headers time stamp is stored after receiving request headers.
	// Response headers time stamp is stored after receiving response headers.
	RecordHeadersReceivedTime bool
	// Indicates whether report downstream connection info
	RecordDownstreamConnection bool
	// If enabled, upstream connection information will be reported.
	RecordUpstreamConnection bool
	// contains filtered or unexported fields
}

func (Tap_builder) Build

func (b0 Tap_builder) Build() *Tap

Source Files

  • tap.pb.go

Jump to