Documentation
¶
Index ¶
- Variables
- type LocalRateLimit
- func (x *LocalRateLimit) ClearRuntimeEnabled()
- func (x *LocalRateLimit) ClearTokenBucket()
- func (x *LocalRateLimit) GetRuntimeEnabled() *v31.RuntimeFeatureFlag
- func (x *LocalRateLimit) GetStatPrefix() string
- func (x *LocalRateLimit) GetTokenBucket() *v3.TokenBucket
- func (x *LocalRateLimit) HasRuntimeEnabled() bool
- func (x *LocalRateLimit) HasTokenBucket() bool
- func (*LocalRateLimit) ProtoMessage()
- func (x *LocalRateLimit) ProtoReflect() protoreflect.Message
- func (x *LocalRateLimit) Reset()
- func (x *LocalRateLimit) SetRuntimeEnabled(v *v31.RuntimeFeatureFlag)
- func (x *LocalRateLimit) SetStatPrefix(v string)
- func (x *LocalRateLimit) SetTokenBucket(v *v3.TokenBucket)
- func (x *LocalRateLimit) String() string
- type LocalRateLimit_builder
Constants ¶
This section is empty.
Variables ¶
var File_envoy_extensions_filters_listener_local_ratelimit_v3_local_ratelimit_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type LocalRateLimit ¶
type LocalRateLimit struct {
// The prefix to use when emitting :ref:`statistics
// <config_listener_filters_local_rate_limit_stats>`.
StatPrefix string `protobuf:"bytes,1,opt,name=stat_prefix,json=statPrefix,proto3" json:"stat_prefix,omitempty"`
// The token bucket configuration to use for rate limiting all incoming sockets. If the token is available,
// the socket will be allowed. If no tokens are available, the socket will be immediately closed.
//
// .. note::
//
// In the current implementation the token bucket's :ref:`fill_interval
// <envoy_v3_api_field_type.v3.TokenBucket.fill_interval>` must be >= 50ms to avoid too aggressive
// refills.
TokenBucket *v3.TokenBucket `protobuf:"bytes,2,opt,name=token_bucket,json=tokenBucket,proto3" json:"token_bucket,omitempty"`
// Runtime flag that controls whether the filter is enabled or not. If not specified, defaults
// to enabled.
RuntimeEnabled *v31.RuntimeFeatureFlag `protobuf:"bytes,3,opt,name=runtime_enabled,json=runtimeEnabled,proto3" json:"runtime_enabled,omitempty"`
// contains filtered or unexported fields
}
func (*LocalRateLimit) ClearRuntimeEnabled ¶
func (x *LocalRateLimit) ClearRuntimeEnabled()
func (*LocalRateLimit) ClearTokenBucket ¶
func (x *LocalRateLimit) ClearTokenBucket()
func (*LocalRateLimit) GetRuntimeEnabled ¶
func (x *LocalRateLimit) GetRuntimeEnabled() *v31.RuntimeFeatureFlag
func (*LocalRateLimit) GetStatPrefix ¶
func (x *LocalRateLimit) GetStatPrefix() string
func (*LocalRateLimit) GetTokenBucket ¶
func (x *LocalRateLimit) GetTokenBucket() *v3.TokenBucket
func (*LocalRateLimit) HasRuntimeEnabled ¶
func (x *LocalRateLimit) HasRuntimeEnabled() bool
func (*LocalRateLimit) HasTokenBucket ¶
func (x *LocalRateLimit) HasTokenBucket() bool
func (*LocalRateLimit) ProtoMessage ¶
func (*LocalRateLimit) ProtoMessage()
func (*LocalRateLimit) ProtoReflect ¶
func (x *LocalRateLimit) ProtoReflect() protoreflect.Message
func (*LocalRateLimit) Reset ¶
func (x *LocalRateLimit) Reset()
func (*LocalRateLimit) SetRuntimeEnabled ¶
func (x *LocalRateLimit) SetRuntimeEnabled(v *v31.RuntimeFeatureFlag)
func (*LocalRateLimit) SetStatPrefix ¶
func (x *LocalRateLimit) SetStatPrefix(v string)
func (*LocalRateLimit) SetTokenBucket ¶
func (x *LocalRateLimit) SetTokenBucket(v *v3.TokenBucket)
func (*LocalRateLimit) String ¶
func (x *LocalRateLimit) String() string
type LocalRateLimit_builder ¶
type LocalRateLimit_builder struct {
// The prefix to use when emitting :ref:`statistics
// <config_listener_filters_local_rate_limit_stats>`.
StatPrefix string
// The token bucket configuration to use for rate limiting all incoming sockets. If the token is available,
// the socket will be allowed. If no tokens are available, the socket will be immediately closed.
//
// .. note::
//
// In the current implementation the token bucket's :ref:`fill_interval
// <envoy_v3_api_field_type.v3.TokenBucket.fill_interval>` must be >= 50ms to avoid too aggressive
// refills.
TokenBucket *v3.TokenBucket
// Runtime flag that controls whether the filter is enabled or not. If not specified, defaults
// to enabled.
RuntimeEnabled *v31.RuntimeFeatureFlag
// contains filtered or unexported fields
}
func (LocalRateLimit_builder) Build ¶
func (b0 LocalRateLimit_builder) Build() *LocalRateLimit
Source Files
¶
- local_ratelimit.pb.go
Click to show internal directories.
Click to hide internal directories.