dubbo_proxyv3

package
v1.36.11-2026011520535... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 12 Imported by: 0

Documentation

Index

Constants

const DubboProxy_Drds_case case_DubboProxy_RouteSpecifier = 6
const DubboProxy_MultipleRouteConfig_case case_DubboProxy_RouteSpecifier = 7
const DubboProxy_RouteSpecifier_not_set_case case_DubboProxy_RouteSpecifier = 0
const MethodMatch_ParameterMatchSpecifier_ExactMatch_case case_MethodMatch_ParameterMatchSpecifier_ParameterMatchSpecifier = 3
const MethodMatch_ParameterMatchSpecifier_ParameterMatchSpecifier_not_set_case case_MethodMatch_ParameterMatchSpecifier_ParameterMatchSpecifier = 0
const MethodMatch_ParameterMatchSpecifier_RangeMatch_case case_MethodMatch_ParameterMatchSpecifier_ParameterMatchSpecifier = 4
const RouteAction_ClusterSpecifier_not_set_case case_RouteAction_ClusterSpecifier = 0
const RouteAction_Cluster_case case_RouteAction_ClusterSpecifier = 1
const RouteAction_WeightedClusters_case case_RouteAction_ClusterSpecifier = 2

Variables

var (
	ProtocolType_name = map[int32]string{
		0: "Dubbo",
	}
	ProtocolType_value = map[string]int32{
		"Dubbo": 0,
	}
)

Enum value maps for ProtocolType.

var (
	SerializationType_name = map[int32]string{
		0: "Hessian2",
	}
	SerializationType_value = map[string]int32{
		"Hessian2": 0,
	}
)

Enum value maps for SerializationType.

var File_envoy_extensions_filters_network_dubbo_proxy_v3_dubbo_proxy_proto protoreflect.FileDescriptor
var File_envoy_extensions_filters_network_dubbo_proxy_v3_route_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type Drds

type Drds struct {

	// Configuration source specifier.
	// In case of “api_config_source“ only aggregated “api_type“ is supported.
	ConfigSource *v3.ConfigSource `protobuf:"bytes,1,opt,name=config_source,json=configSource,proto3" json:"config_source,omitempty"`
	// The name of the multiple route configuration. This allows to use different multiple route
	// configurations. Tells which multiple route configuration should be fetched from the configuration
	// source. Leave unspecified is also valid and means the unnamed multiple route configuration.
	RouteConfigName string `protobuf:"bytes,2,opt,name=route_config_name,json=routeConfigName,proto3" json:"route_config_name,omitempty"`
	// contains filtered or unexported fields
}

func (*Drds) ClearConfigSource

func (x *Drds) ClearConfigSource()

func (*Drds) GetConfigSource

func (x *Drds) GetConfigSource() *v3.ConfigSource

func (*Drds) GetRouteConfigName

func (x *Drds) GetRouteConfigName() string

func (*Drds) HasConfigSource

func (x *Drds) HasConfigSource() bool

func (*Drds) ProtoMessage

func (*Drds) ProtoMessage()

func (*Drds) ProtoReflect

func (x *Drds) ProtoReflect() protoreflect.Message

func (*Drds) Reset

func (x *Drds) Reset()

func (*Drds) SetConfigSource

func (x *Drds) SetConfigSource(v *v3.ConfigSource)

func (*Drds) SetRouteConfigName

func (x *Drds) SetRouteConfigName(v string)

func (*Drds) String

func (x *Drds) String() string

type Drds_builder

type Drds_builder struct {

	// Configuration source specifier.
	// In case of “api_config_source“ only aggregated “api_type“ is supported.
	ConfigSource *v3.ConfigSource
	// The name of the multiple route configuration. This allows to use different multiple route
	// configurations. Tells which multiple route configuration should be fetched from the configuration
	// source. Leave unspecified is also valid and means the unnamed multiple route configuration.
	RouteConfigName string
	// contains filtered or unexported fields
}

func (Drds_builder) Build

func (b0 Drds_builder) Build() *Drds

type DubboFilter

type DubboFilter struct {

	// The name of the filter to instantiate. The name must match a supported
	// filter.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Filter specific configuration which depends on the filter being
	// instantiated. See the supported filters for further documentation.
	Config *anypb.Any `protobuf:"bytes,2,opt,name=config,proto3" json:"config,omitempty"`
	// contains filtered or unexported fields
}

DubboFilter configures a Dubbo filter.

func (*DubboFilter) ClearConfig

func (x *DubboFilter) ClearConfig()

func (*DubboFilter) GetConfig

func (x *DubboFilter) GetConfig() *anypb.Any

func (*DubboFilter) GetName

func (x *DubboFilter) GetName() string

func (*DubboFilter) HasConfig

func (x *DubboFilter) HasConfig() bool

func (*DubboFilter) ProtoMessage

func (*DubboFilter) ProtoMessage()

func (*DubboFilter) ProtoReflect

func (x *DubboFilter) ProtoReflect() protoreflect.Message

func (*DubboFilter) Reset

func (x *DubboFilter) Reset()

func (*DubboFilter) SetConfig

func (x *DubboFilter) SetConfig(v *anypb.Any)

func (*DubboFilter) SetName

func (x *DubboFilter) SetName(v string)

func (*DubboFilter) String

func (x *DubboFilter) String() string

type DubboFilter_builder

type DubboFilter_builder struct {

	// The name of the filter to instantiate. The name must match a supported
	// filter.
	Name string
	// Filter specific configuration which depends on the filter being
	// instantiated. See the supported filters for further documentation.
	Config *anypb.Any
	// contains filtered or unexported fields
}

func (DubboFilter_builder) Build

func (b0 DubboFilter_builder) Build() *DubboFilter

type DubboProxy

type DubboProxy struct {

	// The human readable prefix to use when emitting statistics.
	StatPrefix string `protobuf:"bytes,1,opt,name=stat_prefix,json=statPrefix,proto3" json:"stat_prefix,omitempty"`
	// Configure the protocol used.
	ProtocolType ProtocolType `` /* 164-byte string literal not displayed */
	// Configure the serialization protocol used.
	SerializationType SerializationType `` /* 184-byte string literal not displayed */
	// The route table for the connection manager is static and is specified in this property.
	//
	// .. note::
	//
	//	This field is deprecated. Please use “drds“ or “multiple_route_config“ first.
	//
	// Deprecated: Marked as deprecated in envoy/extensions/filters/network/dubbo_proxy/v3/dubbo_proxy.proto.
	RouteConfig []*RouteConfiguration `protobuf:"bytes,4,rep,name=route_config,json=routeConfig,proto3" json:"route_config,omitempty"`
	// Types that are valid to be assigned to RouteSpecifier:
	//
	//	*DubboProxy_Drds
	//	*DubboProxy_MultipleRouteConfig
	RouteSpecifier isDubboProxy_RouteSpecifier `protobuf_oneof:"route_specifier"`
	// A list of individual Dubbo filters that make up the filter chain for requests made to the
	// Dubbo proxy. Order matters as the filters are processed sequentially. For backwards
	// compatibility, if no dubbo_filters are specified, a default Dubbo router filter
	// (“envoy.filters.dubbo.router“) is used.
	DubboFilters []*DubboFilter `protobuf:"bytes,5,rep,name=dubbo_filters,json=dubboFilters,proto3" json:"dubbo_filters,omitempty"`
	// contains filtered or unexported fields
}

[#next-free-field: 8]

func (*DubboProxy) ClearDrds

func (x *DubboProxy) ClearDrds()

func (*DubboProxy) ClearMultipleRouteConfig

func (x *DubboProxy) ClearMultipleRouteConfig()

func (*DubboProxy) ClearRouteSpecifier

func (x *DubboProxy) ClearRouteSpecifier()

func (*DubboProxy) GetDrds

func (x *DubboProxy) GetDrds() *Drds

func (*DubboProxy) GetDubboFilters

func (x *DubboProxy) GetDubboFilters() []*DubboFilter

func (*DubboProxy) GetMultipleRouteConfig

func (x *DubboProxy) GetMultipleRouteConfig() *MultipleRouteConfiguration

func (*DubboProxy) GetProtocolType

func (x *DubboProxy) GetProtocolType() ProtocolType

func (*DubboProxy) GetRouteConfig deprecated

func (x *DubboProxy) GetRouteConfig() []*RouteConfiguration

Deprecated: Marked as deprecated in envoy/extensions/filters/network/dubbo_proxy/v3/dubbo_proxy.proto.

func (*DubboProxy) GetRouteSpecifier

func (x *DubboProxy) GetRouteSpecifier() isDubboProxy_RouteSpecifier

func (*DubboProxy) GetSerializationType

func (x *DubboProxy) GetSerializationType() SerializationType

func (*DubboProxy) GetStatPrefix

func (x *DubboProxy) GetStatPrefix() string

func (*DubboProxy) HasDrds

func (x *DubboProxy) HasDrds() bool

func (*DubboProxy) HasMultipleRouteConfig

func (x *DubboProxy) HasMultipleRouteConfig() bool

func (*DubboProxy) HasRouteSpecifier

func (x *DubboProxy) HasRouteSpecifier() bool

func (*DubboProxy) ProtoMessage

func (*DubboProxy) ProtoMessage()

func (*DubboProxy) ProtoReflect

func (x *DubboProxy) ProtoReflect() protoreflect.Message

func (*DubboProxy) Reset

func (x *DubboProxy) Reset()

func (*DubboProxy) SetDrds

func (x *DubboProxy) SetDrds(v *Drds)

func (*DubboProxy) SetDubboFilters

func (x *DubboProxy) SetDubboFilters(v []*DubboFilter)

func (*DubboProxy) SetMultipleRouteConfig

func (x *DubboProxy) SetMultipleRouteConfig(v *MultipleRouteConfiguration)

func (*DubboProxy) SetProtocolType

func (x *DubboProxy) SetProtocolType(v ProtocolType)

func (*DubboProxy) SetRouteConfig deprecated

func (x *DubboProxy) SetRouteConfig(v []*RouteConfiguration)

Deprecated: Marked as deprecated in envoy/extensions/filters/network/dubbo_proxy/v3/dubbo_proxy.proto.

func (*DubboProxy) SetSerializationType

func (x *DubboProxy) SetSerializationType(v SerializationType)

func (*DubboProxy) SetStatPrefix

func (x *DubboProxy) SetStatPrefix(v string)

func (*DubboProxy) String

func (x *DubboProxy) String() string

func (*DubboProxy) WhichRouteSpecifier

func (x *DubboProxy) WhichRouteSpecifier() case_DubboProxy_RouteSpecifier

type DubboProxy_Drds

type DubboProxy_Drds struct {
	// Use xDS to fetch the route configuration. It is invalid to define both “route_config“ and “drds“.
	Drds *Drds `protobuf:"bytes,6,opt,name=drds,proto3,oneof"`
}

type DubboProxy_MultipleRouteConfig

type DubboProxy_MultipleRouteConfig struct {
	MultipleRouteConfig *MultipleRouteConfiguration `protobuf:"bytes,7,opt,name=multiple_route_config,json=multipleRouteConfig,proto3,oneof"`
}

type DubboProxy_builder

type DubboProxy_builder struct {

	// The human readable prefix to use when emitting statistics.
	StatPrefix string
	// Configure the protocol used.
	ProtocolType ProtocolType
	// Configure the serialization protocol used.
	SerializationType SerializationType
	// The route table for the connection manager is static and is specified in this property.
	//
	// .. note::
	//
	//	This field is deprecated. Please use “drds“ or “multiple_route_config“ first.
	//
	// Deprecated: Marked as deprecated in envoy/extensions/filters/network/dubbo_proxy/v3/dubbo_proxy.proto.
	RouteConfig []*RouteConfiguration
	// Fields of oneof RouteSpecifier:
	// Use xDS to fetch the route configuration. It is invalid to define both “route_config“ and “drds“.
	Drds                *Drds
	MultipleRouteConfig *MultipleRouteConfiguration
	// -- end of RouteSpecifier
	// A list of individual Dubbo filters that make up the filter chain for requests made to the
	// Dubbo proxy. Order matters as the filters are processed sequentially. For backwards
	// compatibility, if no dubbo_filters are specified, a default Dubbo router filter
	// (“envoy.filters.dubbo.router“) is used.
	DubboFilters []*DubboFilter
	// contains filtered or unexported fields
}

func (DubboProxy_builder) Build

func (b0 DubboProxy_builder) Build() *DubboProxy

type MethodMatch

type MethodMatch struct {

	// The name of the method.
	Name *v32.StringMatcher `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Method parameter definition.
	// The key is the parameter index, starting from 0.
	// The value is the parameter matching type.
	ParamsMatch map[uint32]*MethodMatch_ParameterMatchSpecifier `` /* 169-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*MethodMatch) ClearName

func (x *MethodMatch) ClearName()

func (*MethodMatch) GetName

func (x *MethodMatch) GetName() *v32.StringMatcher

func (*MethodMatch) GetParamsMatch

func (x *MethodMatch) GetParamsMatch() map[uint32]*MethodMatch_ParameterMatchSpecifier

func (*MethodMatch) HasName

func (x *MethodMatch) HasName() bool

func (*MethodMatch) ProtoMessage

func (*MethodMatch) ProtoMessage()

func (*MethodMatch) ProtoReflect

func (x *MethodMatch) ProtoReflect() protoreflect.Message

func (*MethodMatch) Reset

func (x *MethodMatch) Reset()

func (*MethodMatch) SetName

func (x *MethodMatch) SetName(v *v32.StringMatcher)

func (*MethodMatch) SetParamsMatch

func (x *MethodMatch) SetParamsMatch(v map[uint32]*MethodMatch_ParameterMatchSpecifier)

func (*MethodMatch) String

func (x *MethodMatch) String() string

type MethodMatch_ParameterMatchSpecifier

type MethodMatch_ParameterMatchSpecifier struct {

	// Types that are valid to be assigned to ParameterMatchSpecifier:
	//
	//	*MethodMatch_ParameterMatchSpecifier_ExactMatch
	//	*MethodMatch_ParameterMatchSpecifier_RangeMatch
	ParameterMatchSpecifier isMethodMatch_ParameterMatchSpecifier_ParameterMatchSpecifier `protobuf_oneof:"parameter_match_specifier"`
	// contains filtered or unexported fields
}

The parameter matching type.

func (*MethodMatch_ParameterMatchSpecifier) ClearExactMatch

func (x *MethodMatch_ParameterMatchSpecifier) ClearExactMatch()

func (*MethodMatch_ParameterMatchSpecifier) ClearParameterMatchSpecifier

func (x *MethodMatch_ParameterMatchSpecifier) ClearParameterMatchSpecifier()

func (*MethodMatch_ParameterMatchSpecifier) ClearRangeMatch

func (x *MethodMatch_ParameterMatchSpecifier) ClearRangeMatch()

func (*MethodMatch_ParameterMatchSpecifier) GetExactMatch

func (x *MethodMatch_ParameterMatchSpecifier) GetExactMatch() string

func (*MethodMatch_ParameterMatchSpecifier) GetParameterMatchSpecifier

func (x *MethodMatch_ParameterMatchSpecifier) GetParameterMatchSpecifier() isMethodMatch_ParameterMatchSpecifier_ParameterMatchSpecifier

func (*MethodMatch_ParameterMatchSpecifier) GetRangeMatch

func (*MethodMatch_ParameterMatchSpecifier) HasExactMatch

func (x *MethodMatch_ParameterMatchSpecifier) HasExactMatch() bool

func (*MethodMatch_ParameterMatchSpecifier) HasParameterMatchSpecifier

func (x *MethodMatch_ParameterMatchSpecifier) HasParameterMatchSpecifier() bool

func (*MethodMatch_ParameterMatchSpecifier) HasRangeMatch

func (x *MethodMatch_ParameterMatchSpecifier) HasRangeMatch() bool

func (*MethodMatch_ParameterMatchSpecifier) ProtoMessage

func (*MethodMatch_ParameterMatchSpecifier) ProtoMessage()

func (*MethodMatch_ParameterMatchSpecifier) ProtoReflect

func (*MethodMatch_ParameterMatchSpecifier) Reset

func (*MethodMatch_ParameterMatchSpecifier) SetExactMatch

func (x *MethodMatch_ParameterMatchSpecifier) SetExactMatch(v string)

func (*MethodMatch_ParameterMatchSpecifier) SetRangeMatch

func (x *MethodMatch_ParameterMatchSpecifier) SetRangeMatch(v *v33.Int64Range)

func (*MethodMatch_ParameterMatchSpecifier) String

func (*MethodMatch_ParameterMatchSpecifier) WhichParameterMatchSpecifier

func (x *MethodMatch_ParameterMatchSpecifier) WhichParameterMatchSpecifier() case_MethodMatch_ParameterMatchSpecifier_ParameterMatchSpecifier

type MethodMatch_ParameterMatchSpecifier_ExactMatch

type MethodMatch_ParameterMatchSpecifier_ExactMatch struct {
	// If specified, header match will be performed based on the value of the header.
	ExactMatch string `protobuf:"bytes,3,opt,name=exact_match,json=exactMatch,proto3,oneof"`
}

type MethodMatch_ParameterMatchSpecifier_RangeMatch

type MethodMatch_ParameterMatchSpecifier_RangeMatch struct {
	// If specified, header match will be performed based on range.
	// The rule will match if the request header value is within this range.
	// The entire request header value must represent an integer in base 10 notation: consisting
	// of an optional plus or minus sign followed by a sequence of digits. The rule will not match
	// if the header value does not represent an integer. Match will fail for empty values,
	// floating point numbers or if only a subsequence of the header value is an integer.
	//
	// Examples:
	//
	//   - For range [-10,0), route will match for header value -1, but not for 0,
	//     "somestring", 10.9, "-1somestring"
	RangeMatch *v33.Int64Range `protobuf:"bytes,4,opt,name=range_match,json=rangeMatch,proto3,oneof"`
}

type MethodMatch_ParameterMatchSpecifier_builder

type MethodMatch_ParameterMatchSpecifier_builder struct {

	// Fields of oneof ParameterMatchSpecifier:
	// If specified, header match will be performed based on the value of the header.
	ExactMatch *string
	// If specified, header match will be performed based on range.
	// The rule will match if the request header value is within this range.
	// The entire request header value must represent an integer in base 10 notation: consisting
	// of an optional plus or minus sign followed by a sequence of digits. The rule will not match
	// if the header value does not represent an integer. Match will fail for empty values,
	// floating point numbers or if only a subsequence of the header value is an integer.
	//
	// Examples:
	//
	//   - For range [-10,0), route will match for header value -1, but not for 0,
	//     "somestring", 10.9, "-1somestring"
	RangeMatch *v33.Int64Range
	// contains filtered or unexported fields
}

func (MethodMatch_ParameterMatchSpecifier_builder) Build

type MethodMatch_builder

type MethodMatch_builder struct {

	// The name of the method.
	Name *v32.StringMatcher
	// Method parameter definition.
	// The key is the parameter index, starting from 0.
	// The value is the parameter matching type.
	ParamsMatch map[uint32]*MethodMatch_ParameterMatchSpecifier
	// contains filtered or unexported fields
}

func (MethodMatch_builder) Build

func (b0 MethodMatch_builder) Build() *MethodMatch

type MultipleRouteConfiguration

type MultipleRouteConfiguration struct {

	// The name of the named route configurations. This name is used in asynchronous route discovery.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// The route table of the dubbo connection manager.
	RouteConfig []*RouteConfiguration `protobuf:"bytes,4,rep,name=route_config,json=routeConfig,proto3" json:"route_config,omitempty"`
	// contains filtered or unexported fields
}

func (*MultipleRouteConfiguration) GetName

func (x *MultipleRouteConfiguration) GetName() string

func (*MultipleRouteConfiguration) GetRouteConfig

func (x *MultipleRouteConfiguration) GetRouteConfig() []*RouteConfiguration

func (*MultipleRouteConfiguration) ProtoMessage

func (*MultipleRouteConfiguration) ProtoMessage()

func (*MultipleRouteConfiguration) ProtoReflect

func (*MultipleRouteConfiguration) Reset

func (x *MultipleRouteConfiguration) Reset()

func (*MultipleRouteConfiguration) SetName

func (x *MultipleRouteConfiguration) SetName(v string)

func (*MultipleRouteConfiguration) SetRouteConfig

func (x *MultipleRouteConfiguration) SetRouteConfig(v []*RouteConfiguration)

func (*MultipleRouteConfiguration) String

func (x *MultipleRouteConfiguration) String() string

type MultipleRouteConfiguration_builder

type MultipleRouteConfiguration_builder struct {

	// The name of the named route configurations. This name is used in asynchronous route discovery.
	Name string
	// The route table of the dubbo connection manager.
	RouteConfig []*RouteConfiguration
	// contains filtered or unexported fields
}

func (MultipleRouteConfiguration_builder) Build

type ProtocolType

type ProtocolType int32

Dubbo Protocol types supported by Envoy.

const (
	// the default protocol.
	ProtocolType_Dubbo ProtocolType = 0
)

func (ProtocolType) Descriptor

func (ProtocolType) Enum

func (x ProtocolType) Enum() *ProtocolType

func (ProtocolType) Number

func (ProtocolType) String

func (x ProtocolType) String() string

func (ProtocolType) Type

type Route

type Route struct {

	// Route matching parameters.
	Match *RouteMatch `protobuf:"bytes,1,opt,name=match,proto3" json:"match,omitempty"`
	// Route request to some upstream cluster.
	Route *RouteAction `protobuf:"bytes,2,opt,name=route,proto3" json:"route,omitempty"`
	// contains filtered or unexported fields
}

func (*Route) ClearMatch

func (x *Route) ClearMatch()

func (*Route) ClearRoute

func (x *Route) ClearRoute()

func (*Route) GetMatch

func (x *Route) GetMatch() *RouteMatch

func (*Route) GetRoute

func (x *Route) GetRoute() *RouteAction

func (*Route) HasMatch

func (x *Route) HasMatch() bool

func (*Route) HasRoute

func (x *Route) HasRoute() bool

func (*Route) ProtoMessage

func (*Route) ProtoMessage()

func (*Route) ProtoReflect

func (x *Route) ProtoReflect() protoreflect.Message

func (*Route) Reset

func (x *Route) Reset()

func (*Route) SetMatch

func (x *Route) SetMatch(v *RouteMatch)

func (*Route) SetRoute

func (x *Route) SetRoute(v *RouteAction)

func (*Route) String

func (x *Route) String() string

type RouteAction

type RouteAction struct {

	// Types that are valid to be assigned to ClusterSpecifier:
	//
	//	*RouteAction_Cluster
	//	*RouteAction_WeightedClusters
	ClusterSpecifier isRouteAction_ClusterSpecifier `protobuf_oneof:"cluster_specifier"`
	// Optional endpoint metadata match criteria used by the subset load balancer. Only endpoints in
	// the upstream cluster with metadata matching what is set in this field will be considered for
	// load balancing. The filter name should be specified as “envoy.lb“.
	MetadataMatch *v31.Metadata `protobuf:"bytes,3,opt,name=metadata_match,json=metadataMatch,proto3" json:"metadata_match,omitempty"`
	// contains filtered or unexported fields
}

func (*RouteAction) ClearCluster

func (x *RouteAction) ClearCluster()

func (*RouteAction) ClearClusterSpecifier

func (x *RouteAction) ClearClusterSpecifier()

func (*RouteAction) ClearMetadataMatch

func (x *RouteAction) ClearMetadataMatch()

func (*RouteAction) ClearWeightedClusters

func (x *RouteAction) ClearWeightedClusters()

func (*RouteAction) GetCluster

func (x *RouteAction) GetCluster() string

func (*RouteAction) GetClusterSpecifier

func (x *RouteAction) GetClusterSpecifier() isRouteAction_ClusterSpecifier

func (*RouteAction) GetMetadataMatch

func (x *RouteAction) GetMetadataMatch() *v31.Metadata

func (*RouteAction) GetWeightedClusters

func (x *RouteAction) GetWeightedClusters() *v3.WeightedCluster

func (*RouteAction) HasCluster

func (x *RouteAction) HasCluster() bool

func (*RouteAction) HasClusterSpecifier

func (x *RouteAction) HasClusterSpecifier() bool

func (*RouteAction) HasMetadataMatch

func (x *RouteAction) HasMetadataMatch() bool

func (*RouteAction) HasWeightedClusters

func (x *RouteAction) HasWeightedClusters() bool

func (*RouteAction) ProtoMessage

func (*RouteAction) ProtoMessage()

func (*RouteAction) ProtoReflect

func (x *RouteAction) ProtoReflect() protoreflect.Message

func (*RouteAction) Reset

func (x *RouteAction) Reset()

func (*RouteAction) SetCluster

func (x *RouteAction) SetCluster(v string)

func (*RouteAction) SetMetadataMatch

func (x *RouteAction) SetMetadataMatch(v *v31.Metadata)

func (*RouteAction) SetWeightedClusters

func (x *RouteAction) SetWeightedClusters(v *v3.WeightedCluster)

func (*RouteAction) String

func (x *RouteAction) String() string

func (*RouteAction) WhichClusterSpecifier

func (x *RouteAction) WhichClusterSpecifier() case_RouteAction_ClusterSpecifier

type RouteAction_Cluster

type RouteAction_Cluster struct {
	// Indicates the upstream cluster to which the request should be routed.
	Cluster string `protobuf:"bytes,1,opt,name=cluster,proto3,oneof"`
}

type RouteAction_WeightedClusters

type RouteAction_WeightedClusters struct {
	// Multiple upstream clusters can be specified for a given route. The
	// request is routed to one of the upstream clusters based on weights
	// assigned to each cluster.
	// Currently ClusterWeight only supports the name and weight fields.
	WeightedClusters *v3.WeightedCluster `protobuf:"bytes,2,opt,name=weighted_clusters,json=weightedClusters,proto3,oneof"`
}

type RouteAction_builder

type RouteAction_builder struct {

	// Fields of oneof ClusterSpecifier:
	// Indicates the upstream cluster to which the request should be routed.
	Cluster *string
	// Multiple upstream clusters can be specified for a given route. The
	// request is routed to one of the upstream clusters based on weights
	// assigned to each cluster.
	// Currently ClusterWeight only supports the name and weight fields.
	WeightedClusters *v3.WeightedCluster
	// -- end of ClusterSpecifier
	// Optional endpoint metadata match criteria used by the subset load balancer. Only endpoints in
	// the upstream cluster with metadata matching what is set in this field will be considered for
	// load balancing. The filter name should be specified as “envoy.lb“.
	MetadataMatch *v31.Metadata
	// contains filtered or unexported fields
}

func (RouteAction_builder) Build

func (b0 RouteAction_builder) Build() *RouteAction

type RouteConfiguration

type RouteConfiguration struct {

	// The name of the route configuration. Reserved for future use in asynchronous route discovery.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// The interface name of the service. Wildcard interface are supported in the suffix or prefix form.
	// e.g. “*.methods.add“ will match “com.dev.methods.add“, “com.prod.methods.add“, etc.
	// “com.dev.methods.*“ will match “com.dev.methods.add“, “com.dev.methods.update“, etc.
	// Special wildcard “*“ matching any interface.
	//
	// .. note::
	//
	//	The wildcard will not match the empty string.
	//	e.g. “*.methods.add“ will match “com.dev.methods.add“ but not “.methods.add“.
	Interface string `protobuf:"bytes,2,opt,name=interface,proto3" json:"interface,omitempty"`
	// Which group does the interface belong to.
	Group string `protobuf:"bytes,3,opt,name=group,proto3" json:"group,omitempty"`
	// The version number of the interface.
	Version string `protobuf:"bytes,4,opt,name=version,proto3" json:"version,omitempty"`
	// The list of routes that will be matched, in order, against incoming requests. The first route
	// that matches will be used.
	Routes []*Route `protobuf:"bytes,5,rep,name=routes,proto3" json:"routes,omitempty"`
	// contains filtered or unexported fields
}

[#next-free-field: 6]

func (*RouteConfiguration) GetGroup

func (x *RouteConfiguration) GetGroup() string

func (*RouteConfiguration) GetInterface

func (x *RouteConfiguration) GetInterface() string

func (*RouteConfiguration) GetName

func (x *RouteConfiguration) GetName() string

func (*RouteConfiguration) GetRoutes

func (x *RouteConfiguration) GetRoutes() []*Route

func (*RouteConfiguration) GetVersion

func (x *RouteConfiguration) GetVersion() string

func (*RouteConfiguration) ProtoMessage

func (*RouteConfiguration) ProtoMessage()

func (*RouteConfiguration) ProtoReflect

func (x *RouteConfiguration) ProtoReflect() protoreflect.Message

func (*RouteConfiguration) Reset

func (x *RouteConfiguration) Reset()

func (*RouteConfiguration) SetGroup

func (x *RouteConfiguration) SetGroup(v string)

func (*RouteConfiguration) SetInterface

func (x *RouteConfiguration) SetInterface(v string)

func (*RouteConfiguration) SetName

func (x *RouteConfiguration) SetName(v string)

func (*RouteConfiguration) SetRoutes

func (x *RouteConfiguration) SetRoutes(v []*Route)

func (*RouteConfiguration) SetVersion

func (x *RouteConfiguration) SetVersion(v string)

func (*RouteConfiguration) String

func (x *RouteConfiguration) String() string

type RouteConfiguration_builder

type RouteConfiguration_builder struct {

	// The name of the route configuration. Reserved for future use in asynchronous route discovery.
	Name string
	// The interface name of the service. Wildcard interface are supported in the suffix or prefix form.
	// e.g. “*.methods.add“ will match “com.dev.methods.add“, “com.prod.methods.add“, etc.
	// “com.dev.methods.*“ will match “com.dev.methods.add“, “com.dev.methods.update“, etc.
	// Special wildcard “*“ matching any interface.
	//
	// .. note::
	//
	//	The wildcard will not match the empty string.
	//	e.g. “*.methods.add“ will match “com.dev.methods.add“ but not “.methods.add“.
	Interface string
	// Which group does the interface belong to.
	Group string
	// The version number of the interface.
	Version string
	// The list of routes that will be matched, in order, against incoming requests. The first route
	// that matches will be used.
	Routes []*Route
	// contains filtered or unexported fields
}

func (RouteConfiguration_builder) Build

type RouteMatch

type RouteMatch struct {

	// Method level routing matching.
	Method *MethodMatch `protobuf:"bytes,1,opt,name=method,proto3" json:"method,omitempty"`
	// Specifies a set of headers that the route should match on. The router will check the request’s
	// headers against all the specified headers in the route config. A match will happen if all the
	// headers in the route are present in the request with the same values (or based on presence if
	// the value field is not in the config).
	Headers []*v3.HeaderMatcher `protobuf:"bytes,2,rep,name=headers,proto3" json:"headers,omitempty"`
	// contains filtered or unexported fields
}

func (*RouteMatch) ClearMethod

func (x *RouteMatch) ClearMethod()

func (*RouteMatch) GetHeaders

func (x *RouteMatch) GetHeaders() []*v3.HeaderMatcher

func (*RouteMatch) GetMethod

func (x *RouteMatch) GetMethod() *MethodMatch

func (*RouteMatch) HasMethod

func (x *RouteMatch) HasMethod() bool

func (*RouteMatch) ProtoMessage

func (*RouteMatch) ProtoMessage()

func (*RouteMatch) ProtoReflect

func (x *RouteMatch) ProtoReflect() protoreflect.Message

func (*RouteMatch) Reset

func (x *RouteMatch) Reset()

func (*RouteMatch) SetHeaders

func (x *RouteMatch) SetHeaders(v []*v3.HeaderMatcher)

func (*RouteMatch) SetMethod

func (x *RouteMatch) SetMethod(v *MethodMatch)

func (*RouteMatch) String

func (x *RouteMatch) String() string

type RouteMatch_builder

type RouteMatch_builder struct {

	// Method level routing matching.
	Method *MethodMatch
	// Specifies a set of headers that the route should match on. The router will check the request’s
	// headers against all the specified headers in the route config. A match will happen if all the
	// headers in the route are present in the request with the same values (or based on presence if
	// the value field is not in the config).
	Headers []*v3.HeaderMatcher
	// contains filtered or unexported fields
}

func (RouteMatch_builder) Build

func (b0 RouteMatch_builder) Build() *RouteMatch

type Route_builder

type Route_builder struct {

	// Route matching parameters.
	Match *RouteMatch
	// Route request to some upstream cluster.
	Route *RouteAction
	// contains filtered or unexported fields
}

func (Route_builder) Build

func (b0 Route_builder) Build() *Route

type SerializationType

type SerializationType int32

Dubbo Serialization types supported by Envoy.

const (
	// the default serialization protocol.
	SerializationType_Hessian2 SerializationType = 0
)

func (SerializationType) Descriptor

func (SerializationType) Enum

func (SerializationType) Number

func (SerializationType) String

func (x SerializationType) String() string

func (SerializationType) Type

Source Files

  • dubbo_proxy.pb.go
  • route.pb.go

Jump to