payload_to_metadatav3

package
v1.36.11-2026031120213... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

const PayloadToMetadata_KeyValuePair_RegexValueRewrite_case case_PayloadToMetadata_KeyValuePair_ValueType = 4
const PayloadToMetadata_KeyValuePair_ValueType_not_set_case case_PayloadToMetadata_KeyValuePair_ValueType = 0
const PayloadToMetadata_KeyValuePair_Value_case case_PayloadToMetadata_KeyValuePair_ValueType = 3
const PayloadToMetadata_Rule_MatchSpecifier_not_set_case case_PayloadToMetadata_Rule_MatchSpecifier = 0
const PayloadToMetadata_Rule_MethodName_case case_PayloadToMetadata_Rule_MatchSpecifier = 1
const PayloadToMetadata_Rule_ServiceName_case case_PayloadToMetadata_Rule_MatchSpecifier = 2

Variables

var (
	PayloadToMetadata_ValueType_name = map[int32]string{
		0: "STRING",
		1: "NUMBER",
	}
	PayloadToMetadata_ValueType_value = map[string]int32{
		"STRING": 0,
		"NUMBER": 1,
	}
)

Enum value maps for PayloadToMetadata_ValueType.

var File_envoy_extensions_filters_network_thrift_proxy_filters_payload_to_metadata_v3_payload_to_metadata_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type PayloadToMetadata

type PayloadToMetadata struct {

	// The list of rules to apply to requests.
	RequestRules []*PayloadToMetadata_Rule `protobuf:"bytes,1,rep,name=request_rules,json=requestRules,proto3" json:"request_rules,omitempty"`
	// contains filtered or unexported fields
}

func (*PayloadToMetadata) GetRequestRules

func (x *PayloadToMetadata) GetRequestRules() []*PayloadToMetadata_Rule

func (*PayloadToMetadata) ProtoMessage

func (*PayloadToMetadata) ProtoMessage()

func (*PayloadToMetadata) ProtoReflect

func (x *PayloadToMetadata) ProtoReflect() protoreflect.Message

func (*PayloadToMetadata) Reset

func (x *PayloadToMetadata) Reset()

func (*PayloadToMetadata) SetRequestRules

func (x *PayloadToMetadata) SetRequestRules(v []*PayloadToMetadata_Rule)

func (*PayloadToMetadata) String

func (x *PayloadToMetadata) String() string

type PayloadToMetadata_FieldSelector

type PayloadToMetadata_FieldSelector struct {

	// field name to log
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// field id to match
	Id int32 `protobuf:"varint,2,opt,name=id,proto3" json:"id,omitempty"`
	// next node of the field selector
	Child *PayloadToMetadata_FieldSelector `protobuf:"bytes,3,opt,name=child,proto3" json:"child,omitempty"`
	// contains filtered or unexported fields
}

func (*PayloadToMetadata_FieldSelector) ClearChild

func (x *PayloadToMetadata_FieldSelector) ClearChild()

func (*PayloadToMetadata_FieldSelector) GetChild

func (*PayloadToMetadata_FieldSelector) GetId

func (*PayloadToMetadata_FieldSelector) GetName

func (*PayloadToMetadata_FieldSelector) HasChild

func (x *PayloadToMetadata_FieldSelector) HasChild() bool

func (*PayloadToMetadata_FieldSelector) ProtoMessage

func (*PayloadToMetadata_FieldSelector) ProtoMessage()

func (*PayloadToMetadata_FieldSelector) ProtoReflect

func (*PayloadToMetadata_FieldSelector) Reset

func (*PayloadToMetadata_FieldSelector) SetChild

func (*PayloadToMetadata_FieldSelector) SetId

func (*PayloadToMetadata_FieldSelector) SetName

func (*PayloadToMetadata_FieldSelector) String

type PayloadToMetadata_FieldSelector_builder

type PayloadToMetadata_FieldSelector_builder struct {

	// field name to log
	Name string
	// field id to match
	Id int32
	// next node of the field selector
	Child *PayloadToMetadata_FieldSelector
	// contains filtered or unexported fields
}

func (PayloadToMetadata_FieldSelector_builder) Build

type PayloadToMetadata_KeyValuePair

type PayloadToMetadata_KeyValuePair struct {

	// The namespace — if this is empty, the filter's namespace will be used.
	MetadataNamespace string `protobuf:"bytes,1,opt,name=metadata_namespace,json=metadataNamespace,proto3" json:"metadata_namespace,omitempty"`
	// The key to use within the namespace.
	Key string `protobuf:"bytes,2,opt,name=key,proto3" json:"key,omitempty"`
	// Types that are valid to be assigned to ValueType:
	//
	//	*PayloadToMetadata_KeyValuePair_Value
	//	*PayloadToMetadata_KeyValuePair_RegexValueRewrite
	ValueType isPayloadToMetadata_KeyValuePair_ValueType `protobuf_oneof:"value_type"`
	// The value's type — defaults to string.
	Type PayloadToMetadata_ValueType `` /* 172-byte string literal not displayed */
	// contains filtered or unexported fields
}

[#next-free-field: 6]

func (*PayloadToMetadata_KeyValuePair) ClearRegexValueRewrite

func (x *PayloadToMetadata_KeyValuePair) ClearRegexValueRewrite()

func (*PayloadToMetadata_KeyValuePair) ClearValue

func (x *PayloadToMetadata_KeyValuePair) ClearValue()

func (*PayloadToMetadata_KeyValuePair) ClearValueType

func (x *PayloadToMetadata_KeyValuePair) ClearValueType()

func (*PayloadToMetadata_KeyValuePair) GetKey

func (*PayloadToMetadata_KeyValuePair) GetMetadataNamespace

func (x *PayloadToMetadata_KeyValuePair) GetMetadataNamespace() string

func (*PayloadToMetadata_KeyValuePair) GetRegexValueRewrite

func (x *PayloadToMetadata_KeyValuePair) GetRegexValueRewrite() *v3.RegexMatchAndSubstitute

func (*PayloadToMetadata_KeyValuePair) GetType

func (*PayloadToMetadata_KeyValuePair) GetValue

func (x *PayloadToMetadata_KeyValuePair) GetValue() string

func (*PayloadToMetadata_KeyValuePair) GetValueType

func (x *PayloadToMetadata_KeyValuePair) GetValueType() isPayloadToMetadata_KeyValuePair_ValueType

func (*PayloadToMetadata_KeyValuePair) HasRegexValueRewrite

func (x *PayloadToMetadata_KeyValuePair) HasRegexValueRewrite() bool

func (*PayloadToMetadata_KeyValuePair) HasValue

func (x *PayloadToMetadata_KeyValuePair) HasValue() bool

func (*PayloadToMetadata_KeyValuePair) HasValueType

func (x *PayloadToMetadata_KeyValuePair) HasValueType() bool

func (*PayloadToMetadata_KeyValuePair) ProtoMessage

func (*PayloadToMetadata_KeyValuePair) ProtoMessage()

func (*PayloadToMetadata_KeyValuePair) ProtoReflect

func (*PayloadToMetadata_KeyValuePair) Reset

func (x *PayloadToMetadata_KeyValuePair) Reset()

func (*PayloadToMetadata_KeyValuePair) SetKey

func (*PayloadToMetadata_KeyValuePair) SetMetadataNamespace

func (x *PayloadToMetadata_KeyValuePair) SetMetadataNamespace(v string)

func (*PayloadToMetadata_KeyValuePair) SetRegexValueRewrite

func (x *PayloadToMetadata_KeyValuePair) SetRegexValueRewrite(v *v3.RegexMatchAndSubstitute)

func (*PayloadToMetadata_KeyValuePair) SetType

func (*PayloadToMetadata_KeyValuePair) SetValue

func (x *PayloadToMetadata_KeyValuePair) SetValue(v string)

func (*PayloadToMetadata_KeyValuePair) String

func (*PayloadToMetadata_KeyValuePair) WhichValueType

func (x *PayloadToMetadata_KeyValuePair) WhichValueType() case_PayloadToMetadata_KeyValuePair_ValueType

type PayloadToMetadata_KeyValuePair_RegexValueRewrite

type PayloadToMetadata_KeyValuePair_RegexValueRewrite struct {
	// If present, the header's value will be matched and substituted with this.
	// If there is no match or substitution, the field value is used as-is.
	//
	// This is only used for on_present.
	RegexValueRewrite *v3.RegexMatchAndSubstitute `protobuf:"bytes,4,opt,name=regex_value_rewrite,json=regexValueRewrite,proto3,oneof"`
}

type PayloadToMetadata_KeyValuePair_Value

type PayloadToMetadata_KeyValuePair_Value struct {
	// The value to pair with the given key.
	//
	// When used for on_present case, if value is non-empty it'll be used instead
	// of the field value. If both are empty, the field value is used as-is.
	//
	// When used for on_missing case, a non-empty value must be provided.
	Value string `protobuf:"bytes,3,opt,name=value,proto3,oneof"`
}

type PayloadToMetadata_KeyValuePair_builder

type PayloadToMetadata_KeyValuePair_builder struct {

	// The namespace — if this is empty, the filter's namespace will be used.
	MetadataNamespace string
	// The key to use within the namespace.
	Key string
	// Fields of oneof ValueType:
	// The value to pair with the given key.
	//
	// When used for on_present case, if value is non-empty it'll be used instead
	// of the field value. If both are empty, the field value is used as-is.
	//
	// When used for on_missing case, a non-empty value must be provided.
	Value *string
	// If present, the header's value will be matched and substituted with this.
	// If there is no match or substitution, the field value is used as-is.
	//
	// This is only used for on_present.
	RegexValueRewrite *v3.RegexMatchAndSubstitute
	// -- end of ValueType
	// The value's type — defaults to string.
	Type PayloadToMetadata_ValueType
	// contains filtered or unexported fields
}

func (PayloadToMetadata_KeyValuePair_builder) Build

type PayloadToMetadata_Rule

type PayloadToMetadata_Rule struct {

	// Types that are valid to be assigned to MatchSpecifier:
	//
	//	*PayloadToMetadata_Rule_MethodName
	//	*PayloadToMetadata_Rule_ServiceName
	MatchSpecifier isPayloadToMetadata_Rule_MatchSpecifier `protobuf_oneof:"match_specifier"`
	// Specifies that a match will be performed on the value of a field.
	FieldSelector *PayloadToMetadata_FieldSelector `protobuf:"bytes,3,opt,name=field_selector,json=fieldSelector,proto3" json:"field_selector,omitempty"`
	// If the field is present, apply this metadata KeyValuePair.
	OnPresent *PayloadToMetadata_KeyValuePair `protobuf:"bytes,4,opt,name=on_present,json=onPresent,proto3" json:"on_present,omitempty"`
	// If the field is missing, apply this metadata KeyValuePair.
	//
	// The value in the KeyValuePair must be set, since it'll be used in lieu
	// of the missing field value.
	OnMissing *PayloadToMetadata_KeyValuePair `protobuf:"bytes,5,opt,name=on_missing,json=onMissing,proto3" json:"on_missing,omitempty"`
	// contains filtered or unexported fields
}

A Rule defines what metadata to apply when a field is present or missing. [#next-free-field: 6]

func (*PayloadToMetadata_Rule) ClearFieldSelector

func (x *PayloadToMetadata_Rule) ClearFieldSelector()

func (*PayloadToMetadata_Rule) ClearMatchSpecifier

func (x *PayloadToMetadata_Rule) ClearMatchSpecifier()

func (*PayloadToMetadata_Rule) ClearMethodName

func (x *PayloadToMetadata_Rule) ClearMethodName()

func (*PayloadToMetadata_Rule) ClearOnMissing

func (x *PayloadToMetadata_Rule) ClearOnMissing()

func (*PayloadToMetadata_Rule) ClearOnPresent

func (x *PayloadToMetadata_Rule) ClearOnPresent()

func (*PayloadToMetadata_Rule) ClearServiceName

func (x *PayloadToMetadata_Rule) ClearServiceName()

func (*PayloadToMetadata_Rule) GetFieldSelector

func (*PayloadToMetadata_Rule) GetMatchSpecifier

func (x *PayloadToMetadata_Rule) GetMatchSpecifier() isPayloadToMetadata_Rule_MatchSpecifier

func (*PayloadToMetadata_Rule) GetMethodName

func (x *PayloadToMetadata_Rule) GetMethodName() string

func (*PayloadToMetadata_Rule) GetOnMissing

func (*PayloadToMetadata_Rule) GetOnPresent

func (*PayloadToMetadata_Rule) GetServiceName

func (x *PayloadToMetadata_Rule) GetServiceName() string

func (*PayloadToMetadata_Rule) HasFieldSelector

func (x *PayloadToMetadata_Rule) HasFieldSelector() bool

func (*PayloadToMetadata_Rule) HasMatchSpecifier

func (x *PayloadToMetadata_Rule) HasMatchSpecifier() bool

func (*PayloadToMetadata_Rule) HasMethodName

func (x *PayloadToMetadata_Rule) HasMethodName() bool

func (*PayloadToMetadata_Rule) HasOnMissing

func (x *PayloadToMetadata_Rule) HasOnMissing() bool

func (*PayloadToMetadata_Rule) HasOnPresent

func (x *PayloadToMetadata_Rule) HasOnPresent() bool

func (*PayloadToMetadata_Rule) HasServiceName

func (x *PayloadToMetadata_Rule) HasServiceName() bool

func (*PayloadToMetadata_Rule) ProtoMessage

func (*PayloadToMetadata_Rule) ProtoMessage()

func (*PayloadToMetadata_Rule) ProtoReflect

func (x *PayloadToMetadata_Rule) ProtoReflect() protoreflect.Message

func (*PayloadToMetadata_Rule) Reset

func (x *PayloadToMetadata_Rule) Reset()

func (*PayloadToMetadata_Rule) SetFieldSelector

func (*PayloadToMetadata_Rule) SetMethodName

func (x *PayloadToMetadata_Rule) SetMethodName(v string)

func (*PayloadToMetadata_Rule) SetOnMissing

func (*PayloadToMetadata_Rule) SetOnPresent

func (*PayloadToMetadata_Rule) SetServiceName

func (x *PayloadToMetadata_Rule) SetServiceName(v string)

func (*PayloadToMetadata_Rule) String

func (x *PayloadToMetadata_Rule) String() string

func (*PayloadToMetadata_Rule) WhichMatchSpecifier

func (x *PayloadToMetadata_Rule) WhichMatchSpecifier() case_PayloadToMetadata_Rule_MatchSpecifier

type PayloadToMetadata_Rule_MethodName

type PayloadToMetadata_Rule_MethodName struct {
	// If specified, the route must exactly match the request method name. As a special case,
	// an empty string matches any request method name.
	MethodName string `protobuf:"bytes,1,opt,name=method_name,json=methodName,proto3,oneof"`
}

type PayloadToMetadata_Rule_ServiceName

type PayloadToMetadata_Rule_ServiceName struct {
	// If specified, the route must have the service name as the request method name prefix.
	// As a special case, an empty string matches any service name. Only relevant when service
	// multiplexing.
	ServiceName string `protobuf:"bytes,2,opt,name=service_name,json=serviceName,proto3,oneof"`
}

type PayloadToMetadata_Rule_builder

type PayloadToMetadata_Rule_builder struct {

	// Fields of oneof MatchSpecifier:
	// If specified, the route must exactly match the request method name. As a special case,
	// an empty string matches any request method name.
	MethodName *string
	// If specified, the route must have the service name as the request method name prefix.
	// As a special case, an empty string matches any service name. Only relevant when service
	// multiplexing.
	ServiceName *string
	// -- end of MatchSpecifier
	// Specifies that a match will be performed on the value of a field.
	FieldSelector *PayloadToMetadata_FieldSelector
	// If the field is present, apply this metadata KeyValuePair.
	OnPresent *PayloadToMetadata_KeyValuePair
	// If the field is missing, apply this metadata KeyValuePair.
	//
	// The value in the KeyValuePair must be set, since it'll be used in lieu
	// of the missing field value.
	OnMissing *PayloadToMetadata_KeyValuePair
	// contains filtered or unexported fields
}

func (PayloadToMetadata_Rule_builder) Build

type PayloadToMetadata_ValueType

type PayloadToMetadata_ValueType int32
const (
	PayloadToMetadata_STRING PayloadToMetadata_ValueType = 0
	PayloadToMetadata_NUMBER PayloadToMetadata_ValueType = 1
)

func (PayloadToMetadata_ValueType) Descriptor

func (PayloadToMetadata_ValueType) Enum

func (PayloadToMetadata_ValueType) Number

func (PayloadToMetadata_ValueType) String

func (PayloadToMetadata_ValueType) Type

type PayloadToMetadata_builder

type PayloadToMetadata_builder struct {

	// The list of rules to apply to requests.
	RequestRules []*PayloadToMetadata_Rule
	// contains filtered or unexported fields
}

func (PayloadToMetadata_builder) Build

Source Files

  • payload_to_metadata.pb.go

Jump to