Documentation
¶
Index ¶
- Variables
- type RateLimit
- func (x *RateLimit) ClearRateLimitService()
- func (x *RateLimit) ClearTimeout()
- func (x *RateLimit) GetDomain() string
- func (x *RateLimit) GetFailureModeDeny() bool
- func (x *RateLimit) GetRateLimitService() *v3.RateLimitServiceConfig
- func (x *RateLimit) GetStage() uint32
- func (x *RateLimit) GetTimeout() *durationpb.Duration
- func (x *RateLimit) HasRateLimitService() bool
- func (x *RateLimit) HasTimeout() bool
- func (*RateLimit) ProtoMessage()
- func (x *RateLimit) ProtoReflect() protoreflect.Message
- func (x *RateLimit) Reset()
- func (x *RateLimit) SetDomain(v string)
- func (x *RateLimit) SetFailureModeDeny(v bool)
- func (x *RateLimit) SetRateLimitService(v *v3.RateLimitServiceConfig)
- func (x *RateLimit) SetStage(v uint32)
- func (x *RateLimit) SetTimeout(v *durationpb.Duration)
- func (x *RateLimit) String() string
- type RateLimit_builder
Constants ¶
This section is empty.
Variables ¶
var File_envoy_extensions_filters_network_thrift_proxy_filters_ratelimit_v3_rate_limit_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type RateLimit ¶
type RateLimit struct {
// The rate limit domain to use in the rate limit service request.
Domain string `protobuf:"bytes,1,opt,name=domain,proto3" json:"domain,omitempty"`
// Specifies the rate limit configuration stage. Each configured rate limit filter performs a
// rate limit check using descriptors configured in the
// :ref:`envoy_v3_api_msg_extensions.filters.network.thrift_proxy.v3.RouteAction` for the request.
// Only those entries with a matching stage number are used for a given filter. If not set, the
// default stage number is 0.
//
// .. note::
//
// The filter supports a range of 0 - 10 inclusively for stage numbers.
Stage uint32 `protobuf:"varint,2,opt,name=stage,proto3" json:"stage,omitempty"`
// The timeout in milliseconds for the rate limit service RPC. If not
// set, this defaults to 20ms.
Timeout *durationpb.Duration `protobuf:"bytes,3,opt,name=timeout,proto3" json:"timeout,omitempty"`
// The filter's behaviour in case the rate limiting service does
// not respond back. When it is set to true, Envoy will not allow traffic in case of
// communication failure between rate limiting service and the proxy.
// Defaults to false.
FailureModeDeny bool `protobuf:"varint,4,opt,name=failure_mode_deny,json=failureModeDeny,proto3" json:"failure_mode_deny,omitempty"`
// Configuration for an external rate limit service provider. If not
// specified, any calls to the rate limit service will immediately return
// success.
RateLimitService *v3.RateLimitServiceConfig `protobuf:"bytes,5,opt,name=rate_limit_service,json=rateLimitService,proto3" json:"rate_limit_service,omitempty"`
// contains filtered or unexported fields
}
[#next-free-field: 6]
func (*RateLimit) GetRateLimitService ¶
func (x *RateLimit) GetRateLimitService() *v3.RateLimitServiceConfig
func (*RateLimit) GetTimeout ¶
func (x *RateLimit) GetTimeout() *durationpb.Duration
func (*RateLimit) ProtoReflect ¶
func (x *RateLimit) ProtoReflect() protoreflect.Message
func (*RateLimit) SetRateLimitService ¶
func (x *RateLimit) SetRateLimitService(v *v3.RateLimitServiceConfig)
func (*RateLimit) SetTimeout ¶
func (x *RateLimit) SetTimeout(v *durationpb.Duration)
type RateLimit_builder ¶
type RateLimit_builder struct {
// The rate limit domain to use in the rate limit service request.
Domain string
// Specifies the rate limit configuration stage. Each configured rate limit filter performs a
// rate limit check using descriptors configured in the
// :ref:`envoy_v3_api_msg_extensions.filters.network.thrift_proxy.v3.RouteAction` for the request.
// Only those entries with a matching stage number are used for a given filter. If not set, the
// default stage number is 0.
//
// .. note::
//
// The filter supports a range of 0 - 10 inclusively for stage numbers.
Stage uint32
// The timeout in milliseconds for the rate limit service RPC. If not
// set, this defaults to 20ms.
Timeout *durationpb.Duration
// The filter's behaviour in case the rate limiting service does
// not respond back. When it is set to true, Envoy will not allow traffic in case of
// communication failure between rate limiting service and the proxy.
// Defaults to false.
FailureModeDeny bool
// Configuration for an external rate limit service provider. If not
// specified, any calls to the rate limit service will immediately return
// success.
RateLimitService *v3.RateLimitServiceConfig
// contains filtered or unexported fields
}
func (RateLimit_builder) Build ¶
func (b0 RateLimit_builder) Build() *RateLimit
Source Files
¶
- rate_limit.pb.go
Click to show internal directories.
Click to hide internal directories.