Documentation
¶
Index ¶
- Variables
- type LatencyThresholdOverride
- func (x *LatencyThresholdOverride) ClearThreshold()
- func (x *LatencyThresholdOverride) GetOpcode() LatencyThresholdOverride_Opcode
- func (x *LatencyThresholdOverride) GetThreshold() *durationpb.Duration
- func (x *LatencyThresholdOverride) HasThreshold() bool
- func (*LatencyThresholdOverride) ProtoMessage()
- func (x *LatencyThresholdOverride) ProtoReflect() protoreflect.Message
- func (x *LatencyThresholdOverride) Reset()
- func (x *LatencyThresholdOverride) SetOpcode(v LatencyThresholdOverride_Opcode)
- func (x *LatencyThresholdOverride) SetThreshold(v *durationpb.Duration)
- func (x *LatencyThresholdOverride) String() string
- type LatencyThresholdOverride_Opcode
- func (LatencyThresholdOverride_Opcode) Descriptor() protoreflect.EnumDescriptor
- func (x LatencyThresholdOverride_Opcode) Enum() *LatencyThresholdOverride_Opcode
- func (x LatencyThresholdOverride_Opcode) Number() protoreflect.EnumNumber
- func (x LatencyThresholdOverride_Opcode) String() string
- func (LatencyThresholdOverride_Opcode) Type() protoreflect.EnumType
- type LatencyThresholdOverride_builder
- type ZooKeeperProxy
- func (x *ZooKeeperProxy) ClearDefaultLatencyThreshold()
- func (x *ZooKeeperProxy) ClearMaxPacketBytes()
- func (x *ZooKeeperProxy) GetAccessLog() string
- func (x *ZooKeeperProxy) GetDefaultLatencyThreshold() *durationpb.Duration
- func (x *ZooKeeperProxy) GetEnableLatencyThresholdMetrics() bool
- func (x *ZooKeeperProxy) GetEnablePerOpcodeDecoderErrorMetrics() bool
- func (x *ZooKeeperProxy) GetEnablePerOpcodeRequestBytesMetrics() bool
- func (x *ZooKeeperProxy) GetEnablePerOpcodeResponseBytesMetrics() bool
- func (x *ZooKeeperProxy) GetLatencyThresholdOverrides() []*LatencyThresholdOverride
- func (x *ZooKeeperProxy) GetMaxPacketBytes() *wrapperspb.UInt32Value
- func (x *ZooKeeperProxy) GetStatPrefix() string
- func (x *ZooKeeperProxy) HasDefaultLatencyThreshold() bool
- func (x *ZooKeeperProxy) HasMaxPacketBytes() bool
- func (*ZooKeeperProxy) ProtoMessage()
- func (x *ZooKeeperProxy) ProtoReflect() protoreflect.Message
- func (x *ZooKeeperProxy) Reset()
- func (x *ZooKeeperProxy) SetAccessLog(v string)
- func (x *ZooKeeperProxy) SetDefaultLatencyThreshold(v *durationpb.Duration)
- func (x *ZooKeeperProxy) SetEnableLatencyThresholdMetrics(v bool)
- func (x *ZooKeeperProxy) SetEnablePerOpcodeDecoderErrorMetrics(v bool)
- func (x *ZooKeeperProxy) SetEnablePerOpcodeRequestBytesMetrics(v bool)
- func (x *ZooKeeperProxy) SetEnablePerOpcodeResponseBytesMetrics(v bool)
- func (x *ZooKeeperProxy) SetLatencyThresholdOverrides(v []*LatencyThresholdOverride)
- func (x *ZooKeeperProxy) SetMaxPacketBytes(v *wrapperspb.UInt32Value)
- func (x *ZooKeeperProxy) SetStatPrefix(v string)
- func (x *ZooKeeperProxy) String() string
- type ZooKeeperProxy_builder
Constants ¶
This section is empty.
Variables ¶
var ( LatencyThresholdOverride_Opcode_name = map[int32]string{ 0: "Connect", 1: "Create", 2: "Delete", 3: "Exists", 4: "GetData", 5: "SetData", 6: "GetAcl", 7: "SetAcl", 8: "GetChildren", 9: "Sync", 10: "Ping", 11: "GetChildren2", 12: "Check", 13: "Multi", 14: "Create2", 15: "Reconfig", 16: "CheckWatches", 17: "RemoveWatches", 18: "CreateContainer", 19: "CreateTtl", 20: "Close", 21: "SetAuth", 22: "SetWatches", 23: "GetEphemerals", 24: "GetAllChildrenNumber", 25: "SetWatches2", 26: "AddWatch", } LatencyThresholdOverride_Opcode_value = map[string]int32{ "Connect": 0, "Create": 1, "Delete": 2, "Exists": 3, "GetData": 4, "SetData": 5, "GetAcl": 6, "SetAcl": 7, "GetChildren": 8, "Sync": 9, "Ping": 10, "GetChildren2": 11, "Check": 12, "Multi": 13, "Create2": 14, "Reconfig": 15, "CheckWatches": 16, "RemoveWatches": 17, "CreateContainer": 18, "CreateTtl": 19, "Close": 20, "SetAuth": 21, "SetWatches": 22, "GetEphemerals": 23, "GetAllChildrenNumber": 24, "SetWatches2": 25, "AddWatch": 26, } )
Enum value maps for LatencyThresholdOverride_Opcode.
var File_envoy_extensions_filters_network_zookeeper_proxy_v3_zookeeper_proxy_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type LatencyThresholdOverride ¶
type LatencyThresholdOverride struct {
// The ZooKeeper opcodes. Can be found as part of the ZooKeeper source code:
//
// https://github.com/apache/zookeeper/blob/master/zookeeper-server/src/main/java/org/apache/zookeeper/ZooDefs.java
Opcode LatencyThresholdOverride_Opcode `` /* 155-byte string literal not displayed */
// The latency threshold override of certain opcode.
Threshold *durationpb.Duration `protobuf:"bytes,2,opt,name=threshold,proto3" json:"threshold,omitempty"`
// contains filtered or unexported fields
}
func (*LatencyThresholdOverride) ClearThreshold ¶
func (x *LatencyThresholdOverride) ClearThreshold()
func (*LatencyThresholdOverride) GetOpcode ¶
func (x *LatencyThresholdOverride) GetOpcode() LatencyThresholdOverride_Opcode
func (*LatencyThresholdOverride) GetThreshold ¶
func (x *LatencyThresholdOverride) GetThreshold() *durationpb.Duration
func (*LatencyThresholdOverride) HasThreshold ¶
func (x *LatencyThresholdOverride) HasThreshold() bool
func (*LatencyThresholdOverride) ProtoMessage ¶
func (*LatencyThresholdOverride) ProtoMessage()
func (*LatencyThresholdOverride) ProtoReflect ¶
func (x *LatencyThresholdOverride) ProtoReflect() protoreflect.Message
func (*LatencyThresholdOverride) Reset ¶
func (x *LatencyThresholdOverride) Reset()
func (*LatencyThresholdOverride) SetOpcode ¶
func (x *LatencyThresholdOverride) SetOpcode(v LatencyThresholdOverride_Opcode)
func (*LatencyThresholdOverride) SetThreshold ¶
func (x *LatencyThresholdOverride) SetThreshold(v *durationpb.Duration)
func (*LatencyThresholdOverride) String ¶
func (x *LatencyThresholdOverride) String() string
type LatencyThresholdOverride_Opcode ¶
type LatencyThresholdOverride_Opcode int32
const ( LatencyThresholdOverride_Connect LatencyThresholdOverride_Opcode = 0 LatencyThresholdOverride_Create LatencyThresholdOverride_Opcode = 1 LatencyThresholdOverride_Delete LatencyThresholdOverride_Opcode = 2 LatencyThresholdOverride_Exists LatencyThresholdOverride_Opcode = 3 LatencyThresholdOverride_GetData LatencyThresholdOverride_Opcode = 4 LatencyThresholdOverride_SetData LatencyThresholdOverride_Opcode = 5 LatencyThresholdOverride_GetAcl LatencyThresholdOverride_Opcode = 6 LatencyThresholdOverride_SetAcl LatencyThresholdOverride_Opcode = 7 LatencyThresholdOverride_GetChildren LatencyThresholdOverride_Opcode = 8 LatencyThresholdOverride_Sync LatencyThresholdOverride_Opcode = 9 LatencyThresholdOverride_Ping LatencyThresholdOverride_Opcode = 10 LatencyThresholdOverride_GetChildren2 LatencyThresholdOverride_Opcode = 11 LatencyThresholdOverride_Check LatencyThresholdOverride_Opcode = 12 LatencyThresholdOverride_Multi LatencyThresholdOverride_Opcode = 13 LatencyThresholdOverride_Create2 LatencyThresholdOverride_Opcode = 14 LatencyThresholdOverride_Reconfig LatencyThresholdOverride_Opcode = 15 LatencyThresholdOverride_CheckWatches LatencyThresholdOverride_Opcode = 16 LatencyThresholdOverride_RemoveWatches LatencyThresholdOverride_Opcode = 17 LatencyThresholdOverride_CreateContainer LatencyThresholdOverride_Opcode = 18 LatencyThresholdOverride_CreateTtl LatencyThresholdOverride_Opcode = 19 LatencyThresholdOverride_Close LatencyThresholdOverride_Opcode = 20 LatencyThresholdOverride_SetAuth LatencyThresholdOverride_Opcode = 21 LatencyThresholdOverride_SetWatches LatencyThresholdOverride_Opcode = 22 LatencyThresholdOverride_GetEphemerals LatencyThresholdOverride_Opcode = 23 LatencyThresholdOverride_GetAllChildrenNumber LatencyThresholdOverride_Opcode = 24 LatencyThresholdOverride_SetWatches2 LatencyThresholdOverride_Opcode = 25 LatencyThresholdOverride_AddWatch LatencyThresholdOverride_Opcode = 26 )
func (LatencyThresholdOverride_Opcode) Descriptor ¶
func (LatencyThresholdOverride_Opcode) Descriptor() protoreflect.EnumDescriptor
func (LatencyThresholdOverride_Opcode) Enum ¶
func (x LatencyThresholdOverride_Opcode) Enum() *LatencyThresholdOverride_Opcode
func (LatencyThresholdOverride_Opcode) Number ¶
func (x LatencyThresholdOverride_Opcode) Number() protoreflect.EnumNumber
func (LatencyThresholdOverride_Opcode) String ¶
func (x LatencyThresholdOverride_Opcode) String() string
func (LatencyThresholdOverride_Opcode) Type ¶
func (LatencyThresholdOverride_Opcode) Type() protoreflect.EnumType
type LatencyThresholdOverride_builder ¶
type LatencyThresholdOverride_builder struct {
// The ZooKeeper opcodes. Can be found as part of the ZooKeeper source code:
//
// https://github.com/apache/zookeeper/blob/master/zookeeper-server/src/main/java/org/apache/zookeeper/ZooDefs.java
Opcode LatencyThresholdOverride_Opcode
// The latency threshold override of certain opcode.
Threshold *durationpb.Duration
// contains filtered or unexported fields
}
func (LatencyThresholdOverride_builder) Build ¶
func (b0 LatencyThresholdOverride_builder) Build() *LatencyThresholdOverride
type ZooKeeperProxy ¶
type ZooKeeperProxy struct {
// The human readable prefix to use when emitting :ref:`statistics
// <config_network_filters_zookeeper_proxy_stats>`.
StatPrefix string `protobuf:"bytes,1,opt,name=stat_prefix,json=statPrefix,proto3" json:"stat_prefix,omitempty"`
// [#not-implemented-hide:] The optional path to use for writing ZooKeeper access logs.
// If the access log field is empty, access logs will not be written.
AccessLog string `protobuf:"bytes,2,opt,name=access_log,json=accessLog,proto3" json:"access_log,omitempty"`
// Messages — requests, responses and events — that are bigger than this value will
// be ignored. If it is not set, the default value is 1Mb.
//
// The value here should match the jute.maxbuffer property in your cluster configuration:
//
// https://zookeeper.apache.org/doc/r3.4.10/zookeeperAdmin.html#Unsafe+Options
//
// if that is set. If it isn't, ZooKeeper's default is also 1Mb.
MaxPacketBytes *wrapperspb.UInt32Value `protobuf:"bytes,3,opt,name=max_packet_bytes,json=maxPacketBytes,proto3" json:"max_packet_bytes,omitempty"`
// Whether to emit latency threshold metrics. If not set, it defaults to false.
// If false, setting “default_latency_threshold“ and “latency_threshold_overrides“ will not have effect.
EnableLatencyThresholdMetrics bool `` /* 153-byte string literal not displayed */
// The default latency threshold to decide the fast/slow responses and emit metrics (used for error budget calculation).
//
// https://sre.google/workbook/implementing-slos/
//
// If it is not set, the default value is 100 milliseconds.
DefaultLatencyThreshold *durationpb.Duration `` /* 132-byte string literal not displayed */
// List of latency threshold overrides for opcodes.
// If the threshold override of one opcode is not set, it will fallback to the default latency
// threshold.
// Specifying latency threshold overrides multiple times for one opcode is not allowed.
LatencyThresholdOverrides []*LatencyThresholdOverride `` /* 138-byte string literal not displayed */
// Whether to emit per opcode request bytes metrics. If not set, it defaults to false.
EnablePerOpcodeRequestBytesMetrics bool `` /* 172-byte string literal not displayed */
// Whether to emit per opcode response bytes metrics. If not set, it defaults to false.
EnablePerOpcodeResponseBytesMetrics bool `` /* 175-byte string literal not displayed */
// Whether to emit per opcode decoder error metrics. If not set, it defaults to false.
EnablePerOpcodeDecoderErrorMetrics bool `` /* 172-byte string literal not displayed */
// contains filtered or unexported fields
}
[#next-free-field: 10]
func (*ZooKeeperProxy) ClearDefaultLatencyThreshold ¶
func (x *ZooKeeperProxy) ClearDefaultLatencyThreshold()
func (*ZooKeeperProxy) ClearMaxPacketBytes ¶
func (x *ZooKeeperProxy) ClearMaxPacketBytes()
func (*ZooKeeperProxy) GetAccessLog ¶
func (x *ZooKeeperProxy) GetAccessLog() string
func (*ZooKeeperProxy) GetDefaultLatencyThreshold ¶
func (x *ZooKeeperProxy) GetDefaultLatencyThreshold() *durationpb.Duration
func (*ZooKeeperProxy) GetEnableLatencyThresholdMetrics ¶
func (x *ZooKeeperProxy) GetEnableLatencyThresholdMetrics() bool
func (*ZooKeeperProxy) GetEnablePerOpcodeDecoderErrorMetrics ¶
func (x *ZooKeeperProxy) GetEnablePerOpcodeDecoderErrorMetrics() bool
func (*ZooKeeperProxy) GetEnablePerOpcodeRequestBytesMetrics ¶
func (x *ZooKeeperProxy) GetEnablePerOpcodeRequestBytesMetrics() bool
func (*ZooKeeperProxy) GetEnablePerOpcodeResponseBytesMetrics ¶
func (x *ZooKeeperProxy) GetEnablePerOpcodeResponseBytesMetrics() bool
func (*ZooKeeperProxy) GetLatencyThresholdOverrides ¶
func (x *ZooKeeperProxy) GetLatencyThresholdOverrides() []*LatencyThresholdOverride
func (*ZooKeeperProxy) GetMaxPacketBytes ¶
func (x *ZooKeeperProxy) GetMaxPacketBytes() *wrapperspb.UInt32Value
func (*ZooKeeperProxy) GetStatPrefix ¶
func (x *ZooKeeperProxy) GetStatPrefix() string
func (*ZooKeeperProxy) HasDefaultLatencyThreshold ¶
func (x *ZooKeeperProxy) HasDefaultLatencyThreshold() bool
func (*ZooKeeperProxy) HasMaxPacketBytes ¶
func (x *ZooKeeperProxy) HasMaxPacketBytes() bool
func (*ZooKeeperProxy) ProtoMessage ¶
func (*ZooKeeperProxy) ProtoMessage()
func (*ZooKeeperProxy) ProtoReflect ¶
func (x *ZooKeeperProxy) ProtoReflect() protoreflect.Message
func (*ZooKeeperProxy) Reset ¶
func (x *ZooKeeperProxy) Reset()
func (*ZooKeeperProxy) SetAccessLog ¶
func (x *ZooKeeperProxy) SetAccessLog(v string)
func (*ZooKeeperProxy) SetDefaultLatencyThreshold ¶
func (x *ZooKeeperProxy) SetDefaultLatencyThreshold(v *durationpb.Duration)
func (*ZooKeeperProxy) SetEnableLatencyThresholdMetrics ¶
func (x *ZooKeeperProxy) SetEnableLatencyThresholdMetrics(v bool)
func (*ZooKeeperProxy) SetEnablePerOpcodeDecoderErrorMetrics ¶
func (x *ZooKeeperProxy) SetEnablePerOpcodeDecoderErrorMetrics(v bool)
func (*ZooKeeperProxy) SetEnablePerOpcodeRequestBytesMetrics ¶
func (x *ZooKeeperProxy) SetEnablePerOpcodeRequestBytesMetrics(v bool)
func (*ZooKeeperProxy) SetEnablePerOpcodeResponseBytesMetrics ¶
func (x *ZooKeeperProxy) SetEnablePerOpcodeResponseBytesMetrics(v bool)
func (*ZooKeeperProxy) SetLatencyThresholdOverrides ¶
func (x *ZooKeeperProxy) SetLatencyThresholdOverrides(v []*LatencyThresholdOverride)
func (*ZooKeeperProxy) SetMaxPacketBytes ¶
func (x *ZooKeeperProxy) SetMaxPacketBytes(v *wrapperspb.UInt32Value)
func (*ZooKeeperProxy) SetStatPrefix ¶
func (x *ZooKeeperProxy) SetStatPrefix(v string)
func (*ZooKeeperProxy) String ¶
func (x *ZooKeeperProxy) String() string
type ZooKeeperProxy_builder ¶
type ZooKeeperProxy_builder struct {
// The human readable prefix to use when emitting :ref:`statistics
// <config_network_filters_zookeeper_proxy_stats>`.
StatPrefix string
// [#not-implemented-hide:] The optional path to use for writing ZooKeeper access logs.
// If the access log field is empty, access logs will not be written.
AccessLog string
// Messages — requests, responses and events — that are bigger than this value will
// be ignored. If it is not set, the default value is 1Mb.
//
// The value here should match the jute.maxbuffer property in your cluster configuration:
//
// https://zookeeper.apache.org/doc/r3.4.10/zookeeperAdmin.html#Unsafe+Options
//
// if that is set. If it isn't, ZooKeeper's default is also 1Mb.
MaxPacketBytes *wrapperspb.UInt32Value
// Whether to emit latency threshold metrics. If not set, it defaults to false.
// If false, setting “default_latency_threshold“ and “latency_threshold_overrides“ will not have effect.
EnableLatencyThresholdMetrics bool
// The default latency threshold to decide the fast/slow responses and emit metrics (used for error budget calculation).
//
// https://sre.google/workbook/implementing-slos/
//
// If it is not set, the default value is 100 milliseconds.
DefaultLatencyThreshold *durationpb.Duration
// List of latency threshold overrides for opcodes.
// If the threshold override of one opcode is not set, it will fallback to the default latency
// threshold.
// Specifying latency threshold overrides multiple times for one opcode is not allowed.
LatencyThresholdOverrides []*LatencyThresholdOverride
// Whether to emit per opcode request bytes metrics. If not set, it defaults to false.
EnablePerOpcodeRequestBytesMetrics bool
// Whether to emit per opcode response bytes metrics. If not set, it defaults to false.
EnablePerOpcodeResponseBytesMetrics bool
// Whether to emit per opcode decoder error metrics. If not set, it defaults to false.
EnablePerOpcodeDecoderErrorMetrics bool
// contains filtered or unexported fields
}
func (ZooKeeperProxy_builder) Build ¶
func (b0 ZooKeeperProxy_builder) Build() *ZooKeeperProxy
Source Files
¶
- zookeeper_proxy.pb.go
Click to show internal directories.
Click to hide internal directories.