dynamic_forward_proxyv3

package
v1.36.11-2025121120105... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

const FilterConfig_DnsCacheConfig_case case_FilterConfig_ImplementationSpecifier = 2
const FilterConfig_ImplementationSpecifier_not_set_case case_FilterConfig_ImplementationSpecifier = 0

Variables

var File_envoy_extensions_filters_udp_udp_proxy_session_dynamic_forward_proxy_v3_dynamic_forward_proxy_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type FilterConfig

type FilterConfig struct {

	// The prefix to use when emitting :ref:`statistics <config_udp_session_filters_dynamic_forward_proxy_stats>`.
	StatPrefix string `protobuf:"bytes,1,opt,name=stat_prefix,json=statPrefix,proto3" json:"stat_prefix,omitempty"`
	// Types that are valid to be assigned to ImplementationSpecifier:
	//
	//	*FilterConfig_DnsCacheConfig
	ImplementationSpecifier isFilterConfig_ImplementationSpecifier `protobuf_oneof:"implementation_specifier"`
	// If configured, the filter will buffer datagrams in case that it is waiting for a DNS response.
	// If this field is not configured, there will be no buffering and downstream datagrams that arrive
	// while the DNS resolution is in progress will be dropped. In case this field is set but the options
	// are not configured, the default values will be applied as described in the “BufferOptions“.
	BufferOptions *FilterConfig_BufferOptions `protobuf:"bytes,3,opt,name=buffer_options,json=bufferOptions,proto3" json:"buffer_options,omitempty"`
	// contains filtered or unexported fields
}

Configuration for the filter state based dynamic forward proxy filter. See the :ref:`architecture overview <arch_overview_http_dynamic_forward_proxy>` for more information. Note this filter must be used in conjunction to another filter that sets the 'envoy.upstream.dynamic_host' and the 'envoy.upstream.dynamic_port' filter state keys for the required upstream UDP session. [#extension: envoy.filters.udp.session.dynamic_forward_proxy]

func (*FilterConfig) ClearBufferOptions

func (x *FilterConfig) ClearBufferOptions()

func (*FilterConfig) ClearDnsCacheConfig

func (x *FilterConfig) ClearDnsCacheConfig()

func (*FilterConfig) ClearImplementationSpecifier

func (x *FilterConfig) ClearImplementationSpecifier()

func (*FilterConfig) GetBufferOptions

func (x *FilterConfig) GetBufferOptions() *FilterConfig_BufferOptions

func (*FilterConfig) GetDnsCacheConfig

func (x *FilterConfig) GetDnsCacheConfig() *v3.DnsCacheConfig

func (*FilterConfig) GetImplementationSpecifier

func (x *FilterConfig) GetImplementationSpecifier() isFilterConfig_ImplementationSpecifier

func (*FilterConfig) GetStatPrefix

func (x *FilterConfig) GetStatPrefix() string

func (*FilterConfig) HasBufferOptions

func (x *FilterConfig) HasBufferOptions() bool

func (*FilterConfig) HasDnsCacheConfig

func (x *FilterConfig) HasDnsCacheConfig() bool

func (*FilterConfig) HasImplementationSpecifier

func (x *FilterConfig) HasImplementationSpecifier() bool

func (*FilterConfig) ProtoMessage

func (*FilterConfig) ProtoMessage()

func (*FilterConfig) ProtoReflect

func (x *FilterConfig) ProtoReflect() protoreflect.Message

func (*FilterConfig) Reset

func (x *FilterConfig) Reset()

func (*FilterConfig) SetBufferOptions

func (x *FilterConfig) SetBufferOptions(v *FilterConfig_BufferOptions)

func (*FilterConfig) SetDnsCacheConfig

func (x *FilterConfig) SetDnsCacheConfig(v *v3.DnsCacheConfig)

func (*FilterConfig) SetStatPrefix

func (x *FilterConfig) SetStatPrefix(v string)

func (*FilterConfig) String

func (x *FilterConfig) String() string

func (*FilterConfig) WhichImplementationSpecifier

func (x *FilterConfig) WhichImplementationSpecifier() case_FilterConfig_ImplementationSpecifier

type FilterConfig_BufferOptions

type FilterConfig_BufferOptions struct {

	// If set, the filter will only buffer datagrams up to the requested limit, and will drop
	// new UDP datagrams if the buffer contains the max_buffered_datagrams value at the time
	// of a new datagram arrival. If not set, the default value is 1024 datagrams.
	MaxBufferedDatagrams *wrapperspb.UInt32Value `protobuf:"bytes,1,opt,name=max_buffered_datagrams,json=maxBufferedDatagrams,proto3" json:"max_buffered_datagrams,omitempty"`
	// If set, the filter will only buffer datagrams up to the requested total buffered bytes limit,
	// and will drop new UDP datagrams if the buffer contains the max_buffered_datagrams value
	// at the time of a new datagram arrival. If not set, the default value is 16,384 (16KB).
	MaxBufferedBytes *wrapperspb.UInt64Value `protobuf:"bytes,2,opt,name=max_buffered_bytes,json=maxBufferedBytes,proto3" json:"max_buffered_bytes,omitempty"`
	// contains filtered or unexported fields
}

Configuration for UDP datagrams buffering.

func (*FilterConfig_BufferOptions) ClearMaxBufferedBytes

func (x *FilterConfig_BufferOptions) ClearMaxBufferedBytes()

func (*FilterConfig_BufferOptions) ClearMaxBufferedDatagrams

func (x *FilterConfig_BufferOptions) ClearMaxBufferedDatagrams()

func (*FilterConfig_BufferOptions) GetMaxBufferedBytes

func (x *FilterConfig_BufferOptions) GetMaxBufferedBytes() *wrapperspb.UInt64Value

func (*FilterConfig_BufferOptions) GetMaxBufferedDatagrams

func (x *FilterConfig_BufferOptions) GetMaxBufferedDatagrams() *wrapperspb.UInt32Value

func (*FilterConfig_BufferOptions) HasMaxBufferedBytes

func (x *FilterConfig_BufferOptions) HasMaxBufferedBytes() bool

func (*FilterConfig_BufferOptions) HasMaxBufferedDatagrams

func (x *FilterConfig_BufferOptions) HasMaxBufferedDatagrams() bool

func (*FilterConfig_BufferOptions) ProtoMessage

func (*FilterConfig_BufferOptions) ProtoMessage()

func (*FilterConfig_BufferOptions) ProtoReflect

func (*FilterConfig_BufferOptions) Reset

func (x *FilterConfig_BufferOptions) Reset()

func (*FilterConfig_BufferOptions) SetMaxBufferedBytes

func (x *FilterConfig_BufferOptions) SetMaxBufferedBytes(v *wrapperspb.UInt64Value)

func (*FilterConfig_BufferOptions) SetMaxBufferedDatagrams

func (x *FilterConfig_BufferOptions) SetMaxBufferedDatagrams(v *wrapperspb.UInt32Value)

func (*FilterConfig_BufferOptions) String

func (x *FilterConfig_BufferOptions) String() string

type FilterConfig_BufferOptions_builder

type FilterConfig_BufferOptions_builder struct {

	// If set, the filter will only buffer datagrams up to the requested limit, and will drop
	// new UDP datagrams if the buffer contains the max_buffered_datagrams value at the time
	// of a new datagram arrival. If not set, the default value is 1024 datagrams.
	MaxBufferedDatagrams *wrapperspb.UInt32Value
	// If set, the filter will only buffer datagrams up to the requested total buffered bytes limit,
	// and will drop new UDP datagrams if the buffer contains the max_buffered_datagrams value
	// at the time of a new datagram arrival. If not set, the default value is 16,384 (16KB).
	MaxBufferedBytes *wrapperspb.UInt64Value
	// contains filtered or unexported fields
}

func (FilterConfig_BufferOptions_builder) Build

type FilterConfig_DnsCacheConfig

type FilterConfig_DnsCacheConfig struct {
	// The DNS cache configuration that the filter will attach to. Note this
	// configuration must match that of associated :ref:`dynamic forward proxy cluster configuration
	// <envoy_v3_api_field_extensions.clusters.dynamic_forward_proxy.v3.ClusterConfig.dns_cache_config>`.
	DnsCacheConfig *v3.DnsCacheConfig `protobuf:"bytes,2,opt,name=dns_cache_config,json=dnsCacheConfig,proto3,oneof"`
}

type FilterConfig_builder

type FilterConfig_builder struct {

	// The prefix to use when emitting :ref:`statistics <config_udp_session_filters_dynamic_forward_proxy_stats>`.
	StatPrefix string
	// Fields of oneof ImplementationSpecifier:
	// The DNS cache configuration that the filter will attach to. Note this
	// configuration must match that of associated :ref:`dynamic forward proxy cluster configuration
	// <envoy_v3_api_field_extensions.clusters.dynamic_forward_proxy.v3.ClusterConfig.dns_cache_config>`.
	DnsCacheConfig *v3.DnsCacheConfig
	// -- end of ImplementationSpecifier
	// If configured, the filter will buffer datagrams in case that it is waiting for a DNS response.
	// If this field is not configured, there will be no buffering and downstream datagrams that arrive
	// while the DNS resolution is in progress will be dropped. In case this field is set but the options
	// are not configured, the default values will be applied as described in the “BufferOptions“.
	BufferOptions *FilterConfig_BufferOptions
	// contains filtered or unexported fields
}

func (FilterConfig_builder) Build

func (b0 FilterConfig_builder) Build() *FilterConfig

Source Files

  • dynamic_forward_proxy.pb.go

Jump to