maxmindv3

package
v1.36.11-2026041321000... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var File_envoy_extensions_geoip_providers_maxmind_v3_maxmind_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type MaxMindConfig

type MaxMindConfig struct {

	// Full file path to the MaxMind city database, e.g., “/etc/GeoLite2-City.mmdb“.
	// Database file is expected to have “.mmdb“ extension.
	CityDbPath string `protobuf:"bytes,1,opt,name=city_db_path,json=cityDbPath,proto3" json:"city_db_path,omitempty"`
	// Full file path to the MaxMind ASN database, e.g., “/etc/GeoLite2-ASN.mmdb“.
	// Database file is expected to have “.mmdb“ extension.
	// When this is defined, the ASN information will always be fetched from the “asn_db“.
	AsnDbPath string `protobuf:"bytes,2,opt,name=asn_db_path,json=asnDbPath,proto3" json:"asn_db_path,omitempty"`
	// Full file path to the MaxMind Anonymous IP database, e.g., “/etc/GeoIP2-Anonymous-IP.mmdb“.
	// Database file is expected to have “.mmdb“ extension.
	AnonDbPath string `protobuf:"bytes,3,opt,name=anon_db_path,json=anonDbPath,proto3" json:"anon_db_path,omitempty"`
	// Full file path to the MaxMind ISP database, e.g., “/etc/GeoLite2-ISP.mmdb“.
	// Database file is expected to have “.mmdb“ extension.
	// If “asn_db_path“ is not defined, ASN information will be fetched from
	// “isp_db“ instead.
	IspDbPath string `protobuf:"bytes,5,opt,name=isp_db_path,json=ispDbPath,proto3" json:"isp_db_path,omitempty"`
	// Full file path to the MaxMind Country database, e.g., “/etc/GeoLite2-Country.mmdb“.
	// Database file is expected to have “.mmdb“ extension.
	//
	// If “country_db_path“ is not specified, country information will be fetched from
	// “city_db“ if “city_db“ is configured.
	CountryDbPath string `protobuf:"bytes,6,opt,name=country_db_path,json=countryDbPath,proto3" json:"country_db_path,omitempty"`
	// Common provider configuration that specifies which geolocation headers will be populated with geolocation data.
	CommonProviderConfig *v3.CommonGeoipProviderConfig `protobuf:"bytes,4,opt,name=common_provider_config,json=commonProviderConfig,proto3" json:"common_provider_config,omitempty"`
	// contains filtered or unexported fields
}

[#next-free-field: 7]

func (*MaxMindConfig) ClearCommonProviderConfig

func (x *MaxMindConfig) ClearCommonProviderConfig()

func (*MaxMindConfig) GetAnonDbPath

func (x *MaxMindConfig) GetAnonDbPath() string

func (*MaxMindConfig) GetAsnDbPath

func (x *MaxMindConfig) GetAsnDbPath() string

func (*MaxMindConfig) GetCityDbPath

func (x *MaxMindConfig) GetCityDbPath() string

func (*MaxMindConfig) GetCommonProviderConfig

func (x *MaxMindConfig) GetCommonProviderConfig() *v3.CommonGeoipProviderConfig

func (*MaxMindConfig) GetCountryDbPath

func (x *MaxMindConfig) GetCountryDbPath() string

func (*MaxMindConfig) GetIspDbPath

func (x *MaxMindConfig) GetIspDbPath() string

func (*MaxMindConfig) HasCommonProviderConfig

func (x *MaxMindConfig) HasCommonProviderConfig() bool

func (*MaxMindConfig) ProtoMessage

func (*MaxMindConfig) ProtoMessage()

func (*MaxMindConfig) ProtoReflect

func (x *MaxMindConfig) ProtoReflect() protoreflect.Message

func (*MaxMindConfig) Reset

func (x *MaxMindConfig) Reset()

func (*MaxMindConfig) SetAnonDbPath

func (x *MaxMindConfig) SetAnonDbPath(v string)

func (*MaxMindConfig) SetAsnDbPath

func (x *MaxMindConfig) SetAsnDbPath(v string)

func (*MaxMindConfig) SetCityDbPath

func (x *MaxMindConfig) SetCityDbPath(v string)

func (*MaxMindConfig) SetCommonProviderConfig

func (x *MaxMindConfig) SetCommonProviderConfig(v *v3.CommonGeoipProviderConfig)

func (*MaxMindConfig) SetCountryDbPath

func (x *MaxMindConfig) SetCountryDbPath(v string)

func (*MaxMindConfig) SetIspDbPath

func (x *MaxMindConfig) SetIspDbPath(v string)

func (*MaxMindConfig) String

func (x *MaxMindConfig) String() string

type MaxMindConfig_builder

type MaxMindConfig_builder struct {

	// Full file path to the MaxMind city database, e.g., “/etc/GeoLite2-City.mmdb“.
	// Database file is expected to have “.mmdb“ extension.
	CityDbPath string
	// Full file path to the MaxMind ASN database, e.g., “/etc/GeoLite2-ASN.mmdb“.
	// Database file is expected to have “.mmdb“ extension.
	// When this is defined, the ASN information will always be fetched from the “asn_db“.
	AsnDbPath string
	// Full file path to the MaxMind Anonymous IP database, e.g., “/etc/GeoIP2-Anonymous-IP.mmdb“.
	// Database file is expected to have “.mmdb“ extension.
	AnonDbPath string
	// Full file path to the MaxMind ISP database, e.g., “/etc/GeoLite2-ISP.mmdb“.
	// Database file is expected to have “.mmdb“ extension.
	// If “asn_db_path“ is not defined, ASN information will be fetched from
	// “isp_db“ instead.
	IspDbPath string
	// Full file path to the MaxMind Country database, e.g., “/etc/GeoLite2-Country.mmdb“.
	// Database file is expected to have “.mmdb“ extension.
	//
	// If “country_db_path“ is not specified, country information will be fetched from
	// “city_db“ if “city_db“ is configured.
	CountryDbPath string
	// Common provider configuration that specifies which geolocation headers will be populated with geolocation data.
	CommonProviderConfig *v3.CommonGeoipProviderConfig
	// contains filtered or unexported fields
}

func (MaxMindConfig_builder) Build

Source Files

  • maxmind.pb.go

Jump to