Documentation
¶
Index ¶
- Variables
- type HealthCheckEventFileSink
- func (x *HealthCheckEventFileSink) GetEventLogPath() string
- func (*HealthCheckEventFileSink) ProtoMessage()
- func (x *HealthCheckEventFileSink) ProtoReflect() protoreflect.Message
- func (x *HealthCheckEventFileSink) Reset()
- func (x *HealthCheckEventFileSink) SetEventLogPath(v string)
- func (x *HealthCheckEventFileSink) String() string
- type HealthCheckEventFileSink_builder
Constants ¶
This section is empty.
Variables ¶
var File_envoy_extensions_health_check_event_sinks_file_v3_file_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type HealthCheckEventFileSink ¶
type HealthCheckEventFileSink struct {
// Specifies the path to the health check event log.
EventLogPath string `protobuf:"bytes,1,opt,name=event_log_path,json=eventLogPath,proto3" json:"event_log_path,omitempty"`
// contains filtered or unexported fields
}
Health check event file sink. The health check event will be converted to JSON.
func (*HealthCheckEventFileSink) GetEventLogPath ¶
func (x *HealthCheckEventFileSink) GetEventLogPath() string
func (*HealthCheckEventFileSink) ProtoMessage ¶
func (*HealthCheckEventFileSink) ProtoMessage()
func (*HealthCheckEventFileSink) ProtoReflect ¶
func (x *HealthCheckEventFileSink) ProtoReflect() protoreflect.Message
func (*HealthCheckEventFileSink) Reset ¶
func (x *HealthCheckEventFileSink) Reset()
func (*HealthCheckEventFileSink) SetEventLogPath ¶
func (x *HealthCheckEventFileSink) SetEventLogPath(v string)
func (*HealthCheckEventFileSink) String ¶
func (x *HealthCheckEventFileSink) String() string
type HealthCheckEventFileSink_builder ¶
type HealthCheckEventFileSink_builder struct {
// Specifies the path to the health check event log.
EventLogPath string
// contains filtered or unexported fields
}
func (HealthCheckEventFileSink_builder) Build ¶
func (b0 HealthCheckEventFileSink_builder) Build() *HealthCheckEventFileSink
Source Files
¶
- file.pb.go
Click to show internal directories.
Click to hide internal directories.