Documentation
¶
Index ¶
- Variables
- type Redis
- func (x *Redis) ClearAwsIam()
- func (x *Redis) GetAwsIam() *v3.AwsIam
- func (x *Redis) GetKey() string
- func (x *Redis) HasAwsIam() bool
- func (*Redis) ProtoMessage()
- func (x *Redis) ProtoReflect() protoreflect.Message
- func (x *Redis) Reset()
- func (x *Redis) SetAwsIam(v *v3.AwsIam)
- func (x *Redis) SetKey(v string)
- func (x *Redis) String() string
- type Redis_builder
Constants ¶
This section is empty.
Variables ¶
var File_envoy_extensions_health_checkers_redis_v3_redis_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Redis ¶
type Redis struct {
// If set, optionally perform “EXISTS <key>“ instead of “PING“. A return value
// from Redis of 0 (does not exist) is considered a passing healthcheck. A return value other
// than 0 is considered a failure. This allows the user to mark a Redis instance for maintenance
// by setting the specified key to any value and waiting for traffic to drain.
Key string `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
// Use AWS IAM for health checker authentication
AwsIam *v3.AwsIam `protobuf:"bytes,2,opt,name=aws_iam,json=awsIam,proto3" json:"aws_iam,omitempty"`
// contains filtered or unexported fields
}
func (*Redis) ProtoReflect ¶
func (x *Redis) ProtoReflect() protoreflect.Message
type Redis_builder ¶
type Redis_builder struct {
// If set, optionally perform “EXISTS <key>“ instead of “PING“. A return value
// from Redis of 0 (does not exist) is considered a passing healthcheck. A return value other
// than 0 is considered a failure. This allows the user to mark a Redis instance for maintenance
// by setting the specified key to any value and waiting for traffic to drain.
Key string
// Use AWS IAM for health checker authentication
AwsIam *v3.AwsIam
// contains filtered or unexported fields
}
func (Redis_builder) Build ¶
func (b0 Redis_builder) Build() *Redis
Source Files
¶
- redis.pb.go
Click to show internal directories.
Click to hide internal directories.