Documentation
¶
Index ¶
- Variables
- type Thrift
- func (x *Thrift) GetMethodName() string
- func (x *Thrift) GetProtocol() v3.ProtocolType
- func (x *Thrift) GetTransport() v3.TransportType
- func (*Thrift) ProtoMessage()
- func (x *Thrift) ProtoReflect() protoreflect.Message
- func (x *Thrift) Reset()
- func (x *Thrift) SetMethodName(v string)
- func (x *Thrift) SetProtocol(v v3.ProtocolType)
- func (x *Thrift) SetTransport(v v3.TransportType)
- func (x *Thrift) String() string
- type Thrift_builder
Constants ¶
This section is empty.
Variables ¶
var File_envoy_extensions_health_checkers_thrift_v3_thrift_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Thrift ¶
type Thrift struct {
// Specifies the method name that will be set on each health check request dispatched to an upstream host.
// Note that method name is case sensitive.
MethodName string `protobuf:"bytes,1,opt,name=method_name,json=methodName,proto3" json:"method_name,omitempty"`
// Configures the transport type to be used with the health checks. Note that
// :ref:`AUTO_TRANSPORT<envoy_v3_api_enum_value_extensions.filters.network.thrift_proxy.v3.TransportType.AUTO_TRANSPORT>`
// is not supported, and we don't honor :ref:`ThriftProtocolOptions<envoy_v3_api_msg_extensions.filters.network.thrift_proxy.v3.ThriftProtocolOptions>`
// since it's possible to set to :ref:`AUTO_TRANSPORT<envoy_v3_api_enum_value_extensions.filters.network.thrift_proxy.v3.TransportType.AUTO_TRANSPORT>`.
// [#extension-category: envoy.filters.network]
Transport v3.TransportType `` /* 140-byte string literal not displayed */
// Configures the protocol type to be used with the health checks. Note that
// :ref:`AUTO_PROTOCOL<envoy_v3_api_enum_value_extensions.filters.network.thrift_proxy.v3.ProtocolType.AUTO_PROTOCOL>`
// and :ref:`TWITTER<envoy_v3_api_enum_value_extensions.filters.network.thrift_proxy.v3.ProtocolType.TWITTER>`
// are not supported, and we don't honor :ref:`ThriftProtocolOptions<envoy_v3_api_msg_extensions.filters.network.thrift_proxy.v3.ThriftProtocolOptions>`
// since it's possible to set to :ref:`AUTO_PROTOCOL<envoy_v3_api_enum_value_extensions.filters.network.thrift_proxy.v3.ProtocolType.AUTO_PROTOCOL>`
// or :ref:`TWITTER<envoy_v3_api_enum_value_extensions.filters.network.thrift_proxy.v3.ProtocolType.TWITTER>`.
Protocol v3.ProtocolType `` /* 137-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*Thrift) GetProtocol ¶
func (x *Thrift) GetProtocol() v3.ProtocolType
func (*Thrift) GetTransport ¶
func (x *Thrift) GetTransport() v3.TransportType
func (*Thrift) ProtoReflect ¶
func (x *Thrift) ProtoReflect() protoreflect.Message
func (*Thrift) SetProtocol ¶
func (x *Thrift) SetProtocol(v v3.ProtocolType)
func (*Thrift) SetTransport ¶
func (x *Thrift) SetTransport(v v3.TransportType)
type Thrift_builder ¶
type Thrift_builder struct {
// Specifies the method name that will be set on each health check request dispatched to an upstream host.
// Note that method name is case sensitive.
MethodName string
// Configures the transport type to be used with the health checks. Note that
// :ref:`AUTO_TRANSPORT<envoy_v3_api_enum_value_extensions.filters.network.thrift_proxy.v3.TransportType.AUTO_TRANSPORT>`
// is not supported, and we don't honor :ref:`ThriftProtocolOptions<envoy_v3_api_msg_extensions.filters.network.thrift_proxy.v3.ThriftProtocolOptions>`
// since it's possible to set to :ref:`AUTO_TRANSPORT<envoy_v3_api_enum_value_extensions.filters.network.thrift_proxy.v3.TransportType.AUTO_TRANSPORT>`.
// [#extension-category: envoy.filters.network]
Transport v3.TransportType
// Configures the protocol type to be used with the health checks. Note that
// :ref:`AUTO_PROTOCOL<envoy_v3_api_enum_value_extensions.filters.network.thrift_proxy.v3.ProtocolType.AUTO_PROTOCOL>`
// and :ref:`TWITTER<envoy_v3_api_enum_value_extensions.filters.network.thrift_proxy.v3.ProtocolType.TWITTER>`
// are not supported, and we don't honor :ref:`ThriftProtocolOptions<envoy_v3_api_msg_extensions.filters.network.thrift_proxy.v3.ThriftProtocolOptions>`
// since it's possible to set to :ref:`AUTO_PROTOCOL<envoy_v3_api_enum_value_extensions.filters.network.thrift_proxy.v3.ProtocolType.AUTO_PROTOCOL>`
// or :ref:`TWITTER<envoy_v3_api_enum_value_extensions.filters.network.thrift_proxy.v3.ProtocolType.TWITTER>`.
Protocol v3.ProtocolType
// contains filtered or unexported fields
}
func (Thrift_builder) Build ¶
func (b0 Thrift_builder) Build() *Thrift
Source Files
¶
- thrift.pb.go
Click to show internal directories.
Click to hide internal directories.