Documentation
¶
Index ¶
- Variables
- type CustomHeaderConfig
- func (x *CustomHeaderConfig) ClearRejectWithStatus()
- func (x *CustomHeaderConfig) GetAllowExtensionToSetAddressAsTrusted() bool
- func (x *CustomHeaderConfig) GetHeaderName() string
- func (x *CustomHeaderConfig) GetRejectWithStatus() *v3.HttpStatus
- func (x *CustomHeaderConfig) HasRejectWithStatus() bool
- func (*CustomHeaderConfig) ProtoMessage()
- func (x *CustomHeaderConfig) ProtoReflect() protoreflect.Message
- func (x *CustomHeaderConfig) Reset()
- func (x *CustomHeaderConfig) SetAllowExtensionToSetAddressAsTrusted(v bool)
- func (x *CustomHeaderConfig) SetHeaderName(v string)
- func (x *CustomHeaderConfig) SetRejectWithStatus(v *v3.HttpStatus)
- func (x *CustomHeaderConfig) String() string
- type CustomHeaderConfig_builder
Constants ¶
This section is empty.
Variables ¶
var File_envoy_extensions_http_original_ip_detection_custom_header_v3_custom_header_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type CustomHeaderConfig ¶
type CustomHeaderConfig struct {
// The header name containing the original downstream remote address, if present.
//
// Note: in the case of a multi-valued header, only the first value is tried and the rest are ignored.
HeaderName string `protobuf:"bytes,1,opt,name=header_name,json=headerName,proto3" json:"header_name,omitempty"`
// If set to true, the extension could decide that the detected address should be treated as
// trusted by the HCM. If the address is considered :ref:`trusted<config_http_conn_man_headers_x-forwarded-for_trusted_client_address>`,
// it might be used as input to determine if the request is internal (among other things).
AllowExtensionToSetAddressAsTrusted bool `` /* 177-byte string literal not displayed */
// If this is set, the request will be rejected when detection fails using it as the HTTP response status.
//
// .. note::
//
// If this is set to < 400 or > 511, the default status 403 will be used instead.
RejectWithStatus *v3.HttpStatus `protobuf:"bytes,3,opt,name=reject_with_status,json=rejectWithStatus,proto3" json:"reject_with_status,omitempty"`
// contains filtered or unexported fields
}
This extension allows for the original downstream remote IP to be detected by reading the value from a configured header name. If the value is successfully parsed as an IP, it'll be treated as the effective downstream remote address and seen as such by all filters. See :ref:`original_ip_detection_extensions <envoy_v3_api_field_extensions.filters.network.http_connection_manager.v3.HttpConnectionManager.original_ip_detection_extensions>` for an overview of how extensions operate and what happens when an extension fails to detect the remote IP.
[#extension: envoy.http.original_ip_detection.custom_header]
func (*CustomHeaderConfig) ClearRejectWithStatus ¶
func (x *CustomHeaderConfig) ClearRejectWithStatus()
func (*CustomHeaderConfig) GetAllowExtensionToSetAddressAsTrusted ¶
func (x *CustomHeaderConfig) GetAllowExtensionToSetAddressAsTrusted() bool
func (*CustomHeaderConfig) GetHeaderName ¶
func (x *CustomHeaderConfig) GetHeaderName() string
func (*CustomHeaderConfig) GetRejectWithStatus ¶
func (x *CustomHeaderConfig) GetRejectWithStatus() *v3.HttpStatus
func (*CustomHeaderConfig) HasRejectWithStatus ¶
func (x *CustomHeaderConfig) HasRejectWithStatus() bool
func (*CustomHeaderConfig) ProtoMessage ¶
func (*CustomHeaderConfig) ProtoMessage()
func (*CustomHeaderConfig) ProtoReflect ¶
func (x *CustomHeaderConfig) ProtoReflect() protoreflect.Message
func (*CustomHeaderConfig) Reset ¶
func (x *CustomHeaderConfig) Reset()
func (*CustomHeaderConfig) SetAllowExtensionToSetAddressAsTrusted ¶
func (x *CustomHeaderConfig) SetAllowExtensionToSetAddressAsTrusted(v bool)
func (*CustomHeaderConfig) SetHeaderName ¶
func (x *CustomHeaderConfig) SetHeaderName(v string)
func (*CustomHeaderConfig) SetRejectWithStatus ¶
func (x *CustomHeaderConfig) SetRejectWithStatus(v *v3.HttpStatus)
func (*CustomHeaderConfig) String ¶
func (x *CustomHeaderConfig) String() string
type CustomHeaderConfig_builder ¶
type CustomHeaderConfig_builder struct {
// The header name containing the original downstream remote address, if present.
//
// Note: in the case of a multi-valued header, only the first value is tried and the rest are ignored.
HeaderName string
// If set to true, the extension could decide that the detected address should be treated as
// trusted by the HCM. If the address is considered :ref:`trusted<config_http_conn_man_headers_x-forwarded-for_trusted_client_address>`,
// it might be used as input to determine if the request is internal (among other things).
AllowExtensionToSetAddressAsTrusted bool
// If this is set, the request will be rejected when detection fails using it as the HTTP response status.
//
// .. note::
//
// If this is set to < 400 or > 511, the default status 403 will be used instead.
RejectWithStatus *v3.HttpStatus
// contains filtered or unexported fields
}
func (CustomHeaderConfig_builder) Build ¶
func (b0 CustomHeaderConfig_builder) Build() *CustomHeaderConfig
Source Files
¶
- custom_header.pb.go
Click to show internal directories.
Click to hide internal directories.