Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var File_envoy_extensions_internal_redirect_safe_cross_scheme_v3_safe_cross_scheme_config_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type SafeCrossSchemeConfig ¶
type SafeCrossSchemeConfig struct {
// contains filtered or unexported fields
}
An internal redirect predicate that checks the scheme between the downstream url and the redirect target url and allows a) same scheme redirect and b) safe cross scheme redirect, which means if the downstream scheme is HTTPS, both HTTPS and HTTP redirect targets are allowed, but if the downstream scheme is HTTP, only HTTP redirect targets are allowed. [#extension: envoy.internal_redirect_predicates.safe_cross_scheme]
func (*SafeCrossSchemeConfig) ProtoMessage ¶
func (*SafeCrossSchemeConfig) ProtoMessage()
func (*SafeCrossSchemeConfig) ProtoReflect ¶
func (x *SafeCrossSchemeConfig) ProtoReflect() protoreflect.Message
func (*SafeCrossSchemeConfig) Reset ¶
func (x *SafeCrossSchemeConfig) Reset()
func (*SafeCrossSchemeConfig) String ¶
func (x *SafeCrossSchemeConfig) String() string
type SafeCrossSchemeConfig_builder ¶
type SafeCrossSchemeConfig_builder struct {
// contains filtered or unexported fields
}
func (SafeCrossSchemeConfig_builder) Build ¶
func (b0 SafeCrossSchemeConfig_builder) Build() *SafeCrossSchemeConfig
Source Files
¶
- safe_cross_scheme_config.pb.go
Click to show internal directories.
Click to hide internal directories.