Documentation
¶
Index ¶
- Variables
- type Maglev
- func (x *Maglev) ClearConsistentHashingLbConfig()
- func (x *Maglev) ClearLocalityWeightedLbConfig()
- func (x *Maglev) ClearTableSize()
- func (x *Maglev) GetConsistentHashingLbConfig() *v3.ConsistentHashingLbConfig
- func (x *Maglev) GetLocalityWeightedLbConfig() *v3.LocalityLbConfig_LocalityWeightedLbConfig
- func (x *Maglev) GetTableSize() *wrapperspb.UInt64Value
- func (x *Maglev) HasConsistentHashingLbConfig() bool
- func (x *Maglev) HasLocalityWeightedLbConfig() bool
- func (x *Maglev) HasTableSize() bool
- func (*Maglev) ProtoMessage()
- func (x *Maglev) ProtoReflect() protoreflect.Message
- func (x *Maglev) Reset()
- func (x *Maglev) SetConsistentHashingLbConfig(v *v3.ConsistentHashingLbConfig)
- func (x *Maglev) SetLocalityWeightedLbConfig(v *v3.LocalityLbConfig_LocalityWeightedLbConfig)
- func (x *Maglev) SetTableSize(v *wrapperspb.UInt64Value)
- func (x *Maglev) String() string
- type Maglev_builder
Constants ¶
This section is empty.
Variables ¶
var File_envoy_extensions_load_balancing_policies_maglev_v3_maglev_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Maglev ¶
type Maglev struct {
// The table size for Maglev hashing. Maglev aims for "minimal disruption" rather than an absolute guarantee.
// Minimal disruption means that when the set of upstream hosts change, a connection will likely be sent to the same
// upstream as it was before. Increasing the table size reduces the amount of disruption.
// The table size must be prime number limited to 5000011. If it is not specified, the default is 65537.
TableSize *wrapperspb.UInt64Value `protobuf:"bytes,1,opt,name=table_size,json=tableSize,proto3" json:"table_size,omitempty"`
// Common configuration for hashing-based load balancing policies.
ConsistentHashingLbConfig *v3.ConsistentHashingLbConfig `` /* 140-byte string literal not displayed */
// Enable locality weighted load balancing for maglev lb explicitly.
LocalityWeightedLbConfig *v3.LocalityLbConfig_LocalityWeightedLbConfig `` /* 137-byte string literal not displayed */
// contains filtered or unexported fields
}
This configuration allows the built-in Maglev LB policy to be configured via the LB policy extension point. See the :ref:`load balancing architecture overview <arch_overview_load_balancing_types>` and :ref:`Maglev<arch_overview_load_balancing_types_maglev>` for more information.
func (*Maglev) GetConsistentHashingLbConfig ¶
func (x *Maglev) GetConsistentHashingLbConfig() *v3.ConsistentHashingLbConfig
func (*Maglev) GetLocalityWeightedLbConfig ¶
func (x *Maglev) GetLocalityWeightedLbConfig() *v3.LocalityLbConfig_LocalityWeightedLbConfig
func (*Maglev) GetTableSize ¶
func (x *Maglev) GetTableSize() *wrapperspb.UInt64Value
func (*Maglev) ProtoReflect ¶
func (x *Maglev) ProtoReflect() protoreflect.Message
func (*Maglev) SetConsistentHashingLbConfig ¶
func (x *Maglev) SetConsistentHashingLbConfig(v *v3.ConsistentHashingLbConfig)
func (*Maglev) SetLocalityWeightedLbConfig ¶
func (x *Maglev) SetLocalityWeightedLbConfig(v *v3.LocalityLbConfig_LocalityWeightedLbConfig)
func (*Maglev) SetTableSize ¶
func (x *Maglev) SetTableSize(v *wrapperspb.UInt64Value)
type Maglev_builder ¶
type Maglev_builder struct {
// The table size for Maglev hashing. Maglev aims for "minimal disruption" rather than an absolute guarantee.
// Minimal disruption means that when the set of upstream hosts change, a connection will likely be sent to the same
// upstream as it was before. Increasing the table size reduces the amount of disruption.
// The table size must be prime number limited to 5000011. If it is not specified, the default is 65537.
TableSize *wrapperspb.UInt64Value
// Common configuration for hashing-based load balancing policies.
ConsistentHashingLbConfig *v3.ConsistentHashingLbConfig
// Enable locality weighted load balancing for maglev lb explicitly.
LocalityWeightedLbConfig *v3.LocalityLbConfig_LocalityWeightedLbConfig
// contains filtered or unexported fields
}
func (Maglev_builder) Build ¶
func (b0 Maglev_builder) Build() *Maglev
Source Files
¶
- maglev.pb.go
Click to show internal directories.
Click to hide internal directories.