pick_firstv3

package
v1.36.11-2026041321000... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var File_envoy_extensions_load_balancing_policies_pick_first_v3_pick_first_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type PickFirst

type PickFirst struct {

	// If set to true, instructs the LB policy to shuffle the list of addresses
	// received from the name resolver before attempting to connect to them.
	ShuffleAddressList bool `protobuf:"varint,1,opt,name=shuffle_address_list,json=shuffleAddressList,proto3" json:"shuffle_address_list,omitempty"`
	// contains filtered or unexported fields
}

This configuration allows the built-in PICK_FIRST LB policy to be configured via the LB policy extension point.

func (*PickFirst) GetShuffleAddressList

func (x *PickFirst) GetShuffleAddressList() bool

func (*PickFirst) ProtoMessage

func (*PickFirst) ProtoMessage()

func (*PickFirst) ProtoReflect

func (x *PickFirst) ProtoReflect() protoreflect.Message

func (*PickFirst) Reset

func (x *PickFirst) Reset()

func (*PickFirst) SetShuffleAddressList

func (x *PickFirst) SetShuffleAddressList(v bool)

func (*PickFirst) String

func (x *PickFirst) String() string

type PickFirst_builder

type PickFirst_builder struct {

	// If set to true, instructs the LB policy to shuffle the list of addresses
	// received from the name resolver before attempting to connect to them.
	ShuffleAddressList bool
	// contains filtered or unexported fields
}

func (PickFirst_builder) Build

func (b0 PickFirst_builder) Build() *PickFirst

Source Files

  • pick_first.pb.go

Jump to