quic_statsv3

package
v1.36.11-2026011520535... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var File_envoy_extensions_quic_connection_debug_visitor_quic_stats_v3_quic_stats_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type Config

type Config struct {

	// Period to update stats while the connection is open. If unset, updates only happen when the
	// connection is closed. Stats are always updated one final time when the connection is closed.
	UpdatePeriod *durationpb.Duration `protobuf:"bytes,2,opt,name=update_period,json=updatePeriod,proto3" json:"update_period,omitempty"`
	// contains filtered or unexported fields
}

Configuration for a QUIC debug visitor which emits stats from the underlying QUIC transport.

func (*Config) ClearUpdatePeriod

func (x *Config) ClearUpdatePeriod()

func (*Config) GetUpdatePeriod

func (x *Config) GetUpdatePeriod() *durationpb.Duration

func (*Config) HasUpdatePeriod

func (x *Config) HasUpdatePeriod() bool

func (*Config) ProtoMessage

func (*Config) ProtoMessage()

func (*Config) ProtoReflect

func (x *Config) ProtoReflect() protoreflect.Message

func (*Config) Reset

func (x *Config) Reset()

func (*Config) SetUpdatePeriod

func (x *Config) SetUpdatePeriod(v *durationpb.Duration)

func (*Config) String

func (x *Config) String() string

type Config_builder

type Config_builder struct {

	// Period to update stats while the connection is open. If unset, updates only happen when the
	// connection is closed. Stats are always updated one final time when the connection is closed.
	UpdatePeriod *durationpb.Duration
	// contains filtered or unexported fields
}

func (Config_builder) Build

func (b0 Config_builder) Build() *Config

Source Files

  • quic_stats.pb.go

Jump to