exprv3

package
v1.36.11-2025121120105... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

const Descriptor_ExprSpecifier_not_set_case case_Descriptor_ExprSpecifier = 0
const Descriptor_Parsed_case case_Descriptor_ExprSpecifier = 4
const Descriptor_Text_case case_Descriptor_ExprSpecifier = 3

Variables

var File_envoy_extensions_rate_limit_descriptors_expr_v3_expr_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type Descriptor

type Descriptor struct {

	// The key to use in the descriptor entry.
	DescriptorKey string `protobuf:"bytes,1,opt,name=descriptor_key,json=descriptorKey,proto3" json:"descriptor_key,omitempty"`
	// If set to true, Envoy skips the descriptor if the expression evaluates to an error.
	// By default, the rate limit is not applied when an expression produces an error.
	SkipIfError bool `protobuf:"varint,2,opt,name=skip_if_error,json=skipIfError,proto3" json:"skip_if_error,omitempty"`
	// Types that are valid to be assigned to ExprSpecifier:
	//
	//	*Descriptor_Text
	//	*Descriptor_Parsed
	ExprSpecifier isDescriptor_ExprSpecifier `protobuf_oneof:"expr_specifier"`
	// contains filtered or unexported fields
}

The following descriptor entry is appended with a value computed from a symbolic Common Expression Language expression. See :ref:`attributes <arch_overview_attributes>` for the set of available attributes.

.. code-block:: cpp

("<descriptor_key>", "<expression_value>")

func (*Descriptor) ClearExprSpecifier

func (x *Descriptor) ClearExprSpecifier()

func (*Descriptor) ClearParsed

func (x *Descriptor) ClearParsed()

func (*Descriptor) ClearText

func (x *Descriptor) ClearText()

func (*Descriptor) GetDescriptorKey

func (x *Descriptor) GetDescriptorKey() string

func (*Descriptor) GetExprSpecifier

func (x *Descriptor) GetExprSpecifier() isDescriptor_ExprSpecifier

func (*Descriptor) GetParsed

func (x *Descriptor) GetParsed() *v1alpha1.Expr

func (*Descriptor) GetSkipIfError

func (x *Descriptor) GetSkipIfError() bool

func (*Descriptor) GetText

func (x *Descriptor) GetText() string

func (*Descriptor) HasExprSpecifier

func (x *Descriptor) HasExprSpecifier() bool

func (*Descriptor) HasParsed

func (x *Descriptor) HasParsed() bool

func (*Descriptor) HasText

func (x *Descriptor) HasText() bool

func (*Descriptor) ProtoMessage

func (*Descriptor) ProtoMessage()

func (*Descriptor) ProtoReflect

func (x *Descriptor) ProtoReflect() protoreflect.Message

func (*Descriptor) Reset

func (x *Descriptor) Reset()

func (*Descriptor) SetDescriptorKey

func (x *Descriptor) SetDescriptorKey(v string)

func (*Descriptor) SetParsed

func (x *Descriptor) SetParsed(v *v1alpha1.Expr)

func (*Descriptor) SetSkipIfError

func (x *Descriptor) SetSkipIfError(v bool)

func (*Descriptor) SetText

func (x *Descriptor) SetText(v string)

func (*Descriptor) String

func (x *Descriptor) String() string

func (*Descriptor) WhichExprSpecifier

func (x *Descriptor) WhichExprSpecifier() case_Descriptor_ExprSpecifier

type Descriptor_Parsed

type Descriptor_Parsed struct {
	// Parsed expression in AST form.
	Parsed *v1alpha1.Expr `protobuf:"bytes,4,opt,name=parsed,proto3,oneof"`
}

type Descriptor_Text

type Descriptor_Text struct {
	// Expression in a text form, e.g. "connection.requested_server_name".
	Text string `protobuf:"bytes,3,opt,name=text,proto3,oneof"`
}

type Descriptor_builder

type Descriptor_builder struct {

	// The key to use in the descriptor entry.
	DescriptorKey string
	// If set to true, Envoy skips the descriptor if the expression evaluates to an error.
	// By default, the rate limit is not applied when an expression produces an error.
	SkipIfError bool
	// Fields of oneof ExprSpecifier:
	// Expression in a text form, e.g. "connection.requested_server_name".
	Text *string
	// Parsed expression in AST form.
	Parsed *v1alpha1.Expr
	// contains filtered or unexported fields
}

func (Descriptor_builder) Build

func (b0 Descriptor_builder) Build() *Descriptor

Source Files

  • expr.pb.go

Jump to