Documentation
¶
Index ¶
- Variables
- type DownstreamConnectionsConfig
- func (x *DownstreamConnectionsConfig) GetMaxActiveDownstreamConnections() int64
- func (*DownstreamConnectionsConfig) ProtoMessage()
- func (x *DownstreamConnectionsConfig) ProtoReflect() protoreflect.Message
- func (x *DownstreamConnectionsConfig) Reset()
- func (x *DownstreamConnectionsConfig) SetMaxActiveDownstreamConnections(v int64)
- func (x *DownstreamConnectionsConfig) String() string
- type DownstreamConnectionsConfig_builder
Constants ¶
This section is empty.
Variables ¶
var File_envoy_extensions_resource_monitors_downstream_connections_v3_downstream_connections_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type DownstreamConnectionsConfig ¶
type DownstreamConnectionsConfig struct {
// Maximum threshold for global open downstream connections, defaults to 0.
// If monitor is enabled in Overload manager api, this field should be explicitly configured with value greater than 0.
MaxActiveDownstreamConnections int64 `` /* 156-byte string literal not displayed */
// contains filtered or unexported fields
}
The downstream connections resource monitor tracks the global number of open downstream connections.
func (*DownstreamConnectionsConfig) GetMaxActiveDownstreamConnections ¶
func (x *DownstreamConnectionsConfig) GetMaxActiveDownstreamConnections() int64
func (*DownstreamConnectionsConfig) ProtoMessage ¶
func (*DownstreamConnectionsConfig) ProtoMessage()
func (*DownstreamConnectionsConfig) ProtoReflect ¶
func (x *DownstreamConnectionsConfig) ProtoReflect() protoreflect.Message
func (*DownstreamConnectionsConfig) Reset ¶
func (x *DownstreamConnectionsConfig) Reset()
func (*DownstreamConnectionsConfig) SetMaxActiveDownstreamConnections ¶
func (x *DownstreamConnectionsConfig) SetMaxActiveDownstreamConnections(v int64)
func (*DownstreamConnectionsConfig) String ¶
func (x *DownstreamConnectionsConfig) String() string
type DownstreamConnectionsConfig_builder ¶
type DownstreamConnectionsConfig_builder struct {
// Maximum threshold for global open downstream connections, defaults to 0.
// If monitor is enabled in Overload manager api, this field should be explicitly configured with value greater than 0.
MaxActiveDownstreamConnections int64
// contains filtered or unexported fields
}
func (DownstreamConnectionsConfig_builder) Build ¶
func (b0 DownstreamConnectionsConfig_builder) Build() *DownstreamConnectionsConfig
Source Files
¶
- downstream_connections.pb.go
Click to show internal directories.
Click to hide internal directories.