fixed_heapv3

package
v1.36.11-2026011520535... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var File_envoy_extensions_resource_monitors_fixed_heap_v3_fixed_heap_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type FixedHeapConfig

type FixedHeapConfig struct {
	MaxHeapSizeBytes uint64 `protobuf:"varint,1,opt,name=max_heap_size_bytes,json=maxHeapSizeBytes,proto3" json:"max_heap_size_bytes,omitempty"`
	// contains filtered or unexported fields
}

The fixed heap resource monitor reports the Envoy process memory pressure, computed as a fraction of currently reserved heap memory divided by a statically configured maximum specified in the FixedHeapConfig.

func (*FixedHeapConfig) GetMaxHeapSizeBytes

func (x *FixedHeapConfig) GetMaxHeapSizeBytes() uint64

func (*FixedHeapConfig) ProtoMessage

func (*FixedHeapConfig) ProtoMessage()

func (*FixedHeapConfig) ProtoReflect

func (x *FixedHeapConfig) ProtoReflect() protoreflect.Message

func (*FixedHeapConfig) Reset

func (x *FixedHeapConfig) Reset()

func (*FixedHeapConfig) SetMaxHeapSizeBytes

func (x *FixedHeapConfig) SetMaxHeapSizeBytes(v uint64)

func (*FixedHeapConfig) String

func (x *FixedHeapConfig) String() string

type FixedHeapConfig_builder

type FixedHeapConfig_builder struct {
	MaxHeapSizeBytes uint64
	// contains filtered or unexported fields
}

func (FixedHeapConfig_builder) Build

Source Files

  • fixed_heap.pb.go

Jump to