injected_resourcev3

package
v1.36.11-2026011520535... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var File_envoy_extensions_resource_monitors_injected_resource_v3_injected_resource_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type InjectedResourceConfig

type InjectedResourceConfig struct {
	Filename string `protobuf:"bytes,1,opt,name=filename,proto3" json:"filename,omitempty"`
	// contains filtered or unexported fields
}

The injected resource monitor allows injecting a synthetic resource pressure into Envoy via a text file, which must contain a floating-point number in the range [0..1] representing the resource pressure and be updated atomically by a symbolic link swap. This is intended primarily for integration tests to force Envoy into an overloaded state.

func (*InjectedResourceConfig) GetFilename

func (x *InjectedResourceConfig) GetFilename() string

func (*InjectedResourceConfig) ProtoMessage

func (*InjectedResourceConfig) ProtoMessage()

func (*InjectedResourceConfig) ProtoReflect

func (x *InjectedResourceConfig) ProtoReflect() protoreflect.Message

func (*InjectedResourceConfig) Reset

func (x *InjectedResourceConfig) Reset()

func (*InjectedResourceConfig) SetFilename

func (x *InjectedResourceConfig) SetFilename(v string)

func (*InjectedResourceConfig) String

func (x *InjectedResourceConfig) String() string

type InjectedResourceConfig_builder

type InjectedResourceConfig_builder struct {
	Filename string
	// contains filtered or unexported fields
}

func (InjectedResourceConfig_builder) Build

Source Files

  • injected_resource.pb.go

Jump to