Documentation
¶
Index ¶
- Variables
- type LuaConfig
- func (x *LuaConfig) ClearSourceCode()
- func (x *LuaConfig) GetDefaultCluster() string
- func (x *LuaConfig) GetSourceCode() *v3.DataSource
- func (x *LuaConfig) HasSourceCode() bool
- func (*LuaConfig) ProtoMessage()
- func (x *LuaConfig) ProtoReflect() protoreflect.Message
- func (x *LuaConfig) Reset()
- func (x *LuaConfig) SetDefaultCluster(v string)
- func (x *LuaConfig) SetSourceCode(v *v3.DataSource)
- func (x *LuaConfig) String() string
- type LuaConfig_builder
Constants ¶
This section is empty.
Variables ¶
var File_envoy_extensions_router_cluster_specifiers_lua_v3_lua_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type LuaConfig ¶
type LuaConfig struct {
// The lua code that Envoy will execute to select cluster.
SourceCode *v3.DataSource `protobuf:"bytes,1,opt,name=source_code,json=sourceCode,proto3" json:"source_code,omitempty"`
// Default cluster. It will be used when the lua code execute failure.
DefaultCluster string `protobuf:"bytes,2,opt,name=default_cluster,json=defaultCluster,proto3" json:"default_cluster,omitempty"`
// contains filtered or unexported fields
}
func (*LuaConfig) GetSourceCode ¶
func (x *LuaConfig) GetSourceCode() *v3.DataSource
func (*LuaConfig) ProtoReflect ¶
func (x *LuaConfig) ProtoReflect() protoreflect.Message
func (*LuaConfig) SetSourceCode ¶
func (x *LuaConfig) SetSourceCode(v *v3.DataSource)
type LuaConfig_builder ¶
type LuaConfig_builder struct {
// The lua code that Envoy will execute to select cluster.
SourceCode *v3.DataSource
// Default cluster. It will be used when the lua code execute failure.
DefaultCluster string
// contains filtered or unexported fields
}
func (LuaConfig_builder) Build ¶
func (b0 LuaConfig_builder) Build() *LuaConfig
Source Files
¶
- lua.pb.go
Click to show internal directories.
Click to hide internal directories.