open_telemetryv3

package
v1.36.11-2026011520535... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 10 Imported by: 0

Documentation

Index

Constants

const SinkConfig_GrpcService_case case_SinkConfig_ProtocolSpecifier = 1
const SinkConfig_ProtocolSpecifier_not_set_case case_SinkConfig_ProtocolSpecifier = 0

Variables

var File_envoy_extensions_stat_sinks_open_telemetry_v3_open_telemetry_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type SinkConfig

type SinkConfig struct {

	// Types that are valid to be assigned to ProtocolSpecifier:
	//
	//	*SinkConfig_GrpcService
	ProtocolSpecifier isSinkConfig_ProtocolSpecifier `protobuf_oneof:"protocol_specifier"`
	// Attributes to be associated with the resource in the OTLP message.
	// [#extension-category: envoy.tracers.opentelemetry.resource_detectors]
	ResourceDetectors []*v3.TypedExtensionConfig `protobuf:"bytes,7,rep,name=resource_detectors,json=resourceDetectors,proto3" json:"resource_detectors,omitempty"`
	// If set to true, counters will be emitted as deltas, and the OTLP message will have
	// “AGGREGATION_TEMPORALITY_DELTA“ set as AggregationTemporality.
	ReportCountersAsDeltas bool `` /* 132-byte string literal not displayed */
	// If set to true, histograms will be emitted as deltas, and the OTLP message will have
	// “AGGREGATION_TEMPORALITY_DELTA“ set as AggregationTemporality.
	ReportHistogramsAsDeltas bool `` /* 138-byte string literal not displayed */
	// If set to true, metrics will have their tags emitted as OTLP attributes, which may
	// contain values used by the tag extractor or additional tags added during stats creation.
	// Otherwise, no attributes will be associated with the export message. Default value is true.
	EmitTagsAsAttributes *wrapperspb.BoolValue `protobuf:"bytes,4,opt,name=emit_tags_as_attributes,json=emitTagsAsAttributes,proto3" json:"emit_tags_as_attributes,omitempty"`
	// If set to true, metric names will be represented as the tag extracted name instead
	// of the full metric name. Default value is true.
	UseTagExtractedName *wrapperspb.BoolValue `protobuf:"bytes,5,opt,name=use_tag_extracted_name,json=useTagExtractedName,proto3" json:"use_tag_extracted_name,omitempty"`
	// If set, emitted stats names will be prepended with a prefix, so full stat name will be
	// <prefix>.<stats_name>. For example, if the stat name is "foo.bar" and prefix is
	// "pre", the full stat name will be "pre.foo.bar". If this field is not set, there is no
	// prefix added. According to the example, the full stat name will remain "foo.bar".
	Prefix string `protobuf:"bytes,6,opt,name=prefix,proto3" json:"prefix,omitempty"`
	// The custom conversion from a stat to a metric. Currently, the only supported input is
	// “envoy.extensions.matching.common_inputs.stats.v3.StatFullNameMatchInput“.
	// The supported actions are
	// - “envoy.extensions.stat_sinks.open_telemetry.v3.SinkConfig.DropAction“.
	// - “envoy.extensions.stat_sinks.open_telemetry.v3.SinkConfig.ConversionAction“.
	// If stats are not matched, they will be directly converted to OTLP metrics as usual.
	CustomMetricConversions *v31.Matcher `` /* 132-byte string literal not displayed */
	// contains filtered or unexported fields
}

[#next-free-field: 9]

func (*SinkConfig) ClearCustomMetricConversions

func (x *SinkConfig) ClearCustomMetricConversions()

func (*SinkConfig) ClearEmitTagsAsAttributes

func (x *SinkConfig) ClearEmitTagsAsAttributes()

func (*SinkConfig) ClearGrpcService

func (x *SinkConfig) ClearGrpcService()

func (*SinkConfig) ClearProtocolSpecifier

func (x *SinkConfig) ClearProtocolSpecifier()

func (*SinkConfig) ClearUseTagExtractedName

func (x *SinkConfig) ClearUseTagExtractedName()

func (*SinkConfig) GetCustomMetricConversions

func (x *SinkConfig) GetCustomMetricConversions() *v31.Matcher

func (*SinkConfig) GetEmitTagsAsAttributes

func (x *SinkConfig) GetEmitTagsAsAttributes() *wrapperspb.BoolValue

func (*SinkConfig) GetGrpcService

func (x *SinkConfig) GetGrpcService() *v3.GrpcService

func (*SinkConfig) GetPrefix

func (x *SinkConfig) GetPrefix() string

func (*SinkConfig) GetProtocolSpecifier

func (x *SinkConfig) GetProtocolSpecifier() isSinkConfig_ProtocolSpecifier

func (*SinkConfig) GetReportCountersAsDeltas

func (x *SinkConfig) GetReportCountersAsDeltas() bool

func (*SinkConfig) GetReportHistogramsAsDeltas

func (x *SinkConfig) GetReportHistogramsAsDeltas() bool

func (*SinkConfig) GetResourceDetectors

func (x *SinkConfig) GetResourceDetectors() []*v3.TypedExtensionConfig

func (*SinkConfig) GetUseTagExtractedName

func (x *SinkConfig) GetUseTagExtractedName() *wrapperspb.BoolValue

func (*SinkConfig) HasCustomMetricConversions

func (x *SinkConfig) HasCustomMetricConversions() bool

func (*SinkConfig) HasEmitTagsAsAttributes

func (x *SinkConfig) HasEmitTagsAsAttributes() bool

func (*SinkConfig) HasGrpcService

func (x *SinkConfig) HasGrpcService() bool

func (*SinkConfig) HasProtocolSpecifier

func (x *SinkConfig) HasProtocolSpecifier() bool

func (*SinkConfig) HasUseTagExtractedName

func (x *SinkConfig) HasUseTagExtractedName() bool

func (*SinkConfig) ProtoMessage

func (*SinkConfig) ProtoMessage()

func (*SinkConfig) ProtoReflect

func (x *SinkConfig) ProtoReflect() protoreflect.Message

func (*SinkConfig) Reset

func (x *SinkConfig) Reset()

func (*SinkConfig) SetCustomMetricConversions

func (x *SinkConfig) SetCustomMetricConversions(v *v31.Matcher)

func (*SinkConfig) SetEmitTagsAsAttributes

func (x *SinkConfig) SetEmitTagsAsAttributes(v *wrapperspb.BoolValue)

func (*SinkConfig) SetGrpcService

func (x *SinkConfig) SetGrpcService(v *v3.GrpcService)

func (*SinkConfig) SetPrefix

func (x *SinkConfig) SetPrefix(v string)

func (*SinkConfig) SetReportCountersAsDeltas

func (x *SinkConfig) SetReportCountersAsDeltas(v bool)

func (*SinkConfig) SetReportHistogramsAsDeltas

func (x *SinkConfig) SetReportHistogramsAsDeltas(v bool)

func (*SinkConfig) SetResourceDetectors

func (x *SinkConfig) SetResourceDetectors(v []*v3.TypedExtensionConfig)

func (*SinkConfig) SetUseTagExtractedName

func (x *SinkConfig) SetUseTagExtractedName(v *wrapperspb.BoolValue)

func (*SinkConfig) String

func (x *SinkConfig) String() string

func (*SinkConfig) WhichProtocolSpecifier

func (x *SinkConfig) WhichProtocolSpecifier() case_SinkConfig_ProtocolSpecifier

type SinkConfig_ConversionAction

type SinkConfig_ConversionAction struct {

	// The metric name to use for the stat.
	MetricName string `protobuf:"bytes,2,opt,name=metric_name,json=metricName,proto3" json:"metric_name,omitempty"`
	// Static metric labels to use for the metric.
	StaticMetricLabels []*v1.KeyValue `protobuf:"bytes,3,rep,name=static_metric_labels,json=staticMetricLabels,proto3" json:"static_metric_labels,omitempty"`
	// contains filtered or unexported fields
}

ConversionAction is used to convert a stat to a metric. If a stat matches, the metric_name and static_metric_labels will be used to create the metric. This can be used to rename a stat, add static labels, and aggregate multiple stats into a single metric.

func (*SinkConfig_ConversionAction) GetMetricName

func (x *SinkConfig_ConversionAction) GetMetricName() string

func (*SinkConfig_ConversionAction) GetStaticMetricLabels

func (x *SinkConfig_ConversionAction) GetStaticMetricLabels() []*v1.KeyValue

func (*SinkConfig_ConversionAction) ProtoMessage

func (*SinkConfig_ConversionAction) ProtoMessage()

func (*SinkConfig_ConversionAction) ProtoReflect

func (*SinkConfig_ConversionAction) Reset

func (x *SinkConfig_ConversionAction) Reset()

func (*SinkConfig_ConversionAction) SetMetricName

func (x *SinkConfig_ConversionAction) SetMetricName(v string)

func (*SinkConfig_ConversionAction) SetStaticMetricLabels

func (x *SinkConfig_ConversionAction) SetStaticMetricLabels(v []*v1.KeyValue)

func (*SinkConfig_ConversionAction) String

func (x *SinkConfig_ConversionAction) String() string

type SinkConfig_ConversionAction_builder

type SinkConfig_ConversionAction_builder struct {

	// The metric name to use for the stat.
	MetricName string
	// Static metric labels to use for the metric.
	StaticMetricLabels []*v1.KeyValue
	// contains filtered or unexported fields
}

func (SinkConfig_ConversionAction_builder) Build

type SinkConfig_DropAction

type SinkConfig_DropAction struct {
	// contains filtered or unexported fields
}

DropAction is an action that, when matched, will prevent the stat from being converted to an OTLP metric and flushed.

func (*SinkConfig_DropAction) ProtoMessage

func (*SinkConfig_DropAction) ProtoMessage()

func (*SinkConfig_DropAction) ProtoReflect

func (x *SinkConfig_DropAction) ProtoReflect() protoreflect.Message

func (*SinkConfig_DropAction) Reset

func (x *SinkConfig_DropAction) Reset()

func (*SinkConfig_DropAction) String

func (x *SinkConfig_DropAction) String() string

type SinkConfig_DropAction_builder

type SinkConfig_DropAction_builder struct {
	// contains filtered or unexported fields
}

func (SinkConfig_DropAction_builder) Build

type SinkConfig_GrpcService

type SinkConfig_GrpcService struct {
	// The upstream gRPC cluster that implements the OTLP/gRPC collector.
	GrpcService *v3.GrpcService `protobuf:"bytes,1,opt,name=grpc_service,json=grpcService,proto3,oneof"`
}

type SinkConfig_builder

type SinkConfig_builder struct {

	// Fields of oneof ProtocolSpecifier:
	// The upstream gRPC cluster that implements the OTLP/gRPC collector.
	GrpcService *v3.GrpcService
	// -- end of ProtocolSpecifier
	// Attributes to be associated with the resource in the OTLP message.
	// [#extension-category: envoy.tracers.opentelemetry.resource_detectors]
	ResourceDetectors []*v3.TypedExtensionConfig
	// If set to true, counters will be emitted as deltas, and the OTLP message will have
	// “AGGREGATION_TEMPORALITY_DELTA“ set as AggregationTemporality.
	ReportCountersAsDeltas bool
	// If set to true, histograms will be emitted as deltas, and the OTLP message will have
	// “AGGREGATION_TEMPORALITY_DELTA“ set as AggregationTemporality.
	ReportHistogramsAsDeltas bool
	// If set to true, metrics will have their tags emitted as OTLP attributes, which may
	// contain values used by the tag extractor or additional tags added during stats creation.
	// Otherwise, no attributes will be associated with the export message. Default value is true.
	EmitTagsAsAttributes *wrapperspb.BoolValue
	// If set to true, metric names will be represented as the tag extracted name instead
	// of the full metric name. Default value is true.
	UseTagExtractedName *wrapperspb.BoolValue
	// If set, emitted stats names will be prepended with a prefix, so full stat name will be
	// <prefix>.<stats_name>. For example, if the stat name is "foo.bar" and prefix is
	// "pre", the full stat name will be "pre.foo.bar". If this field is not set, there is no
	// prefix added. According to the example, the full stat name will remain "foo.bar".
	Prefix string
	// The custom conversion from a stat to a metric. Currently, the only supported input is
	// “envoy.extensions.matching.common_inputs.stats.v3.StatFullNameMatchInput“.
	// The supported actions are
	// - “envoy.extensions.stat_sinks.open_telemetry.v3.SinkConfig.DropAction“.
	// - “envoy.extensions.stat_sinks.open_telemetry.v3.SinkConfig.ConversionAction“.
	// If stats are not matched, they will be directly converted to OTLP metrics as usual.
	CustomMetricConversions *v31.Matcher
	// contains filtered or unexported fields
}

func (SinkConfig_builder) Build

func (b0 SinkConfig_builder) Build() *SinkConfig

Source Files

  • open_telemetry.pb.go

Jump to