samplersv3

package
v1.36.11-2026011520535... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var File_envoy_extensions_tracers_opentelemetry_samplers_v3_always_on_sampler_proto protoreflect.FileDescriptor
var File_envoy_extensions_tracers_opentelemetry_samplers_v3_cel_sampler_proto protoreflect.FileDescriptor
var File_envoy_extensions_tracers_opentelemetry_samplers_v3_dynatrace_sampler_proto protoreflect.FileDescriptor
var File_envoy_extensions_tracers_opentelemetry_samplers_v3_parent_based_sampler_proto protoreflect.FileDescriptor
var File_envoy_extensions_tracers_opentelemetry_samplers_v3_trace_id_ratio_based_sampler_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type AlwaysOnSamplerConfig

type AlwaysOnSamplerConfig struct {
	// contains filtered or unexported fields
}

func (*AlwaysOnSamplerConfig) ProtoMessage

func (*AlwaysOnSamplerConfig) ProtoMessage()

func (*AlwaysOnSamplerConfig) ProtoReflect

func (x *AlwaysOnSamplerConfig) ProtoReflect() protoreflect.Message

func (*AlwaysOnSamplerConfig) Reset

func (x *AlwaysOnSamplerConfig) Reset()

func (*AlwaysOnSamplerConfig) String

func (x *AlwaysOnSamplerConfig) String() string

type AlwaysOnSamplerConfig_builder

type AlwaysOnSamplerConfig_builder struct {
	// contains filtered or unexported fields
}

func (AlwaysOnSamplerConfig_builder) Build

type CELSamplerConfig

type CELSamplerConfig struct {

	// Expression that, when evaluated, will be used to make sample decision.
	Expression *v3.CelExpression `protobuf:"bytes,1,opt,name=expression,proto3" json:"expression,omitempty"`
	// contains filtered or unexported fields
}

func (*CELSamplerConfig) ClearExpression

func (x *CELSamplerConfig) ClearExpression()

func (*CELSamplerConfig) GetExpression

func (x *CELSamplerConfig) GetExpression() *v3.CelExpression

func (*CELSamplerConfig) HasExpression

func (x *CELSamplerConfig) HasExpression() bool

func (*CELSamplerConfig) ProtoMessage

func (*CELSamplerConfig) ProtoMessage()

func (*CELSamplerConfig) ProtoReflect

func (x *CELSamplerConfig) ProtoReflect() protoreflect.Message

func (*CELSamplerConfig) Reset

func (x *CELSamplerConfig) Reset()

func (*CELSamplerConfig) SetExpression

func (x *CELSamplerConfig) SetExpression(v *v3.CelExpression)

func (*CELSamplerConfig) String

func (x *CELSamplerConfig) String() string

type CELSamplerConfig_builder

type CELSamplerConfig_builder struct {

	// Expression that, when evaluated, will be used to make sample decision.
	Expression *v3.CelExpression
	// contains filtered or unexported fields
}

func (CELSamplerConfig_builder) Build

type DynatraceSamplerConfig

type DynatraceSamplerConfig struct {

	// The Dynatrace tenant.
	//
	// The value can be obtained from the Envoy deployment page in Dynatrace.
	Tenant string `protobuf:"bytes,1,opt,name=tenant,proto3" json:"tenant,omitempty"`
	// The id of the Dynatrace cluster id.
	//
	// The value can be obtained from the Envoy deployment page in Dynatrace.
	ClusterId int32 `protobuf:"varint,2,opt,name=cluster_id,json=clusterId,proto3" json:"cluster_id,omitempty"`
	// The HTTP service to fetch the sampler configuration from the Dynatrace API (root spans per minute). For example:
	//
	// .. code-block:: yaml
	//
	//	http_service:
	//	  http_uri:
	//	    cluster: dynatrace
	//	    uri: <tenant>.dev.dynatracelabs.com/api/v2/samplingConfiguration
	//	    timeout: 10s
	//	  request_headers_to_add:
	//	  - header:
	//	      key : "authorization"
	//	      value: "Api-Token dt..."
	HttpService *v3.HttpService `protobuf:"bytes,3,opt,name=http_service,json=httpService,proto3" json:"http_service,omitempty"`
	// Default number of root spans per minute, used when the value can't be obtained from the Dynatrace API.
	//
	// A default value of “1000“ is used when:
	//
	// - “root_spans_per_minute“ is unset
	// - “root_spans_per_minute“ is set to 0
	RootSpansPerMinute uint32 `protobuf:"varint,4,opt,name=root_spans_per_minute,json=rootSpansPerMinute,proto3" json:"root_spans_per_minute,omitempty"`
	// contains filtered or unexported fields
}

Configuration for the Dynatrace Sampler extension. [#extension: envoy.tracers.opentelemetry.samplers.dynatrace]

func (*DynatraceSamplerConfig) ClearHttpService

func (x *DynatraceSamplerConfig) ClearHttpService()

func (*DynatraceSamplerConfig) GetClusterId

func (x *DynatraceSamplerConfig) GetClusterId() int32

func (*DynatraceSamplerConfig) GetHttpService

func (x *DynatraceSamplerConfig) GetHttpService() *v3.HttpService

func (*DynatraceSamplerConfig) GetRootSpansPerMinute

func (x *DynatraceSamplerConfig) GetRootSpansPerMinute() uint32

func (*DynatraceSamplerConfig) GetTenant

func (x *DynatraceSamplerConfig) GetTenant() string

func (*DynatraceSamplerConfig) HasHttpService

func (x *DynatraceSamplerConfig) HasHttpService() bool

func (*DynatraceSamplerConfig) ProtoMessage

func (*DynatraceSamplerConfig) ProtoMessage()

func (*DynatraceSamplerConfig) ProtoReflect

func (x *DynatraceSamplerConfig) ProtoReflect() protoreflect.Message

func (*DynatraceSamplerConfig) Reset

func (x *DynatraceSamplerConfig) Reset()

func (*DynatraceSamplerConfig) SetClusterId

func (x *DynatraceSamplerConfig) SetClusterId(v int32)

func (*DynatraceSamplerConfig) SetHttpService

func (x *DynatraceSamplerConfig) SetHttpService(v *v3.HttpService)

func (*DynatraceSamplerConfig) SetRootSpansPerMinute

func (x *DynatraceSamplerConfig) SetRootSpansPerMinute(v uint32)

func (*DynatraceSamplerConfig) SetTenant

func (x *DynatraceSamplerConfig) SetTenant(v string)

func (*DynatraceSamplerConfig) String

func (x *DynatraceSamplerConfig) String() string

type DynatraceSamplerConfig_builder

type DynatraceSamplerConfig_builder struct {

	// The Dynatrace tenant.
	//
	// The value can be obtained from the Envoy deployment page in Dynatrace.
	Tenant string
	// The id of the Dynatrace cluster id.
	//
	// The value can be obtained from the Envoy deployment page in Dynatrace.
	ClusterId int32
	// The HTTP service to fetch the sampler configuration from the Dynatrace API (root spans per minute). For example:
	//
	// .. code-block:: yaml
	//
	//	http_service:
	//	  http_uri:
	//	    cluster: dynatrace
	//	    uri: <tenant>.dev.dynatracelabs.com/api/v2/samplingConfiguration
	//	    timeout: 10s
	//	  request_headers_to_add:
	//	  - header:
	//	      key : "authorization"
	//	      value: "Api-Token dt..."
	HttpService *v3.HttpService
	// Default number of root spans per minute, used when the value can't be obtained from the Dynatrace API.
	//
	// A default value of “1000“ is used when:
	//
	// - “root_spans_per_minute“ is unset
	// - “root_spans_per_minute“ is set to 0
	RootSpansPerMinute uint32
	// contains filtered or unexported fields
}

func (DynatraceSamplerConfig_builder) Build

type ParentBasedSamplerConfig

type ParentBasedSamplerConfig struct {

	// Specifies the sampler to be used by this sampler.
	// The configured sampler will be used if the parent trace ID is not passed to Envoy
	//
	// required
	// [#extension-category: envoy.tracers.opentelemetry.samplers]
	WrappedSampler *v3.TypedExtensionConfig `protobuf:"bytes,1,opt,name=wrapped_sampler,json=wrappedSampler,proto3" json:"wrapped_sampler,omitempty"`
	// contains filtered or unexported fields
}

func (*ParentBasedSamplerConfig) ClearWrappedSampler

func (x *ParentBasedSamplerConfig) ClearWrappedSampler()

func (*ParentBasedSamplerConfig) GetWrappedSampler

func (x *ParentBasedSamplerConfig) GetWrappedSampler() *v3.TypedExtensionConfig

func (*ParentBasedSamplerConfig) HasWrappedSampler

func (x *ParentBasedSamplerConfig) HasWrappedSampler() bool

func (*ParentBasedSamplerConfig) ProtoMessage

func (*ParentBasedSamplerConfig) ProtoMessage()

func (*ParentBasedSamplerConfig) ProtoReflect

func (x *ParentBasedSamplerConfig) ProtoReflect() protoreflect.Message

func (*ParentBasedSamplerConfig) Reset

func (x *ParentBasedSamplerConfig) Reset()

func (*ParentBasedSamplerConfig) SetWrappedSampler

func (x *ParentBasedSamplerConfig) SetWrappedSampler(v *v3.TypedExtensionConfig)

func (*ParentBasedSamplerConfig) String

func (x *ParentBasedSamplerConfig) String() string

type ParentBasedSamplerConfig_builder

type ParentBasedSamplerConfig_builder struct {

	// Specifies the sampler to be used by this sampler.
	// The configured sampler will be used if the parent trace ID is not passed to Envoy
	//
	// required
	// [#extension-category: envoy.tracers.opentelemetry.samplers]
	WrappedSampler *v3.TypedExtensionConfig
	// contains filtered or unexported fields
}

func (ParentBasedSamplerConfig_builder) Build

type TraceIdRatioBasedSamplerConfig

type TraceIdRatioBasedSamplerConfig struct {

	// If the given trace_id falls into a given percentage of all possible
	// trace_id values, ShouldSample will return RECORD_AND_SAMPLE.
	// required
	// [#extension-category: envoy.tracers.opentelemetry.samplers]
	SamplingPercentage *v3.FractionalPercent `protobuf:"bytes,1,opt,name=sampling_percentage,json=samplingPercentage,proto3" json:"sampling_percentage,omitempty"`
	// contains filtered or unexported fields
}

func (*TraceIdRatioBasedSamplerConfig) ClearSamplingPercentage

func (x *TraceIdRatioBasedSamplerConfig) ClearSamplingPercentage()

func (*TraceIdRatioBasedSamplerConfig) GetSamplingPercentage

func (x *TraceIdRatioBasedSamplerConfig) GetSamplingPercentage() *v3.FractionalPercent

func (*TraceIdRatioBasedSamplerConfig) HasSamplingPercentage

func (x *TraceIdRatioBasedSamplerConfig) HasSamplingPercentage() bool

func (*TraceIdRatioBasedSamplerConfig) ProtoMessage

func (*TraceIdRatioBasedSamplerConfig) ProtoMessage()

func (*TraceIdRatioBasedSamplerConfig) ProtoReflect

func (*TraceIdRatioBasedSamplerConfig) Reset

func (x *TraceIdRatioBasedSamplerConfig) Reset()

func (*TraceIdRatioBasedSamplerConfig) SetSamplingPercentage

func (x *TraceIdRatioBasedSamplerConfig) SetSamplingPercentage(v *v3.FractionalPercent)

func (*TraceIdRatioBasedSamplerConfig) String

type TraceIdRatioBasedSamplerConfig_builder

type TraceIdRatioBasedSamplerConfig_builder struct {

	// If the given trace_id falls into a given percentage of all possible
	// trace_id values, ShouldSample will return RECORD_AND_SAMPLE.
	// required
	// [#extension-category: envoy.tracers.opentelemetry.samplers]
	SamplingPercentage *v3.FractionalPercent
	// contains filtered or unexported fields
}

func (TraceIdRatioBasedSamplerConfig_builder) Build

Source Files

  • always_on_sampler.pb.go
  • cel_sampler.pb.go
  • dynatrace_sampler.pb.go
  • parent_based_sampler.pb.go
  • trace_id_ratio_based_sampler.pb.go

Jump to