http_11_proxyv3

package
v1.36.11-2026042420273... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var File_envoy_extensions_transport_sockets_http_11_proxy_v3_upstream_http_11_connect_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type Http11ProxyUpstreamTransport

type Http11ProxyUpstreamTransport struct {

	// The underlying transport socket being wrapped. Defaults to plaintext (raw_buffer) if unset.
	TransportSocket *v3.TransportSocket `protobuf:"bytes,1,opt,name=transport_socket,json=transportSocket,proto3" json:"transport_socket,omitempty"`
	// Specifies the default proxy address to use if the proxy address is not present in the
	// “typed_filter_metadata“ of the endpoint.
	DefaultProxyAddress *v3.Address `protobuf:"bytes,2,opt,name=default_proxy_address,json=defaultProxyAddress,proto3" json:"default_proxy_address,omitempty"`
	// contains filtered or unexported fields
}

HTTP/1.1 proxy transport socket establishes an upstream connection to a proxy address instead of the target host's address. This behavior is triggered when the transport socket is configured and proxy information is provided.

Behavior when proxying: ======================= When an upstream connection is established, instead of connecting directly to the endpoint address, the client will connect to the specified proxy address, send an HTTP/1.1 “CONNECT“ request indicating the endpoint address, and process the response. If the response has HTTP status 200, the connection will be passed down to the underlying transport socket.

Configuring proxy information: ============================== Set “typed_filter_metadata“ in :ref:`LbEndpoint.Metadata <envoy_v3_api_field_config.endpoint.v3.lbendpoint.metadata>` or :ref:`LocalityLbEndpoints.Metadata <envoy_v3_api_field_config.endpoint.v3.LocalityLbEndpoints.metadata>`. using the key “envoy.http11_proxy_transport_socket.proxy_address“ and the proxy address in “config::core::v3::Address“ format.

If the “default_proxy_address“ is set and proxy address is not found in “typed_filter_metadata“, the default proxy address is used.

func (*Http11ProxyUpstreamTransport) ClearDefaultProxyAddress

func (x *Http11ProxyUpstreamTransport) ClearDefaultProxyAddress()

func (*Http11ProxyUpstreamTransport) ClearTransportSocket

func (x *Http11ProxyUpstreamTransport) ClearTransportSocket()

func (*Http11ProxyUpstreamTransport) GetDefaultProxyAddress

func (x *Http11ProxyUpstreamTransport) GetDefaultProxyAddress() *v3.Address

func (*Http11ProxyUpstreamTransport) GetTransportSocket

func (x *Http11ProxyUpstreamTransport) GetTransportSocket() *v3.TransportSocket

func (*Http11ProxyUpstreamTransport) HasDefaultProxyAddress

func (x *Http11ProxyUpstreamTransport) HasDefaultProxyAddress() bool

func (*Http11ProxyUpstreamTransport) HasTransportSocket

func (x *Http11ProxyUpstreamTransport) HasTransportSocket() bool

func (*Http11ProxyUpstreamTransport) ProtoMessage

func (*Http11ProxyUpstreamTransport) ProtoMessage()

func (*Http11ProxyUpstreamTransport) ProtoReflect

func (*Http11ProxyUpstreamTransport) Reset

func (x *Http11ProxyUpstreamTransport) Reset()

func (*Http11ProxyUpstreamTransport) SetDefaultProxyAddress

func (x *Http11ProxyUpstreamTransport) SetDefaultProxyAddress(v *v3.Address)

func (*Http11ProxyUpstreamTransport) SetTransportSocket

func (x *Http11ProxyUpstreamTransport) SetTransportSocket(v *v3.TransportSocket)

func (*Http11ProxyUpstreamTransport) String

type Http11ProxyUpstreamTransport_builder

type Http11ProxyUpstreamTransport_builder struct {

	// The underlying transport socket being wrapped. Defaults to plaintext (raw_buffer) if unset.
	TransportSocket *v3.TransportSocket
	// Specifies the default proxy address to use if the proxy address is not present in the
	// “typed_filter_metadata“ of the endpoint.
	DefaultProxyAddress *v3.Address
	// contains filtered or unexported fields
}

func (Http11ProxyUpstreamTransport_builder) Build

Source Files

  • upstream_http_11_connect.pb.go

Jump to