Documentation
¶
Index ¶
- Variables
- type SocketTapConfig
- func (x *SocketTapConfig) GetSetConnectionPerEvent() bool
- func (x *SocketTapConfig) GetStatsPrefix() string
- func (*SocketTapConfig) ProtoMessage()
- func (x *SocketTapConfig) ProtoReflect() protoreflect.Message
- func (x *SocketTapConfig) Reset()
- func (x *SocketTapConfig) SetSetConnectionPerEvent(v bool)
- func (x *SocketTapConfig) SetStatsPrefix(v string)
- func (x *SocketTapConfig) String() string
- type SocketTapConfig_builder
- type Tap
- func (x *Tap) ClearCommonConfig()
- func (x *Tap) ClearSocketTapConfig()
- func (x *Tap) ClearTransportSocket()
- func (x *Tap) GetCommonConfig() *v3.CommonExtensionConfig
- func (x *Tap) GetSocketTapConfig() *SocketTapConfig
- func (x *Tap) GetTransportSocket() *v31.TransportSocket
- func (x *Tap) HasCommonConfig() bool
- func (x *Tap) HasSocketTapConfig() bool
- func (x *Tap) HasTransportSocket() bool
- func (*Tap) ProtoMessage()
- func (x *Tap) ProtoReflect() protoreflect.Message
- func (x *Tap) Reset()
- func (x *Tap) SetCommonConfig(v *v3.CommonExtensionConfig)
- func (x *Tap) SetSocketTapConfig(v *SocketTapConfig)
- func (x *Tap) SetTransportSocket(v *v31.TransportSocket)
- func (x *Tap) String() string
- type Tap_builder
Constants ¶
This section is empty.
Variables ¶
var File_envoy_extensions_transport_sockets_tap_v3_tap_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type SocketTapConfig ¶
type SocketTapConfig struct {
// Indicates to whether output the connection information per event
// This is only applicable if the streamed trace is enabled
SetConnectionPerEvent bool `` /* 129-byte string literal not displayed */
// The contents of the transport tap's statistics prefix.
StatsPrefix string `protobuf:"bytes,2,opt,name=stats_prefix,json=statsPrefix,proto3" json:"stats_prefix,omitempty"`
// contains filtered or unexported fields
}
Additional configurations for the transport socket tap
func (*SocketTapConfig) GetSetConnectionPerEvent ¶
func (x *SocketTapConfig) GetSetConnectionPerEvent() bool
func (*SocketTapConfig) GetStatsPrefix ¶
func (x *SocketTapConfig) GetStatsPrefix() string
func (*SocketTapConfig) ProtoMessage ¶
func (*SocketTapConfig) ProtoMessage()
func (*SocketTapConfig) ProtoReflect ¶
func (x *SocketTapConfig) ProtoReflect() protoreflect.Message
func (*SocketTapConfig) Reset ¶
func (x *SocketTapConfig) Reset()
func (*SocketTapConfig) SetSetConnectionPerEvent ¶
func (x *SocketTapConfig) SetSetConnectionPerEvent(v bool)
func (*SocketTapConfig) SetStatsPrefix ¶
func (x *SocketTapConfig) SetStatsPrefix(v string)
func (*SocketTapConfig) String ¶
func (x *SocketTapConfig) String() string
type SocketTapConfig_builder ¶
type SocketTapConfig_builder struct {
// Indicates to whether output the connection information per event
// This is only applicable if the streamed trace is enabled
SetConnectionPerEvent bool
// The contents of the transport tap's statistics prefix.
StatsPrefix string
// contains filtered or unexported fields
}
func (SocketTapConfig_builder) Build ¶
func (b0 SocketTapConfig_builder) Build() *SocketTapConfig
type Tap ¶
type Tap struct {
// Common configuration for the tap transport socket.
CommonConfig *v3.CommonExtensionConfig `protobuf:"bytes,1,opt,name=common_config,json=commonConfig,proto3" json:"common_config,omitempty"`
// The underlying transport socket being wrapped.
TransportSocket *v31.TransportSocket `protobuf:"bytes,2,opt,name=transport_socket,json=transportSocket,proto3" json:"transport_socket,omitempty"`
// Additional configurations for the transport socket tap
SocketTapConfig *SocketTapConfig `protobuf:"bytes,3,opt,name=socket_tap_config,json=socketTapConfig,proto3" json:"socket_tap_config,omitempty"`
// contains filtered or unexported fields
}
Configuration for tap transport socket. This wraps another transport socket, providing the ability to interpose and record in plain text any traffic that is surfaced to Envoy.
func (*Tap) GetCommonConfig ¶
func (x *Tap) GetCommonConfig() *v3.CommonExtensionConfig
func (*Tap) GetSocketTapConfig ¶
func (x *Tap) GetSocketTapConfig() *SocketTapConfig
func (*Tap) GetTransportSocket ¶
func (x *Tap) GetTransportSocket() *v31.TransportSocket
func (*Tap) ProtoReflect ¶
func (x *Tap) ProtoReflect() protoreflect.Message
func (*Tap) SetCommonConfig ¶
func (x *Tap) SetCommonConfig(v *v3.CommonExtensionConfig)
func (*Tap) SetSocketTapConfig ¶
func (x *Tap) SetSocketTapConfig(v *SocketTapConfig)
func (*Tap) SetTransportSocket ¶
func (x *Tap) SetTransportSocket(v *v31.TransportSocket)
type Tap_builder ¶
type Tap_builder struct {
// Common configuration for the tap transport socket.
CommonConfig *v3.CommonExtensionConfig
// The underlying transport socket being wrapped.
TransportSocket *v31.TransportSocket
// Additional configurations for the transport socket tap
SocketTapConfig *SocketTapConfig
// contains filtered or unexported fields
}
func (Tap_builder) Build ¶
func (b0 Tap_builder) Build() *Tap
Source Files
¶
- tap.pb.go
Click to show internal directories.
Click to hide internal directories.