Documentation
¶
Index ¶
- Variables
- type Config
- func (x *Config) ClearTransportSocket()
- func (x *Config) ClearUpdatePeriod()
- func (x *Config) GetTransportSocket() *v3.TransportSocket
- func (x *Config) GetUpdatePeriod() *durationpb.Duration
- func (x *Config) HasTransportSocket() bool
- func (x *Config) HasUpdatePeriod() bool
- func (*Config) ProtoMessage()
- func (x *Config) ProtoReflect() protoreflect.Message
- func (x *Config) Reset()
- func (x *Config) SetTransportSocket(v *v3.TransportSocket)
- func (x *Config) SetUpdatePeriod(v *durationpb.Duration)
- func (x *Config) String() string
- type Config_builder
Constants ¶
This section is empty.
Variables ¶
var File_envoy_extensions_transport_sockets_tcp_stats_v3_tcp_stats_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
// The underlying transport socket being wrapped.
TransportSocket *v3.TransportSocket `protobuf:"bytes,1,opt,name=transport_socket,json=transportSocket,proto3" json:"transport_socket,omitempty"`
// Period to update stats while the connection is open. If unset, updates only happen when the
// connection is closed. Stats are always updated one final time when the connection is closed.
UpdatePeriod *durationpb.Duration `protobuf:"bytes,2,opt,name=update_period,json=updatePeriod,proto3" json:"update_period,omitempty"`
// contains filtered or unexported fields
}
Configuration for the TCP Stats transport socket wrapper, which wraps another transport socket for all communication, but emits stats about the underlying TCP connection.
The stats are documented :ref:`here <config_listener_stats_tcp>` for listeners and :ref:`here <config_cluster_manager_cluster_stats_tcp>` for clusters.
This transport socket is currently only supported on Linux.
func (*Config) GetTransportSocket ¶
func (x *Config) GetTransportSocket() *v3.TransportSocket
func (*Config) GetUpdatePeriod ¶
func (x *Config) GetUpdatePeriod() *durationpb.Duration
func (*Config) ProtoReflect ¶
func (x *Config) ProtoReflect() protoreflect.Message
func (*Config) SetTransportSocket ¶
func (x *Config) SetTransportSocket(v *v3.TransportSocket)
func (*Config) SetUpdatePeriod ¶
func (x *Config) SetUpdatePeriod(v *durationpb.Duration)
type Config_builder ¶
type Config_builder struct {
// The underlying transport socket being wrapped.
TransportSocket *v3.TransportSocket
// Period to update stats while the connection is open. If unset, updates only happen when the
// connection is closed. Stats are always updated one final time when the connection is closed.
UpdatePeriod *durationpb.Duration
// contains filtered or unexported fields
}
func (Config_builder) Build ¶
func (b0 Config_builder) Build() *Config
Source Files
¶
- tcp_stats.pb.go
Click to show internal directories.
Click to hide internal directories.