Documentation
¶
Index ¶
- Variables
- type ProfileActionConfig
- func (x *ProfileActionConfig) ClearProfileDuration()
- func (x *ProfileActionConfig) GetMaxProfiles() uint64
- func (x *ProfileActionConfig) GetProfileDuration() *durationpb.Duration
- func (x *ProfileActionConfig) GetProfilePath() string
- func (x *ProfileActionConfig) HasProfileDuration() bool
- func (*ProfileActionConfig) ProtoMessage()
- func (x *ProfileActionConfig) ProtoReflect() protoreflect.Message
- func (x *ProfileActionConfig) Reset()
- func (x *ProfileActionConfig) SetMaxProfiles(v uint64)
- func (x *ProfileActionConfig) SetProfileDuration(v *durationpb.Duration)
- func (x *ProfileActionConfig) SetProfilePath(v string)
- func (x *ProfileActionConfig) String() string
- type ProfileActionConfig_builder
Constants ¶
This section is empty.
Variables ¶
var File_envoy_extensions_watchdog_profile_action_v3_profile_action_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type ProfileActionConfig ¶
type ProfileActionConfig struct {
// How long the profile should last. If not set defaults to 5 seconds.
ProfileDuration *durationpb.Duration `protobuf:"bytes,1,opt,name=profile_duration,json=profileDuration,proto3" json:"profile_duration,omitempty"`
// File path to the directory to output profiles.
ProfilePath string `protobuf:"bytes,2,opt,name=profile_path,json=profilePath,proto3" json:"profile_path,omitempty"`
// Limits the max number of profiles that can be generated by this action
// over its lifetime to avoid filling the disk.
// If not set (i.e. it's 0), a default of 10 will be used.
MaxProfiles uint64 `protobuf:"varint,3,opt,name=max_profiles,json=maxProfiles,proto3" json:"max_profiles,omitempty"`
// contains filtered or unexported fields
}
Configuration for the profile watchdog action.
func (*ProfileActionConfig) ClearProfileDuration ¶
func (x *ProfileActionConfig) ClearProfileDuration()
func (*ProfileActionConfig) GetMaxProfiles ¶
func (x *ProfileActionConfig) GetMaxProfiles() uint64
func (*ProfileActionConfig) GetProfileDuration ¶
func (x *ProfileActionConfig) GetProfileDuration() *durationpb.Duration
func (*ProfileActionConfig) GetProfilePath ¶
func (x *ProfileActionConfig) GetProfilePath() string
func (*ProfileActionConfig) HasProfileDuration ¶
func (x *ProfileActionConfig) HasProfileDuration() bool
func (*ProfileActionConfig) ProtoMessage ¶
func (*ProfileActionConfig) ProtoMessage()
func (*ProfileActionConfig) ProtoReflect ¶
func (x *ProfileActionConfig) ProtoReflect() protoreflect.Message
func (*ProfileActionConfig) Reset ¶
func (x *ProfileActionConfig) Reset()
func (*ProfileActionConfig) SetMaxProfiles ¶
func (x *ProfileActionConfig) SetMaxProfiles(v uint64)
func (*ProfileActionConfig) SetProfileDuration ¶
func (x *ProfileActionConfig) SetProfileDuration(v *durationpb.Duration)
func (*ProfileActionConfig) SetProfilePath ¶
func (x *ProfileActionConfig) SetProfilePath(v string)
func (*ProfileActionConfig) String ¶
func (x *ProfileActionConfig) String() string
type ProfileActionConfig_builder ¶
type ProfileActionConfig_builder struct {
// How long the profile should last. If not set defaults to 5 seconds.
ProfileDuration *durationpb.Duration
// File path to the directory to output profiles.
ProfilePath string
// Limits the max number of profiles that can be generated by this action
// over its lifetime to avoid filling the disk.
// If not set (i.e. it's 0), a default of 10 will be used.
MaxProfiles uint64
// contains filtered or unexported fields
}
func (ProfileActionConfig_builder) Build ¶
func (b0 ProfileActionConfig_builder) Build() *ProfileActionConfig
Source Files
¶
- profile_action.pb.go
Click to show internal directories.
Click to hide internal directories.