redis_authv3

package
v1.36.11-2026011520535... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 7 Imported by: 3

Documentation

Index

Constants

This section is empty.

Variables

var File_envoy_service_redis_auth_v3_redis_external_auth_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type RedisProxyExternalAuthRequest

type RedisProxyExternalAuthRequest struct {

	// Username, if applicable. Otherwise, empty.
	Username string `protobuf:"bytes,1,opt,name=username,proto3" json:"username,omitempty"`
	// Password sent with the AUTH command.
	Password string `protobuf:"bytes,2,opt,name=password,proto3" json:"password,omitempty"`
	// contains filtered or unexported fields
}

func (*RedisProxyExternalAuthRequest) GetPassword

func (x *RedisProxyExternalAuthRequest) GetPassword() string

func (*RedisProxyExternalAuthRequest) GetUsername

func (x *RedisProxyExternalAuthRequest) GetUsername() string

func (*RedisProxyExternalAuthRequest) ProtoMessage

func (*RedisProxyExternalAuthRequest) ProtoMessage()

func (*RedisProxyExternalAuthRequest) ProtoReflect

func (*RedisProxyExternalAuthRequest) Reset

func (x *RedisProxyExternalAuthRequest) Reset()

func (*RedisProxyExternalAuthRequest) SetPassword

func (x *RedisProxyExternalAuthRequest) SetPassword(v string)

func (*RedisProxyExternalAuthRequest) SetUsername

func (x *RedisProxyExternalAuthRequest) SetUsername(v string)

func (*RedisProxyExternalAuthRequest) String

type RedisProxyExternalAuthRequest_builder

type RedisProxyExternalAuthRequest_builder struct {

	// Username, if applicable. Otherwise, empty.
	Username string
	// Password sent with the AUTH command.
	Password string
	// contains filtered or unexported fields
}

func (RedisProxyExternalAuthRequest_builder) Build

type RedisProxyExternalAuthResponse

type RedisProxyExternalAuthResponse struct {

	// Status of the authentication check.
	Status *status.Status `protobuf:"bytes,1,opt,name=status,proto3" json:"status,omitempty"`
	// Optional expiration time for the authentication.
	// If set, the authentication will be valid until this time.
	// If not set, the authentication will be valid indefinitely.
	Expiration *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=expiration,proto3" json:"expiration,omitempty"`
	// Optional message to be sent back to the client.
	Message string `protobuf:"bytes,3,opt,name=message,proto3" json:"message,omitempty"`
	// contains filtered or unexported fields
}

func (*RedisProxyExternalAuthResponse) ClearExpiration

func (x *RedisProxyExternalAuthResponse) ClearExpiration()

func (*RedisProxyExternalAuthResponse) ClearStatus

func (x *RedisProxyExternalAuthResponse) ClearStatus()

func (*RedisProxyExternalAuthResponse) GetExpiration

func (*RedisProxyExternalAuthResponse) GetMessage

func (x *RedisProxyExternalAuthResponse) GetMessage() string

func (*RedisProxyExternalAuthResponse) GetStatus

func (*RedisProxyExternalAuthResponse) HasExpiration

func (x *RedisProxyExternalAuthResponse) HasExpiration() bool

func (*RedisProxyExternalAuthResponse) HasStatus

func (x *RedisProxyExternalAuthResponse) HasStatus() bool

func (*RedisProxyExternalAuthResponse) ProtoMessage

func (*RedisProxyExternalAuthResponse) ProtoMessage()

func (*RedisProxyExternalAuthResponse) ProtoReflect

func (*RedisProxyExternalAuthResponse) Reset

func (x *RedisProxyExternalAuthResponse) Reset()

func (*RedisProxyExternalAuthResponse) SetExpiration

func (*RedisProxyExternalAuthResponse) SetMessage

func (x *RedisProxyExternalAuthResponse) SetMessage(v string)

func (*RedisProxyExternalAuthResponse) SetStatus

func (x *RedisProxyExternalAuthResponse) SetStatus(v *status.Status)

func (*RedisProxyExternalAuthResponse) String

type RedisProxyExternalAuthResponse_builder

type RedisProxyExternalAuthResponse_builder struct {

	// Status of the authentication check.
	Status *status.Status
	// Optional expiration time for the authentication.
	// If set, the authentication will be valid until this time.
	// If not set, the authentication will be valid indefinitely.
	Expiration *timestamppb.Timestamp
	// Optional message to be sent back to the client.
	Message string
	// contains filtered or unexported fields
}

func (RedisProxyExternalAuthResponse_builder) Build

Source Files

  • redis_external_auth.pb.go

Jump to