Documentation
¶
Index ¶
- Constants
- Variables
- type ClientConfig
- func (x *ClientConfig) ClearNode()
- func (x *ClientConfig) GetNode() *core.Node
- func (x *ClientConfig) GetXdsConfig() []*PerXdsConfig
- func (x *ClientConfig) HasNode() bool
- func (*ClientConfig) ProtoMessage()
- func (x *ClientConfig) ProtoReflect() protoreflect.Message
- func (x *ClientConfig) Reset()
- func (x *ClientConfig) SetNode(v *core.Node)
- func (x *ClientConfig) SetXdsConfig(v []*PerXdsConfig)
- func (x *ClientConfig) String() string
- type ClientConfig_builder
- type ClientStatusRequest
- func (x *ClientStatusRequest) GetNodeMatchers() []*matcher.NodeMatcher
- func (*ClientStatusRequest) ProtoMessage()
- func (x *ClientStatusRequest) ProtoReflect() protoreflect.Message
- func (x *ClientStatusRequest) Reset()
- func (x *ClientStatusRequest) SetNodeMatchers(v []*matcher.NodeMatcher)
- func (x *ClientStatusRequest) String() string
- type ClientStatusRequest_builder
- type ClientStatusResponse
- func (x *ClientStatusResponse) GetConfig() []*ClientConfig
- func (*ClientStatusResponse) ProtoMessage()
- func (x *ClientStatusResponse) ProtoReflect() protoreflect.Message
- func (x *ClientStatusResponse) Reset()
- func (x *ClientStatusResponse) SetConfig(v []*ClientConfig)
- func (x *ClientStatusResponse) String() string
- type ClientStatusResponse_builder
- type ConfigStatus
- type PerXdsConfig
- func (x *PerXdsConfig) ClearClusterConfig()
- func (x *PerXdsConfig) ClearListenerConfig()
- func (x *PerXdsConfig) ClearPerXdsConfig()
- func (x *PerXdsConfig) ClearRouteConfig()
- func (x *PerXdsConfig) ClearScopedRouteConfig()
- func (x *PerXdsConfig) GetClusterConfig() *v2alpha.ClustersConfigDump
- func (x *PerXdsConfig) GetListenerConfig() *v2alpha.ListenersConfigDump
- func (x *PerXdsConfig) GetPerXdsConfig() isPerXdsConfig_PerXdsConfig
- func (x *PerXdsConfig) GetRouteConfig() *v2alpha.RoutesConfigDump
- func (x *PerXdsConfig) GetScopedRouteConfig() *v2alpha.ScopedRoutesConfigDump
- func (x *PerXdsConfig) GetStatus() ConfigStatus
- func (x *PerXdsConfig) HasClusterConfig() bool
- func (x *PerXdsConfig) HasListenerConfig() bool
- func (x *PerXdsConfig) HasPerXdsConfig() bool
- func (x *PerXdsConfig) HasRouteConfig() bool
- func (x *PerXdsConfig) HasScopedRouteConfig() bool
- func (*PerXdsConfig) ProtoMessage()
- func (x *PerXdsConfig) ProtoReflect() protoreflect.Message
- func (x *PerXdsConfig) Reset()
- func (x *PerXdsConfig) SetClusterConfig(v *v2alpha.ClustersConfigDump)
- func (x *PerXdsConfig) SetListenerConfig(v *v2alpha.ListenersConfigDump)
- func (x *PerXdsConfig) SetRouteConfig(v *v2alpha.RoutesConfigDump)
- func (x *PerXdsConfig) SetScopedRouteConfig(v *v2alpha.ScopedRoutesConfigDump)
- func (x *PerXdsConfig) SetStatus(v ConfigStatus)
- func (x *PerXdsConfig) String() string
- func (x *PerXdsConfig) WhichPerXdsConfig() case_PerXdsConfig_PerXdsConfig
- type PerXdsConfig_ClusterConfig
- type PerXdsConfig_ListenerConfig
- type PerXdsConfig_RouteConfig
- type PerXdsConfig_ScopedRouteConfig
- type PerXdsConfig_builder
Constants ¶
const PerXdsConfig_ClusterConfig_case case_PerXdsConfig_PerXdsConfig = 3
const PerXdsConfig_ListenerConfig_case case_PerXdsConfig_PerXdsConfig = 2
const PerXdsConfig_PerXdsConfig_not_set_case case_PerXdsConfig_PerXdsConfig = 0
const PerXdsConfig_RouteConfig_case case_PerXdsConfig_PerXdsConfig = 4
const PerXdsConfig_ScopedRouteConfig_case case_PerXdsConfig_PerXdsConfig = 5
Variables ¶
var ( ConfigStatus_name = map[int32]string{ 0: "UNKNOWN", 1: "SYNCED", 2: "NOT_SENT", 3: "STALE", 4: "ERROR", } ConfigStatus_value = map[string]int32{ "UNKNOWN": 0, "SYNCED": 1, "NOT_SENT": 2, "STALE": 3, "ERROR": 4, } )
Enum value maps for ConfigStatus.
var File_envoy_service_status_v2_csds_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type ClientConfig ¶
type ClientConfig struct {
// Node for a particular client.
Node *core.Node `protobuf:"bytes,1,opt,name=node,proto3" json:"node,omitempty"`
XdsConfig []*PerXdsConfig `protobuf:"bytes,2,rep,name=xds_config,json=xdsConfig,proto3" json:"xds_config,omitempty"`
// contains filtered or unexported fields
}
All xds configs for a particular client.
func (*ClientConfig) ClearNode ¶
func (x *ClientConfig) ClearNode()
func (*ClientConfig) GetNode ¶
func (x *ClientConfig) GetNode() *core.Node
func (*ClientConfig) GetXdsConfig ¶
func (x *ClientConfig) GetXdsConfig() []*PerXdsConfig
func (*ClientConfig) HasNode ¶
func (x *ClientConfig) HasNode() bool
func (*ClientConfig) ProtoMessage ¶
func (*ClientConfig) ProtoMessage()
func (*ClientConfig) ProtoReflect ¶
func (x *ClientConfig) ProtoReflect() protoreflect.Message
func (*ClientConfig) Reset ¶
func (x *ClientConfig) Reset()
func (*ClientConfig) SetNode ¶
func (x *ClientConfig) SetNode(v *core.Node)
func (*ClientConfig) SetXdsConfig ¶
func (x *ClientConfig) SetXdsConfig(v []*PerXdsConfig)
func (*ClientConfig) String ¶
func (x *ClientConfig) String() string
type ClientConfig_builder ¶
type ClientConfig_builder struct {
// Node for a particular client.
Node *core.Node
XdsConfig []*PerXdsConfig
// contains filtered or unexported fields
}
func (ClientConfig_builder) Build ¶
func (b0 ClientConfig_builder) Build() *ClientConfig
type ClientStatusRequest ¶
type ClientStatusRequest struct {
// Management server can use these match criteria to identify clients.
// The match follows OR semantics.
NodeMatchers []*matcher.NodeMatcher `protobuf:"bytes,1,rep,name=node_matchers,json=nodeMatchers,proto3" json:"node_matchers,omitempty"`
// contains filtered or unexported fields
}
Request for client status of clients identified by a list of NodeMatchers.
func (*ClientStatusRequest) GetNodeMatchers ¶
func (x *ClientStatusRequest) GetNodeMatchers() []*matcher.NodeMatcher
func (*ClientStatusRequest) ProtoMessage ¶
func (*ClientStatusRequest) ProtoMessage()
func (*ClientStatusRequest) ProtoReflect ¶
func (x *ClientStatusRequest) ProtoReflect() protoreflect.Message
func (*ClientStatusRequest) Reset ¶
func (x *ClientStatusRequest) Reset()
func (*ClientStatusRequest) SetNodeMatchers ¶
func (x *ClientStatusRequest) SetNodeMatchers(v []*matcher.NodeMatcher)
func (*ClientStatusRequest) String ¶
func (x *ClientStatusRequest) String() string
type ClientStatusRequest_builder ¶
type ClientStatusRequest_builder struct {
// Management server can use these match criteria to identify clients.
// The match follows OR semantics.
NodeMatchers []*matcher.NodeMatcher
// contains filtered or unexported fields
}
func (ClientStatusRequest_builder) Build ¶
func (b0 ClientStatusRequest_builder) Build() *ClientStatusRequest
type ClientStatusResponse ¶
type ClientStatusResponse struct {
// Client configs for the clients specified in the ClientStatusRequest.
Config []*ClientConfig `protobuf:"bytes,1,rep,name=config,proto3" json:"config,omitempty"`
// contains filtered or unexported fields
}
func (*ClientStatusResponse) GetConfig ¶
func (x *ClientStatusResponse) GetConfig() []*ClientConfig
func (*ClientStatusResponse) ProtoMessage ¶
func (*ClientStatusResponse) ProtoMessage()
func (*ClientStatusResponse) ProtoReflect ¶
func (x *ClientStatusResponse) ProtoReflect() protoreflect.Message
func (*ClientStatusResponse) Reset ¶
func (x *ClientStatusResponse) Reset()
func (*ClientStatusResponse) SetConfig ¶
func (x *ClientStatusResponse) SetConfig(v []*ClientConfig)
func (*ClientStatusResponse) String ¶
func (x *ClientStatusResponse) String() string
type ClientStatusResponse_builder ¶
type ClientStatusResponse_builder struct {
// Client configs for the clients specified in the ClientStatusRequest.
Config []*ClientConfig
// contains filtered or unexported fields
}
func (ClientStatusResponse_builder) Build ¶
func (b0 ClientStatusResponse_builder) Build() *ClientStatusResponse
type ConfigStatus ¶
type ConfigStatus int32
Status of a config.
const ( // Status info is not available/unknown. ConfigStatus_UNKNOWN ConfigStatus = 0 // Management server has sent the config to client and received ACK. ConfigStatus_SYNCED ConfigStatus = 1 // Config is not sent. ConfigStatus_NOT_SENT ConfigStatus = 2 // Management server has sent the config to client but hasn’t received // ACK/NACK. ConfigStatus_STALE ConfigStatus = 3 // Management server has sent the config to client but received NACK. ConfigStatus_ERROR ConfigStatus = 4 )
func (ConfigStatus) Descriptor ¶
func (ConfigStatus) Descriptor() protoreflect.EnumDescriptor
func (ConfigStatus) Enum ¶
func (x ConfigStatus) Enum() *ConfigStatus
func (ConfigStatus) Number ¶
func (x ConfigStatus) Number() protoreflect.EnumNumber
func (ConfigStatus) String ¶
func (x ConfigStatus) String() string
func (ConfigStatus) Type ¶
func (ConfigStatus) Type() protoreflect.EnumType
type PerXdsConfig ¶
type PerXdsConfig struct {
Status ConfigStatus `protobuf:"varint,1,opt,name=status,proto3,enum=envoy.service.status.v2.ConfigStatus" json:"status,omitempty"`
// Types that are valid to be assigned to PerXdsConfig:
//
// *PerXdsConfig_ListenerConfig
// *PerXdsConfig_ClusterConfig
// *PerXdsConfig_RouteConfig
// *PerXdsConfig_ScopedRouteConfig
PerXdsConfig isPerXdsConfig_PerXdsConfig `protobuf_oneof:"per_xds_config"`
// contains filtered or unexported fields
}
Detailed config (per xDS) with status. [#next-free-field: 6]
func (*PerXdsConfig) ClearClusterConfig ¶
func (x *PerXdsConfig) ClearClusterConfig()
func (*PerXdsConfig) ClearListenerConfig ¶
func (x *PerXdsConfig) ClearListenerConfig()
func (*PerXdsConfig) ClearPerXdsConfig ¶
func (x *PerXdsConfig) ClearPerXdsConfig()
func (*PerXdsConfig) ClearRouteConfig ¶
func (x *PerXdsConfig) ClearRouteConfig()
func (*PerXdsConfig) ClearScopedRouteConfig ¶
func (x *PerXdsConfig) ClearScopedRouteConfig()
func (*PerXdsConfig) GetClusterConfig ¶
func (x *PerXdsConfig) GetClusterConfig() *v2alpha.ClustersConfigDump
func (*PerXdsConfig) GetListenerConfig ¶
func (x *PerXdsConfig) GetListenerConfig() *v2alpha.ListenersConfigDump
func (*PerXdsConfig) GetPerXdsConfig ¶
func (x *PerXdsConfig) GetPerXdsConfig() isPerXdsConfig_PerXdsConfig
func (*PerXdsConfig) GetRouteConfig ¶
func (x *PerXdsConfig) GetRouteConfig() *v2alpha.RoutesConfigDump
func (*PerXdsConfig) GetScopedRouteConfig ¶
func (x *PerXdsConfig) GetScopedRouteConfig() *v2alpha.ScopedRoutesConfigDump
func (*PerXdsConfig) GetStatus ¶
func (x *PerXdsConfig) GetStatus() ConfigStatus
func (*PerXdsConfig) HasClusterConfig ¶
func (x *PerXdsConfig) HasClusterConfig() bool
func (*PerXdsConfig) HasListenerConfig ¶
func (x *PerXdsConfig) HasListenerConfig() bool
func (*PerXdsConfig) HasPerXdsConfig ¶
func (x *PerXdsConfig) HasPerXdsConfig() bool
func (*PerXdsConfig) HasRouteConfig ¶
func (x *PerXdsConfig) HasRouteConfig() bool
func (*PerXdsConfig) HasScopedRouteConfig ¶
func (x *PerXdsConfig) HasScopedRouteConfig() bool
func (*PerXdsConfig) ProtoMessage ¶
func (*PerXdsConfig) ProtoMessage()
func (*PerXdsConfig) ProtoReflect ¶
func (x *PerXdsConfig) ProtoReflect() protoreflect.Message
func (*PerXdsConfig) Reset ¶
func (x *PerXdsConfig) Reset()
func (*PerXdsConfig) SetClusterConfig ¶
func (x *PerXdsConfig) SetClusterConfig(v *v2alpha.ClustersConfigDump)
func (*PerXdsConfig) SetListenerConfig ¶
func (x *PerXdsConfig) SetListenerConfig(v *v2alpha.ListenersConfigDump)
func (*PerXdsConfig) SetRouteConfig ¶
func (x *PerXdsConfig) SetRouteConfig(v *v2alpha.RoutesConfigDump)
func (*PerXdsConfig) SetScopedRouteConfig ¶
func (x *PerXdsConfig) SetScopedRouteConfig(v *v2alpha.ScopedRoutesConfigDump)
func (*PerXdsConfig) SetStatus ¶
func (x *PerXdsConfig) SetStatus(v ConfigStatus)
func (*PerXdsConfig) String ¶
func (x *PerXdsConfig) String() string
func (*PerXdsConfig) WhichPerXdsConfig ¶
func (x *PerXdsConfig) WhichPerXdsConfig() case_PerXdsConfig_PerXdsConfig
type PerXdsConfig_ClusterConfig ¶
type PerXdsConfig_ClusterConfig struct {
ClusterConfig *v2alpha.ClustersConfigDump `protobuf:"bytes,3,opt,name=cluster_config,json=clusterConfig,proto3,oneof"`
}
type PerXdsConfig_ListenerConfig ¶
type PerXdsConfig_ListenerConfig struct {
ListenerConfig *v2alpha.ListenersConfigDump `protobuf:"bytes,2,opt,name=listener_config,json=listenerConfig,proto3,oneof"`
}
type PerXdsConfig_RouteConfig ¶
type PerXdsConfig_RouteConfig struct {
RouteConfig *v2alpha.RoutesConfigDump `protobuf:"bytes,4,opt,name=route_config,json=routeConfig,proto3,oneof"`
}
type PerXdsConfig_ScopedRouteConfig ¶
type PerXdsConfig_ScopedRouteConfig struct {
ScopedRouteConfig *v2alpha.ScopedRoutesConfigDump `protobuf:"bytes,5,opt,name=scoped_route_config,json=scopedRouteConfig,proto3,oneof"`
}
type PerXdsConfig_builder ¶
type PerXdsConfig_builder struct {
Status ConfigStatus
// Fields of oneof PerXdsConfig:
ListenerConfig *v2alpha.ListenersConfigDump
ClusterConfig *v2alpha.ClustersConfigDump
RouteConfig *v2alpha.RoutesConfigDump
ScopedRouteConfig *v2alpha.ScopedRoutesConfigDump
// contains filtered or unexported fields
}
func (PerXdsConfig_builder) Build ¶
func (b0 PerXdsConfig_builder) Build() *PerXdsConfig
Source Files
¶
- csds.pb.go
Click to show internal directories.
Click to hide internal directories.