httpv3

package
v1.36.11-2026011520535... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

const PathTransformation_Operation_MergeSlashes_case case_PathTransformation_Operation_OperationSpecifier = 3
const PathTransformation_Operation_NormalizePathRfc_3986_case case_PathTransformation_Operation_OperationSpecifier = 2
const PathTransformation_Operation_OperationSpecifier_not_set_case case_PathTransformation_Operation_OperationSpecifier = 0

Variables

var File_envoy_type_http_v3_cookie_proto protoreflect.FileDescriptor
var File_envoy_type_http_v3_path_transformation_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type Cookie struct {

	// The name that will be used to obtain cookie value from downstream HTTP request or generate
	// new cookie for downstream.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Duration of cookie. This will be used to set the expiry time of a new cookie when it is
	// generated. Set this to 0s to use a session cookie and disable cookie expiration.
	Ttl *durationpb.Duration `protobuf:"bytes,2,opt,name=ttl,proto3" json:"ttl,omitempty"`
	// Path of cookie. This will be used to set the path of a new cookie when it is generated.
	// If no path is specified here, no path will be set for the cookie.
	Path string `protobuf:"bytes,3,opt,name=path,proto3" json:"path,omitempty"`
	// Additional attributes for the cookie. They will be used when generating a new cookie.
	Attributes []*CookieAttribute `protobuf:"bytes,4,rep,name=attributes,proto3" json:"attributes,omitempty"`
	// contains filtered or unexported fields
}

Cookie defines an API for obtaining or generating HTTP cookie.

func (*Cookie) ClearTtl

func (x *Cookie) ClearTtl()

func (*Cookie) GetAttributes

func (x *Cookie) GetAttributes() []*CookieAttribute

func (*Cookie) GetName

func (x *Cookie) GetName() string

func (*Cookie) GetPath

func (x *Cookie) GetPath() string

func (*Cookie) GetTtl

func (x *Cookie) GetTtl() *durationpb.Duration

func (*Cookie) HasTtl

func (x *Cookie) HasTtl() bool

func (*Cookie) ProtoMessage

func (*Cookie) ProtoMessage()

func (*Cookie) ProtoReflect

func (x *Cookie) ProtoReflect() protoreflect.Message

func (*Cookie) Reset

func (x *Cookie) Reset()

func (*Cookie) SetAttributes

func (x *Cookie) SetAttributes(v []*CookieAttribute)

func (*Cookie) SetName

func (x *Cookie) SetName(v string)

func (*Cookie) SetPath

func (x *Cookie) SetPath(v string)

func (*Cookie) SetTtl

func (x *Cookie) SetTtl(v *durationpb.Duration)

func (*Cookie) String

func (x *Cookie) String() string

type CookieAttribute

type CookieAttribute struct {

	// The name of the cookie attribute.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// The optional value of the cookie attribute.
	Value string `protobuf:"bytes,2,opt,name=value,proto3" json:"value,omitempty"`
	// contains filtered or unexported fields
}

CookieAttribute defines an API for adding additional attributes for a HTTP cookie.

func (*CookieAttribute) GetName

func (x *CookieAttribute) GetName() string

func (*CookieAttribute) GetValue

func (x *CookieAttribute) GetValue() string

func (*CookieAttribute) ProtoMessage

func (*CookieAttribute) ProtoMessage()

func (*CookieAttribute) ProtoReflect

func (x *CookieAttribute) ProtoReflect() protoreflect.Message

func (*CookieAttribute) Reset

func (x *CookieAttribute) Reset()

func (*CookieAttribute) SetName

func (x *CookieAttribute) SetName(v string)

func (*CookieAttribute) SetValue

func (x *CookieAttribute) SetValue(v string)

func (*CookieAttribute) String

func (x *CookieAttribute) String() string

type CookieAttribute_builder

type CookieAttribute_builder struct {

	// The name of the cookie attribute.
	Name string
	// The optional value of the cookie attribute.
	Value string
	// contains filtered or unexported fields
}

func (CookieAttribute_builder) Build

type Cookie_builder struct {

	// The name that will be used to obtain cookie value from downstream HTTP request or generate
	// new cookie for downstream.
	Name string
	// Duration of cookie. This will be used to set the expiry time of a new cookie when it is
	// generated. Set this to 0s to use a session cookie and disable cookie expiration.
	Ttl *durationpb.Duration
	// Path of cookie. This will be used to set the path of a new cookie when it is generated.
	// If no path is specified here, no path will be set for the cookie.
	Path string
	// Additional attributes for the cookie. They will be used when generating a new cookie.
	Attributes []*CookieAttribute
	// contains filtered or unexported fields
}
func (b0 Cookie_builder) Build() *Cookie

type PathTransformation

type PathTransformation struct {

	// A list of operations to apply. Transformations will be performed in the order that they appear.
	Operations []*PathTransformation_Operation `protobuf:"bytes,1,rep,name=operations,proto3" json:"operations,omitempty"`
	// contains filtered or unexported fields
}

func (*PathTransformation) GetOperations

func (x *PathTransformation) GetOperations() []*PathTransformation_Operation

func (*PathTransformation) ProtoMessage

func (*PathTransformation) ProtoMessage()

func (*PathTransformation) ProtoReflect

func (x *PathTransformation) ProtoReflect() protoreflect.Message

func (*PathTransformation) Reset

func (x *PathTransformation) Reset()

func (*PathTransformation) SetOperations

func (x *PathTransformation) SetOperations(v []*PathTransformation_Operation)

func (*PathTransformation) String

func (x *PathTransformation) String() string

type PathTransformation_Operation

type PathTransformation_Operation struct {

	// Types that are valid to be assigned to OperationSpecifier:
	//
	//	*PathTransformation_Operation_NormalizePathRfc_3986
	//	*PathTransformation_Operation_MergeSlashes_
	OperationSpecifier isPathTransformation_Operation_OperationSpecifier `protobuf_oneof:"operation_specifier"`
	// contains filtered or unexported fields
}

A type of operation to alter text.

func (*PathTransformation_Operation) ClearMergeSlashes

func (x *PathTransformation_Operation) ClearMergeSlashes()

func (*PathTransformation_Operation) ClearNormalizePathRfc_3986

func (x *PathTransformation_Operation) ClearNormalizePathRfc_3986()

func (*PathTransformation_Operation) ClearOperationSpecifier

func (x *PathTransformation_Operation) ClearOperationSpecifier()

func (*PathTransformation_Operation) GetMergeSlashes

func (*PathTransformation_Operation) GetNormalizePathRfc_3986

func (*PathTransformation_Operation) GetOperationSpecifier

func (x *PathTransformation_Operation) GetOperationSpecifier() isPathTransformation_Operation_OperationSpecifier

func (*PathTransformation_Operation) HasMergeSlashes

func (x *PathTransformation_Operation) HasMergeSlashes() bool

func (*PathTransformation_Operation) HasNormalizePathRfc_3986

func (x *PathTransformation_Operation) HasNormalizePathRfc_3986() bool

func (*PathTransformation_Operation) HasOperationSpecifier

func (x *PathTransformation_Operation) HasOperationSpecifier() bool

func (*PathTransformation_Operation) ProtoMessage

func (*PathTransformation_Operation) ProtoMessage()

func (*PathTransformation_Operation) ProtoReflect

func (*PathTransformation_Operation) Reset

func (x *PathTransformation_Operation) Reset()

func (*PathTransformation_Operation) SetMergeSlashes

func (*PathTransformation_Operation) SetNormalizePathRfc_3986

func (*PathTransformation_Operation) String

func (*PathTransformation_Operation) WhichOperationSpecifier

func (x *PathTransformation_Operation) WhichOperationSpecifier() case_PathTransformation_Operation_OperationSpecifier

type PathTransformation_Operation_MergeSlashes

type PathTransformation_Operation_MergeSlashes struct {
	// contains filtered or unexported fields
}

Determines if adjacent slashes are merged into one. A common use case is for a request path header. Using this option in “:ref: PathNormalizationOptions <envoy_v3_api_msg_extensions.filters.network.http_connection_manager.v3.HttpConnectionManager.PathNormalizationOptions>“ will allow incoming requests with path “//dir///file“ to match against route with “prefix“ match set to “/dir“. When using for header transformations, note that slash merging is not part of `HTTP spec <https://tools.ietf.org/html/rfc3986>`_ and is provided for convenience.

func (*PathTransformation_Operation_MergeSlashes) ProtoMessage

func (*PathTransformation_Operation_MergeSlashes) ProtoReflect

func (*PathTransformation_Operation_MergeSlashes) Reset

func (*PathTransformation_Operation_MergeSlashes) String

type PathTransformation_Operation_MergeSlashes_

type PathTransformation_Operation_MergeSlashes_ struct {
	// Enable merging adjacent slashes.
	MergeSlashes *PathTransformation_Operation_MergeSlashes `protobuf:"bytes,3,opt,name=merge_slashes,json=mergeSlashes,proto3,oneof"`
}

type PathTransformation_Operation_MergeSlashes_builder

type PathTransformation_Operation_MergeSlashes_builder struct {
	// contains filtered or unexported fields
}

func (PathTransformation_Operation_MergeSlashes_builder) Build

type PathTransformation_Operation_NormalizePathRFC3986

type PathTransformation_Operation_NormalizePathRFC3986 struct {
	// contains filtered or unexported fields
}

Should text be normalized according to RFC 3986? This typically is used for path headers before any processing of requests by HTTP filters or routing. This applies percent-encoded normalization and path segment normalization. Fails on characters disallowed in URLs (e.g. NULLs). See `Normalization and Comparison <https://tools.ietf.org/html/rfc3986#section-6>`_ for details of normalization. Note that this options does not perform `case normalization <https://tools.ietf.org/html/rfc3986#section-6.2.2.1>`_

func (*PathTransformation_Operation_NormalizePathRFC3986) ProtoMessage

func (*PathTransformation_Operation_NormalizePathRFC3986) ProtoReflect

func (*PathTransformation_Operation_NormalizePathRFC3986) Reset

func (*PathTransformation_Operation_NormalizePathRFC3986) String

type PathTransformation_Operation_NormalizePathRFC3986_builder

type PathTransformation_Operation_NormalizePathRFC3986_builder struct {
	// contains filtered or unexported fields
}

func (PathTransformation_Operation_NormalizePathRFC3986_builder) Build

type PathTransformation_Operation_NormalizePathRfc_3986

type PathTransformation_Operation_NormalizePathRfc_3986 struct {
	// Enable path normalization per RFC 3986.
	NormalizePathRfc_3986 *PathTransformation_Operation_NormalizePathRFC3986 `protobuf:"bytes,2,opt,name=normalize_path_rfc_3986,json=normalizePathRfc3986,proto3,oneof"`
}

type PathTransformation_Operation_builder

type PathTransformation_Operation_builder struct {

	// Fields of oneof OperationSpecifier:
	// Enable path normalization per RFC 3986.
	NormalizePathRfc_3986 *PathTransformation_Operation_NormalizePathRFC3986
	// Enable merging adjacent slashes.
	MergeSlashes *PathTransformation_Operation_MergeSlashes
	// contains filtered or unexported fields
}

func (PathTransformation_Operation_builder) Build

type PathTransformation_builder

type PathTransformation_builder struct {

	// A list of operations to apply. Transformations will be performed in the order that they appear.
	Operations []*PathTransformation_Operation
	// contains filtered or unexported fields
}

func (PathTransformation_builder) Build

Source Files

  • cookie.pb.go
  • path_transformation.pb.go

Jump to