Documentation
¶
Index ¶
- Constants
- Variables
- type MetadataKey
- func (x *MetadataKey) GetKey() string
- func (x *MetadataKey) GetPath() []*MetadataKey_PathSegment
- func (*MetadataKey) ProtoMessage()
- func (x *MetadataKey) ProtoReflect() protoreflect.Message
- func (x *MetadataKey) Reset()
- func (x *MetadataKey) SetKey(v string)
- func (x *MetadataKey) SetPath(v []*MetadataKey_PathSegment)
- func (x *MetadataKey) String() string
- type MetadataKey_PathSegment
- func (x *MetadataKey_PathSegment) ClearKey()
- func (x *MetadataKey_PathSegment) ClearSegment()
- func (x *MetadataKey_PathSegment) GetKey() string
- func (x *MetadataKey_PathSegment) GetSegment() isMetadataKey_PathSegment_Segment
- func (x *MetadataKey_PathSegment) HasKey() bool
- func (x *MetadataKey_PathSegment) HasSegment() bool
- func (*MetadataKey_PathSegment) ProtoMessage()
- func (x *MetadataKey_PathSegment) ProtoReflect() protoreflect.Message
- func (x *MetadataKey_PathSegment) Reset()
- func (x *MetadataKey_PathSegment) SetKey(v string)
- func (x *MetadataKey_PathSegment) String() string
- func (x *MetadataKey_PathSegment) WhichSegment() case_MetadataKey_PathSegment_Segment
- type MetadataKey_PathSegment_Key
- type MetadataKey_PathSegment_builder
- type MetadataKey_builder
- type MetadataKind
- func (x *MetadataKind) ClearCluster()
- func (x *MetadataKind) ClearHost()
- func (x *MetadataKind) ClearKind()
- func (x *MetadataKind) ClearRequest()
- func (x *MetadataKind) ClearRoute()
- func (x *MetadataKind) GetCluster() *MetadataKind_Cluster
- func (x *MetadataKind) GetHost() *MetadataKind_Host
- func (x *MetadataKind) GetKind() isMetadataKind_Kind
- func (x *MetadataKind) GetRequest() *MetadataKind_Request
- func (x *MetadataKind) GetRoute() *MetadataKind_Route
- func (x *MetadataKind) HasCluster() bool
- func (x *MetadataKind) HasHost() bool
- func (x *MetadataKind) HasKind() bool
- func (x *MetadataKind) HasRequest() bool
- func (x *MetadataKind) HasRoute() bool
- func (*MetadataKind) ProtoMessage()
- func (x *MetadataKind) ProtoReflect() protoreflect.Message
- func (x *MetadataKind) Reset()
- func (x *MetadataKind) SetCluster(v *MetadataKind_Cluster)
- func (x *MetadataKind) SetHost(v *MetadataKind_Host)
- func (x *MetadataKind) SetRequest(v *MetadataKind_Request)
- func (x *MetadataKind) SetRoute(v *MetadataKind_Route)
- func (x *MetadataKind) String() string
- func (x *MetadataKind) WhichKind() case_MetadataKind_Kind
- type MetadataKind_Cluster
- type MetadataKind_Cluster_
- type MetadataKind_Cluster_builder
- type MetadataKind_Host
- type MetadataKind_Host_
- type MetadataKind_Host_builder
- type MetadataKind_Request
- type MetadataKind_Request_
- type MetadataKind_Request_builder
- type MetadataKind_Route
- type MetadataKind_Route_
- type MetadataKind_Route_builder
- type MetadataKind_builder
Constants ¶
const MetadataKey_PathSegment_Key_case case_MetadataKey_PathSegment_Segment = 1
const MetadataKey_PathSegment_Segment_not_set_case case_MetadataKey_PathSegment_Segment = 0
const MetadataKind_Cluster_case case_MetadataKind_Kind = 3
const MetadataKind_Host_case case_MetadataKind_Kind = 4
const MetadataKind_Kind_not_set_case case_MetadataKind_Kind = 0
const MetadataKind_Request_case case_MetadataKind_Kind = 1
const MetadataKind_Route_case case_MetadataKind_Kind = 2
Variables ¶
var File_envoy_type_metadata_v2_metadata_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type MetadataKey ¶
type MetadataKey struct {
// The key name of Metadata to retrieve the Struct from the metadata.
// Typically, it represents a builtin subsystem or custom extension.
Key string `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
// The path to retrieve the Value from the Struct. It can be a prefix or a full path,
// e.g. “[prop, xyz]“ for a struct or “[prop, foo]“ for a string in the example,
// which depends on the particular scenario.
//
// Note: Due to that only the key type segment is supported, the path can not specify a list
// unless the list is the last segment.
Path []*MetadataKey_PathSegment `protobuf:"bytes,2,rep,name=path,proto3" json:"path,omitempty"`
// contains filtered or unexported fields
}
MetadataKey provides a general interface using `key` and `path` to retrieve value from :ref:`Metadata <envoy_api_msg_core.Metadata>`.
For example, for the following Metadata:
.. code-block:: yaml
filter_metadata:
envoy.xxx:
prop:
foo: bar
xyz:
hello: envoy
The following MetadataKey will retrieve a string value "bar" from the Metadata.
.. code-block:: yaml
key: envoy.xxx path: - key: prop - key: foo
func (*MetadataKey) GetKey ¶
func (x *MetadataKey) GetKey() string
func (*MetadataKey) GetPath ¶
func (x *MetadataKey) GetPath() []*MetadataKey_PathSegment
func (*MetadataKey) ProtoMessage ¶
func (*MetadataKey) ProtoMessage()
func (*MetadataKey) ProtoReflect ¶
func (x *MetadataKey) ProtoReflect() protoreflect.Message
func (*MetadataKey) Reset ¶
func (x *MetadataKey) Reset()
func (*MetadataKey) SetKey ¶
func (x *MetadataKey) SetKey(v string)
func (*MetadataKey) SetPath ¶
func (x *MetadataKey) SetPath(v []*MetadataKey_PathSegment)
func (*MetadataKey) String ¶
func (x *MetadataKey) String() string
type MetadataKey_PathSegment ¶
type MetadataKey_PathSegment struct {
// Types that are valid to be assigned to Segment:
//
// *MetadataKey_PathSegment_Key
Segment isMetadataKey_PathSegment_Segment `protobuf_oneof:"segment"`
// contains filtered or unexported fields
}
Specifies the segment in a path to retrieve value from Metadata. Currently it is only supported to specify the key, i.e. field name, as one segment of a path.
func (*MetadataKey_PathSegment) ClearKey ¶
func (x *MetadataKey_PathSegment) ClearKey()
func (*MetadataKey_PathSegment) ClearSegment ¶
func (x *MetadataKey_PathSegment) ClearSegment()
func (*MetadataKey_PathSegment) GetKey ¶
func (x *MetadataKey_PathSegment) GetKey() string
func (*MetadataKey_PathSegment) GetSegment ¶
func (x *MetadataKey_PathSegment) GetSegment() isMetadataKey_PathSegment_Segment
func (*MetadataKey_PathSegment) HasKey ¶
func (x *MetadataKey_PathSegment) HasKey() bool
func (*MetadataKey_PathSegment) HasSegment ¶
func (x *MetadataKey_PathSegment) HasSegment() bool
func (*MetadataKey_PathSegment) ProtoMessage ¶
func (*MetadataKey_PathSegment) ProtoMessage()
func (*MetadataKey_PathSegment) ProtoReflect ¶
func (x *MetadataKey_PathSegment) ProtoReflect() protoreflect.Message
func (*MetadataKey_PathSegment) Reset ¶
func (x *MetadataKey_PathSegment) Reset()
func (*MetadataKey_PathSegment) SetKey ¶
func (x *MetadataKey_PathSegment) SetKey(v string)
func (*MetadataKey_PathSegment) String ¶
func (x *MetadataKey_PathSegment) String() string
func (*MetadataKey_PathSegment) WhichSegment ¶
func (x *MetadataKey_PathSegment) WhichSegment() case_MetadataKey_PathSegment_Segment
type MetadataKey_PathSegment_Key ¶
type MetadataKey_PathSegment_Key struct {
// If specified, use the key to retrieve the value in a Struct.
Key string `protobuf:"bytes,1,opt,name=key,proto3,oneof"`
}
type MetadataKey_PathSegment_builder ¶
type MetadataKey_PathSegment_builder struct {
// Fields of oneof Segment:
// If specified, use the key to retrieve the value in a Struct.
Key *string
// contains filtered or unexported fields
}
func (MetadataKey_PathSegment_builder) Build ¶
func (b0 MetadataKey_PathSegment_builder) Build() *MetadataKey_PathSegment
type MetadataKey_builder ¶
type MetadataKey_builder struct {
// The key name of Metadata to retrieve the Struct from the metadata.
// Typically, it represents a builtin subsystem or custom extension.
Key string
// The path to retrieve the Value from the Struct. It can be a prefix or a full path,
// e.g. “[prop, xyz]“ for a struct or “[prop, foo]“ for a string in the example,
// which depends on the particular scenario.
//
// Note: Due to that only the key type segment is supported, the path can not specify a list
// unless the list is the last segment.
Path []*MetadataKey_PathSegment
// contains filtered or unexported fields
}
func (MetadataKey_builder) Build ¶
func (b0 MetadataKey_builder) Build() *MetadataKey
type MetadataKind ¶
type MetadataKind struct {
// Types that are valid to be assigned to Kind:
//
// *MetadataKind_Request_
// *MetadataKind_Route_
// *MetadataKind_Cluster_
// *MetadataKind_Host_
Kind isMetadataKind_Kind `protobuf_oneof:"kind"`
// contains filtered or unexported fields
}
Describes what kind of metadata.
func (*MetadataKind) ClearCluster ¶
func (x *MetadataKind) ClearCluster()
func (*MetadataKind) ClearHost ¶
func (x *MetadataKind) ClearHost()
func (*MetadataKind) ClearKind ¶
func (x *MetadataKind) ClearKind()
func (*MetadataKind) ClearRequest ¶
func (x *MetadataKind) ClearRequest()
func (*MetadataKind) ClearRoute ¶
func (x *MetadataKind) ClearRoute()
func (*MetadataKind) GetCluster ¶
func (x *MetadataKind) GetCluster() *MetadataKind_Cluster
func (*MetadataKind) GetHost ¶
func (x *MetadataKind) GetHost() *MetadataKind_Host
func (*MetadataKind) GetKind ¶
func (x *MetadataKind) GetKind() isMetadataKind_Kind
func (*MetadataKind) GetRequest ¶
func (x *MetadataKind) GetRequest() *MetadataKind_Request
func (*MetadataKind) GetRoute ¶
func (x *MetadataKind) GetRoute() *MetadataKind_Route
func (*MetadataKind) HasCluster ¶
func (x *MetadataKind) HasCluster() bool
func (*MetadataKind) HasHost ¶
func (x *MetadataKind) HasHost() bool
func (*MetadataKind) HasKind ¶
func (x *MetadataKind) HasKind() bool
func (*MetadataKind) HasRequest ¶
func (x *MetadataKind) HasRequest() bool
func (*MetadataKind) HasRoute ¶
func (x *MetadataKind) HasRoute() bool
func (*MetadataKind) ProtoMessage ¶
func (*MetadataKind) ProtoMessage()
func (*MetadataKind) ProtoReflect ¶
func (x *MetadataKind) ProtoReflect() protoreflect.Message
func (*MetadataKind) Reset ¶
func (x *MetadataKind) Reset()
func (*MetadataKind) SetCluster ¶
func (x *MetadataKind) SetCluster(v *MetadataKind_Cluster)
func (*MetadataKind) SetHost ¶
func (x *MetadataKind) SetHost(v *MetadataKind_Host)
func (*MetadataKind) SetRequest ¶
func (x *MetadataKind) SetRequest(v *MetadataKind_Request)
func (*MetadataKind) SetRoute ¶
func (x *MetadataKind) SetRoute(v *MetadataKind_Route)
func (*MetadataKind) String ¶
func (x *MetadataKind) String() string
func (*MetadataKind) WhichKind ¶
func (x *MetadataKind) WhichKind() case_MetadataKind_Kind
type MetadataKind_Cluster ¶
type MetadataKind_Cluster struct {
// contains filtered or unexported fields
}
Represents metadata from :ref:`the upstream cluster<envoy_api_field_Cluster.metadata>`.
func (*MetadataKind_Cluster) ProtoMessage ¶
func (*MetadataKind_Cluster) ProtoMessage()
func (*MetadataKind_Cluster) ProtoReflect ¶
func (x *MetadataKind_Cluster) ProtoReflect() protoreflect.Message
func (*MetadataKind_Cluster) Reset ¶
func (x *MetadataKind_Cluster) Reset()
func (*MetadataKind_Cluster) String ¶
func (x *MetadataKind_Cluster) String() string
type MetadataKind_Cluster_ ¶
type MetadataKind_Cluster_ struct {
// Cluster kind of metadata.
Cluster *MetadataKind_Cluster `protobuf:"bytes,3,opt,name=cluster,proto3,oneof"`
}
type MetadataKind_Cluster_builder ¶
type MetadataKind_Cluster_builder struct {
// contains filtered or unexported fields
}
func (MetadataKind_Cluster_builder) Build ¶
func (b0 MetadataKind_Cluster_builder) Build() *MetadataKind_Cluster
type MetadataKind_Host ¶
type MetadataKind_Host struct {
// contains filtered or unexported fields
}
Represents metadata from :ref:`the upstream host<envoy_api_field_endpoint.LbEndpoint.metadata>`.
func (*MetadataKind_Host) ProtoMessage ¶
func (*MetadataKind_Host) ProtoMessage()
func (*MetadataKind_Host) ProtoReflect ¶
func (x *MetadataKind_Host) ProtoReflect() protoreflect.Message
func (*MetadataKind_Host) Reset ¶
func (x *MetadataKind_Host) Reset()
func (*MetadataKind_Host) String ¶
func (x *MetadataKind_Host) String() string
type MetadataKind_Host_ ¶
type MetadataKind_Host_ struct {
// Host kind of metadata.
Host *MetadataKind_Host `protobuf:"bytes,4,opt,name=host,proto3,oneof"`
}
type MetadataKind_Host_builder ¶
type MetadataKind_Host_builder struct {
// contains filtered or unexported fields
}
func (MetadataKind_Host_builder) Build ¶
func (b0 MetadataKind_Host_builder) Build() *MetadataKind_Host
type MetadataKind_Request ¶
type MetadataKind_Request struct {
// contains filtered or unexported fields
}
Represents dynamic metadata associated with the request.
func (*MetadataKind_Request) ProtoMessage ¶
func (*MetadataKind_Request) ProtoMessage()
func (*MetadataKind_Request) ProtoReflect ¶
func (x *MetadataKind_Request) ProtoReflect() protoreflect.Message
func (*MetadataKind_Request) Reset ¶
func (x *MetadataKind_Request) Reset()
func (*MetadataKind_Request) String ¶
func (x *MetadataKind_Request) String() string
type MetadataKind_Request_ ¶
type MetadataKind_Request_ struct {
// Request kind of metadata.
Request *MetadataKind_Request `protobuf:"bytes,1,opt,name=request,proto3,oneof"`
}
type MetadataKind_Request_builder ¶
type MetadataKind_Request_builder struct {
// contains filtered or unexported fields
}
func (MetadataKind_Request_builder) Build ¶
func (b0 MetadataKind_Request_builder) Build() *MetadataKind_Request
type MetadataKind_Route ¶
type MetadataKind_Route struct {
// contains filtered or unexported fields
}
Represents metadata from :ref:`the route<envoy_api_field_route.Route.metadata>`.
func (*MetadataKind_Route) ProtoMessage ¶
func (*MetadataKind_Route) ProtoMessage()
func (*MetadataKind_Route) ProtoReflect ¶
func (x *MetadataKind_Route) ProtoReflect() protoreflect.Message
func (*MetadataKind_Route) Reset ¶
func (x *MetadataKind_Route) Reset()
func (*MetadataKind_Route) String ¶
func (x *MetadataKind_Route) String() string
type MetadataKind_Route_ ¶
type MetadataKind_Route_ struct {
// Route kind of metadata.
Route *MetadataKind_Route `protobuf:"bytes,2,opt,name=route,proto3,oneof"`
}
type MetadataKind_Route_builder ¶
type MetadataKind_Route_builder struct {
// contains filtered or unexported fields
}
func (MetadataKind_Route_builder) Build ¶
func (b0 MetadataKind_Route_builder) Build() *MetadataKind_Route
type MetadataKind_builder ¶
type MetadataKind_builder struct {
// Fields of oneof Kind:
// Request kind of metadata.
Request *MetadataKind_Request
// Route kind of metadata.
Route *MetadataKind_Route
// Cluster kind of metadata.
Cluster *MetadataKind_Cluster
// Host kind of metadata.
Host *MetadataKind_Host
// contains filtered or unexported fields
}
func (MetadataKind_builder) Build ¶
func (b0 MetadataKind_builder) Build() *MetadataKind
Source Files
¶
- metadata.pb.go