authgrpc

package
v1.6.1-20251002153105-... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	AuthenticationService_GetAuthenticationSelf_FullMethodName    = "/flipt.auth.AuthenticationService/GetAuthenticationSelf"
	AuthenticationService_GetAuthentication_FullMethodName        = "/flipt.auth.AuthenticationService/GetAuthentication"
	AuthenticationService_ListAuthentications_FullMethodName      = "/flipt.auth.AuthenticationService/ListAuthentications"
	AuthenticationService_DeleteAuthentication_FullMethodName     = "/flipt.auth.AuthenticationService/DeleteAuthentication"
	AuthenticationService_ExpireAuthenticationSelf_FullMethodName = "/flipt.auth.AuthenticationService/ExpireAuthenticationSelf"
)
const (
	AuthenticationMethodOIDCService_AuthorizeURL_FullMethodName = "/flipt.auth.AuthenticationMethodOIDCService/AuthorizeURL"
	AuthenticationMethodOIDCService_Callback_FullMethodName     = "/flipt.auth.AuthenticationMethodOIDCService/Callback"
)
const (
	AuthenticationMethodGithubService_AuthorizeURL_FullMethodName = "/flipt.auth.AuthenticationMethodGithubService/AuthorizeURL"
	AuthenticationMethodGithubService_Callback_FullMethodName     = "/flipt.auth.AuthenticationMethodGithubService/Callback"
)
const (
	AuthenticationMethodKubernetesService_VerifyServiceAccount_FullMethodName = "/flipt.auth.AuthenticationMethodKubernetesService/VerifyServiceAccount"
)
const (
	AuthenticationMethodTokenService_CreateToken_FullMethodName = "/flipt.auth.AuthenticationMethodTokenService/CreateToken"
)
const (
	PublicAuthenticationService_ListAuthenticationMethods_FullMethodName = "/flipt.auth.PublicAuthenticationService/ListAuthenticationMethods"
)

Variables

var AuthenticationMethodGithubService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "flipt.auth.AuthenticationMethodGithubService",
	HandlerType: (*AuthenticationMethodGithubServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "AuthorizeURL",
			Handler:    _AuthenticationMethodGithubService_AuthorizeURL_Handler,
		},
		{
			MethodName: "Callback",
			Handler:    _AuthenticationMethodGithubService_Callback_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "auth/auth.proto",
}

AuthenticationMethodGithubService_ServiceDesc is the grpc.ServiceDesc for AuthenticationMethodGithubService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var AuthenticationMethodKubernetesService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "flipt.auth.AuthenticationMethodKubernetesService",
	HandlerType: (*AuthenticationMethodKubernetesServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "VerifyServiceAccount",
			Handler:    _AuthenticationMethodKubernetesService_VerifyServiceAccount_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "auth/auth.proto",
}

AuthenticationMethodKubernetesService_ServiceDesc is the grpc.ServiceDesc for AuthenticationMethodKubernetesService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var AuthenticationMethodOIDCService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "flipt.auth.AuthenticationMethodOIDCService",
	HandlerType: (*AuthenticationMethodOIDCServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "AuthorizeURL",
			Handler:    _AuthenticationMethodOIDCService_AuthorizeURL_Handler,
		},
		{
			MethodName: "Callback",
			Handler:    _AuthenticationMethodOIDCService_Callback_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "auth/auth.proto",
}

AuthenticationMethodOIDCService_ServiceDesc is the grpc.ServiceDesc for AuthenticationMethodOIDCService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var AuthenticationMethodTokenService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "flipt.auth.AuthenticationMethodTokenService",
	HandlerType: (*AuthenticationMethodTokenServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "CreateToken",
			Handler:    _AuthenticationMethodTokenService_CreateToken_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "auth/auth.proto",
}

AuthenticationMethodTokenService_ServiceDesc is the grpc.ServiceDesc for AuthenticationMethodTokenService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var AuthenticationService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "flipt.auth.AuthenticationService",
	HandlerType: (*AuthenticationServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetAuthenticationSelf",
			Handler:    _AuthenticationService_GetAuthenticationSelf_Handler,
		},
		{
			MethodName: "GetAuthentication",
			Handler:    _AuthenticationService_GetAuthentication_Handler,
		},
		{
			MethodName: "ListAuthentications",
			Handler:    _AuthenticationService_ListAuthentications_Handler,
		},
		{
			MethodName: "DeleteAuthentication",
			Handler:    _AuthenticationService_DeleteAuthentication_Handler,
		},
		{
			MethodName: "ExpireAuthenticationSelf",
			Handler:    _AuthenticationService_ExpireAuthenticationSelf_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "auth/auth.proto",
}

AuthenticationService_ServiceDesc is the grpc.ServiceDesc for AuthenticationService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var PublicAuthenticationService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "flipt.auth.PublicAuthenticationService",
	HandlerType: (*PublicAuthenticationServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "ListAuthenticationMethods",
			Handler:    _PublicAuthenticationService_ListAuthenticationMethods_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "auth/auth.proto",
}

PublicAuthenticationService_ServiceDesc is the grpc.ServiceDesc for PublicAuthenticationService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterAuthenticationMethodGithubServiceServer

func RegisterAuthenticationMethodGithubServiceServer(s grpc.ServiceRegistrar, srv AuthenticationMethodGithubServiceServer)

func RegisterAuthenticationMethodKubernetesServiceServer

func RegisterAuthenticationMethodKubernetesServiceServer(s grpc.ServiceRegistrar, srv AuthenticationMethodKubernetesServiceServer)

func RegisterAuthenticationMethodOIDCServiceServer

func RegisterAuthenticationMethodOIDCServiceServer(s grpc.ServiceRegistrar, srv AuthenticationMethodOIDCServiceServer)

func RegisterAuthenticationMethodTokenServiceServer

func RegisterAuthenticationMethodTokenServiceServer(s grpc.ServiceRegistrar, srv AuthenticationMethodTokenServiceServer)

func RegisterAuthenticationServiceServer

func RegisterAuthenticationServiceServer(s grpc.ServiceRegistrar, srv AuthenticationServiceServer)

func RegisterPublicAuthenticationServiceServer

func RegisterPublicAuthenticationServiceServer(s grpc.ServiceRegistrar, srv PublicAuthenticationServiceServer)

Types

type AuthenticationMethodGithubServiceClient

type AuthenticationMethodGithubServiceClient interface {
	AuthorizeURL(ctx context.Context, in *auth.AuthorizeURLRequest, opts ...grpc.CallOption) (*auth.AuthorizeURLResponse, error)
	Callback(ctx context.Context, in *auth.CallbackRequest, opts ...grpc.CallOption) (*auth.CallbackResponse, error)
}

AuthenticationMethodGithubServiceClient is the client API for AuthenticationMethodGithubService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewAuthenticationMethodGithubServiceClient

func NewAuthenticationMethodGithubServiceClient(cc grpc.ClientConnInterface) AuthenticationMethodGithubServiceClient

type AuthenticationMethodGithubServiceServer

type AuthenticationMethodGithubServiceServer interface {
	AuthorizeURL(context.Context, *auth.AuthorizeURLRequest) (*auth.AuthorizeURLResponse, error)
	Callback(context.Context, *auth.CallbackRequest) (*auth.CallbackResponse, error)
}

AuthenticationMethodGithubServiceServer is the server API for AuthenticationMethodGithubService service. All implementations should embed UnimplementedAuthenticationMethodGithubServiceServer for forward compatibility.

type AuthenticationMethodKubernetesServiceClient

type AuthenticationMethodKubernetesServiceClient interface {
	VerifyServiceAccount(ctx context.Context, in *auth.VerifyServiceAccountRequest, opts ...grpc.CallOption) (*auth.VerifyServiceAccountResponse, error)
}

AuthenticationMethodKubernetesServiceClient is the client API for AuthenticationMethodKubernetesService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewAuthenticationMethodKubernetesServiceClient

func NewAuthenticationMethodKubernetesServiceClient(cc grpc.ClientConnInterface) AuthenticationMethodKubernetesServiceClient

type AuthenticationMethodKubernetesServiceServer

type AuthenticationMethodKubernetesServiceServer interface {
	VerifyServiceAccount(context.Context, *auth.VerifyServiceAccountRequest) (*auth.VerifyServiceAccountResponse, error)
}

AuthenticationMethodKubernetesServiceServer is the server API for AuthenticationMethodKubernetesService service. All implementations should embed UnimplementedAuthenticationMethodKubernetesServiceServer for forward compatibility.

type AuthenticationMethodOIDCServiceClient

type AuthenticationMethodOIDCServiceClient interface {
	AuthorizeURL(ctx context.Context, in *auth.AuthorizeURLRequest, opts ...grpc.CallOption) (*auth.AuthorizeURLResponse, error)
	Callback(ctx context.Context, in *auth.CallbackRequest, opts ...grpc.CallOption) (*auth.CallbackResponse, error)
}

AuthenticationMethodOIDCServiceClient is the client API for AuthenticationMethodOIDCService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewAuthenticationMethodOIDCServiceClient

func NewAuthenticationMethodOIDCServiceClient(cc grpc.ClientConnInterface) AuthenticationMethodOIDCServiceClient

type AuthenticationMethodOIDCServiceServer

type AuthenticationMethodOIDCServiceServer interface {
	AuthorizeURL(context.Context, *auth.AuthorizeURLRequest) (*auth.AuthorizeURLResponse, error)
	Callback(context.Context, *auth.CallbackRequest) (*auth.CallbackResponse, error)
}

AuthenticationMethodOIDCServiceServer is the server API for AuthenticationMethodOIDCService service. All implementations should embed UnimplementedAuthenticationMethodOIDCServiceServer for forward compatibility.

type AuthenticationMethodTokenServiceClient

type AuthenticationMethodTokenServiceClient interface {
	CreateToken(ctx context.Context, in *auth.CreateTokenRequest, opts ...grpc.CallOption) (*auth.CreateTokenResponse, error)
}

AuthenticationMethodTokenServiceClient is the client API for AuthenticationMethodTokenService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewAuthenticationMethodTokenServiceClient

func NewAuthenticationMethodTokenServiceClient(cc grpc.ClientConnInterface) AuthenticationMethodTokenServiceClient

type AuthenticationMethodTokenServiceServer

type AuthenticationMethodTokenServiceServer interface {
	CreateToken(context.Context, *auth.CreateTokenRequest) (*auth.CreateTokenResponse, error)
}

AuthenticationMethodTokenServiceServer is the server API for AuthenticationMethodTokenService service. All implementations should embed UnimplementedAuthenticationMethodTokenServiceServer for forward compatibility.

type AuthenticationServiceClient

type AuthenticationServiceClient interface {
	GetAuthenticationSelf(ctx context.Context, in *emptypb.Empty, opts ...grpc.CallOption) (*auth.Authentication, error)
	GetAuthentication(ctx context.Context, in *auth.GetAuthenticationRequest, opts ...grpc.CallOption) (*auth.Authentication, error)
	ListAuthentications(ctx context.Context, in *auth.ListAuthenticationsRequest, opts ...grpc.CallOption) (*auth.ListAuthenticationsResponse, error)
	DeleteAuthentication(ctx context.Context, in *auth.DeleteAuthenticationRequest, opts ...grpc.CallOption) (*emptypb.Empty, error)
	ExpireAuthenticationSelf(ctx context.Context, in *auth.ExpireAuthenticationSelfRequest, opts ...grpc.CallOption) (*emptypb.Empty, error)
}

AuthenticationServiceClient is the client API for AuthenticationService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewAuthenticationServiceClient

func NewAuthenticationServiceClient(cc grpc.ClientConnInterface) AuthenticationServiceClient

type AuthenticationServiceServer

type AuthenticationServiceServer interface {
	GetAuthenticationSelf(context.Context, *emptypb.Empty) (*auth.Authentication, error)
	GetAuthentication(context.Context, *auth.GetAuthenticationRequest) (*auth.Authentication, error)
	ListAuthentications(context.Context, *auth.ListAuthenticationsRequest) (*auth.ListAuthenticationsResponse, error)
	DeleteAuthentication(context.Context, *auth.DeleteAuthenticationRequest) (*emptypb.Empty, error)
	ExpireAuthenticationSelf(context.Context, *auth.ExpireAuthenticationSelfRequest) (*emptypb.Empty, error)
}

AuthenticationServiceServer is the server API for AuthenticationService service. All implementations should embed UnimplementedAuthenticationServiceServer for forward compatibility.

type PublicAuthenticationServiceClient

type PublicAuthenticationServiceClient interface {
	ListAuthenticationMethods(ctx context.Context, in *emptypb.Empty, opts ...grpc.CallOption) (*auth.ListAuthenticationMethodsResponse, error)
}

PublicAuthenticationServiceClient is the client API for PublicAuthenticationService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewPublicAuthenticationServiceClient

func NewPublicAuthenticationServiceClient(cc grpc.ClientConnInterface) PublicAuthenticationServiceClient

type PublicAuthenticationServiceServer

type PublicAuthenticationServiceServer interface {
	ListAuthenticationMethods(context.Context, *emptypb.Empty) (*auth.ListAuthenticationMethodsResponse, error)
}

PublicAuthenticationServiceServer is the server API for PublicAuthenticationService service. All implementations should embed UnimplementedPublicAuthenticationServiceServer for forward compatibility.

type UnimplementedAuthenticationMethodGithubServiceServer

type UnimplementedAuthenticationMethodGithubServiceServer struct{}

UnimplementedAuthenticationMethodGithubServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedAuthenticationMethodGithubServiceServer) AuthorizeURL

func (UnimplementedAuthenticationMethodGithubServiceServer) Callback

type UnimplementedAuthenticationMethodKubernetesServiceServer

type UnimplementedAuthenticationMethodKubernetesServiceServer struct{}

UnimplementedAuthenticationMethodKubernetesServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedAuthenticationMethodKubernetesServiceServer) VerifyServiceAccount

type UnimplementedAuthenticationMethodOIDCServiceServer

type UnimplementedAuthenticationMethodOIDCServiceServer struct{}

UnimplementedAuthenticationMethodOIDCServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedAuthenticationMethodOIDCServiceServer) AuthorizeURL

func (UnimplementedAuthenticationMethodOIDCServiceServer) Callback

type UnimplementedAuthenticationMethodTokenServiceServer

type UnimplementedAuthenticationMethodTokenServiceServer struct{}

UnimplementedAuthenticationMethodTokenServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedAuthenticationMethodTokenServiceServer) CreateToken

type UnimplementedAuthenticationServiceServer

type UnimplementedAuthenticationServiceServer struct{}

UnimplementedAuthenticationServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedAuthenticationServiceServer) DeleteAuthentication

func (UnimplementedAuthenticationServiceServer) ExpireAuthenticationSelf

func (UnimplementedAuthenticationServiceServer) GetAuthentication

func (UnimplementedAuthenticationServiceServer) GetAuthenticationSelf

func (UnimplementedAuthenticationServiceServer) ListAuthentications

type UnimplementedPublicAuthenticationServiceServer

type UnimplementedPublicAuthenticationServiceServer struct{}

UnimplementedPublicAuthenticationServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedPublicAuthenticationServiceServer) ListAuthenticationMethods

type UnsafeAuthenticationMethodGithubServiceServer

type UnsafeAuthenticationMethodGithubServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeAuthenticationMethodGithubServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to AuthenticationMethodGithubServiceServer will result in compilation errors.

type UnsafeAuthenticationMethodKubernetesServiceServer

type UnsafeAuthenticationMethodKubernetesServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeAuthenticationMethodKubernetesServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to AuthenticationMethodKubernetesServiceServer will result in compilation errors.

type UnsafeAuthenticationMethodOIDCServiceServer

type UnsafeAuthenticationMethodOIDCServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeAuthenticationMethodOIDCServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to AuthenticationMethodOIDCServiceServer will result in compilation errors.

type UnsafeAuthenticationMethodTokenServiceServer

type UnsafeAuthenticationMethodTokenServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeAuthenticationMethodTokenServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to AuthenticationMethodTokenServiceServer will result in compilation errors.

type UnsafeAuthenticationServiceServer

type UnsafeAuthenticationServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeAuthenticationServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to AuthenticationServiceServer will result in compilation errors.

type UnsafePublicAuthenticationServiceServer

type UnsafePublicAuthenticationServiceServer interface {
	// contains filtered or unexported methods
}

UnsafePublicAuthenticationServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to PublicAuthenticationServiceServer will result in compilation errors.

Source Files

  • auth_grpc.pb.go

Jump to