ofrepgrpc

package
v1.6.1-20251002153105-... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	OFREPService_GetProviderConfiguration_FullMethodName = "/flipt.ofrep.OFREPService/GetProviderConfiguration"
	OFREPService_EvaluateFlag_FullMethodName             = "/flipt.ofrep.OFREPService/EvaluateFlag"
	OFREPService_EvaluateBulk_FullMethodName             = "/flipt.ofrep.OFREPService/EvaluateBulk"
)

Variables

var OFREPService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "flipt.ofrep.OFREPService",
	HandlerType: (*OFREPServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetProviderConfiguration",
			Handler:    _OFREPService_GetProviderConfiguration_Handler,
		},
		{
			MethodName: "EvaluateFlag",
			Handler:    _OFREPService_EvaluateFlag_Handler,
		},
		{
			MethodName: "EvaluateBulk",
			Handler:    _OFREPService_EvaluateBulk_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "ofrep/ofrep.proto",
}

OFREPService_ServiceDesc is the grpc.ServiceDesc for OFREPService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterOFREPServiceServer

func RegisterOFREPServiceServer(s grpc.ServiceRegistrar, srv OFREPServiceServer)

Types

type OFREPServiceClient

type OFREPServiceClient interface {
	// OFREP provider configuration
	GetProviderConfiguration(ctx context.Context, in *ofrep.GetProviderConfigurationRequest, opts ...grpc.CallOption) (*ofrep.GetProviderConfigurationResponse, error)
	// OFREP single flag evaluation
	EvaluateFlag(ctx context.Context, in *ofrep.EvaluateFlagRequest, opts ...grpc.CallOption) (*ofrep.EvaluatedFlag, error)
	// OFREP bulk flag evaluation
	EvaluateBulk(ctx context.Context, in *ofrep.EvaluateBulkRequest, opts ...grpc.CallOption) (*ofrep.BulkEvaluationResponse, error)
}

OFREPServiceClient is the client API for OFREPService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewOFREPServiceClient

func NewOFREPServiceClient(cc grpc.ClientConnInterface) OFREPServiceClient

type OFREPServiceServer

type OFREPServiceServer interface {
	// OFREP provider configuration
	GetProviderConfiguration(context.Context, *ofrep.GetProviderConfigurationRequest) (*ofrep.GetProviderConfigurationResponse, error)
	// OFREP single flag evaluation
	EvaluateFlag(context.Context, *ofrep.EvaluateFlagRequest) (*ofrep.EvaluatedFlag, error)
	// OFREP bulk flag evaluation
	EvaluateBulk(context.Context, *ofrep.EvaluateBulkRequest) (*ofrep.BulkEvaluationResponse, error)
}

OFREPServiceServer is the server API for OFREPService service. All implementations should embed UnimplementedOFREPServiceServer for forward compatibility.

type UnimplementedOFREPServiceServer

type UnimplementedOFREPServiceServer struct{}

UnimplementedOFREPServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedOFREPServiceServer) EvaluateBulk

func (UnimplementedOFREPServiceServer) EvaluateFlag

func (UnimplementedOFREPServiceServer) GetProviderConfiguration

type UnsafeOFREPServiceServer

type UnsafeOFREPServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeOFREPServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to OFREPServiceServer will result in compilation errors.

Source Files

  • ofrep_grpc.pb.go

Jump to