midtierv1grpc

package
v1.6.1-20250318055254-... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	RunService_Delete_FullMethodName = "/frgrisk.vor_stream.plugin_sdk.midtier.v1.RunService/Delete"
)

Variables

var RunService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "frgrisk.vor_stream.plugin_sdk.midtier.v1.RunService",
	HandlerType: (*RunServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "Delete",
			Handler:    _RunService_Delete_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "frgrisk/vor_stream/plugin_sdk/midtier/v1/run_service.proto",
}

RunService_ServiceDesc is the grpc.ServiceDesc for RunService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterRunServiceServer

func RegisterRunServiceServer(s grpc.ServiceRegistrar, srv RunServiceServer)

Types

type RunServiceClient

type RunServiceClient interface {
	Delete(ctx context.Context, in *v1.RunServiceDeleteRequest, opts ...grpc.CallOption) (*v1.RunServiceDeleteResponse, error)
}

RunServiceClient is the client API for RunService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewRunServiceClient

func NewRunServiceClient(cc grpc.ClientConnInterface) RunServiceClient

type RunServiceServer

type RunServiceServer interface {
	Delete(context.Context, *v1.RunServiceDeleteRequest) (*v1.RunServiceDeleteResponse, error)
}

RunServiceServer is the server API for RunService service. All implementations should embed UnimplementedRunServiceServer for forward compatibility.

type UnimplementedRunServiceServer

type UnimplementedRunServiceServer struct{}

UnimplementedRunServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedRunServiceServer) Delete

type UnsafeRunServiceServer

type UnsafeRunServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeRunServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to RunServiceServer will result in compilation errors.

Source Files

  • run_service_grpc.pb.go

Jump to