Documentation
¶
Index ¶
- Variables
- type BigQueryFieldOptions
- func (x *BigQueryFieldOptions) GetDefaultValueExpression() string
- func (x *BigQueryFieldOptions) GetDescription() string
- func (x *BigQueryFieldOptions) GetIgnore() bool
- func (x *BigQueryFieldOptions) GetName() string
- func (x *BigQueryFieldOptions) GetPolicyTags() string
- func (x *BigQueryFieldOptions) GetRequire() bool
- func (x *BigQueryFieldOptions) GetTypeOverride() string
- func (*BigQueryFieldOptions) ProtoMessage()
- func (x *BigQueryFieldOptions) ProtoReflect() protoreflect.Message
- func (x *BigQueryFieldOptions) Reset()
- func (x *BigQueryFieldOptions) SetDefaultValueExpression(v string)
- func (x *BigQueryFieldOptions) SetDescription(v string)
- func (x *BigQueryFieldOptions) SetIgnore(v bool)
- func (x *BigQueryFieldOptions) SetName(v string)
- func (x *BigQueryFieldOptions) SetPolicyTags(v string)
- func (x *BigQueryFieldOptions) SetRequire(v bool)
- func (x *BigQueryFieldOptions) SetTypeOverride(v string)
- func (x *BigQueryFieldOptions) String() string
- type BigQueryFieldOptions_builder
- type BigQueryMessageOptions
- func (x *BigQueryMessageOptions) GetExtraFields() []string
- func (x *BigQueryMessageOptions) GetOutputFieldOrder() BigQueryMessageOptions_FieldOrder
- func (x *BigQueryMessageOptions) GetTableName() string
- func (x *BigQueryMessageOptions) GetUseJsonNames() bool
- func (*BigQueryMessageOptions) ProtoMessage()
- func (x *BigQueryMessageOptions) ProtoReflect() protoreflect.Message
- func (x *BigQueryMessageOptions) Reset()
- func (x *BigQueryMessageOptions) SetExtraFields(v []string)
- func (x *BigQueryMessageOptions) SetOutputFieldOrder(v BigQueryMessageOptions_FieldOrder)
- func (x *BigQueryMessageOptions) SetTableName(v string)
- func (x *BigQueryMessageOptions) SetUseJsonNames(v bool)
- func (x *BigQueryMessageOptions) String() string
- type BigQueryMessageOptions_FieldOrder
- func (BigQueryMessageOptions_FieldOrder) Descriptor() protoreflect.EnumDescriptor
- func (x BigQueryMessageOptions_FieldOrder) Enum() *BigQueryMessageOptions_FieldOrder
- func (x BigQueryMessageOptions_FieldOrder) Number() protoreflect.EnumNumber
- func (x BigQueryMessageOptions_FieldOrder) String() string
- func (BigQueryMessageOptions_FieldOrder) Type() protoreflect.EnumType
- type BigQueryMessageOptions_builder
Constants ¶
This section is empty.
Variables ¶
var ( BigQueryMessageOptions_FieldOrder_name = map[int32]string{ 0: "FIELD_ORDER_UNSPECIFIED", 1: "FIELD_ORDER_BY_NUMBER", } BigQueryMessageOptions_FieldOrder_value = map[string]int32{ "FIELD_ORDER_UNSPECIFIED": 0, "FIELD_ORDER_BY_NUMBER": 1, } )
Enum value maps for BigQueryMessageOptions_FieldOrder.
var ( // BigQuery field schema generation options. // // optional gen_bq_schema.BigQueryFieldOptions bigquery = 1021; E_Bigquery = &file_bq_field_proto_extTypes[0] )
Extension fields to descriptorpb.FieldOptions.
var ( // BigQuery message schema generation options. // // The field number is a globally unique id for this option, assigned by // protobuf-global-extension-registry@google.com // // optional gen_bq_schema.BigQueryMessageOptions bigquery_opts = 1021; E_BigqueryOpts = &file_bq_table_proto_extTypes[0] )
Extension fields to descriptorpb.MessageOptions.
var File_bq_field_proto protoreflect.FileDescriptor
var File_bq_table_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type BigQueryFieldOptions ¶
type BigQueryFieldOptions struct {
// Flag to specify that a field should be marked as 'REQUIRED' when
// used to generate schema for BigQuery.
Require bool `protobuf:"varint,1,opt,name=require,proto3" json:"require,omitempty"`
// Optionally override whatever type is resolved by the schema
// generator. This is useful, for example, to store epoch timestamps
// with the underlying 'TIMESTAMP' type, when normally, they would
// be structured as 'INTEGER' fields.
TypeOverride string `protobuf:"bytes,2,opt,name=type_override,json=typeOverride,proto3" json:"type_override,omitempty"`
// Optionally omit a field from BigQuery schema.
Ignore bool `protobuf:"varint,3,opt,name=ignore,proto3" json:"ignore,omitempty"`
// Set the description for a field in BigQuery schema.
Description string `protobuf:"bytes,4,opt,name=description,proto3" json:"description,omitempty"`
// Customize the name of the field in the BigQuery schema.
Name string `protobuf:"bytes,5,opt,name=name,proto3" json:"name,omitempty"`
// Optionally add PolicyTag for a field in BigQuery schema.
PolicyTags string `protobuf:"bytes,6,opt,name=policy_tags,json=policyTags,proto3" json:"policy_tags,omitempty"`
// Optional default value.
//
// See https://cloud.google.com/bigquery/docs/default-values for possible
// values.
DefaultValueExpression string `` /* 129-byte string literal not displayed */
// contains filtered or unexported fields
}
Message containing options related to BigQuery schema generation and management via Protobuf.
func (*BigQueryFieldOptions) GetDefaultValueExpression ¶
func (x *BigQueryFieldOptions) GetDefaultValueExpression() string
func (*BigQueryFieldOptions) GetDescription ¶
func (x *BigQueryFieldOptions) GetDescription() string
func (*BigQueryFieldOptions) GetIgnore ¶
func (x *BigQueryFieldOptions) GetIgnore() bool
func (*BigQueryFieldOptions) GetName ¶
func (x *BigQueryFieldOptions) GetName() string
func (*BigQueryFieldOptions) GetPolicyTags ¶
func (x *BigQueryFieldOptions) GetPolicyTags() string
func (*BigQueryFieldOptions) GetRequire ¶
func (x *BigQueryFieldOptions) GetRequire() bool
func (*BigQueryFieldOptions) GetTypeOverride ¶
func (x *BigQueryFieldOptions) GetTypeOverride() string
func (*BigQueryFieldOptions) ProtoMessage ¶
func (*BigQueryFieldOptions) ProtoMessage()
func (*BigQueryFieldOptions) ProtoReflect ¶
func (x *BigQueryFieldOptions) ProtoReflect() protoreflect.Message
func (*BigQueryFieldOptions) Reset ¶
func (x *BigQueryFieldOptions) Reset()
func (*BigQueryFieldOptions) SetDefaultValueExpression ¶
func (x *BigQueryFieldOptions) SetDefaultValueExpression(v string)
func (*BigQueryFieldOptions) SetDescription ¶
func (x *BigQueryFieldOptions) SetDescription(v string)
func (*BigQueryFieldOptions) SetIgnore ¶
func (x *BigQueryFieldOptions) SetIgnore(v bool)
func (*BigQueryFieldOptions) SetName ¶
func (x *BigQueryFieldOptions) SetName(v string)
func (*BigQueryFieldOptions) SetPolicyTags ¶
func (x *BigQueryFieldOptions) SetPolicyTags(v string)
func (*BigQueryFieldOptions) SetRequire ¶
func (x *BigQueryFieldOptions) SetRequire(v bool)
func (*BigQueryFieldOptions) SetTypeOverride ¶
func (x *BigQueryFieldOptions) SetTypeOverride(v string)
func (*BigQueryFieldOptions) String ¶
func (x *BigQueryFieldOptions) String() string
type BigQueryFieldOptions_builder ¶
type BigQueryFieldOptions_builder struct {
// Flag to specify that a field should be marked as 'REQUIRED' when
// used to generate schema for BigQuery.
Require bool
// Optionally override whatever type is resolved by the schema
// generator. This is useful, for example, to store epoch timestamps
// with the underlying 'TIMESTAMP' type, when normally, they would
// be structured as 'INTEGER' fields.
TypeOverride string
// Optionally omit a field from BigQuery schema.
Ignore bool
// Set the description for a field in BigQuery schema.
Description string
// Customize the name of the field in the BigQuery schema.
Name string
// Optionally add PolicyTag for a field in BigQuery schema.
PolicyTags string
// Optional default value.
//
// See https://cloud.google.com/bigquery/docs/default-values for possible
// values.
DefaultValueExpression string
// contains filtered or unexported fields
}
func (BigQueryFieldOptions_builder) Build ¶
func (b0 BigQueryFieldOptions_builder) Build() *BigQueryFieldOptions
type BigQueryMessageOptions ¶
type BigQueryMessageOptions struct {
// Specifies a name of table in BigQuery for the message.
//
// If not blank, indicates the message is a type of record to be stored into BigQuery.
TableName string `protobuf:"bytes,1,opt,name=table_name,json=tableName,proto3" json:"table_name,omitempty"`
// If true, BigQuery field names will default to a field's JSON name,
// not its original/proto field name.
UseJsonNames bool `protobuf:"varint,2,opt,name=use_json_names,json=useJsonNames,proto3" json:"use_json_names,omitempty"`
// If set, adds defined extra fields to a JSON representation of the message.
// Value format: "<field name>:<BigQuery field type>" for basic types
// or "<field name>:RECORD:<protobuf type>" for message types.
// "NULLABLE" by default, different mode may be set via optional suffix ":<mode>"
ExtraFields []string `protobuf:"bytes,3,rep,name=extra_fields,json=extraFields,proto3" json:"extra_fields,omitempty"`
OutputFieldOrder BigQueryMessageOptions_FieldOrder `` /* 165-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*BigQueryMessageOptions) GetExtraFields ¶
func (x *BigQueryMessageOptions) GetExtraFields() []string
func (*BigQueryMessageOptions) GetOutputFieldOrder ¶
func (x *BigQueryMessageOptions) GetOutputFieldOrder() BigQueryMessageOptions_FieldOrder
func (*BigQueryMessageOptions) GetTableName ¶
func (x *BigQueryMessageOptions) GetTableName() string
func (*BigQueryMessageOptions) GetUseJsonNames ¶
func (x *BigQueryMessageOptions) GetUseJsonNames() bool
func (*BigQueryMessageOptions) ProtoMessage ¶
func (*BigQueryMessageOptions) ProtoMessage()
func (*BigQueryMessageOptions) ProtoReflect ¶
func (x *BigQueryMessageOptions) ProtoReflect() protoreflect.Message
func (*BigQueryMessageOptions) Reset ¶
func (x *BigQueryMessageOptions) Reset()
func (*BigQueryMessageOptions) SetExtraFields ¶
func (x *BigQueryMessageOptions) SetExtraFields(v []string)
func (*BigQueryMessageOptions) SetOutputFieldOrder ¶
func (x *BigQueryMessageOptions) SetOutputFieldOrder(v BigQueryMessageOptions_FieldOrder)
func (*BigQueryMessageOptions) SetTableName ¶
func (x *BigQueryMessageOptions) SetTableName(v string)
func (*BigQueryMessageOptions) SetUseJsonNames ¶
func (x *BigQueryMessageOptions) SetUseJsonNames(v bool)
func (*BigQueryMessageOptions) String ¶
func (x *BigQueryMessageOptions) String() string
type BigQueryMessageOptions_FieldOrder ¶
type BigQueryMessageOptions_FieldOrder int32
If set will output the schema file order based on the provided value.
const ( BigQueryMessageOptions_FIELD_ORDER_UNSPECIFIED BigQueryMessageOptions_FieldOrder = 0 BigQueryMessageOptions_FIELD_ORDER_BY_NUMBER BigQueryMessageOptions_FieldOrder = 1 )
func (BigQueryMessageOptions_FieldOrder) Descriptor ¶
func (BigQueryMessageOptions_FieldOrder) Descriptor() protoreflect.EnumDescriptor
func (BigQueryMessageOptions_FieldOrder) Enum ¶
func (x BigQueryMessageOptions_FieldOrder) Enum() *BigQueryMessageOptions_FieldOrder
func (BigQueryMessageOptions_FieldOrder) Number ¶
func (x BigQueryMessageOptions_FieldOrder) Number() protoreflect.EnumNumber
func (BigQueryMessageOptions_FieldOrder) String ¶
func (x BigQueryMessageOptions_FieldOrder) String() string
func (BigQueryMessageOptions_FieldOrder) Type ¶
func (BigQueryMessageOptions_FieldOrder) Type() protoreflect.EnumType
type BigQueryMessageOptions_builder ¶
type BigQueryMessageOptions_builder struct {
// Specifies a name of table in BigQuery for the message.
//
// If not blank, indicates the message is a type of record to be stored into BigQuery.
TableName string
// If true, BigQuery field names will default to a field's JSON name,
// not its original/proto field name.
UseJsonNames bool
// If set, adds defined extra fields to a JSON representation of the message.
// Value format: "<field name>:<BigQuery field type>" for basic types
// or "<field name>:RECORD:<protobuf type>" for message types.
// "NULLABLE" by default, different mode may be set via optional suffix ":<mode>"
ExtraFields []string
OutputFieldOrder BigQueryMessageOptions_FieldOrder
// contains filtered or unexported fields
}
func (BigQueryMessageOptions_builder) Build ¶
func (b0 BigQueryMessageOptions_builder) Build() *BigQueryMessageOptions
Source Files
¶
- bq_field.pb.go
- bq_table.pb.go
Click to show internal directories.
Click to hide internal directories.