xdsconfigconnect

package
v1.10.0-20250429200738... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	// XdsConfigControlServiceStopOnRequestProcedure is the fully-qualified name of the
	// XdsConfigControlService's StopOnRequest RPC.
	XdsConfigControlServiceStopOnRequestProcedure = "/grpc.testing.xdsconfig.XdsConfigControlService/StopOnRequest"
	// XdsConfigControlServiceSetResourcesProcedure is the fully-qualified name of the
	// XdsConfigControlService's SetResources RPC.
	XdsConfigControlServiceSetResourcesProcedure = "/grpc.testing.xdsconfig.XdsConfigControlService/SetResources"
)

These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.

Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.

const (
	// XdsConfigControlServiceName is the fully-qualified name of the XdsConfigControlService service.
	XdsConfigControlServiceName = "grpc.testing.xdsconfig.XdsConfigControlService"
)

Variables

This section is empty.

Functions

func NewXdsConfigControlServiceHandler

func NewXdsConfigControlServiceHandler(svc XdsConfigControlServiceHandler, opts ...connect_go.HandlerOption) (string, http.Handler)

NewXdsConfigControlServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.

By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.

Types

type UnimplementedXdsConfigControlServiceHandler

type UnimplementedXdsConfigControlServiceHandler struct{}

UnimplementedXdsConfigControlServiceHandler returns CodeUnimplemented from all methods.

func (UnimplementedXdsConfigControlServiceHandler) SetResources

func (UnimplementedXdsConfigControlServiceHandler) StopOnRequest

type XdsConfigControlServiceClient

type XdsConfigControlServiceClient interface {
	// Instructs the server to exit when given resource is requested
	StopOnRequest(context.Context, *connect_go.Request[xdsconfig.StopOnRequestRequest]) (*connect_go.Response[xdsconfig.StopOnRequestResponse], error)
	// A generic way to set xDS resources
	SetResources(context.Context, *connect_go.Request[xdsconfig.SetResourcesRequest]) (*connect_go.Response[xdsconfig.SetResourcesResponse], error)
}

XdsConfigControlServiceClient is a client for the grpc.testing.xdsconfig.XdsConfigControlService service.

func NewXdsConfigControlServiceClient

func NewXdsConfigControlServiceClient(httpClient connect_go.HTTPClient, baseURL string, opts ...connect_go.ClientOption) XdsConfigControlServiceClient

NewXdsConfigControlServiceClient constructs a client for the grpc.testing.xdsconfig.XdsConfigControlService service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.

The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).

type XdsConfigControlServiceHandler

type XdsConfigControlServiceHandler interface {
	// Instructs the server to exit when given resource is requested
	StopOnRequest(context.Context, *connect_go.Request[xdsconfig.StopOnRequestRequest]) (*connect_go.Response[xdsconfig.StopOnRequestResponse], error)
	// A generic way to set xDS resources
	SetResources(context.Context, *connect_go.Request[xdsconfig.SetResourcesRequest]) (*connect_go.Response[xdsconfig.SetResourcesResponse], error)
}

XdsConfigControlServiceHandler is an implementation of the grpc.testing.xdsconfig.XdsConfigControlService service.

Source Files

  • xdsconfig.connect.go

Jump to