Documentation
¶
Index ¶
- Constants
- Variables
- type GrpcLogEntry
- func (x *GrpcLogEntry) ClearCallId()deprecated
- func (x *GrpcLogEntry) ClearMessage()deprecated
- func (x *GrpcLogEntry) ClearMetadata()deprecated
- func (x *GrpcLogEntry) ClearPayload()
- func (x *GrpcLogEntry) ClearPeer()deprecated
- func (x *GrpcLogEntry) ClearTimeout()deprecated
- func (x *GrpcLogEntry) GetCallId() *Uint128deprecated
- func (x *GrpcLogEntry) GetLogger() GrpcLogEntry_Loggerdeprecated
- func (x *GrpcLogEntry) GetMessage() *Messagedeprecated
- func (x *GrpcLogEntry) GetMetadata() *Metadatadeprecated
- func (x *GrpcLogEntry) GetMethodName() stringdeprecated
- func (x *GrpcLogEntry) GetPayload() isGrpcLogEntry_Payload
- func (x *GrpcLogEntry) GetPeer() *Peerdeprecated
- func (x *GrpcLogEntry) GetSequenceIdWithinCall() uint32deprecated
- func (x *GrpcLogEntry) GetStatusCode() uint32deprecated
- func (x *GrpcLogEntry) GetStatusDetails() []bytedeprecated
- func (x *GrpcLogEntry) GetStatusMessage() stringdeprecated
- func (x *GrpcLogEntry) GetTimeout() *durationpb.Durationdeprecated
- func (x *GrpcLogEntry) GetTruncated() booldeprecated
- func (x *GrpcLogEntry) GetType() GrpcLogEntry_Typedeprecated
- func (x *GrpcLogEntry) HasCallId() booldeprecated
- func (x *GrpcLogEntry) HasMessage() booldeprecated
- func (x *GrpcLogEntry) HasMetadata() booldeprecated
- func (x *GrpcLogEntry) HasPayload() bool
- func (x *GrpcLogEntry) HasPeer() booldeprecated
- func (x *GrpcLogEntry) HasTimeout() booldeprecated
- func (*GrpcLogEntry) ProtoMessage()
- func (x *GrpcLogEntry) ProtoReflect() protoreflect.Message
- func (x *GrpcLogEntry) Reset()
- func (x *GrpcLogEntry) SetCallId(v *Uint128)deprecated
- func (x *GrpcLogEntry) SetLogger(v GrpcLogEntry_Logger)deprecated
- func (x *GrpcLogEntry) SetMessage(v *Message)deprecated
- func (x *GrpcLogEntry) SetMetadata(v *Metadata)deprecated
- func (x *GrpcLogEntry) SetMethodName(v string)deprecated
- func (x *GrpcLogEntry) SetPeer(v *Peer)deprecated
- func (x *GrpcLogEntry) SetSequenceIdWithinCall(v uint32)deprecated
- func (x *GrpcLogEntry) SetStatusCode(v uint32)deprecated
- func (x *GrpcLogEntry) SetStatusDetails(v []byte)deprecated
- func (x *GrpcLogEntry) SetStatusMessage(v string)deprecated
- func (x *GrpcLogEntry) SetTimeout(v *durationpb.Duration)deprecated
- func (x *GrpcLogEntry) SetTruncated(v bool)deprecated
- func (x *GrpcLogEntry) SetType(v GrpcLogEntry_Type)deprecated
- func (x *GrpcLogEntry) String() string
- func (x *GrpcLogEntry) WhichPayload() case_GrpcLogEntry_Payload
- type GrpcLogEntry_Logger
- type GrpcLogEntry_Message
- type GrpcLogEntry_Metadata
- type GrpcLogEntry_Type
- type GrpcLogEntry_builder
- type Message
- func (x *Message) GetData() []bytedeprecated
- func (x *Message) GetFlags() uint32deprecated
- func (x *Message) GetLength() uint32deprecated
- func (*Message) ProtoMessage()
- func (x *Message) ProtoReflect() protoreflect.Message
- func (x *Message) Reset()
- func (x *Message) SetData(v []byte)deprecated
- func (x *Message) SetFlags(v uint32)deprecated
- func (x *Message) SetLength(v uint32)deprecated
- func (x *Message) String() string
- type Message_builder
- type Metadata
- type MetadataEntry
- func (x *MetadataEntry) GetKey() []bytedeprecated
- func (x *MetadataEntry) GetValue() []bytedeprecated
- func (*MetadataEntry) ProtoMessage()
- func (x *MetadataEntry) ProtoReflect() protoreflect.Message
- func (x *MetadataEntry) Reset()
- func (x *MetadataEntry) SetKey(v []byte)deprecated
- func (x *MetadataEntry) SetValue(v []byte)deprecated
- func (x *MetadataEntry) String() string
- type MetadataEntry_builder
- type Metadata_builder
- type Peer
- func (x *Peer) GetAddress() stringdeprecated
- func (x *Peer) GetIpPort() uint32deprecated
- func (x *Peer) GetPeer() []bytedeprecated
- func (x *Peer) GetPeerType() Peer_PeerTypedeprecated
- func (*Peer) ProtoMessage()
- func (x *Peer) ProtoReflect() protoreflect.Message
- func (x *Peer) Reset()
- func (x *Peer) SetAddress(v string)deprecated
- func (x *Peer) SetIpPort(v uint32)deprecated
- func (x *Peer) SetPeer(v []byte)deprecated
- func (x *Peer) SetPeerType(v Peer_PeerType)deprecated
- func (x *Peer) String() string
- type Peer_PeerType
- type Peer_builder
- type Uint128
- func (x *Uint128) GetHigh() uint64deprecated
- func (x *Uint128) GetLow() uint64deprecated
- func (*Uint128) ProtoMessage()
- func (x *Uint128) ProtoReflect() protoreflect.Message
- func (x *Uint128) Reset()
- func (x *Uint128) SetHigh(v uint64)deprecated
- func (x *Uint128) SetLow(v uint64)deprecated
- func (x *Uint128) String() string
- type Uint128_builder
Constants ¶
const GrpcLogEntry_Message_case case_GrpcLogEntry_Payload = 5
const GrpcLogEntry_Metadata_case case_GrpcLogEntry_Payload = 4
const GrpcLogEntry_Payload_not_set_case case_GrpcLogEntry_Payload = 0
Variables ¶
var ( GrpcLogEntry_Type_name = map[int32]string{ 0: "UNKNOWN_TYPE", 1: "SEND_INITIAL_METADATA", 2: "SEND_TRAILING_METADATA", 3: "SEND_MESSAGE", 4: "RECV_INITIAL_METADATA", 5: "RECV_TRAILING_METADATA", 6: "RECV_MESSAGE", } GrpcLogEntry_Type_value = map[string]int32{ "UNKNOWN_TYPE": 0, "SEND_INITIAL_METADATA": 1, "SEND_TRAILING_METADATA": 2, "SEND_MESSAGE": 3, "RECV_INITIAL_METADATA": 4, "RECV_TRAILING_METADATA": 5, "RECV_MESSAGE": 6, } )
Enum value maps for GrpcLogEntry_Type.
var ( GrpcLogEntry_Logger_name = map[int32]string{ 0: "UNKNOWN_LOGGER", 1: "CLIENT", 2: "SERVER", } GrpcLogEntry_Logger_value = map[string]int32{ "UNKNOWN_LOGGER": 0, "CLIENT": 1, "SERVER": 2, } )
Enum value maps for GrpcLogEntry_Logger.
var ( Peer_PeerType_name = map[int32]string{ 0: "UNKNOWN_PEERTYPE", 1: "PEER_IPV4", 2: "PEER_IPV6", 3: "PEER_UNIX", } Peer_PeerType_value = map[string]int32{ "UNKNOWN_PEERTYPE": 0, "PEER_IPV4": 1, "PEER_IPV6": 2, "PEER_UNIX": 3, } )
Enum value maps for Peer_PeerType.
var File_grpc_binlog_v1alpha_binarylog_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type GrpcLogEntry ¶
type GrpcLogEntry struct {
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
Type GrpcLogEntry_Type `protobuf:"varint,1,opt,name=type,proto3,enum=grpc.binarylog.v1alpha.GrpcLogEntry_Type" json:"type,omitempty"` // One of the above Type enum
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
Logger GrpcLogEntry_Logger `protobuf:"varint,2,opt,name=logger,proto3,enum=grpc.binarylog.v1alpha.GrpcLogEntry_Logger" json:"logger,omitempty"` // One of the above Logger enum
// Uniquely identifies a call. Each call may have several log entries, they
// will share the same call_id. 128 bits split into 2 64-bit parts.
//
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
CallId *Uint128 `protobuf:"bytes,3,opt,name=call_id,json=callId,proto3" json:"call_id,omitempty"`
// The logger uses one of the following fields to record the payload,
// according to the type of the log entry.
//
// Types that are valid to be assigned to Payload:
//
// *GrpcLogEntry_Metadata
// *GrpcLogEntry_Message
Payload isGrpcLogEntry_Payload `protobuf_oneof:"payload"`
// Peer address information, will only be recorded in SEND_INITIAL_METADATA
// and RECV_INITIAL_METADATA entries.
//
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
Peer *Peer `protobuf:"bytes,6,opt,name=peer,proto3" json:"peer,omitempty"`
// true if payload does not represent the full message or metadata.
//
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
Truncated bool `protobuf:"varint,7,opt,name=truncated,proto3" json:"truncated,omitempty"`
// The method name. Logged for the first entry:
// RECV_INITIAL_METADATA for server side or
// SEND_INITIAL_METADATA for client side.
//
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
MethodName string `protobuf:"bytes,8,opt,name=method_name,json=methodName,proto3" json:"method_name,omitempty"`
// status_code and status_message:
// Only present for SEND_TRAILING_METADATA on server side or
// RECV_TRAILING_METADATA on client side.
//
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
StatusCode uint32 `protobuf:"varint,9,opt,name=status_code,json=statusCode,proto3" json:"status_code,omitempty"`
// An original status message before any transport specific
// encoding.
//
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
StatusMessage string `protobuf:"bytes,10,opt,name=status_message,json=statusMessage,proto3" json:"status_message,omitempty"`
// The value of the 'grpc-status-details-bin' metadata key. If
// present, this is always an encoded 'google.rpc.Status' message.
//
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
StatusDetails []byte `protobuf:"bytes,11,opt,name=status_details,json=statusDetails,proto3" json:"status_details,omitempty"`
// the RPC timeout
//
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
Timeout *durationpb.Duration `protobuf:"bytes,12,opt,name=timeout,proto3" json:"timeout,omitempty"`
// The entry sequence id for this call. The first GrpcLogEntry has a
// value of 1, to disambiguate from an unset value. The purpose of
// this field is to detect missing entries in environments where
// durability or ordering is not guaranteed.
//
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
SequenceIdWithinCall uint32 `` /* 127-byte string literal not displayed */
// contains filtered or unexported fields
}
Log entry we store in binary logs
func (*GrpcLogEntry) ClearCallId
deprecated
func (x *GrpcLogEntry) ClearCallId()
Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
func (*GrpcLogEntry) ClearMessage
deprecated
func (x *GrpcLogEntry) ClearMessage()
Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
func (*GrpcLogEntry) ClearMetadata
deprecated
func (x *GrpcLogEntry) ClearMetadata()
Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
func (*GrpcLogEntry) ClearPayload ¶
func (x *GrpcLogEntry) ClearPayload()
func (*GrpcLogEntry) ClearPeer
deprecated
func (x *GrpcLogEntry) ClearPeer()
Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
func (*GrpcLogEntry) ClearTimeout
deprecated
func (x *GrpcLogEntry) ClearTimeout()
Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
func (*GrpcLogEntry) GetCallId
deprecated
func (x *GrpcLogEntry) GetCallId() *Uint128
Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
func (*GrpcLogEntry) GetLogger
deprecated
func (x *GrpcLogEntry) GetLogger() GrpcLogEntry_Logger
Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
func (*GrpcLogEntry) GetMessage
deprecated
func (x *GrpcLogEntry) GetMessage() *Message
Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
func (*GrpcLogEntry) GetMetadata
deprecated
func (x *GrpcLogEntry) GetMetadata() *Metadata
Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
func (*GrpcLogEntry) GetMethodName
deprecated
func (x *GrpcLogEntry) GetMethodName() string
Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
func (*GrpcLogEntry) GetPayload ¶
func (x *GrpcLogEntry) GetPayload() isGrpcLogEntry_Payload
func (*GrpcLogEntry) GetPeer
deprecated
func (x *GrpcLogEntry) GetPeer() *Peer
Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
func (*GrpcLogEntry) GetSequenceIdWithinCall
deprecated
func (x *GrpcLogEntry) GetSequenceIdWithinCall() uint32
Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
func (*GrpcLogEntry) GetStatusCode
deprecated
func (x *GrpcLogEntry) GetStatusCode() uint32
Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
func (*GrpcLogEntry) GetStatusDetails
deprecated
func (x *GrpcLogEntry) GetStatusDetails() []byte
Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
func (*GrpcLogEntry) GetStatusMessage
deprecated
func (x *GrpcLogEntry) GetStatusMessage() string
Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
func (*GrpcLogEntry) GetTimeout
deprecated
func (x *GrpcLogEntry) GetTimeout() *durationpb.Duration
Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
func (*GrpcLogEntry) GetTruncated
deprecated
func (x *GrpcLogEntry) GetTruncated() bool
Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
func (*GrpcLogEntry) GetType
deprecated
func (x *GrpcLogEntry) GetType() GrpcLogEntry_Type
Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
func (*GrpcLogEntry) HasCallId
deprecated
func (x *GrpcLogEntry) HasCallId() bool
Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
func (*GrpcLogEntry) HasMessage
deprecated
func (x *GrpcLogEntry) HasMessage() bool
Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
func (*GrpcLogEntry) HasMetadata
deprecated
func (x *GrpcLogEntry) HasMetadata() bool
Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
func (*GrpcLogEntry) HasPayload ¶
func (x *GrpcLogEntry) HasPayload() bool
func (*GrpcLogEntry) HasPeer
deprecated
func (x *GrpcLogEntry) HasPeer() bool
Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
func (*GrpcLogEntry) HasTimeout
deprecated
func (x *GrpcLogEntry) HasTimeout() bool
Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
func (*GrpcLogEntry) ProtoMessage ¶
func (*GrpcLogEntry) ProtoMessage()
func (*GrpcLogEntry) ProtoReflect ¶
func (x *GrpcLogEntry) ProtoReflect() protoreflect.Message
func (*GrpcLogEntry) Reset ¶
func (x *GrpcLogEntry) Reset()
func (*GrpcLogEntry) SetCallId
deprecated
func (x *GrpcLogEntry) SetCallId(v *Uint128)
Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
func (*GrpcLogEntry) SetLogger
deprecated
func (x *GrpcLogEntry) SetLogger(v GrpcLogEntry_Logger)
Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
func (*GrpcLogEntry) SetMessage
deprecated
func (x *GrpcLogEntry) SetMessage(v *Message)
Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
func (*GrpcLogEntry) SetMetadata
deprecated
func (x *GrpcLogEntry) SetMetadata(v *Metadata)
Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
func (*GrpcLogEntry) SetMethodName
deprecated
func (x *GrpcLogEntry) SetMethodName(v string)
Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
func (*GrpcLogEntry) SetPeer
deprecated
func (x *GrpcLogEntry) SetPeer(v *Peer)
Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
func (*GrpcLogEntry) SetSequenceIdWithinCall
deprecated
func (x *GrpcLogEntry) SetSequenceIdWithinCall(v uint32)
Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
func (*GrpcLogEntry) SetStatusCode
deprecated
func (x *GrpcLogEntry) SetStatusCode(v uint32)
Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
func (*GrpcLogEntry) SetStatusDetails
deprecated
func (x *GrpcLogEntry) SetStatusDetails(v []byte)
Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
func (*GrpcLogEntry) SetStatusMessage
deprecated
func (x *GrpcLogEntry) SetStatusMessage(v string)
Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
func (*GrpcLogEntry) SetTimeout
deprecated
func (x *GrpcLogEntry) SetTimeout(v *durationpb.Duration)
Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
func (*GrpcLogEntry) SetTruncated
deprecated
func (x *GrpcLogEntry) SetTruncated(v bool)
Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
func (*GrpcLogEntry) SetType
deprecated
func (x *GrpcLogEntry) SetType(v GrpcLogEntry_Type)
Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
func (*GrpcLogEntry) String ¶
func (x *GrpcLogEntry) String() string
func (*GrpcLogEntry) WhichPayload ¶
func (x *GrpcLogEntry) WhichPayload() case_GrpcLogEntry_Payload
type GrpcLogEntry_Logger ¶
type GrpcLogEntry_Logger int32
Enumerates the entity that generates the log entry
const ( GrpcLogEntry_UNKNOWN_LOGGER GrpcLogEntry_Logger = 0 GrpcLogEntry_CLIENT GrpcLogEntry_Logger = 1 GrpcLogEntry_SERVER GrpcLogEntry_Logger = 2 )
func (GrpcLogEntry_Logger) Descriptor ¶
func (GrpcLogEntry_Logger) Descriptor() protoreflect.EnumDescriptor
func (GrpcLogEntry_Logger) Enum ¶
func (x GrpcLogEntry_Logger) Enum() *GrpcLogEntry_Logger
func (GrpcLogEntry_Logger) Number ¶
func (x GrpcLogEntry_Logger) Number() protoreflect.EnumNumber
func (GrpcLogEntry_Logger) String ¶
func (x GrpcLogEntry_Logger) String() string
func (GrpcLogEntry_Logger) Type ¶
func (GrpcLogEntry_Logger) Type() protoreflect.EnumType
type GrpcLogEntry_Message ¶
type GrpcLogEntry_Message struct {
// Used by {SEND,RECV}_MESSAGE
//
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
Message *Message `protobuf:"bytes,5,opt,name=message,proto3,oneof"`
}
type GrpcLogEntry_Metadata ¶
type GrpcLogEntry_Metadata struct {
// Used by {SEND,RECV}_INITIAL_METADATA and
// {SEND,RECV}_TRAILING_METADATA. This contains only the metadata
// from the application.
//
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
Metadata *Metadata `protobuf:"bytes,4,opt,name=metadata,proto3,oneof"`
}
type GrpcLogEntry_Type ¶
type GrpcLogEntry_Type int32
Enumerates the type of logs
const ( GrpcLogEntry_UNKNOWN_TYPE GrpcLogEntry_Type = 0 GrpcLogEntry_SEND_INITIAL_METADATA GrpcLogEntry_Type = 1 GrpcLogEntry_SEND_TRAILING_METADATA GrpcLogEntry_Type = 2 GrpcLogEntry_SEND_MESSAGE GrpcLogEntry_Type = 3 GrpcLogEntry_RECV_INITIAL_METADATA GrpcLogEntry_Type = 4 GrpcLogEntry_RECV_TRAILING_METADATA GrpcLogEntry_Type = 5 GrpcLogEntry_RECV_MESSAGE GrpcLogEntry_Type = 6 )
func (GrpcLogEntry_Type) Descriptor ¶
func (GrpcLogEntry_Type) Descriptor() protoreflect.EnumDescriptor
func (GrpcLogEntry_Type) Enum ¶
func (x GrpcLogEntry_Type) Enum() *GrpcLogEntry_Type
func (GrpcLogEntry_Type) Number ¶
func (x GrpcLogEntry_Type) Number() protoreflect.EnumNumber
func (GrpcLogEntry_Type) String ¶
func (x GrpcLogEntry_Type) String() string
func (GrpcLogEntry_Type) Type ¶
func (GrpcLogEntry_Type) Type() protoreflect.EnumType
type GrpcLogEntry_builder ¶
type GrpcLogEntry_builder struct {
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
Type GrpcLogEntry_Type
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
Logger GrpcLogEntry_Logger
// Uniquely identifies a call. Each call may have several log entries, they
// will share the same call_id. 128 bits split into 2 64-bit parts.
//
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
CallId *Uint128
// Fields of oneof Payload:
// Used by {SEND,RECV}_INITIAL_METADATA and
// {SEND,RECV}_TRAILING_METADATA. This contains only the metadata
// from the application.
//
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
Metadata *Metadata
// Used by {SEND,RECV}_MESSAGE
//
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
Message *Message
// -- end of Payload
// Peer address information, will only be recorded in SEND_INITIAL_METADATA
// and RECV_INITIAL_METADATA entries.
//
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
Peer *Peer
// true if payload does not represent the full message or metadata.
//
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
Truncated bool
// The method name. Logged for the first entry:
// RECV_INITIAL_METADATA for server side or
// SEND_INITIAL_METADATA for client side.
//
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
MethodName string
// status_code and status_message:
// Only present for SEND_TRAILING_METADATA on server side or
// RECV_TRAILING_METADATA on client side.
//
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
StatusCode uint32
// An original status message before any transport specific
// encoding.
//
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
StatusMessage string
// The value of the 'grpc-status-details-bin' metadata key. If
// present, this is always an encoded 'google.rpc.Status' message.
//
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
StatusDetails []byte
// the RPC timeout
//
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
Timeout *durationpb.Duration
// The entry sequence id for this call. The first GrpcLogEntry has a
// value of 1, to disambiguate from an unset value. The purpose of
// this field is to detect missing entries in environments where
// durability or ordering is not guaranteed.
//
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
SequenceIdWithinCall uint32
// contains filtered or unexported fields
}
func (GrpcLogEntry_builder) Build ¶
func (b0 GrpcLogEntry_builder) Build() *GrpcLogEntry
type Message ¶
type Message struct {
// This flag is currently used to indicate whether the payload is compressed,
// it may contain other semantics in the future. Value of 1 indicates that the
// binary octet sequence of Message is compressed using the mechanism declared
// by the Message-Encoding header. A value of 0 indicates that no encoding of
// Message bytes has occurred.
//
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
Flags uint32 `protobuf:"varint,1,opt,name=flags,proto3" json:"flags,omitempty"` // TODO(zpencer): this is changed because there is no uint8
// Length of the message. It may not be the same as the length of the
// data field, as the logging payload can be truncated or omitted.
//
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
Length uint32 `protobuf:"varint,2,opt,name=length,proto3" json:"length,omitempty"`
// May be truncated or omitted.
//
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
Data []byte `protobuf:"bytes,3,opt,name=data,proto3" json:"data,omitempty"`
// contains filtered or unexported fields
}
Message payload, used by REQUEST and RESPONSE
func (*Message) ProtoReflect ¶
func (x *Message) ProtoReflect() protoreflect.Message
type Message_builder ¶
type Message_builder struct {
// This flag is currently used to indicate whether the payload is compressed,
// it may contain other semantics in the future. Value of 1 indicates that the
// binary octet sequence of Message is compressed using the mechanism declared
// by the Message-Encoding header. A value of 0 indicates that no encoding of
// Message bytes has occurred.
//
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
Flags uint32
// Length of the message. It may not be the same as the length of the
// data field, as the logging payload can be truncated or omitted.
//
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
Length uint32
// May be truncated or omitted.
//
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
Data []byte
// contains filtered or unexported fields
}
func (Message_builder) Build ¶
func (b0 Message_builder) Build() *Message
type Metadata ¶
type Metadata struct {
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
Entry []*MetadataEntry `protobuf:"bytes,1,rep,name=entry,proto3" json:"entry,omitempty"`
// contains filtered or unexported fields
}
A list of metadata pairs, used in the payload of CLIENT_INIT_METADATA, SERVER_INIT_METADATA and TRAILING_METADATA Implementations may omit some entries to honor the header limits of GRPC_BINARY_LOG_CONFIG.
Implementations will not log the following entries, and this is not to be treated as a truncation:
- entries handled by grpc that are not user visible, such as those that begin with 'grpc-' or keys like 'lb-token'
- transport specific entries, including but not limited to: ':path', ':authority', 'content-encoding', 'user-agent', 'te', etc
- entries added for call credentials
func (*Metadata) GetEntry
deprecated
func (x *Metadata) GetEntry() []*MetadataEntry
Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
func (*Metadata) ProtoReflect ¶
func (x *Metadata) ProtoReflect() protoreflect.Message
func (*Metadata) SetEntry
deprecated
func (x *Metadata) SetEntry(v []*MetadataEntry)
Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
type MetadataEntry ¶
type MetadataEntry struct {
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
Key []byte `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
Value []byte `protobuf:"bytes,2,opt,name=value,proto3" json:"value,omitempty"`
// contains filtered or unexported fields
}
A metadata key value pair
func (*MetadataEntry) GetKey
deprecated
func (x *MetadataEntry) GetKey() []byte
Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
func (*MetadataEntry) GetValue
deprecated
func (x *MetadataEntry) GetValue() []byte
Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
func (*MetadataEntry) ProtoMessage ¶
func (*MetadataEntry) ProtoMessage()
func (*MetadataEntry) ProtoReflect ¶
func (x *MetadataEntry) ProtoReflect() protoreflect.Message
func (*MetadataEntry) Reset ¶
func (x *MetadataEntry) Reset()
func (*MetadataEntry) SetKey
deprecated
func (x *MetadataEntry) SetKey(v []byte)
Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
func (*MetadataEntry) SetValue
deprecated
func (x *MetadataEntry) SetValue(v []byte)
Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
func (*MetadataEntry) String ¶
func (x *MetadataEntry) String() string
type MetadataEntry_builder ¶
type MetadataEntry_builder struct {
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
Key []byte
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
Value []byte
// contains filtered or unexported fields
}
func (MetadataEntry_builder) Build ¶
func (b0 MetadataEntry_builder) Build() *MetadataEntry
type Metadata_builder ¶
type Metadata_builder struct {
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
Entry []*MetadataEntry
// contains filtered or unexported fields
}
func (Metadata_builder) Build ¶
func (b0 Metadata_builder) Build() *Metadata
type Peer ¶
type Peer struct {
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
PeerType Peer_PeerType `` /* 128-byte string literal not displayed */
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
Peer []byte `protobuf:"bytes,2,opt,name=peer,proto3" json:"peer,omitempty"` // will be removed: do not use
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
Address string `protobuf:"bytes,3,opt,name=address,proto3" json:"address,omitempty"`
// only for PEER_IPV4 and PEER_IPV6
//
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
IpPort uint32 `protobuf:"varint,4,opt,name=ip_port,json=ipPort,proto3" json:"ip_port,omitempty"`
// contains filtered or unexported fields
}
Peer information
func (*Peer) GetPeerType
deprecated
func (x *Peer) GetPeerType() Peer_PeerType
Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
func (*Peer) ProtoReflect ¶
func (x *Peer) ProtoReflect() protoreflect.Message
func (*Peer) SetPeerType
deprecated
func (x *Peer) SetPeerType(v Peer_PeerType)
Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
type Peer_PeerType ¶
type Peer_PeerType int32
const ( Peer_UNKNOWN_PEERTYPE Peer_PeerType = 0 // address is the address in 1.2.3.4 form Peer_PEER_IPV4 Peer_PeerType = 1 // address the address in canonical form (RFC5952 section 4) // The scope is NOT included in the peer string. Peer_PEER_IPV6 Peer_PeerType = 2 // address is UDS string Peer_PEER_UNIX Peer_PeerType = 3 )
func (Peer_PeerType) Descriptor ¶
func (Peer_PeerType) Descriptor() protoreflect.EnumDescriptor
func (Peer_PeerType) Enum ¶
func (x Peer_PeerType) Enum() *Peer_PeerType
func (Peer_PeerType) Number ¶
func (x Peer_PeerType) Number() protoreflect.EnumNumber
func (Peer_PeerType) String ¶
func (x Peer_PeerType) String() string
func (Peer_PeerType) Type ¶
func (Peer_PeerType) Type() protoreflect.EnumType
type Peer_builder ¶
type Peer_builder struct {
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
PeerType Peer_PeerType
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
Peer []byte
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
Address string
// only for PEER_IPV4 and PEER_IPV6
//
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
IpPort uint32
// contains filtered or unexported fields
}
func (Peer_builder) Build ¶
func (b0 Peer_builder) Build() *Peer
type Uint128 ¶
type Uint128 struct {
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
High uint64 `protobuf:"fixed64,1,opt,name=high,proto3" json:"high,omitempty"`
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
Low uint64 `protobuf:"fixed64,2,opt,name=low,proto3" json:"low,omitempty"`
// contains filtered or unexported fields
}
Used to record call_id.
func (*Uint128) ProtoReflect ¶
func (x *Uint128) ProtoReflect() protoreflect.Message
type Uint128_builder ¶
type Uint128_builder struct {
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
High uint64
// Deprecated: Marked as deprecated in grpc/binlog/v1alpha/binarylog.proto.
Low uint64
// contains filtered or unexported fields
}
func (Uint128_builder) Build ¶
func (b0 Uint128_builder) Build() *Uint128
Source Files
¶
- binarylog.pb.go