gcp

package
v1.36.11-2026020320145... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 4 Imported by: 3

Documentation

Index

Constants

const HandshakerReq_ClientStart_case case_HandshakerReq_ReqOneof = 1
const HandshakerReq_Next_case case_HandshakerReq_ReqOneof = 3
const HandshakerReq_ReqOneof_not_set_case case_HandshakerReq_ReqOneof = 0
const HandshakerReq_ServerStart_case case_HandshakerReq_ReqOneof = 2
const Identity_Hostname_case case_Identity_IdentityOneof = 2
const Identity_IdentityOneof_not_set_case case_Identity_IdentityOneof = 0
const Identity_ServiceAccount_case case_Identity_IdentityOneof = 1

Variables

var (
	HandshakeProtocol_name = map[int32]string{
		0: "HANDSHAKE_PROTOCOL_UNSPECIFIED",
		1: "TLS",
		2: "ALTS",
	}
	HandshakeProtocol_value = map[string]int32{
		"HANDSHAKE_PROTOCOL_UNSPECIFIED": 0,
		"TLS":                            1,
		"ALTS":                           2,
	}
)

Enum value maps for HandshakeProtocol.

var (
	NetworkProtocol_name = map[int32]string{
		0: "NETWORK_PROTOCOL_UNSPECIFIED",
		1: "TCP",
		2: "UDP",
	}
	NetworkProtocol_value = map[string]int32{
		"NETWORK_PROTOCOL_UNSPECIFIED": 0,
		"TCP":                          1,
		"UDP":                          2,
	}
)

Enum value maps for NetworkProtocol.

var (
	SecurityLevel_name = map[int32]string{
		0: "SECURITY_NONE",
		1: "INTEGRITY_ONLY",
		2: "INTEGRITY_AND_PRIVACY",
	}
	SecurityLevel_value = map[string]int32{
		"SECURITY_NONE":         0,
		"INTEGRITY_ONLY":        1,
		"INTEGRITY_AND_PRIVACY": 2,
	}
)

Enum value maps for SecurityLevel.

var File_grpc_gcp_altscontext_proto protoreflect.FileDescriptor
var File_grpc_gcp_handshaker_proto protoreflect.FileDescriptor
var File_grpc_gcp_transport_security_common_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type AltsContext

type AltsContext struct {

	// The application protocol negotiated for this connection.
	ApplicationProtocol string `protobuf:"bytes,1,opt,name=application_protocol,json=applicationProtocol,proto3" json:"application_protocol,omitempty"`
	// The record protocol negotiated for this connection.
	RecordProtocol string `protobuf:"bytes,2,opt,name=record_protocol,json=recordProtocol,proto3" json:"record_protocol,omitempty"`
	// The security level of the created secure channel.
	SecurityLevel SecurityLevel `` /* 129-byte string literal not displayed */
	// The peer service account.
	PeerServiceAccount string `protobuf:"bytes,4,opt,name=peer_service_account,json=peerServiceAccount,proto3" json:"peer_service_account,omitempty"`
	// The local service account.
	LocalServiceAccount string `protobuf:"bytes,5,opt,name=local_service_account,json=localServiceAccount,proto3" json:"local_service_account,omitempty"`
	// The RPC protocol versions supported by the peer.
	PeerRpcVersions *RpcProtocolVersions `protobuf:"bytes,6,opt,name=peer_rpc_versions,json=peerRpcVersions,proto3" json:"peer_rpc_versions,omitempty"`
	// Additional attributes of the peer.
	PeerAttributes map[string]string `` /* 177-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*AltsContext) ClearPeerRpcVersions

func (x *AltsContext) ClearPeerRpcVersions()

func (*AltsContext) GetApplicationProtocol

func (x *AltsContext) GetApplicationProtocol() string

func (*AltsContext) GetLocalServiceAccount

func (x *AltsContext) GetLocalServiceAccount() string

func (*AltsContext) GetPeerAttributes

func (x *AltsContext) GetPeerAttributes() map[string]string

func (*AltsContext) GetPeerRpcVersions

func (x *AltsContext) GetPeerRpcVersions() *RpcProtocolVersions

func (*AltsContext) GetPeerServiceAccount

func (x *AltsContext) GetPeerServiceAccount() string

func (*AltsContext) GetRecordProtocol

func (x *AltsContext) GetRecordProtocol() string

func (*AltsContext) GetSecurityLevel

func (x *AltsContext) GetSecurityLevel() SecurityLevel

func (*AltsContext) HasPeerRpcVersions

func (x *AltsContext) HasPeerRpcVersions() bool

func (*AltsContext) ProtoMessage

func (*AltsContext) ProtoMessage()

func (*AltsContext) ProtoReflect

func (x *AltsContext) ProtoReflect() protoreflect.Message

func (*AltsContext) Reset

func (x *AltsContext) Reset()

func (*AltsContext) SetApplicationProtocol

func (x *AltsContext) SetApplicationProtocol(v string)

func (*AltsContext) SetLocalServiceAccount

func (x *AltsContext) SetLocalServiceAccount(v string)

func (*AltsContext) SetPeerAttributes

func (x *AltsContext) SetPeerAttributes(v map[string]string)

func (*AltsContext) SetPeerRpcVersions

func (x *AltsContext) SetPeerRpcVersions(v *RpcProtocolVersions)

func (*AltsContext) SetPeerServiceAccount

func (x *AltsContext) SetPeerServiceAccount(v string)

func (*AltsContext) SetRecordProtocol

func (x *AltsContext) SetRecordProtocol(v string)

func (*AltsContext) SetSecurityLevel

func (x *AltsContext) SetSecurityLevel(v SecurityLevel)

func (*AltsContext) String

func (x *AltsContext) String() string

type AltsContext_builder

type AltsContext_builder struct {

	// The application protocol negotiated for this connection.
	ApplicationProtocol string
	// The record protocol negotiated for this connection.
	RecordProtocol string
	// The security level of the created secure channel.
	SecurityLevel SecurityLevel
	// The peer service account.
	PeerServiceAccount string
	// The local service account.
	LocalServiceAccount string
	// The RPC protocol versions supported by the peer.
	PeerRpcVersions *RpcProtocolVersions
	// Additional attributes of the peer.
	PeerAttributes map[string]string
	// contains filtered or unexported fields
}

func (AltsContext_builder) Build

func (b0 AltsContext_builder) Build() *AltsContext

type Endpoint

type Endpoint struct {

	// IP address. It should contain an IPv4 or IPv6 string literal, e.g.
	// "192.168.0.1" or "2001:db8::1".
	IpAddress string `protobuf:"bytes,1,opt,name=ip_address,json=ipAddress,proto3" json:"ip_address,omitempty"`
	// Port number.
	Port int32 `protobuf:"varint,2,opt,name=port,proto3" json:"port,omitempty"`
	// Network protocol (e.g., TCP, UDP) associated with this endpoint.
	Protocol NetworkProtocol `protobuf:"varint,3,opt,name=protocol,proto3,enum=grpc.gcp.NetworkProtocol" json:"protocol,omitempty"`
	// contains filtered or unexported fields
}

func (*Endpoint) GetIpAddress

func (x *Endpoint) GetIpAddress() string

func (*Endpoint) GetPort

func (x *Endpoint) GetPort() int32

func (*Endpoint) GetProtocol

func (x *Endpoint) GetProtocol() NetworkProtocol

func (*Endpoint) ProtoMessage

func (*Endpoint) ProtoMessage()

func (*Endpoint) ProtoReflect

func (x *Endpoint) ProtoReflect() protoreflect.Message

func (*Endpoint) Reset

func (x *Endpoint) Reset()

func (*Endpoint) SetIpAddress

func (x *Endpoint) SetIpAddress(v string)

func (*Endpoint) SetPort

func (x *Endpoint) SetPort(v int32)

func (*Endpoint) SetProtocol

func (x *Endpoint) SetProtocol(v NetworkProtocol)

func (*Endpoint) String

func (x *Endpoint) String() string

type Endpoint_builder

type Endpoint_builder struct {

	// IP address. It should contain an IPv4 or IPv6 string literal, e.g.
	// "192.168.0.1" or "2001:db8::1".
	IpAddress string
	// Port number.
	Port int32
	// Network protocol (e.g., TCP, UDP) associated with this endpoint.
	Protocol NetworkProtocol
	// contains filtered or unexported fields
}

func (Endpoint_builder) Build

func (b0 Endpoint_builder) Build() *Endpoint

type HandshakeProtocol

type HandshakeProtocol int32
const (
	// Default value.
	HandshakeProtocol_HANDSHAKE_PROTOCOL_UNSPECIFIED HandshakeProtocol = 0
	// TLS handshake protocol.
	HandshakeProtocol_TLS HandshakeProtocol = 1
	// Application Layer Transport Security handshake protocol.
	HandshakeProtocol_ALTS HandshakeProtocol = 2
)

func (HandshakeProtocol) Descriptor

func (HandshakeProtocol) Enum

func (HandshakeProtocol) Number

func (HandshakeProtocol) String

func (x HandshakeProtocol) String() string

func (HandshakeProtocol) Type

type HandshakerReq

type HandshakerReq struct {

	// Types that are valid to be assigned to ReqOneof:
	//
	//	*HandshakerReq_ClientStart
	//	*HandshakerReq_ServerStart
	//	*HandshakerReq_Next
	ReqOneof isHandshakerReq_ReqOneof `protobuf_oneof:"req_oneof"`
	// contains filtered or unexported fields
}

func (*HandshakerReq) ClearClientStart

func (x *HandshakerReq) ClearClientStart()

func (*HandshakerReq) ClearNext

func (x *HandshakerReq) ClearNext()

func (*HandshakerReq) ClearReqOneof

func (x *HandshakerReq) ClearReqOneof()

func (*HandshakerReq) ClearServerStart

func (x *HandshakerReq) ClearServerStart()

func (*HandshakerReq) GetClientStart

func (x *HandshakerReq) GetClientStart() *StartClientHandshakeReq

func (*HandshakerReq) GetNext

func (x *HandshakerReq) GetNext() *NextHandshakeMessageReq

func (*HandshakerReq) GetReqOneof

func (x *HandshakerReq) GetReqOneof() isHandshakerReq_ReqOneof

func (*HandshakerReq) GetServerStart

func (x *HandshakerReq) GetServerStart() *StartServerHandshakeReq

func (*HandshakerReq) HasClientStart

func (x *HandshakerReq) HasClientStart() bool

func (*HandshakerReq) HasNext

func (x *HandshakerReq) HasNext() bool

func (*HandshakerReq) HasReqOneof

func (x *HandshakerReq) HasReqOneof() bool

func (*HandshakerReq) HasServerStart

func (x *HandshakerReq) HasServerStart() bool

func (*HandshakerReq) ProtoMessage

func (*HandshakerReq) ProtoMessage()

func (*HandshakerReq) ProtoReflect

func (x *HandshakerReq) ProtoReflect() protoreflect.Message

func (*HandshakerReq) Reset

func (x *HandshakerReq) Reset()

func (*HandshakerReq) SetClientStart

func (x *HandshakerReq) SetClientStart(v *StartClientHandshakeReq)

func (*HandshakerReq) SetNext

func (x *HandshakerReq) SetNext(v *NextHandshakeMessageReq)

func (*HandshakerReq) SetServerStart

func (x *HandshakerReq) SetServerStart(v *StartServerHandshakeReq)

func (*HandshakerReq) String

func (x *HandshakerReq) String() string

func (*HandshakerReq) WhichReqOneof

func (x *HandshakerReq) WhichReqOneof() case_HandshakerReq_ReqOneof

type HandshakerReq_ClientStart

type HandshakerReq_ClientStart struct {
	// The start client handshake request message.
	ClientStart *StartClientHandshakeReq `protobuf:"bytes,1,opt,name=client_start,json=clientStart,proto3,oneof"`
}

type HandshakerReq_Next

type HandshakerReq_Next struct {
	// The next handshake request message.
	Next *NextHandshakeMessageReq `protobuf:"bytes,3,opt,name=next,proto3,oneof"`
}

type HandshakerReq_ServerStart

type HandshakerReq_ServerStart struct {
	// The start server handshake request message.
	ServerStart *StartServerHandshakeReq `protobuf:"bytes,2,opt,name=server_start,json=serverStart,proto3,oneof"`
}

type HandshakerReq_builder

type HandshakerReq_builder struct {

	// Fields of oneof ReqOneof:
	// The start client handshake request message.
	ClientStart *StartClientHandshakeReq
	// The start server handshake request message.
	ServerStart *StartServerHandshakeReq
	// The next handshake request message.
	Next *NextHandshakeMessageReq
	// contains filtered or unexported fields
}

func (HandshakerReq_builder) Build

type HandshakerResp

type HandshakerResp struct {

	// Frames to be given to the peer for the NextHandshakeMessageReq. May be
	// empty if no out_frames have to be sent to the peer or if in_bytes in the
	// HandshakerReq are incomplete. All the non-empty out frames must be sent to
	// the peer even if the handshaker status is not OK as these frames may
	// contain the alert frames.
	OutFrames []byte `protobuf:"bytes,1,opt,name=out_frames,json=outFrames,proto3" json:"out_frames,omitempty"`
	// Number of bytes in the in_bytes consumed by the handshaker. It is possible
	// that part of in_bytes in HandshakerReq was unrelated to the handshake
	// process.
	BytesConsumed uint32 `protobuf:"varint,2,opt,name=bytes_consumed,json=bytesConsumed,proto3" json:"bytes_consumed,omitempty"`
	// This is set iff the handshake was successful. out_frames may still be set
	// to frames that needs to be forwarded to the peer.
	Result *HandshakerResult `protobuf:"bytes,3,opt,name=result,proto3" json:"result,omitempty"`
	// Status of the handshaker.
	Status *HandshakerStatus `protobuf:"bytes,4,opt,name=status,proto3" json:"status,omitempty"`
	// contains filtered or unexported fields
}

func (*HandshakerResp) ClearResult

func (x *HandshakerResp) ClearResult()

func (*HandshakerResp) ClearStatus

func (x *HandshakerResp) ClearStatus()

func (*HandshakerResp) GetBytesConsumed

func (x *HandshakerResp) GetBytesConsumed() uint32

func (*HandshakerResp) GetOutFrames

func (x *HandshakerResp) GetOutFrames() []byte

func (*HandshakerResp) GetResult

func (x *HandshakerResp) GetResult() *HandshakerResult

func (*HandshakerResp) GetStatus

func (x *HandshakerResp) GetStatus() *HandshakerStatus

func (*HandshakerResp) HasResult

func (x *HandshakerResp) HasResult() bool

func (*HandshakerResp) HasStatus

func (x *HandshakerResp) HasStatus() bool

func (*HandshakerResp) ProtoMessage

func (*HandshakerResp) ProtoMessage()

func (*HandshakerResp) ProtoReflect

func (x *HandshakerResp) ProtoReflect() protoreflect.Message

func (*HandshakerResp) Reset

func (x *HandshakerResp) Reset()

func (*HandshakerResp) SetBytesConsumed

func (x *HandshakerResp) SetBytesConsumed(v uint32)

func (*HandshakerResp) SetOutFrames

func (x *HandshakerResp) SetOutFrames(v []byte)

func (*HandshakerResp) SetResult

func (x *HandshakerResp) SetResult(v *HandshakerResult)

func (*HandshakerResp) SetStatus

func (x *HandshakerResp) SetStatus(v *HandshakerStatus)

func (*HandshakerResp) String

func (x *HandshakerResp) String() string

type HandshakerResp_builder

type HandshakerResp_builder struct {

	// Frames to be given to the peer for the NextHandshakeMessageReq. May be
	// empty if no out_frames have to be sent to the peer or if in_bytes in the
	// HandshakerReq are incomplete. All the non-empty out frames must be sent to
	// the peer even if the handshaker status is not OK as these frames may
	// contain the alert frames.
	OutFrames []byte
	// Number of bytes in the in_bytes consumed by the handshaker. It is possible
	// that part of in_bytes in HandshakerReq was unrelated to the handshake
	// process.
	BytesConsumed uint32
	// This is set iff the handshake was successful. out_frames may still be set
	// to frames that needs to be forwarded to the peer.
	Result *HandshakerResult
	// Status of the handshaker.
	Status *HandshakerStatus
	// contains filtered or unexported fields
}

func (HandshakerResp_builder) Build

type HandshakerResult

type HandshakerResult struct {

	// The application protocol negotiated for this connection.
	ApplicationProtocol string `protobuf:"bytes,1,opt,name=application_protocol,json=applicationProtocol,proto3" json:"application_protocol,omitempty"`
	// The record protocol negotiated for this connection.
	RecordProtocol string `protobuf:"bytes,2,opt,name=record_protocol,json=recordProtocol,proto3" json:"record_protocol,omitempty"`
	// Cryptographic key data. The key data may be more than the key length
	// required for the record protocol, thus the client of the handshaker
	// service needs to truncate the key data into the right key length.
	KeyData []byte `protobuf:"bytes,3,opt,name=key_data,json=keyData,proto3" json:"key_data,omitempty"`
	// The authenticated identity of the peer.
	PeerIdentity *Identity `protobuf:"bytes,4,opt,name=peer_identity,json=peerIdentity,proto3" json:"peer_identity,omitempty"`
	// The local identity used in the handshake.
	LocalIdentity *Identity `protobuf:"bytes,5,opt,name=local_identity,json=localIdentity,proto3" json:"local_identity,omitempty"`
	// Indicate whether the handshaker service client should keep the channel
	// between the handshaker service open, e.g., in order to handle
	// post-handshake messages in the future.
	KeepChannelOpen bool `protobuf:"varint,6,opt,name=keep_channel_open,json=keepChannelOpen,proto3" json:"keep_channel_open,omitempty"`
	// The RPC protocol versions supported by the peer.
	PeerRpcVersions *RpcProtocolVersions `protobuf:"bytes,7,opt,name=peer_rpc_versions,json=peerRpcVersions,proto3" json:"peer_rpc_versions,omitempty"`
	// The maximum frame size of the peer.
	MaxFrameSize uint32 `protobuf:"varint,8,opt,name=max_frame_size,json=maxFrameSize,proto3" json:"max_frame_size,omitempty"`
	// (Optional) The transport protocol negotiated for this connection.
	TransportProtocol *NegotiatedTransportProtocol `protobuf:"bytes,9,opt,name=transport_protocol,json=transportProtocol,proto3" json:"transport_protocol,omitempty"`
	// contains filtered or unexported fields
}

func (*HandshakerResult) ClearLocalIdentity

func (x *HandshakerResult) ClearLocalIdentity()

func (*HandshakerResult) ClearPeerIdentity

func (x *HandshakerResult) ClearPeerIdentity()

func (*HandshakerResult) ClearPeerRpcVersions

func (x *HandshakerResult) ClearPeerRpcVersions()

func (*HandshakerResult) ClearTransportProtocol

func (x *HandshakerResult) ClearTransportProtocol()

func (*HandshakerResult) GetApplicationProtocol

func (x *HandshakerResult) GetApplicationProtocol() string

func (*HandshakerResult) GetKeepChannelOpen

func (x *HandshakerResult) GetKeepChannelOpen() bool

func (*HandshakerResult) GetKeyData

func (x *HandshakerResult) GetKeyData() []byte

func (*HandshakerResult) GetLocalIdentity

func (x *HandshakerResult) GetLocalIdentity() *Identity

func (*HandshakerResult) GetMaxFrameSize

func (x *HandshakerResult) GetMaxFrameSize() uint32

func (*HandshakerResult) GetPeerIdentity

func (x *HandshakerResult) GetPeerIdentity() *Identity

func (*HandshakerResult) GetPeerRpcVersions

func (x *HandshakerResult) GetPeerRpcVersions() *RpcProtocolVersions

func (*HandshakerResult) GetRecordProtocol

func (x *HandshakerResult) GetRecordProtocol() string

func (*HandshakerResult) GetTransportProtocol

func (x *HandshakerResult) GetTransportProtocol() *NegotiatedTransportProtocol

func (*HandshakerResult) HasLocalIdentity

func (x *HandshakerResult) HasLocalIdentity() bool

func (*HandshakerResult) HasPeerIdentity

func (x *HandshakerResult) HasPeerIdentity() bool

func (*HandshakerResult) HasPeerRpcVersions

func (x *HandshakerResult) HasPeerRpcVersions() bool

func (*HandshakerResult) HasTransportProtocol

func (x *HandshakerResult) HasTransportProtocol() bool

func (*HandshakerResult) ProtoMessage

func (*HandshakerResult) ProtoMessage()

func (*HandshakerResult) ProtoReflect

func (x *HandshakerResult) ProtoReflect() protoreflect.Message

func (*HandshakerResult) Reset

func (x *HandshakerResult) Reset()

func (*HandshakerResult) SetApplicationProtocol

func (x *HandshakerResult) SetApplicationProtocol(v string)

func (*HandshakerResult) SetKeepChannelOpen

func (x *HandshakerResult) SetKeepChannelOpen(v bool)

func (*HandshakerResult) SetKeyData

func (x *HandshakerResult) SetKeyData(v []byte)

func (*HandshakerResult) SetLocalIdentity

func (x *HandshakerResult) SetLocalIdentity(v *Identity)

func (*HandshakerResult) SetMaxFrameSize

func (x *HandshakerResult) SetMaxFrameSize(v uint32)

func (*HandshakerResult) SetPeerIdentity

func (x *HandshakerResult) SetPeerIdentity(v *Identity)

func (*HandshakerResult) SetPeerRpcVersions

func (x *HandshakerResult) SetPeerRpcVersions(v *RpcProtocolVersions)

func (*HandshakerResult) SetRecordProtocol

func (x *HandshakerResult) SetRecordProtocol(v string)

func (*HandshakerResult) SetTransportProtocol

func (x *HandshakerResult) SetTransportProtocol(v *NegotiatedTransportProtocol)

func (*HandshakerResult) String

func (x *HandshakerResult) String() string

type HandshakerResult_builder

type HandshakerResult_builder struct {

	// The application protocol negotiated for this connection.
	ApplicationProtocol string
	// The record protocol negotiated for this connection.
	RecordProtocol string
	// Cryptographic key data. The key data may be more than the key length
	// required for the record protocol, thus the client of the handshaker
	// service needs to truncate the key data into the right key length.
	KeyData []byte
	// The authenticated identity of the peer.
	PeerIdentity *Identity
	// The local identity used in the handshake.
	LocalIdentity *Identity
	// Indicate whether the handshaker service client should keep the channel
	// between the handshaker service open, e.g., in order to handle
	// post-handshake messages in the future.
	KeepChannelOpen bool
	// The RPC protocol versions supported by the peer.
	PeerRpcVersions *RpcProtocolVersions
	// The maximum frame size of the peer.
	MaxFrameSize uint32
	// (Optional) The transport protocol negotiated for this connection.
	TransportProtocol *NegotiatedTransportProtocol
	// contains filtered or unexported fields
}

func (HandshakerResult_builder) Build

type HandshakerStatus

type HandshakerStatus struct {

	// The status code. This could be the gRPC status code.
	Code uint32 `protobuf:"varint,1,opt,name=code,proto3" json:"code,omitempty"`
	// The status details.
	Details string `protobuf:"bytes,2,opt,name=details,proto3" json:"details,omitempty"`
	// contains filtered or unexported fields
}

func (*HandshakerStatus) GetCode

func (x *HandshakerStatus) GetCode() uint32

func (*HandshakerStatus) GetDetails

func (x *HandshakerStatus) GetDetails() string

func (*HandshakerStatus) ProtoMessage

func (*HandshakerStatus) ProtoMessage()

func (*HandshakerStatus) ProtoReflect

func (x *HandshakerStatus) ProtoReflect() protoreflect.Message

func (*HandshakerStatus) Reset

func (x *HandshakerStatus) Reset()

func (*HandshakerStatus) SetCode

func (x *HandshakerStatus) SetCode(v uint32)

func (*HandshakerStatus) SetDetails

func (x *HandshakerStatus) SetDetails(v string)

func (*HandshakerStatus) String

func (x *HandshakerStatus) String() string

type HandshakerStatus_builder

type HandshakerStatus_builder struct {

	// The status code. This could be the gRPC status code.
	Code uint32
	// The status details.
	Details string
	// contains filtered or unexported fields
}

func (HandshakerStatus_builder) Build

type Identity

type Identity struct {

	// Types that are valid to be assigned to IdentityOneof:
	//
	//	*Identity_ServiceAccount
	//	*Identity_Hostname
	IdentityOneof isIdentity_IdentityOneof `protobuf_oneof:"identity_oneof"`
	// Additional attributes of the identity.
	Attributes map[string]string `` /* 147-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*Identity) ClearHostname

func (x *Identity) ClearHostname()

func (*Identity) ClearIdentityOneof

func (x *Identity) ClearIdentityOneof()

func (*Identity) ClearServiceAccount

func (x *Identity) ClearServiceAccount()

func (*Identity) GetAttributes

func (x *Identity) GetAttributes() map[string]string

func (*Identity) GetHostname

func (x *Identity) GetHostname() string

func (*Identity) GetIdentityOneof

func (x *Identity) GetIdentityOneof() isIdentity_IdentityOneof

func (*Identity) GetServiceAccount

func (x *Identity) GetServiceAccount() string

func (*Identity) HasHostname

func (x *Identity) HasHostname() bool

func (*Identity) HasIdentityOneof

func (x *Identity) HasIdentityOneof() bool

func (*Identity) HasServiceAccount

func (x *Identity) HasServiceAccount() bool

func (*Identity) ProtoMessage

func (*Identity) ProtoMessage()

func (*Identity) ProtoReflect

func (x *Identity) ProtoReflect() protoreflect.Message

func (*Identity) Reset

func (x *Identity) Reset()

func (*Identity) SetAttributes

func (x *Identity) SetAttributes(v map[string]string)

func (*Identity) SetHostname

func (x *Identity) SetHostname(v string)

func (*Identity) SetServiceAccount

func (x *Identity) SetServiceAccount(v string)

func (*Identity) String

func (x *Identity) String() string

func (*Identity) WhichIdentityOneof

func (x *Identity) WhichIdentityOneof() case_Identity_IdentityOneof

type Identity_Hostname

type Identity_Hostname struct {
	// Hostname of a connection endpoint.
	Hostname string `protobuf:"bytes,2,opt,name=hostname,proto3,oneof"`
}

type Identity_ServiceAccount

type Identity_ServiceAccount struct {
	// Service account of a connection endpoint.
	ServiceAccount string `protobuf:"bytes,1,opt,name=service_account,json=serviceAccount,proto3,oneof"`
}

type Identity_builder

type Identity_builder struct {

	// Fields of oneof IdentityOneof:
	// Service account of a connection endpoint.
	ServiceAccount *string
	// Hostname of a connection endpoint.
	Hostname *string
	// -- end of IdentityOneof
	// Additional attributes of the identity.
	Attributes map[string]string
	// contains filtered or unexported fields
}

func (Identity_builder) Build

func (b0 Identity_builder) Build() *Identity

type NegotiatedTransportProtocol

type NegotiatedTransportProtocol struct {
	TransportProtocol string `protobuf:"bytes,1,opt,name=transport_protocol,json=transportProtocol,proto3" json:"transport_protocol,omitempty"`
	// contains filtered or unexported fields
}

The negotiated transport protocol.

func (*NegotiatedTransportProtocol) GetTransportProtocol

func (x *NegotiatedTransportProtocol) GetTransportProtocol() string

func (*NegotiatedTransportProtocol) ProtoMessage

func (*NegotiatedTransportProtocol) ProtoMessage()

func (*NegotiatedTransportProtocol) ProtoReflect

func (*NegotiatedTransportProtocol) Reset

func (x *NegotiatedTransportProtocol) Reset()

func (*NegotiatedTransportProtocol) SetTransportProtocol

func (x *NegotiatedTransportProtocol) SetTransportProtocol(v string)

func (*NegotiatedTransportProtocol) String

func (x *NegotiatedTransportProtocol) String() string

type NegotiatedTransportProtocol_builder

type NegotiatedTransportProtocol_builder struct {
	TransportProtocol string
	// contains filtered or unexported fields
}

func (NegotiatedTransportProtocol_builder) Build

type NetworkProtocol

type NetworkProtocol int32
const (
	NetworkProtocol_NETWORK_PROTOCOL_UNSPECIFIED NetworkProtocol = 0
	NetworkProtocol_TCP                          NetworkProtocol = 1
	NetworkProtocol_UDP                          NetworkProtocol = 2
)

func (NetworkProtocol) Descriptor

func (NetworkProtocol) Enum

func (x NetworkProtocol) Enum() *NetworkProtocol

func (NetworkProtocol) Number

func (NetworkProtocol) String

func (x NetworkProtocol) String() string

func (NetworkProtocol) Type

type NextHandshakeMessageReq

type NextHandshakeMessageReq struct {

	// Bytes in out_frames returned from the peer's HandshakerResp. It is possible
	// that the peer's out_frames are split into multiple NextHandshakerMessageReq
	// messages.
	InBytes []byte `protobuf:"bytes,1,opt,name=in_bytes,json=inBytes,proto3" json:"in_bytes,omitempty"`
	// Number of milliseconds between when the application send the last handshake
	// message to the peer and when the application received the current handshake
	// message (in the in_bytes field) from the peer.
	NetworkLatencyMs uint32 `protobuf:"varint,2,opt,name=network_latency_ms,json=networkLatencyMs,proto3" json:"network_latency_ms,omitempty"`
	// contains filtered or unexported fields
}

func (*NextHandshakeMessageReq) GetInBytes

func (x *NextHandshakeMessageReq) GetInBytes() []byte

func (*NextHandshakeMessageReq) GetNetworkLatencyMs

func (x *NextHandshakeMessageReq) GetNetworkLatencyMs() uint32

func (*NextHandshakeMessageReq) ProtoMessage

func (*NextHandshakeMessageReq) ProtoMessage()

func (*NextHandshakeMessageReq) ProtoReflect

func (x *NextHandshakeMessageReq) ProtoReflect() protoreflect.Message

func (*NextHandshakeMessageReq) Reset

func (x *NextHandshakeMessageReq) Reset()

func (*NextHandshakeMessageReq) SetInBytes

func (x *NextHandshakeMessageReq) SetInBytes(v []byte)

func (*NextHandshakeMessageReq) SetNetworkLatencyMs

func (x *NextHandshakeMessageReq) SetNetworkLatencyMs(v uint32)

func (*NextHandshakeMessageReq) String

func (x *NextHandshakeMessageReq) String() string

type NextHandshakeMessageReq_builder

type NextHandshakeMessageReq_builder struct {

	// Bytes in out_frames returned from the peer's HandshakerResp. It is possible
	// that the peer's out_frames are split into multiple NextHandshakerMessageReq
	// messages.
	InBytes []byte
	// Number of milliseconds between when the application send the last handshake
	// message to the peer and when the application received the current handshake
	// message (in the in_bytes field) from the peer.
	NetworkLatencyMs uint32
	// contains filtered or unexported fields
}

func (NextHandshakeMessageReq_builder) Build

type RpcProtocolVersions

type RpcProtocolVersions struct {

	// Maximum supported RPC version.
	MaxRpcVersion *RpcProtocolVersions_Version `protobuf:"bytes,1,opt,name=max_rpc_version,json=maxRpcVersion,proto3" json:"max_rpc_version,omitempty"`
	// Minimum supported RPC version.
	MinRpcVersion *RpcProtocolVersions_Version `protobuf:"bytes,2,opt,name=min_rpc_version,json=minRpcVersion,proto3" json:"min_rpc_version,omitempty"`
	// contains filtered or unexported fields
}

Max and min supported RPC protocol versions.

func (*RpcProtocolVersions) ClearMaxRpcVersion

func (x *RpcProtocolVersions) ClearMaxRpcVersion()

func (*RpcProtocolVersions) ClearMinRpcVersion

func (x *RpcProtocolVersions) ClearMinRpcVersion()

func (*RpcProtocolVersions) GetMaxRpcVersion

func (x *RpcProtocolVersions) GetMaxRpcVersion() *RpcProtocolVersions_Version

func (*RpcProtocolVersions) GetMinRpcVersion

func (x *RpcProtocolVersions) GetMinRpcVersion() *RpcProtocolVersions_Version

func (*RpcProtocolVersions) HasMaxRpcVersion

func (x *RpcProtocolVersions) HasMaxRpcVersion() bool

func (*RpcProtocolVersions) HasMinRpcVersion

func (x *RpcProtocolVersions) HasMinRpcVersion() bool

func (*RpcProtocolVersions) ProtoMessage

func (*RpcProtocolVersions) ProtoMessage()

func (*RpcProtocolVersions) ProtoReflect

func (x *RpcProtocolVersions) ProtoReflect() protoreflect.Message

func (*RpcProtocolVersions) Reset

func (x *RpcProtocolVersions) Reset()

func (*RpcProtocolVersions) SetMaxRpcVersion

func (x *RpcProtocolVersions) SetMaxRpcVersion(v *RpcProtocolVersions_Version)

func (*RpcProtocolVersions) SetMinRpcVersion

func (x *RpcProtocolVersions) SetMinRpcVersion(v *RpcProtocolVersions_Version)

func (*RpcProtocolVersions) String

func (x *RpcProtocolVersions) String() string

type RpcProtocolVersions_Version

type RpcProtocolVersions_Version struct {
	Major uint32 `protobuf:"varint,1,opt,name=major,proto3" json:"major,omitempty"`
	Minor uint32 `protobuf:"varint,2,opt,name=minor,proto3" json:"minor,omitempty"`
	// contains filtered or unexported fields
}

RPC version contains a major version and a minor version.

func (*RpcProtocolVersions_Version) GetMajor

func (x *RpcProtocolVersions_Version) GetMajor() uint32

func (*RpcProtocolVersions_Version) GetMinor

func (x *RpcProtocolVersions_Version) GetMinor() uint32

func (*RpcProtocolVersions_Version) ProtoMessage

func (*RpcProtocolVersions_Version) ProtoMessage()

func (*RpcProtocolVersions_Version) ProtoReflect

func (*RpcProtocolVersions_Version) Reset

func (x *RpcProtocolVersions_Version) Reset()

func (*RpcProtocolVersions_Version) SetMajor

func (x *RpcProtocolVersions_Version) SetMajor(v uint32)

func (*RpcProtocolVersions_Version) SetMinor

func (x *RpcProtocolVersions_Version) SetMinor(v uint32)

func (*RpcProtocolVersions_Version) String

func (x *RpcProtocolVersions_Version) String() string

type RpcProtocolVersions_Version_builder

type RpcProtocolVersions_Version_builder struct {
	Major uint32
	Minor uint32
	// contains filtered or unexported fields
}

func (RpcProtocolVersions_Version_builder) Build

type RpcProtocolVersions_builder

type RpcProtocolVersions_builder struct {

	// Maximum supported RPC version.
	MaxRpcVersion *RpcProtocolVersions_Version
	// Minimum supported RPC version.
	MinRpcVersion *RpcProtocolVersions_Version
	// contains filtered or unexported fields
}

func (RpcProtocolVersions_builder) Build

type SecurityLevel

type SecurityLevel int32

The security level of the created channel. The list is sorted in increasing level of security. This order must always be maintained.

const (
	SecurityLevel_SECURITY_NONE         SecurityLevel = 0
	SecurityLevel_INTEGRITY_ONLY        SecurityLevel = 1
	SecurityLevel_INTEGRITY_AND_PRIVACY SecurityLevel = 2
)

func (SecurityLevel) Descriptor

func (SecurityLevel) Enum

func (x SecurityLevel) Enum() *SecurityLevel

func (SecurityLevel) Number

func (SecurityLevel) String

func (x SecurityLevel) String() string

func (SecurityLevel) Type

type ServerHandshakeParameters

type ServerHandshakeParameters struct {

	// The record protocols supported by the server, e.g.,
	// "ALTSRP_GCM_AES128".
	RecordProtocols []string `protobuf:"bytes,1,rep,name=record_protocols,json=recordProtocols,proto3" json:"record_protocols,omitempty"`
	// (Optional) A list of local identities supported by the server, if
	// specified. Otherwise, the handshaker chooses a default local identity.
	LocalIdentities []*Identity `protobuf:"bytes,2,rep,name=local_identities,json=localIdentities,proto3" json:"local_identities,omitempty"`
	// A token created by the caller only intended for use in
	// ALTS connections. The token should be used to authenticate to
	// the peer. The token MUST be strongly bound to the ALTS credentials
	// used to establish the connection that the token is sent over.
	Token *string `protobuf:"bytes,3,opt,name=token,proto3,oneof" json:"token,omitempty"`
	// contains filtered or unexported fields
}

func (*ServerHandshakeParameters) ClearToken

func (x *ServerHandshakeParameters) ClearToken()

func (*ServerHandshakeParameters) GetLocalIdentities

func (x *ServerHandshakeParameters) GetLocalIdentities() []*Identity

func (*ServerHandshakeParameters) GetRecordProtocols

func (x *ServerHandshakeParameters) GetRecordProtocols() []string

func (*ServerHandshakeParameters) GetToken

func (x *ServerHandshakeParameters) GetToken() string

func (*ServerHandshakeParameters) HasToken

func (x *ServerHandshakeParameters) HasToken() bool

func (*ServerHandshakeParameters) ProtoMessage

func (*ServerHandshakeParameters) ProtoMessage()

func (*ServerHandshakeParameters) ProtoReflect

func (*ServerHandshakeParameters) Reset

func (x *ServerHandshakeParameters) Reset()

func (*ServerHandshakeParameters) SetLocalIdentities

func (x *ServerHandshakeParameters) SetLocalIdentities(v []*Identity)

func (*ServerHandshakeParameters) SetRecordProtocols

func (x *ServerHandshakeParameters) SetRecordProtocols(v []string)

func (*ServerHandshakeParameters) SetToken

func (x *ServerHandshakeParameters) SetToken(v string)

func (*ServerHandshakeParameters) String

func (x *ServerHandshakeParameters) String() string

type ServerHandshakeParameters_builder

type ServerHandshakeParameters_builder struct {

	// The record protocols supported by the server, e.g.,
	// "ALTSRP_GCM_AES128".
	RecordProtocols []string
	// (Optional) A list of local identities supported by the server, if
	// specified. Otherwise, the handshaker chooses a default local identity.
	LocalIdentities []*Identity
	// A token created by the caller only intended for use in
	// ALTS connections. The token should be used to authenticate to
	// the peer. The token MUST be strongly bound to the ALTS credentials
	// used to establish the connection that the token is sent over.
	Token *string
	// contains filtered or unexported fields
}

func (ServerHandshakeParameters_builder) Build

type StartClientHandshakeReq

type StartClientHandshakeReq struct {

	// Handshake security protocol requested by the client.
	HandshakeSecurityProtocol HandshakeProtocol `` /* 171-byte string literal not displayed */
	// The application protocols supported by the client, e.g., "h2" (for http2),
	// "grpc".
	ApplicationProtocols []string `protobuf:"bytes,2,rep,name=application_protocols,json=applicationProtocols,proto3" json:"application_protocols,omitempty"`
	// The record protocols supported by the client, e.g.,
	// "ALTSRP_GCM_AES128".
	RecordProtocols []string `protobuf:"bytes,3,rep,name=record_protocols,json=recordProtocols,proto3" json:"record_protocols,omitempty"`
	// (Optional) Describes which server identities are acceptable by the client.
	// If target identities are provided and none of them matches the peer
	// identity of the server, handshake will fail.
	TargetIdentities []*Identity `protobuf:"bytes,4,rep,name=target_identities,json=targetIdentities,proto3" json:"target_identities,omitempty"`
	// (Optional) Application may specify a local identity. Otherwise, the
	// handshaker chooses a default local identity.
	LocalIdentity *Identity `protobuf:"bytes,5,opt,name=local_identity,json=localIdentity,proto3" json:"local_identity,omitempty"`
	// (Optional) Local endpoint information of the connection to the server,
	// such as local IP address, port number, and network protocol.
	LocalEndpoint *Endpoint `protobuf:"bytes,6,opt,name=local_endpoint,json=localEndpoint,proto3" json:"local_endpoint,omitempty"`
	// (Optional) Endpoint information of the remote server, such as IP address,
	// port number, and network protocol.
	RemoteEndpoint *Endpoint `protobuf:"bytes,7,opt,name=remote_endpoint,json=remoteEndpoint,proto3" json:"remote_endpoint,omitempty"`
	// (Optional) If target name is provided, a secure naming check is performed
	// to verify that the peer authenticated identity is indeed authorized to run
	// the target name.
	TargetName string `protobuf:"bytes,8,opt,name=target_name,json=targetName,proto3" json:"target_name,omitempty"`
	// (Optional) RPC protocol versions supported by the client.
	RpcVersions *RpcProtocolVersions `protobuf:"bytes,9,opt,name=rpc_versions,json=rpcVersions,proto3" json:"rpc_versions,omitempty"`
	// (Optional) Maximum frame size supported by the client.
	MaxFrameSize uint32 `protobuf:"varint,10,opt,name=max_frame_size,json=maxFrameSize,proto3" json:"max_frame_size,omitempty"`
	// (Optional) An access token created by the caller only intended for use in
	// ALTS connections. The access token that should be used to authenticate to
	// the peer. The access token MUST be strongly bound to the ALTS credentials
	// used to establish the connection that the token is sent over.
	AccessToken string `protobuf:"bytes,11,opt,name=access_token,json=accessToken,proto3" json:"access_token,omitempty"`
	// (Optional) Ordered transport protocol preferences supported by the client.
	TransportProtocolPreferences *TransportProtocolPreferences `` /* 148-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*StartClientHandshakeReq) ClearLocalEndpoint

func (x *StartClientHandshakeReq) ClearLocalEndpoint()

func (*StartClientHandshakeReq) ClearLocalIdentity

func (x *StartClientHandshakeReq) ClearLocalIdentity()

func (*StartClientHandshakeReq) ClearRemoteEndpoint

func (x *StartClientHandshakeReq) ClearRemoteEndpoint()

func (*StartClientHandshakeReq) ClearRpcVersions

func (x *StartClientHandshakeReq) ClearRpcVersions()

func (*StartClientHandshakeReq) ClearTransportProtocolPreferences

func (x *StartClientHandshakeReq) ClearTransportProtocolPreferences()

func (*StartClientHandshakeReq) GetAccessToken

func (x *StartClientHandshakeReq) GetAccessToken() string

func (*StartClientHandshakeReq) GetApplicationProtocols

func (x *StartClientHandshakeReq) GetApplicationProtocols() []string

func (*StartClientHandshakeReq) GetHandshakeSecurityProtocol

func (x *StartClientHandshakeReq) GetHandshakeSecurityProtocol() HandshakeProtocol

func (*StartClientHandshakeReq) GetLocalEndpoint

func (x *StartClientHandshakeReq) GetLocalEndpoint() *Endpoint

func (*StartClientHandshakeReq) GetLocalIdentity

func (x *StartClientHandshakeReq) GetLocalIdentity() *Identity

func (*StartClientHandshakeReq) GetMaxFrameSize

func (x *StartClientHandshakeReq) GetMaxFrameSize() uint32

func (*StartClientHandshakeReq) GetRecordProtocols

func (x *StartClientHandshakeReq) GetRecordProtocols() []string

func (*StartClientHandshakeReq) GetRemoteEndpoint

func (x *StartClientHandshakeReq) GetRemoteEndpoint() *Endpoint

func (*StartClientHandshakeReq) GetRpcVersions

func (x *StartClientHandshakeReq) GetRpcVersions() *RpcProtocolVersions

func (*StartClientHandshakeReq) GetTargetIdentities

func (x *StartClientHandshakeReq) GetTargetIdentities() []*Identity

func (*StartClientHandshakeReq) GetTargetName

func (x *StartClientHandshakeReq) GetTargetName() string

func (*StartClientHandshakeReq) GetTransportProtocolPreferences

func (x *StartClientHandshakeReq) GetTransportProtocolPreferences() *TransportProtocolPreferences

func (*StartClientHandshakeReq) HasLocalEndpoint

func (x *StartClientHandshakeReq) HasLocalEndpoint() bool

func (*StartClientHandshakeReq) HasLocalIdentity

func (x *StartClientHandshakeReq) HasLocalIdentity() bool

func (*StartClientHandshakeReq) HasRemoteEndpoint

func (x *StartClientHandshakeReq) HasRemoteEndpoint() bool

func (*StartClientHandshakeReq) HasRpcVersions

func (x *StartClientHandshakeReq) HasRpcVersions() bool

func (*StartClientHandshakeReq) HasTransportProtocolPreferences

func (x *StartClientHandshakeReq) HasTransportProtocolPreferences() bool

func (*StartClientHandshakeReq) ProtoMessage

func (*StartClientHandshakeReq) ProtoMessage()

func (*StartClientHandshakeReq) ProtoReflect

func (x *StartClientHandshakeReq) ProtoReflect() protoreflect.Message

func (*StartClientHandshakeReq) Reset

func (x *StartClientHandshakeReq) Reset()

func (*StartClientHandshakeReq) SetAccessToken

func (x *StartClientHandshakeReq) SetAccessToken(v string)

func (*StartClientHandshakeReq) SetApplicationProtocols

func (x *StartClientHandshakeReq) SetApplicationProtocols(v []string)

func (*StartClientHandshakeReq) SetHandshakeSecurityProtocol

func (x *StartClientHandshakeReq) SetHandshakeSecurityProtocol(v HandshakeProtocol)

func (*StartClientHandshakeReq) SetLocalEndpoint

func (x *StartClientHandshakeReq) SetLocalEndpoint(v *Endpoint)

func (*StartClientHandshakeReq) SetLocalIdentity

func (x *StartClientHandshakeReq) SetLocalIdentity(v *Identity)

func (*StartClientHandshakeReq) SetMaxFrameSize

func (x *StartClientHandshakeReq) SetMaxFrameSize(v uint32)

func (*StartClientHandshakeReq) SetRecordProtocols

func (x *StartClientHandshakeReq) SetRecordProtocols(v []string)

func (*StartClientHandshakeReq) SetRemoteEndpoint

func (x *StartClientHandshakeReq) SetRemoteEndpoint(v *Endpoint)

func (*StartClientHandshakeReq) SetRpcVersions

func (x *StartClientHandshakeReq) SetRpcVersions(v *RpcProtocolVersions)

func (*StartClientHandshakeReq) SetTargetIdentities

func (x *StartClientHandshakeReq) SetTargetIdentities(v []*Identity)

func (*StartClientHandshakeReq) SetTargetName

func (x *StartClientHandshakeReq) SetTargetName(v string)

func (*StartClientHandshakeReq) SetTransportProtocolPreferences

func (x *StartClientHandshakeReq) SetTransportProtocolPreferences(v *TransportProtocolPreferences)

func (*StartClientHandshakeReq) String

func (x *StartClientHandshakeReq) String() string

type StartClientHandshakeReq_builder

type StartClientHandshakeReq_builder struct {

	// Handshake security protocol requested by the client.
	HandshakeSecurityProtocol HandshakeProtocol
	// The application protocols supported by the client, e.g., "h2" (for http2),
	// "grpc".
	ApplicationProtocols []string
	// The record protocols supported by the client, e.g.,
	// "ALTSRP_GCM_AES128".
	RecordProtocols []string
	// (Optional) Describes which server identities are acceptable by the client.
	// If target identities are provided and none of them matches the peer
	// identity of the server, handshake will fail.
	TargetIdentities []*Identity
	// (Optional) Application may specify a local identity. Otherwise, the
	// handshaker chooses a default local identity.
	LocalIdentity *Identity
	// (Optional) Local endpoint information of the connection to the server,
	// such as local IP address, port number, and network protocol.
	LocalEndpoint *Endpoint
	// (Optional) Endpoint information of the remote server, such as IP address,
	// port number, and network protocol.
	RemoteEndpoint *Endpoint
	// (Optional) If target name is provided, a secure naming check is performed
	// to verify that the peer authenticated identity is indeed authorized to run
	// the target name.
	TargetName string
	// (Optional) RPC protocol versions supported by the client.
	RpcVersions *RpcProtocolVersions
	// (Optional) Maximum frame size supported by the client.
	MaxFrameSize uint32
	// (Optional) An access token created by the caller only intended for use in
	// ALTS connections. The access token that should be used to authenticate to
	// the peer. The access token MUST be strongly bound to the ALTS credentials
	// used to establish the connection that the token is sent over.
	AccessToken string
	// (Optional) Ordered transport protocol preferences supported by the client.
	TransportProtocolPreferences *TransportProtocolPreferences
	// contains filtered or unexported fields
}

func (StartClientHandshakeReq_builder) Build

type StartServerHandshakeReq

type StartServerHandshakeReq struct {

	// The application protocols supported by the server, e.g., "h2" (for http2),
	// "grpc".
	ApplicationProtocols []string `protobuf:"bytes,1,rep,name=application_protocols,json=applicationProtocols,proto3" json:"application_protocols,omitempty"`
	// Handshake parameters (record protocols and local identities supported by
	// the server) mapped by the handshake protocol. Each handshake security
	// protocol (e.g., TLS or ALTS) has its own set of record protocols and local
	// identities. Since protobuf does not support enum as key to the map, the key
	// to handshake_parameters is the integer value of HandshakeProtocol enum.
	HandshakeParameters map[int32]*ServerHandshakeParameters `` /* 193-byte string literal not displayed */
	// Bytes in out_frames returned from the peer's HandshakerResp. It is possible
	// that the peer's out_frames are split into multiple HandshakeReq messages.
	InBytes []byte `protobuf:"bytes,3,opt,name=in_bytes,json=inBytes,proto3" json:"in_bytes,omitempty"`
	// (Optional) Local endpoint information of the connection to the client,
	// such as local IP address, port number, and network protocol.
	LocalEndpoint *Endpoint `protobuf:"bytes,4,opt,name=local_endpoint,json=localEndpoint,proto3" json:"local_endpoint,omitempty"`
	// (Optional) Endpoint information of the remote client, such as IP address,
	// port number, and network protocol.
	RemoteEndpoint *Endpoint `protobuf:"bytes,5,opt,name=remote_endpoint,json=remoteEndpoint,proto3" json:"remote_endpoint,omitempty"`
	// (Optional) RPC protocol versions supported by the server.
	RpcVersions *RpcProtocolVersions `protobuf:"bytes,6,opt,name=rpc_versions,json=rpcVersions,proto3" json:"rpc_versions,omitempty"`
	// (Optional) Maximum frame size supported by the server.
	MaxFrameSize uint32 `protobuf:"varint,7,opt,name=max_frame_size,json=maxFrameSize,proto3" json:"max_frame_size,omitempty"`
	// (Optional) Transport protocol preferences supported by the server.
	TransportProtocolPreferences *TransportProtocolPreferences `` /* 147-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*StartServerHandshakeReq) ClearLocalEndpoint

func (x *StartServerHandshakeReq) ClearLocalEndpoint()

func (*StartServerHandshakeReq) ClearRemoteEndpoint

func (x *StartServerHandshakeReq) ClearRemoteEndpoint()

func (*StartServerHandshakeReq) ClearRpcVersions

func (x *StartServerHandshakeReq) ClearRpcVersions()

func (*StartServerHandshakeReq) ClearTransportProtocolPreferences

func (x *StartServerHandshakeReq) ClearTransportProtocolPreferences()

func (*StartServerHandshakeReq) GetApplicationProtocols

func (x *StartServerHandshakeReq) GetApplicationProtocols() []string

func (*StartServerHandshakeReq) GetHandshakeParameters

func (x *StartServerHandshakeReq) GetHandshakeParameters() map[int32]*ServerHandshakeParameters

func (*StartServerHandshakeReq) GetInBytes

func (x *StartServerHandshakeReq) GetInBytes() []byte

func (*StartServerHandshakeReq) GetLocalEndpoint

func (x *StartServerHandshakeReq) GetLocalEndpoint() *Endpoint

func (*StartServerHandshakeReq) GetMaxFrameSize

func (x *StartServerHandshakeReq) GetMaxFrameSize() uint32

func (*StartServerHandshakeReq) GetRemoteEndpoint

func (x *StartServerHandshakeReq) GetRemoteEndpoint() *Endpoint

func (*StartServerHandshakeReq) GetRpcVersions

func (x *StartServerHandshakeReq) GetRpcVersions() *RpcProtocolVersions

func (*StartServerHandshakeReq) GetTransportProtocolPreferences

func (x *StartServerHandshakeReq) GetTransportProtocolPreferences() *TransportProtocolPreferences

func (*StartServerHandshakeReq) HasLocalEndpoint

func (x *StartServerHandshakeReq) HasLocalEndpoint() bool

func (*StartServerHandshakeReq) HasRemoteEndpoint

func (x *StartServerHandshakeReq) HasRemoteEndpoint() bool

func (*StartServerHandshakeReq) HasRpcVersions

func (x *StartServerHandshakeReq) HasRpcVersions() bool

func (*StartServerHandshakeReq) HasTransportProtocolPreferences

func (x *StartServerHandshakeReq) HasTransportProtocolPreferences() bool

func (*StartServerHandshakeReq) ProtoMessage

func (*StartServerHandshakeReq) ProtoMessage()

func (*StartServerHandshakeReq) ProtoReflect

func (x *StartServerHandshakeReq) ProtoReflect() protoreflect.Message

func (*StartServerHandshakeReq) Reset

func (x *StartServerHandshakeReq) Reset()

func (*StartServerHandshakeReq) SetApplicationProtocols

func (x *StartServerHandshakeReq) SetApplicationProtocols(v []string)

func (*StartServerHandshakeReq) SetHandshakeParameters

func (x *StartServerHandshakeReq) SetHandshakeParameters(v map[int32]*ServerHandshakeParameters)

func (*StartServerHandshakeReq) SetInBytes

func (x *StartServerHandshakeReq) SetInBytes(v []byte)

func (*StartServerHandshakeReq) SetLocalEndpoint

func (x *StartServerHandshakeReq) SetLocalEndpoint(v *Endpoint)

func (*StartServerHandshakeReq) SetMaxFrameSize

func (x *StartServerHandshakeReq) SetMaxFrameSize(v uint32)

func (*StartServerHandshakeReq) SetRemoteEndpoint

func (x *StartServerHandshakeReq) SetRemoteEndpoint(v *Endpoint)

func (*StartServerHandshakeReq) SetRpcVersions

func (x *StartServerHandshakeReq) SetRpcVersions(v *RpcProtocolVersions)

func (*StartServerHandshakeReq) SetTransportProtocolPreferences

func (x *StartServerHandshakeReq) SetTransportProtocolPreferences(v *TransportProtocolPreferences)

func (*StartServerHandshakeReq) String

func (x *StartServerHandshakeReq) String() string

type StartServerHandshakeReq_builder

type StartServerHandshakeReq_builder struct {

	// The application protocols supported by the server, e.g., "h2" (for http2),
	// "grpc".
	ApplicationProtocols []string
	// Handshake parameters (record protocols and local identities supported by
	// the server) mapped by the handshake protocol. Each handshake security
	// protocol (e.g., TLS or ALTS) has its own set of record protocols and local
	// identities. Since protobuf does not support enum as key to the map, the key
	// to handshake_parameters is the integer value of HandshakeProtocol enum.
	HandshakeParameters map[int32]*ServerHandshakeParameters
	// Bytes in out_frames returned from the peer's HandshakerResp. It is possible
	// that the peer's out_frames are split into multiple HandshakeReq messages.
	InBytes []byte
	// (Optional) Local endpoint information of the connection to the client,
	// such as local IP address, port number, and network protocol.
	LocalEndpoint *Endpoint
	// (Optional) Endpoint information of the remote client, such as IP address,
	// port number, and network protocol.
	RemoteEndpoint *Endpoint
	// (Optional) RPC protocol versions supported by the server.
	RpcVersions *RpcProtocolVersions
	// (Optional) Maximum frame size supported by the server.
	MaxFrameSize uint32
	// (Optional) Transport protocol preferences supported by the server.
	TransportProtocolPreferences *TransportProtocolPreferences
	// contains filtered or unexported fields
}

func (StartServerHandshakeReq_builder) Build

type TransportProtocolPreferences

type TransportProtocolPreferences struct {
	TransportProtocol []string `protobuf:"bytes,1,rep,name=transport_protocol,json=transportProtocol,proto3" json:"transport_protocol,omitempty"`
	// contains filtered or unexported fields
}

The ordered list of protocols that the client wishes to use, or the set that the server supports.

func (*TransportProtocolPreferences) GetTransportProtocol

func (x *TransportProtocolPreferences) GetTransportProtocol() []string

func (*TransportProtocolPreferences) ProtoMessage

func (*TransportProtocolPreferences) ProtoMessage()

func (*TransportProtocolPreferences) ProtoReflect

func (*TransportProtocolPreferences) Reset

func (x *TransportProtocolPreferences) Reset()

func (*TransportProtocolPreferences) SetTransportProtocol

func (x *TransportProtocolPreferences) SetTransportProtocol(v []string)

func (*TransportProtocolPreferences) String

type TransportProtocolPreferences_builder

type TransportProtocolPreferences_builder struct {
	TransportProtocol []string
	// contains filtered or unexported fields
}

func (TransportProtocolPreferences_builder) Build

Source Files

  • altscontext.pb.go
  • handshaker.pb.go
  • transport_security_common.pb.go

Jump to