reflectionv1

package
v1.36.11-2025121620244... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 4 Imported by: 4

Documentation

Index

Constants

const ServerReflectionRequest_AllExtensionNumbersOfType_case case_ServerReflectionRequest_MessageRequest = 6
const ServerReflectionRequest_FileByFilename_case case_ServerReflectionRequest_MessageRequest = 3
const ServerReflectionRequest_FileContainingExtension_case case_ServerReflectionRequest_MessageRequest = 5
const ServerReflectionRequest_FileContainingSymbol_case case_ServerReflectionRequest_MessageRequest = 4
const ServerReflectionRequest_ListServices_case case_ServerReflectionRequest_MessageRequest = 7
const ServerReflectionRequest_MessageRequest_not_set_case case_ServerReflectionRequest_MessageRequest = 0
const ServerReflectionResponse_AllExtensionNumbersResponse_case case_ServerReflectionResponse_MessageResponse = 5
const ServerReflectionResponse_ErrorResponse_case case_ServerReflectionResponse_MessageResponse = 7
const ServerReflectionResponse_FileDescriptorResponse_case case_ServerReflectionResponse_MessageResponse = 4
const ServerReflectionResponse_ListServicesResponse_case case_ServerReflectionResponse_MessageResponse = 6
const ServerReflectionResponse_MessageResponse_not_set_case case_ServerReflectionResponse_MessageResponse = 0

Variables

var File_grpc_reflection_v1_reflection_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type ErrorResponse

type ErrorResponse struct {

	// This field uses the error codes defined in grpc::StatusCode.
	ErrorCode    int32  `protobuf:"varint,1,opt,name=error_code,json=errorCode,proto3" json:"error_code,omitempty"`
	ErrorMessage string `protobuf:"bytes,2,opt,name=error_message,json=errorMessage,proto3" json:"error_message,omitempty"`
	// contains filtered or unexported fields
}

The error code and error message sent by the server when an error occurs.

func (*ErrorResponse) GetErrorCode

func (x *ErrorResponse) GetErrorCode() int32

func (*ErrorResponse) GetErrorMessage

func (x *ErrorResponse) GetErrorMessage() string

func (*ErrorResponse) ProtoMessage

func (*ErrorResponse) ProtoMessage()

func (*ErrorResponse) ProtoReflect

func (x *ErrorResponse) ProtoReflect() protoreflect.Message

func (*ErrorResponse) Reset

func (x *ErrorResponse) Reset()

func (*ErrorResponse) SetErrorCode

func (x *ErrorResponse) SetErrorCode(v int32)

func (*ErrorResponse) SetErrorMessage

func (x *ErrorResponse) SetErrorMessage(v string)

func (*ErrorResponse) String

func (x *ErrorResponse) String() string

type ErrorResponse_builder

type ErrorResponse_builder struct {

	// This field uses the error codes defined in grpc::StatusCode.
	ErrorCode    int32
	ErrorMessage string
	// contains filtered or unexported fields
}

func (ErrorResponse_builder) Build

type ExtensionNumberResponse

type ExtensionNumberResponse struct {

	// Full name of the base type, including the package name. The format
	// is <package>.<type>
	BaseTypeName    string  `protobuf:"bytes,1,opt,name=base_type_name,json=baseTypeName,proto3" json:"base_type_name,omitempty"`
	ExtensionNumber []int32 `protobuf:"varint,2,rep,packed,name=extension_number,json=extensionNumber,proto3" json:"extension_number,omitempty"`
	// contains filtered or unexported fields
}

A list of extension numbers sent by the server answering all_extension_numbers_of_type request.

func (*ExtensionNumberResponse) GetBaseTypeName

func (x *ExtensionNumberResponse) GetBaseTypeName() string

func (*ExtensionNumberResponse) GetExtensionNumber

func (x *ExtensionNumberResponse) GetExtensionNumber() []int32

func (*ExtensionNumberResponse) ProtoMessage

func (*ExtensionNumberResponse) ProtoMessage()

func (*ExtensionNumberResponse) ProtoReflect

func (x *ExtensionNumberResponse) ProtoReflect() protoreflect.Message

func (*ExtensionNumberResponse) Reset

func (x *ExtensionNumberResponse) Reset()

func (*ExtensionNumberResponse) SetBaseTypeName

func (x *ExtensionNumberResponse) SetBaseTypeName(v string)

func (*ExtensionNumberResponse) SetExtensionNumber

func (x *ExtensionNumberResponse) SetExtensionNumber(v []int32)

func (*ExtensionNumberResponse) String

func (x *ExtensionNumberResponse) String() string

type ExtensionNumberResponse_builder

type ExtensionNumberResponse_builder struct {

	// Full name of the base type, including the package name. The format
	// is <package>.<type>
	BaseTypeName    string
	ExtensionNumber []int32
	// contains filtered or unexported fields
}

func (ExtensionNumberResponse_builder) Build

type ExtensionRequest

type ExtensionRequest struct {

	// Fully-qualified type name. The format should be <package>.<type>
	ContainingType  string `protobuf:"bytes,1,opt,name=containing_type,json=containingType,proto3" json:"containing_type,omitempty"`
	ExtensionNumber int32  `protobuf:"varint,2,opt,name=extension_number,json=extensionNumber,proto3" json:"extension_number,omitempty"`
	// contains filtered or unexported fields
}

The type name and extension number sent by the client when requesting file_containing_extension.

func (*ExtensionRequest) GetContainingType

func (x *ExtensionRequest) GetContainingType() string

func (*ExtensionRequest) GetExtensionNumber

func (x *ExtensionRequest) GetExtensionNumber() int32

func (*ExtensionRequest) ProtoMessage

func (*ExtensionRequest) ProtoMessage()

func (*ExtensionRequest) ProtoReflect

func (x *ExtensionRequest) ProtoReflect() protoreflect.Message

func (*ExtensionRequest) Reset

func (x *ExtensionRequest) Reset()

func (*ExtensionRequest) SetContainingType

func (x *ExtensionRequest) SetContainingType(v string)

func (*ExtensionRequest) SetExtensionNumber

func (x *ExtensionRequest) SetExtensionNumber(v int32)

func (*ExtensionRequest) String

func (x *ExtensionRequest) String() string

type ExtensionRequest_builder

type ExtensionRequest_builder struct {

	// Fully-qualified type name. The format should be <package>.<type>
	ContainingType  string
	ExtensionNumber int32
	// contains filtered or unexported fields
}

func (ExtensionRequest_builder) Build

type FileDescriptorResponse

type FileDescriptorResponse struct {

	// Serialized FileDescriptorProto messages. We avoid taking a dependency on
	// descriptor.proto, which uses proto2 only features, by making them opaque
	// bytes instead.
	FileDescriptorProto [][]byte `protobuf:"bytes,1,rep,name=file_descriptor_proto,json=fileDescriptorProto,proto3" json:"file_descriptor_proto,omitempty"`
	// contains filtered or unexported fields
}

Serialized FileDescriptorProto messages sent by the server answering a file_by_filename, file_containing_symbol, or file_containing_extension request.

func (*FileDescriptorResponse) GetFileDescriptorProto

func (x *FileDescriptorResponse) GetFileDescriptorProto() [][]byte

func (*FileDescriptorResponse) ProtoMessage

func (*FileDescriptorResponse) ProtoMessage()

func (*FileDescriptorResponse) ProtoReflect

func (x *FileDescriptorResponse) ProtoReflect() protoreflect.Message

func (*FileDescriptorResponse) Reset

func (x *FileDescriptorResponse) Reset()

func (*FileDescriptorResponse) SetFileDescriptorProto

func (x *FileDescriptorResponse) SetFileDescriptorProto(v [][]byte)

func (*FileDescriptorResponse) String

func (x *FileDescriptorResponse) String() string

type FileDescriptorResponse_builder

type FileDescriptorResponse_builder struct {

	// Serialized FileDescriptorProto messages. We avoid taking a dependency on
	// descriptor.proto, which uses proto2 only features, by making them opaque
	// bytes instead.
	FileDescriptorProto [][]byte
	// contains filtered or unexported fields
}

func (FileDescriptorResponse_builder) Build

type ListServiceResponse

type ListServiceResponse struct {

	// The information of each service may be expanded in the future, so we use
	// ServiceResponse message to encapsulate it.
	Service []*ServiceResponse `protobuf:"bytes,1,rep,name=service,proto3" json:"service,omitempty"`
	// contains filtered or unexported fields
}

A list of ServiceResponse sent by the server answering list_services request.

func (*ListServiceResponse) GetService

func (x *ListServiceResponse) GetService() []*ServiceResponse

func (*ListServiceResponse) ProtoMessage

func (*ListServiceResponse) ProtoMessage()

func (*ListServiceResponse) ProtoReflect

func (x *ListServiceResponse) ProtoReflect() protoreflect.Message

func (*ListServiceResponse) Reset

func (x *ListServiceResponse) Reset()

func (*ListServiceResponse) SetService

func (x *ListServiceResponse) SetService(v []*ServiceResponse)

func (*ListServiceResponse) String

func (x *ListServiceResponse) String() string

type ListServiceResponse_builder

type ListServiceResponse_builder struct {

	// The information of each service may be expanded in the future, so we use
	// ServiceResponse message to encapsulate it.
	Service []*ServiceResponse
	// contains filtered or unexported fields
}

func (ListServiceResponse_builder) Build

type ServerReflectionRequest

type ServerReflectionRequest struct {
	Host string `protobuf:"bytes,1,opt,name=host,proto3" json:"host,omitempty"`
	// To use reflection service, the client should set one of the following
	// fields in message_request. The server distinguishes requests by their
	// defined field and then handles them using corresponding methods.
	//
	// Types that are valid to be assigned to MessageRequest:
	//
	//	*ServerReflectionRequest_FileByFilename
	//	*ServerReflectionRequest_FileContainingSymbol
	//	*ServerReflectionRequest_FileContainingExtension
	//	*ServerReflectionRequest_AllExtensionNumbersOfType
	//	*ServerReflectionRequest_ListServices
	MessageRequest isServerReflectionRequest_MessageRequest `protobuf_oneof:"message_request"`
	// contains filtered or unexported fields
}

The message sent by the client when calling ServerReflectionInfo method.

func (*ServerReflectionRequest) ClearAllExtensionNumbersOfType

func (x *ServerReflectionRequest) ClearAllExtensionNumbersOfType()

func (*ServerReflectionRequest) ClearFileByFilename

func (x *ServerReflectionRequest) ClearFileByFilename()

func (*ServerReflectionRequest) ClearFileContainingExtension

func (x *ServerReflectionRequest) ClearFileContainingExtension()

func (*ServerReflectionRequest) ClearFileContainingSymbol

func (x *ServerReflectionRequest) ClearFileContainingSymbol()

func (*ServerReflectionRequest) ClearListServices

func (x *ServerReflectionRequest) ClearListServices()

func (*ServerReflectionRequest) ClearMessageRequest

func (x *ServerReflectionRequest) ClearMessageRequest()

func (*ServerReflectionRequest) GetAllExtensionNumbersOfType

func (x *ServerReflectionRequest) GetAllExtensionNumbersOfType() string

func (*ServerReflectionRequest) GetFileByFilename

func (x *ServerReflectionRequest) GetFileByFilename() string

func (*ServerReflectionRequest) GetFileContainingExtension

func (x *ServerReflectionRequest) GetFileContainingExtension() *ExtensionRequest

func (*ServerReflectionRequest) GetFileContainingSymbol

func (x *ServerReflectionRequest) GetFileContainingSymbol() string

func (*ServerReflectionRequest) GetHost

func (x *ServerReflectionRequest) GetHost() string

func (*ServerReflectionRequest) GetListServices

func (x *ServerReflectionRequest) GetListServices() string

func (*ServerReflectionRequest) GetMessageRequest

func (x *ServerReflectionRequest) GetMessageRequest() isServerReflectionRequest_MessageRequest

func (*ServerReflectionRequest) HasAllExtensionNumbersOfType

func (x *ServerReflectionRequest) HasAllExtensionNumbersOfType() bool

func (*ServerReflectionRequest) HasFileByFilename

func (x *ServerReflectionRequest) HasFileByFilename() bool

func (*ServerReflectionRequest) HasFileContainingExtension

func (x *ServerReflectionRequest) HasFileContainingExtension() bool

func (*ServerReflectionRequest) HasFileContainingSymbol

func (x *ServerReflectionRequest) HasFileContainingSymbol() bool

func (*ServerReflectionRequest) HasListServices

func (x *ServerReflectionRequest) HasListServices() bool

func (*ServerReflectionRequest) HasMessageRequest

func (x *ServerReflectionRequest) HasMessageRequest() bool

func (*ServerReflectionRequest) ProtoMessage

func (*ServerReflectionRequest) ProtoMessage()

func (*ServerReflectionRequest) ProtoReflect

func (x *ServerReflectionRequest) ProtoReflect() protoreflect.Message

func (*ServerReflectionRequest) Reset

func (x *ServerReflectionRequest) Reset()

func (*ServerReflectionRequest) SetAllExtensionNumbersOfType

func (x *ServerReflectionRequest) SetAllExtensionNumbersOfType(v string)

func (*ServerReflectionRequest) SetFileByFilename

func (x *ServerReflectionRequest) SetFileByFilename(v string)

func (*ServerReflectionRequest) SetFileContainingExtension

func (x *ServerReflectionRequest) SetFileContainingExtension(v *ExtensionRequest)

func (*ServerReflectionRequest) SetFileContainingSymbol

func (x *ServerReflectionRequest) SetFileContainingSymbol(v string)

func (*ServerReflectionRequest) SetHost

func (x *ServerReflectionRequest) SetHost(v string)

func (*ServerReflectionRequest) SetListServices

func (x *ServerReflectionRequest) SetListServices(v string)

func (*ServerReflectionRequest) String

func (x *ServerReflectionRequest) String() string

func (*ServerReflectionRequest) WhichMessageRequest

func (x *ServerReflectionRequest) WhichMessageRequest() case_ServerReflectionRequest_MessageRequest

type ServerReflectionRequest_AllExtensionNumbersOfType

type ServerReflectionRequest_AllExtensionNumbersOfType struct {
	// Finds the tag numbers used by all known extensions of the given message
	// type, and appends them to ExtensionNumberResponse in an undefined order.
	// Its corresponding method is best-effort: it's not guaranteed that the
	// reflection service will implement this method, and it's not guaranteed
	// that this method will provide all extensions. Returns
	// StatusCode::UNIMPLEMENTED if it's not implemented.
	// This field should be a fully-qualified type name. The format is
	// <package>.<type>
	AllExtensionNumbersOfType string `protobuf:"bytes,6,opt,name=all_extension_numbers_of_type,json=allExtensionNumbersOfType,proto3,oneof"`
}

type ServerReflectionRequest_FileByFilename

type ServerReflectionRequest_FileByFilename struct {
	// Find a proto file by the file name.
	FileByFilename string `protobuf:"bytes,3,opt,name=file_by_filename,json=fileByFilename,proto3,oneof"`
}

type ServerReflectionRequest_FileContainingExtension

type ServerReflectionRequest_FileContainingExtension struct {
	// Find the proto file which defines an extension extending the given
	// message type with the given field number.
	FileContainingExtension *ExtensionRequest `protobuf:"bytes,5,opt,name=file_containing_extension,json=fileContainingExtension,proto3,oneof"`
}

type ServerReflectionRequest_FileContainingSymbol

type ServerReflectionRequest_FileContainingSymbol struct {
	// Find the proto file that declares the given fully-qualified symbol name.
	// This field should be a fully-qualified symbol name
	// (e.g. <package>.<service>[.<method>] or <package>.<type>).
	FileContainingSymbol string `protobuf:"bytes,4,opt,name=file_containing_symbol,json=fileContainingSymbol,proto3,oneof"`
}

type ServerReflectionRequest_ListServices

type ServerReflectionRequest_ListServices struct {
	// List the full names of registered services. The content will not be
	// checked.
	ListServices string `protobuf:"bytes,7,opt,name=list_services,json=listServices,proto3,oneof"`
}

type ServerReflectionRequest_builder

type ServerReflectionRequest_builder struct {
	Host string

	// Fields of oneof MessageRequest:
	// Find a proto file by the file name.
	FileByFilename *string
	// Find the proto file that declares the given fully-qualified symbol name.
	// This field should be a fully-qualified symbol name
	// (e.g. <package>.<service>[.<method>] or <package>.<type>).
	FileContainingSymbol *string
	// Find the proto file which defines an extension extending the given
	// message type with the given field number.
	FileContainingExtension *ExtensionRequest
	// Finds the tag numbers used by all known extensions of the given message
	// type, and appends them to ExtensionNumberResponse in an undefined order.
	// Its corresponding method is best-effort: it's not guaranteed that the
	// reflection service will implement this method, and it's not guaranteed
	// that this method will provide all extensions. Returns
	// StatusCode::UNIMPLEMENTED if it's not implemented.
	// This field should be a fully-qualified type name. The format is
	// <package>.<type>
	AllExtensionNumbersOfType *string
	// List the full names of registered services. The content will not be
	// checked.
	ListServices *string
	// contains filtered or unexported fields
}

func (ServerReflectionRequest_builder) Build

type ServerReflectionResponse

type ServerReflectionResponse struct {
	ValidHost       string                   `protobuf:"bytes,1,opt,name=valid_host,json=validHost,proto3" json:"valid_host,omitempty"`
	OriginalRequest *ServerReflectionRequest `protobuf:"bytes,2,opt,name=original_request,json=originalRequest,proto3" json:"original_request,omitempty"`
	// The server sets one of the following fields according to the message_request
	// in the request.
	//
	// Types that are valid to be assigned to MessageResponse:
	//
	//	*ServerReflectionResponse_FileDescriptorResponse
	//	*ServerReflectionResponse_AllExtensionNumbersResponse
	//	*ServerReflectionResponse_ListServicesResponse
	//	*ServerReflectionResponse_ErrorResponse
	MessageResponse isServerReflectionResponse_MessageResponse `protobuf_oneof:"message_response"`
	// contains filtered or unexported fields
}

The message sent by the server to answer ServerReflectionInfo method.

func (*ServerReflectionResponse) ClearAllExtensionNumbersResponse

func (x *ServerReflectionResponse) ClearAllExtensionNumbersResponse()

func (*ServerReflectionResponse) ClearErrorResponse

func (x *ServerReflectionResponse) ClearErrorResponse()

func (*ServerReflectionResponse) ClearFileDescriptorResponse

func (x *ServerReflectionResponse) ClearFileDescriptorResponse()

func (*ServerReflectionResponse) ClearListServicesResponse

func (x *ServerReflectionResponse) ClearListServicesResponse()

func (*ServerReflectionResponse) ClearMessageResponse

func (x *ServerReflectionResponse) ClearMessageResponse()

func (*ServerReflectionResponse) ClearOriginalRequest

func (x *ServerReflectionResponse) ClearOriginalRequest()

func (*ServerReflectionResponse) GetAllExtensionNumbersResponse

func (x *ServerReflectionResponse) GetAllExtensionNumbersResponse() *ExtensionNumberResponse

func (*ServerReflectionResponse) GetErrorResponse

func (x *ServerReflectionResponse) GetErrorResponse() *ErrorResponse

func (*ServerReflectionResponse) GetFileDescriptorResponse

func (x *ServerReflectionResponse) GetFileDescriptorResponse() *FileDescriptorResponse

func (*ServerReflectionResponse) GetListServicesResponse

func (x *ServerReflectionResponse) GetListServicesResponse() *ListServiceResponse

func (*ServerReflectionResponse) GetMessageResponse

func (x *ServerReflectionResponse) GetMessageResponse() isServerReflectionResponse_MessageResponse

func (*ServerReflectionResponse) GetOriginalRequest

func (x *ServerReflectionResponse) GetOriginalRequest() *ServerReflectionRequest

func (*ServerReflectionResponse) GetValidHost

func (x *ServerReflectionResponse) GetValidHost() string

func (*ServerReflectionResponse) HasAllExtensionNumbersResponse

func (x *ServerReflectionResponse) HasAllExtensionNumbersResponse() bool

func (*ServerReflectionResponse) HasErrorResponse

func (x *ServerReflectionResponse) HasErrorResponse() bool

func (*ServerReflectionResponse) HasFileDescriptorResponse

func (x *ServerReflectionResponse) HasFileDescriptorResponse() bool

func (*ServerReflectionResponse) HasListServicesResponse

func (x *ServerReflectionResponse) HasListServicesResponse() bool

func (*ServerReflectionResponse) HasMessageResponse

func (x *ServerReflectionResponse) HasMessageResponse() bool

func (*ServerReflectionResponse) HasOriginalRequest

func (x *ServerReflectionResponse) HasOriginalRequest() bool

func (*ServerReflectionResponse) ProtoMessage

func (*ServerReflectionResponse) ProtoMessage()

func (*ServerReflectionResponse) ProtoReflect

func (x *ServerReflectionResponse) ProtoReflect() protoreflect.Message

func (*ServerReflectionResponse) Reset

func (x *ServerReflectionResponse) Reset()

func (*ServerReflectionResponse) SetAllExtensionNumbersResponse

func (x *ServerReflectionResponse) SetAllExtensionNumbersResponse(v *ExtensionNumberResponse)

func (*ServerReflectionResponse) SetErrorResponse

func (x *ServerReflectionResponse) SetErrorResponse(v *ErrorResponse)

func (*ServerReflectionResponse) SetFileDescriptorResponse

func (x *ServerReflectionResponse) SetFileDescriptorResponse(v *FileDescriptorResponse)

func (*ServerReflectionResponse) SetListServicesResponse

func (x *ServerReflectionResponse) SetListServicesResponse(v *ListServiceResponse)

func (*ServerReflectionResponse) SetOriginalRequest

func (x *ServerReflectionResponse) SetOriginalRequest(v *ServerReflectionRequest)

func (*ServerReflectionResponse) SetValidHost

func (x *ServerReflectionResponse) SetValidHost(v string)

func (*ServerReflectionResponse) String

func (x *ServerReflectionResponse) String() string

func (*ServerReflectionResponse) WhichMessageResponse

func (x *ServerReflectionResponse) WhichMessageResponse() case_ServerReflectionResponse_MessageResponse

type ServerReflectionResponse_AllExtensionNumbersResponse

type ServerReflectionResponse_AllExtensionNumbersResponse struct {
	// This message is used to answer all_extension_numbers_of_type requests.
	AllExtensionNumbersResponse *ExtensionNumberResponse `protobuf:"bytes,5,opt,name=all_extension_numbers_response,json=allExtensionNumbersResponse,proto3,oneof"`
}

type ServerReflectionResponse_ErrorResponse

type ServerReflectionResponse_ErrorResponse struct {
	// This message is used when an error occurs.
	ErrorResponse *ErrorResponse `protobuf:"bytes,7,opt,name=error_response,json=errorResponse,proto3,oneof"`
}

type ServerReflectionResponse_FileDescriptorResponse

type ServerReflectionResponse_FileDescriptorResponse struct {
	// This message is used to answer file_by_filename, file_containing_symbol,
	// file_containing_extension requests with transitive dependencies.
	// As the repeated label is not allowed in oneof fields, we use a
	// FileDescriptorResponse message to encapsulate the repeated fields.
	// The reflection service is allowed to avoid sending FileDescriptorProtos
	// that were previously sent in response to earlier requests in the stream.
	FileDescriptorResponse *FileDescriptorResponse `protobuf:"bytes,4,opt,name=file_descriptor_response,json=fileDescriptorResponse,proto3,oneof"`
}

type ServerReflectionResponse_ListServicesResponse

type ServerReflectionResponse_ListServicesResponse struct {
	// This message is used to answer list_services requests.
	ListServicesResponse *ListServiceResponse `protobuf:"bytes,6,opt,name=list_services_response,json=listServicesResponse,proto3,oneof"`
}

type ServerReflectionResponse_builder

type ServerReflectionResponse_builder struct {
	ValidHost       string
	OriginalRequest *ServerReflectionRequest

	// Fields of oneof MessageResponse:
	// This message is used to answer file_by_filename, file_containing_symbol,
	// file_containing_extension requests with transitive dependencies.
	// As the repeated label is not allowed in oneof fields, we use a
	// FileDescriptorResponse message to encapsulate the repeated fields.
	// The reflection service is allowed to avoid sending FileDescriptorProtos
	// that were previously sent in response to earlier requests in the stream.
	FileDescriptorResponse *FileDescriptorResponse
	// This message is used to answer all_extension_numbers_of_type requests.
	AllExtensionNumbersResponse *ExtensionNumberResponse
	// This message is used to answer list_services requests.
	ListServicesResponse *ListServiceResponse
	// This message is used when an error occurs.
	ErrorResponse *ErrorResponse
	// contains filtered or unexported fields
}

func (ServerReflectionResponse_builder) Build

type ServiceResponse

type ServiceResponse struct {

	// Full name of a registered service, including its package name. The format
	// is <package>.<service>
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// contains filtered or unexported fields
}

The information of a single service used by ListServiceResponse to answer list_services request.

func (*ServiceResponse) GetName

func (x *ServiceResponse) GetName() string

func (*ServiceResponse) ProtoMessage

func (*ServiceResponse) ProtoMessage()

func (*ServiceResponse) ProtoReflect

func (x *ServiceResponse) ProtoReflect() protoreflect.Message

func (*ServiceResponse) Reset

func (x *ServiceResponse) Reset()

func (*ServiceResponse) SetName

func (x *ServiceResponse) SetName(v string)

func (*ServiceResponse) String

func (x *ServiceResponse) String() string

type ServiceResponse_builder

type ServiceResponse_builder struct {

	// Full name of a registered service, including its package name. The format
	// is <package>.<service>
	Name string
	// contains filtered or unexported fields
}

func (ServiceResponse_builder) Build

Source Files

  • reflection.pb.go

Jump to