Documentation
¶
Index ¶
- Constants
- func NewAuthorizationAPIHandler(svc AuthorizationAPIHandler, opts ...connect_go.HandlerOption) (string, http.Handler)
- type AuthorizationAPIClient
- type AuthorizationAPIHandler
- type UnimplementedAuthorizationAPIHandler
- func (UnimplementedAuthorizationAPIHandler) IsAuthorized(context.Context, *connect_go.Request[v1beta1.IsAuthorizedRequest]) (*connect_go.Response[v1beta1.IsAuthorizedResponse], error)
- func (UnimplementedAuthorizationAPIHandler) WhatAuthorized(context.Context, *connect_go.Request[v1beta1.WhatAuthorizedRequest]) (*connect_go.Response[v1beta1.WhatAuthorizedResponse], error)
- func (UnimplementedAuthorizationAPIHandler) WhoAuthorized(context.Context, *connect_go.Request[v1beta1.WhoAuthorizedRequest]) (*connect_go.Response[v1beta1.WhoAuthorizedResponse], error)
Constants ¶
const ( // AuthorizationAPIIsAuthorizedProcedure is the fully-qualified name of the AuthorizationAPI's // IsAuthorized RPC. AuthorizationAPIIsAuthorizedProcedure = "/indykite.authorization.v1beta1.AuthorizationAPI/IsAuthorized" // AuthorizationAPIWhatAuthorizedProcedure is the fully-qualified name of the AuthorizationAPI's // WhatAuthorized RPC. AuthorizationAPIWhatAuthorizedProcedure = "/indykite.authorization.v1beta1.AuthorizationAPI/WhatAuthorized" // AuthorizationAPIWhoAuthorizedProcedure is the fully-qualified name of the AuthorizationAPI's // WhoAuthorized RPC. AuthorizationAPIWhoAuthorizedProcedure = "/indykite.authorization.v1beta1.AuthorizationAPI/WhoAuthorized" )
These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.
Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.
const (
// AuthorizationAPIName is the fully-qualified name of the AuthorizationAPI service.
AuthorizationAPIName = "indykite.authorization.v1beta1.AuthorizationAPI"
)
Variables ¶
This section is empty.
Functions ¶
func NewAuthorizationAPIHandler ¶
func NewAuthorizationAPIHandler(svc AuthorizationAPIHandler, opts ...connect_go.HandlerOption) (string, http.Handler)
NewAuthorizationAPIHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.
By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.
Types ¶
type AuthorizationAPIClient ¶
type AuthorizationAPIClient interface {
IsAuthorized(context.Context, *connect_go.Request[v1beta1.IsAuthorizedRequest]) (*connect_go.Response[v1beta1.IsAuthorizedResponse], error)
WhatAuthorized(context.Context, *connect_go.Request[v1beta1.WhatAuthorizedRequest]) (*connect_go.Response[v1beta1.WhatAuthorizedResponse], error)
WhoAuthorized(context.Context, *connect_go.Request[v1beta1.WhoAuthorizedRequest]) (*connect_go.Response[v1beta1.WhoAuthorizedResponse], error)
}
AuthorizationAPIClient is a client for the indykite.authorization.v1beta1.AuthorizationAPI service.
func NewAuthorizationAPIClient ¶
func NewAuthorizationAPIClient(httpClient connect_go.HTTPClient, baseURL string, opts ...connect_go.ClientOption) AuthorizationAPIClient
NewAuthorizationAPIClient constructs a client for the indykite.authorization.v1beta1.AuthorizationAPI service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.
The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).
type AuthorizationAPIHandler ¶
type AuthorizationAPIHandler interface {
IsAuthorized(context.Context, *connect_go.Request[v1beta1.IsAuthorizedRequest]) (*connect_go.Response[v1beta1.IsAuthorizedResponse], error)
WhatAuthorized(context.Context, *connect_go.Request[v1beta1.WhatAuthorizedRequest]) (*connect_go.Response[v1beta1.WhatAuthorizedResponse], error)
WhoAuthorized(context.Context, *connect_go.Request[v1beta1.WhoAuthorizedRequest]) (*connect_go.Response[v1beta1.WhoAuthorizedResponse], error)
}
AuthorizationAPIHandler is an implementation of the indykite.authorization.v1beta1.AuthorizationAPI service.
type UnimplementedAuthorizationAPIHandler ¶
type UnimplementedAuthorizationAPIHandler struct{}
UnimplementedAuthorizationAPIHandler returns CodeUnimplemented from all methods.
func (UnimplementedAuthorizationAPIHandler) IsAuthorized ¶
func (UnimplementedAuthorizationAPIHandler) IsAuthorized(context.Context, *connect_go.Request[v1beta1.IsAuthorizedRequest]) (*connect_go.Response[v1beta1.IsAuthorizedResponse], error)
func (UnimplementedAuthorizationAPIHandler) WhatAuthorized ¶
func (UnimplementedAuthorizationAPIHandler) WhatAuthorized(context.Context, *connect_go.Request[v1beta1.WhatAuthorizedRequest]) (*connect_go.Response[v1beta1.WhatAuthorizedResponse], error)
func (UnimplementedAuthorizationAPIHandler) WhoAuthorized ¶
func (UnimplementedAuthorizationAPIHandler) WhoAuthorized(context.Context, *connect_go.Request[v1beta1.WhoAuthorizedRequest]) (*connect_go.Response[v1beta1.WhoAuthorizedResponse], error)
Source Files
¶
- authorization_service.connect.go