configv1beta1connect

package
v1.10.0-20260125204039... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	// ConfigManagementAPIReadCustomerProcedure is the fully-qualified name of the ConfigManagementAPI's
	// ReadCustomer RPC.
	ConfigManagementAPIReadCustomerProcedure = "/indykite.config.v1beta1.ConfigManagementAPI/ReadCustomer"
	// ConfigManagementAPICreateApplicationSpaceProcedure is the fully-qualified name of the
	// ConfigManagementAPI's CreateApplicationSpace RPC.
	ConfigManagementAPICreateApplicationSpaceProcedure = "/indykite.config.v1beta1.ConfigManagementAPI/CreateApplicationSpace"
	// ConfigManagementAPIReadApplicationSpaceProcedure is the fully-qualified name of the
	// ConfigManagementAPI's ReadApplicationSpace RPC.
	ConfigManagementAPIReadApplicationSpaceProcedure = "/indykite.config.v1beta1.ConfigManagementAPI/ReadApplicationSpace"
	// ConfigManagementAPIListApplicationSpacesProcedure is the fully-qualified name of the
	// ConfigManagementAPI's ListApplicationSpaces RPC.
	ConfigManagementAPIListApplicationSpacesProcedure = "/indykite.config.v1beta1.ConfigManagementAPI/ListApplicationSpaces"
	// ConfigManagementAPIUpdateApplicationSpaceProcedure is the fully-qualified name of the
	// ConfigManagementAPI's UpdateApplicationSpace RPC.
	ConfigManagementAPIUpdateApplicationSpaceProcedure = "/indykite.config.v1beta1.ConfigManagementAPI/UpdateApplicationSpace"
	// ConfigManagementAPIDeleteApplicationSpaceProcedure is the fully-qualified name of the
	// ConfigManagementAPI's DeleteApplicationSpace RPC.
	ConfigManagementAPIDeleteApplicationSpaceProcedure = "/indykite.config.v1beta1.ConfigManagementAPI/DeleteApplicationSpace"
	// ConfigManagementAPICreateApplicationProcedure is the fully-qualified name of the
	// ConfigManagementAPI's CreateApplication RPC.
	ConfigManagementAPICreateApplicationProcedure = "/indykite.config.v1beta1.ConfigManagementAPI/CreateApplication"
	// ConfigManagementAPIReadApplicationProcedure is the fully-qualified name of the
	// ConfigManagementAPI's ReadApplication RPC.
	ConfigManagementAPIReadApplicationProcedure = "/indykite.config.v1beta1.ConfigManagementAPI/ReadApplication"
	// ConfigManagementAPIListApplicationsProcedure is the fully-qualified name of the
	// ConfigManagementAPI's ListApplications RPC.
	ConfigManagementAPIListApplicationsProcedure = "/indykite.config.v1beta1.ConfigManagementAPI/ListApplications"
	// ConfigManagementAPIUpdateApplicationProcedure is the fully-qualified name of the
	// ConfigManagementAPI's UpdateApplication RPC.
	ConfigManagementAPIUpdateApplicationProcedure = "/indykite.config.v1beta1.ConfigManagementAPI/UpdateApplication"
	// ConfigManagementAPIDeleteApplicationProcedure is the fully-qualified name of the
	// ConfigManagementAPI's DeleteApplication RPC.
	ConfigManagementAPIDeleteApplicationProcedure = "/indykite.config.v1beta1.ConfigManagementAPI/DeleteApplication"
	// ConfigManagementAPICreateApplicationAgentProcedure is the fully-qualified name of the
	// ConfigManagementAPI's CreateApplicationAgent RPC.
	ConfigManagementAPICreateApplicationAgentProcedure = "/indykite.config.v1beta1.ConfigManagementAPI/CreateApplicationAgent"
	// ConfigManagementAPIReadApplicationAgentProcedure is the fully-qualified name of the
	// ConfigManagementAPI's ReadApplicationAgent RPC.
	ConfigManagementAPIReadApplicationAgentProcedure = "/indykite.config.v1beta1.ConfigManagementAPI/ReadApplicationAgent"
	// ConfigManagementAPIListApplicationAgentsProcedure is the fully-qualified name of the
	// ConfigManagementAPI's ListApplicationAgents RPC.
	ConfigManagementAPIListApplicationAgentsProcedure = "/indykite.config.v1beta1.ConfigManagementAPI/ListApplicationAgents"
	// ConfigManagementAPIUpdateApplicationAgentProcedure is the fully-qualified name of the
	// ConfigManagementAPI's UpdateApplicationAgent RPC.
	ConfigManagementAPIUpdateApplicationAgentProcedure = "/indykite.config.v1beta1.ConfigManagementAPI/UpdateApplicationAgent"
	// ConfigManagementAPIDeleteApplicationAgentProcedure is the fully-qualified name of the
	// ConfigManagementAPI's DeleteApplicationAgent RPC.
	ConfigManagementAPIDeleteApplicationAgentProcedure = "/indykite.config.v1beta1.ConfigManagementAPI/DeleteApplicationAgent"
	// ConfigManagementAPIRegisterApplicationAgentCredentialProcedure is the fully-qualified name of the
	// ConfigManagementAPI's RegisterApplicationAgentCredential RPC.
	ConfigManagementAPIRegisterApplicationAgentCredentialProcedure = "/indykite.config.v1beta1.ConfigManagementAPI/RegisterApplicationAgentCredential"
	// ConfigManagementAPIReadApplicationAgentCredentialProcedure is the fully-qualified name of the
	// ConfigManagementAPI's ReadApplicationAgentCredential RPC.
	ConfigManagementAPIReadApplicationAgentCredentialProcedure = "/indykite.config.v1beta1.ConfigManagementAPI/ReadApplicationAgentCredential"
	// ConfigManagementAPIDeleteApplicationAgentCredentialProcedure is the fully-qualified name of the
	// ConfigManagementAPI's DeleteApplicationAgentCredential RPC.
	ConfigManagementAPIDeleteApplicationAgentCredentialProcedure = "/indykite.config.v1beta1.ConfigManagementAPI/DeleteApplicationAgentCredential"
	// ConfigManagementAPICreateServiceAccountProcedure is the fully-qualified name of the
	// ConfigManagementAPI's CreateServiceAccount RPC.
	ConfigManagementAPICreateServiceAccountProcedure = "/indykite.config.v1beta1.ConfigManagementAPI/CreateServiceAccount"
	// ConfigManagementAPIReadServiceAccountProcedure is the fully-qualified name of the
	// ConfigManagementAPI's ReadServiceAccount RPC.
	ConfigManagementAPIReadServiceAccountProcedure = "/indykite.config.v1beta1.ConfigManagementAPI/ReadServiceAccount"
	// ConfigManagementAPIUpdateServiceAccountProcedure is the fully-qualified name of the
	// ConfigManagementAPI's UpdateServiceAccount RPC.
	ConfigManagementAPIUpdateServiceAccountProcedure = "/indykite.config.v1beta1.ConfigManagementAPI/UpdateServiceAccount"
	// ConfigManagementAPIDeleteServiceAccountProcedure is the fully-qualified name of the
	// ConfigManagementAPI's DeleteServiceAccount RPC.
	ConfigManagementAPIDeleteServiceAccountProcedure = "/indykite.config.v1beta1.ConfigManagementAPI/DeleteServiceAccount"
	// ConfigManagementAPIRegisterServiceAccountCredentialProcedure is the fully-qualified name of the
	// ConfigManagementAPI's RegisterServiceAccountCredential RPC.
	ConfigManagementAPIRegisterServiceAccountCredentialProcedure = "/indykite.config.v1beta1.ConfigManagementAPI/RegisterServiceAccountCredential"
	// ConfigManagementAPIReadServiceAccountCredentialProcedure is the fully-qualified name of the
	// ConfigManagementAPI's ReadServiceAccountCredential RPC.
	ConfigManagementAPIReadServiceAccountCredentialProcedure = "/indykite.config.v1beta1.ConfigManagementAPI/ReadServiceAccountCredential"
	// ConfigManagementAPIDeleteServiceAccountCredentialProcedure is the fully-qualified name of the
	// ConfigManagementAPI's DeleteServiceAccountCredential RPC.
	ConfigManagementAPIDeleteServiceAccountCredentialProcedure = "/indykite.config.v1beta1.ConfigManagementAPI/DeleteServiceAccountCredential"
	// ConfigManagementAPICreateConfigNodeProcedure is the fully-qualified name of the
	// ConfigManagementAPI's CreateConfigNode RPC.
	ConfigManagementAPICreateConfigNodeProcedure = "/indykite.config.v1beta1.ConfigManagementAPI/CreateConfigNode"
	// ConfigManagementAPIReadConfigNodeProcedure is the fully-qualified name of the
	// ConfigManagementAPI's ReadConfigNode RPC.
	ConfigManagementAPIReadConfigNodeProcedure = "/indykite.config.v1beta1.ConfigManagementAPI/ReadConfigNode"
	// ConfigManagementAPIUpdateConfigNodeProcedure is the fully-qualified name of the
	// ConfigManagementAPI's UpdateConfigNode RPC.
	ConfigManagementAPIUpdateConfigNodeProcedure = "/indykite.config.v1beta1.ConfigManagementAPI/UpdateConfigNode"
	// ConfigManagementAPIDeleteConfigNodeProcedure is the fully-qualified name of the
	// ConfigManagementAPI's DeleteConfigNode RPC.
	ConfigManagementAPIDeleteConfigNodeProcedure = "/indykite.config.v1beta1.ConfigManagementAPI/DeleteConfigNode"
	// ConfigManagementAPIListConfigNodeVersionsProcedure is the fully-qualified name of the
	// ConfigManagementAPI's ListConfigNodeVersions RPC.
	ConfigManagementAPIListConfigNodeVersionsProcedure = "/indykite.config.v1beta1.ConfigManagementAPI/ListConfigNodeVersions"
	// ConfigManagementAPIAssignPermissionsProcedure is the fully-qualified name of the
	// ConfigManagementAPI's AssignPermissions RPC.
	ConfigManagementAPIAssignPermissionsProcedure = "/indykite.config.v1beta1.ConfigManagementAPI/AssignPermissions"
	// ConfigManagementAPIRevokePermissionsProcedure is the fully-qualified name of the
	// ConfigManagementAPI's RevokePermissions RPC.
	ConfigManagementAPIRevokePermissionsProcedure = "/indykite.config.v1beta1.ConfigManagementAPI/RevokePermissions"
	// ConfigManagementAPIListPermissionsProcedure is the fully-qualified name of the
	// ConfigManagementAPI's ListPermissions RPC.
	ConfigManagementAPIListPermissionsProcedure = "/indykite.config.v1beta1.ConfigManagementAPI/ListPermissions"
)

These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.

Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.

const (
	// ConfigManagementAPIName is the fully-qualified name of the ConfigManagementAPI service.
	ConfigManagementAPIName = "indykite.config.v1beta1.ConfigManagementAPI"
)

Variables

This section is empty.

Functions

func NewConfigManagementAPIHandler

func NewConfigManagementAPIHandler(svc ConfigManagementAPIHandler, opts ...connect_go.HandlerOption) (string, http.Handler)

NewConfigManagementAPIHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.

By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.

Types

type ConfigManagementAPIClient

type ConfigManagementAPIClient interface {
	// ReadCustomer by ID or name, or gets it from a service account and returns all attributes.
	ReadCustomer(context.Context, *connect_go.Request[v1beta1.ReadCustomerRequest]) (*connect_go.Response[v1beta1.ReadCustomerResponse], error)
	// CreateApplicationSpace for a customer.
	CreateApplicationSpace(context.Context, *connect_go.Request[v1beta1.CreateApplicationSpaceRequest]) (*connect_go.Response[v1beta1.CreateApplicationSpaceResponse], error)
	// ReadApplicationSpace by ID or name and returns all attributes.
	ReadApplicationSpace(context.Context, *connect_go.Request[v1beta1.ReadApplicationSpaceRequest]) (*connect_go.Response[v1beta1.ReadApplicationSpaceResponse], error)
	// ListApplicationSpaces in a given customer space with list of names.
	ListApplicationSpaces(context.Context, *connect_go.Request[v1beta1.ListApplicationSpacesRequest]) (*connect_go.ServerStreamForClient[v1beta1.ListApplicationSpacesResponse], error)
	// UpdateApplicationSpace by ID with optional etag, to prevent overwriting changes made by others in the same time.
	UpdateApplicationSpace(context.Context, *connect_go.Request[v1beta1.UpdateApplicationSpaceRequest]) (*connect_go.Response[v1beta1.UpdateApplicationSpaceResponse], error)
	// DeleteApplicationSpace by ID with optional etag, to prevent deleting AppSpace currently changed by others.
	DeleteApplicationSpace(context.Context, *connect_go.Request[v1beta1.DeleteApplicationSpaceRequest]) (*connect_go.Response[v1beta1.DeleteApplicationSpaceResponse], error)
	// CreateApplication in an Application Space.
	CreateApplication(context.Context, *connect_go.Request[v1beta1.CreateApplicationRequest]) (*connect_go.Response[v1beta1.CreateApplicationResponse], error)
	// ReadApplication by ID or name and returns all attributes.
	ReadApplication(context.Context, *connect_go.Request[v1beta1.ReadApplicationRequest]) (*connect_go.Response[v1beta1.ReadApplicationResponse], error)
	// ListApplications in a given Application Space with list of names.
	ListApplications(context.Context, *connect_go.Request[v1beta1.ListApplicationsRequest]) (*connect_go.ServerStreamForClient[v1beta1.ListApplicationsResponse], error)
	// UpdateApplication by ID with optional etag, to prevent overwriting changes made by others in the same time.
	UpdateApplication(context.Context, *connect_go.Request[v1beta1.UpdateApplicationRequest]) (*connect_go.Response[v1beta1.UpdateApplicationResponse], error)
	// DeleteApplication by ID with optional etag, to prevent deleting Application currently changed by others.
	DeleteApplication(context.Context, *connect_go.Request[v1beta1.DeleteApplicationRequest]) (*connect_go.Response[v1beta1.DeleteApplicationResponse], error)
	// CreateApplicationAgent for an Application.
	CreateApplicationAgent(context.Context, *connect_go.Request[v1beta1.CreateApplicationAgentRequest]) (*connect_go.Response[v1beta1.CreateApplicationAgentResponse], error)
	// ReadApplicationAgent by ID or name and returns all attributes.
	ReadApplicationAgent(context.Context, *connect_go.Request[v1beta1.ReadApplicationAgentRequest]) (*connect_go.Response[v1beta1.ReadApplicationAgentResponse], error)
	// ListApplicationAgents in a given Application Space with list of names.
	// The starting point here is Application Space, not Application!
	ListApplicationAgents(context.Context, *connect_go.Request[v1beta1.ListApplicationAgentsRequest]) (*connect_go.ServerStreamForClient[v1beta1.ListApplicationAgentsResponse], error)
	// UpdateApplicationAgent by ID with optional etag, to prevent overwriting changes made by others in the same time.
	UpdateApplicationAgent(context.Context, *connect_go.Request[v1beta1.UpdateApplicationAgentRequest]) (*connect_go.Response[v1beta1.UpdateApplicationAgentResponse], error)
	// DeleteApplicationAgent by ID with optional etag, to prevent deleting ApplicationAgent currently changed by others.
	DeleteApplicationAgent(context.Context, *connect_go.Request[v1beta1.DeleteApplicationAgentRequest]) (*connect_go.Response[v1beta1.DeleteApplicationAgentResponse], error)
	// RegisterApplicationAgentCredential creates new credentials for given application.
	// Methods either accept Public key, which is registered with credentials.
	// Or will generate new Public-Private pair and Private key is returned in Response.
	// Be aware, that in this case, Private key is sent back only once and cannot be retrieved ever again.
	RegisterApplicationAgentCredential(context.Context, *connect_go.Request[v1beta1.RegisterApplicationAgentCredentialRequest]) (*connect_go.Response[v1beta1.RegisterApplicationAgentCredentialResponse], error)
	// ReadApplicationAgentCredential by ID and returns all attributes. But not Private or Public key, so keep them saved.
	ReadApplicationAgentCredential(context.Context, *connect_go.Request[v1beta1.ReadApplicationAgentCredentialRequest]) (*connect_go.Response[v1beta1.ReadApplicationAgentCredentialResponse], error)
	// DeleteApplicationAgentCredential by ID.
	DeleteApplicationAgentCredential(context.Context, *connect_go.Request[v1beta1.DeleteApplicationAgentCredentialRequest]) (*connect_go.Response[v1beta1.DeleteApplicationAgentCredentialResponse], error)
	// CreateServiceAccount for Customer or Application Space.
	CreateServiceAccount(context.Context, *connect_go.Request[v1beta1.CreateServiceAccountRequest]) (*connect_go.Response[v1beta1.CreateServiceAccountResponse], error)
	// ReadServiceAccount by ID or name and returns all attributes.
	ReadServiceAccount(context.Context, *connect_go.Request[v1beta1.ReadServiceAccountRequest]) (*connect_go.Response[v1beta1.ReadServiceAccountResponse], error)
	// UpdateServiceAccount by ID with optional etag, to prevent overwriting changes made by others in the same time.
	UpdateServiceAccount(context.Context, *connect_go.Request[v1beta1.UpdateServiceAccountRequest]) (*connect_go.Response[v1beta1.UpdateServiceAccountResponse], error)
	// DeleteServiceAccount by ID with optional etag, to prevent deleting ServiceAccount currently changed by others.
	DeleteServiceAccount(context.Context, *connect_go.Request[v1beta1.DeleteServiceAccountRequest]) (*connect_go.Response[v1beta1.DeleteServiceAccountResponse], error)
	// RegisterServiceAccountCredential creates new credentials for given Service Account.
	// Methods either accept Public key, which is registered with credentials.
	// Or will generate new Public-Private pair and Private key is returned in Response.
	// Be aware, that in this case, Private key is sent back only once and cannot be retrieved ever again.
	RegisterServiceAccountCredential(context.Context, *connect_go.Request[v1beta1.RegisterServiceAccountCredentialRequest]) (*connect_go.Response[v1beta1.RegisterServiceAccountCredentialResponse], error)
	// ReadServiceAccountCredential by ID and returns all attributes. But not Private or Public key, so keep them saved.
	ReadServiceAccountCredential(context.Context, *connect_go.Request[v1beta1.ReadServiceAccountCredentialRequest]) (*connect_go.Response[v1beta1.ReadServiceAccountCredentialResponse], error)
	// DeleteServiceAccountCredential by ID.
	DeleteServiceAccountCredential(context.Context, *connect_go.Request[v1beta1.DeleteServiceAccountCredentialRequest]) (*connect_go.Response[v1beta1.DeleteServiceAccountCredentialResponse], error)
	// CreateConfigNode on Customer or Application Space.
	// All generic configuration nodes are created by this endpoint.
	CreateConfigNode(context.Context, *connect_go.Request[v1beta1.CreateConfigNodeRequest]) (*connect_go.Response[v1beta1.CreateConfigNodeResponse], error)
	// ReadConfigNode by ID. Method works with all generic configuration objects.
	ReadConfigNode(context.Context, *connect_go.Request[v1beta1.ReadConfigNodeRequest]) (*connect_go.Response[v1beta1.ReadConfigNodeResponse], error)
	// UpdateConfigNode by ID with optional etag, to prevent overwriting changes made by others in the same time.
	UpdateConfigNode(context.Context, *connect_go.Request[v1beta1.UpdateConfigNodeRequest]) (*connect_go.Response[v1beta1.UpdateConfigNodeResponse], error)
	// DeleteConfigNode by ID with optional etag, to prevent deleting configuration object currently changed by others.
	DeleteConfigNode(context.Context, *connect_go.Request[v1beta1.DeleteConfigNodeRequest]) (*connect_go.Response[v1beta1.DeleteConfigNodeResponse], error)
	// ListConfigNodeVersions list previous versions of a given ConfigNode.
	ListConfigNodeVersions(context.Context, *connect_go.Request[v1beta1.ListConfigNodeVersionsRequest]) (*connect_go.Response[v1beta1.ListConfigNodeVersionsResponse], error)
	// AssignPermissions to a digital twin.
	AssignPermissions(context.Context, *connect_go.Request[v1beta1.AssignPermissionsRequest]) (*connect_go.Response[v1beta1.AssignPermissionsResponse], error)
	// RevokePermissions for a digital twin.
	RevokePermissions(context.Context, *connect_go.Request[v1beta1.RevokePermissionsRequest]) (*connect_go.Response[v1beta1.RevokePermissionsResponse], error)
	// ListPermissions of Digital twins and service accounts related to a customer.
	ListPermissions(context.Context, *connect_go.Request[v1beta1.ListPermissionsRequest]) (*connect_go.Response[v1beta1.ListPermissionsResponse], error)
}

ConfigManagementAPIClient is a client for the indykite.config.v1beta1.ConfigManagementAPI service.

func NewConfigManagementAPIClient

func NewConfigManagementAPIClient(httpClient connect_go.HTTPClient, baseURL string, opts ...connect_go.ClientOption) ConfigManagementAPIClient

NewConfigManagementAPIClient constructs a client for the indykite.config.v1beta1.ConfigManagementAPI service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.

The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).

type ConfigManagementAPIHandler

type ConfigManagementAPIHandler interface {
	// ReadCustomer by ID or name, or gets it from a service account and returns all attributes.
	ReadCustomer(context.Context, *connect_go.Request[v1beta1.ReadCustomerRequest]) (*connect_go.Response[v1beta1.ReadCustomerResponse], error)
	// CreateApplicationSpace for a customer.
	CreateApplicationSpace(context.Context, *connect_go.Request[v1beta1.CreateApplicationSpaceRequest]) (*connect_go.Response[v1beta1.CreateApplicationSpaceResponse], error)
	// ReadApplicationSpace by ID or name and returns all attributes.
	ReadApplicationSpace(context.Context, *connect_go.Request[v1beta1.ReadApplicationSpaceRequest]) (*connect_go.Response[v1beta1.ReadApplicationSpaceResponse], error)
	// ListApplicationSpaces in a given customer space with list of names.
	ListApplicationSpaces(context.Context, *connect_go.Request[v1beta1.ListApplicationSpacesRequest], *connect_go.ServerStream[v1beta1.ListApplicationSpacesResponse]) error
	// UpdateApplicationSpace by ID with optional etag, to prevent overwriting changes made by others in the same time.
	UpdateApplicationSpace(context.Context, *connect_go.Request[v1beta1.UpdateApplicationSpaceRequest]) (*connect_go.Response[v1beta1.UpdateApplicationSpaceResponse], error)
	// DeleteApplicationSpace by ID with optional etag, to prevent deleting AppSpace currently changed by others.
	DeleteApplicationSpace(context.Context, *connect_go.Request[v1beta1.DeleteApplicationSpaceRequest]) (*connect_go.Response[v1beta1.DeleteApplicationSpaceResponse], error)
	// CreateApplication in an Application Space.
	CreateApplication(context.Context, *connect_go.Request[v1beta1.CreateApplicationRequest]) (*connect_go.Response[v1beta1.CreateApplicationResponse], error)
	// ReadApplication by ID or name and returns all attributes.
	ReadApplication(context.Context, *connect_go.Request[v1beta1.ReadApplicationRequest]) (*connect_go.Response[v1beta1.ReadApplicationResponse], error)
	// ListApplications in a given Application Space with list of names.
	ListApplications(context.Context, *connect_go.Request[v1beta1.ListApplicationsRequest], *connect_go.ServerStream[v1beta1.ListApplicationsResponse]) error
	// UpdateApplication by ID with optional etag, to prevent overwriting changes made by others in the same time.
	UpdateApplication(context.Context, *connect_go.Request[v1beta1.UpdateApplicationRequest]) (*connect_go.Response[v1beta1.UpdateApplicationResponse], error)
	// DeleteApplication by ID with optional etag, to prevent deleting Application currently changed by others.
	DeleteApplication(context.Context, *connect_go.Request[v1beta1.DeleteApplicationRequest]) (*connect_go.Response[v1beta1.DeleteApplicationResponse], error)
	// CreateApplicationAgent for an Application.
	CreateApplicationAgent(context.Context, *connect_go.Request[v1beta1.CreateApplicationAgentRequest]) (*connect_go.Response[v1beta1.CreateApplicationAgentResponse], error)
	// ReadApplicationAgent by ID or name and returns all attributes.
	ReadApplicationAgent(context.Context, *connect_go.Request[v1beta1.ReadApplicationAgentRequest]) (*connect_go.Response[v1beta1.ReadApplicationAgentResponse], error)
	// ListApplicationAgents in a given Application Space with list of names.
	// The starting point here is Application Space, not Application!
	ListApplicationAgents(context.Context, *connect_go.Request[v1beta1.ListApplicationAgentsRequest], *connect_go.ServerStream[v1beta1.ListApplicationAgentsResponse]) error
	// UpdateApplicationAgent by ID with optional etag, to prevent overwriting changes made by others in the same time.
	UpdateApplicationAgent(context.Context, *connect_go.Request[v1beta1.UpdateApplicationAgentRequest]) (*connect_go.Response[v1beta1.UpdateApplicationAgentResponse], error)
	// DeleteApplicationAgent by ID with optional etag, to prevent deleting ApplicationAgent currently changed by others.
	DeleteApplicationAgent(context.Context, *connect_go.Request[v1beta1.DeleteApplicationAgentRequest]) (*connect_go.Response[v1beta1.DeleteApplicationAgentResponse], error)
	// RegisterApplicationAgentCredential creates new credentials for given application.
	// Methods either accept Public key, which is registered with credentials.
	// Or will generate new Public-Private pair and Private key is returned in Response.
	// Be aware, that in this case, Private key is sent back only once and cannot be retrieved ever again.
	RegisterApplicationAgentCredential(context.Context, *connect_go.Request[v1beta1.RegisterApplicationAgentCredentialRequest]) (*connect_go.Response[v1beta1.RegisterApplicationAgentCredentialResponse], error)
	// ReadApplicationAgentCredential by ID and returns all attributes. But not Private or Public key, so keep them saved.
	ReadApplicationAgentCredential(context.Context, *connect_go.Request[v1beta1.ReadApplicationAgentCredentialRequest]) (*connect_go.Response[v1beta1.ReadApplicationAgentCredentialResponse], error)
	// DeleteApplicationAgentCredential by ID.
	DeleteApplicationAgentCredential(context.Context, *connect_go.Request[v1beta1.DeleteApplicationAgentCredentialRequest]) (*connect_go.Response[v1beta1.DeleteApplicationAgentCredentialResponse], error)
	// CreateServiceAccount for Customer or Application Space.
	CreateServiceAccount(context.Context, *connect_go.Request[v1beta1.CreateServiceAccountRequest]) (*connect_go.Response[v1beta1.CreateServiceAccountResponse], error)
	// ReadServiceAccount by ID or name and returns all attributes.
	ReadServiceAccount(context.Context, *connect_go.Request[v1beta1.ReadServiceAccountRequest]) (*connect_go.Response[v1beta1.ReadServiceAccountResponse], error)
	// UpdateServiceAccount by ID with optional etag, to prevent overwriting changes made by others in the same time.
	UpdateServiceAccount(context.Context, *connect_go.Request[v1beta1.UpdateServiceAccountRequest]) (*connect_go.Response[v1beta1.UpdateServiceAccountResponse], error)
	// DeleteServiceAccount by ID with optional etag, to prevent deleting ServiceAccount currently changed by others.
	DeleteServiceAccount(context.Context, *connect_go.Request[v1beta1.DeleteServiceAccountRequest]) (*connect_go.Response[v1beta1.DeleteServiceAccountResponse], error)
	// RegisterServiceAccountCredential creates new credentials for given Service Account.
	// Methods either accept Public key, which is registered with credentials.
	// Or will generate new Public-Private pair and Private key is returned in Response.
	// Be aware, that in this case, Private key is sent back only once and cannot be retrieved ever again.
	RegisterServiceAccountCredential(context.Context, *connect_go.Request[v1beta1.RegisterServiceAccountCredentialRequest]) (*connect_go.Response[v1beta1.RegisterServiceAccountCredentialResponse], error)
	// ReadServiceAccountCredential by ID and returns all attributes. But not Private or Public key, so keep them saved.
	ReadServiceAccountCredential(context.Context, *connect_go.Request[v1beta1.ReadServiceAccountCredentialRequest]) (*connect_go.Response[v1beta1.ReadServiceAccountCredentialResponse], error)
	// DeleteServiceAccountCredential by ID.
	DeleteServiceAccountCredential(context.Context, *connect_go.Request[v1beta1.DeleteServiceAccountCredentialRequest]) (*connect_go.Response[v1beta1.DeleteServiceAccountCredentialResponse], error)
	// CreateConfigNode on Customer or Application Space.
	// All generic configuration nodes are created by this endpoint.
	CreateConfigNode(context.Context, *connect_go.Request[v1beta1.CreateConfigNodeRequest]) (*connect_go.Response[v1beta1.CreateConfigNodeResponse], error)
	// ReadConfigNode by ID. Method works with all generic configuration objects.
	ReadConfigNode(context.Context, *connect_go.Request[v1beta1.ReadConfigNodeRequest]) (*connect_go.Response[v1beta1.ReadConfigNodeResponse], error)
	// UpdateConfigNode by ID with optional etag, to prevent overwriting changes made by others in the same time.
	UpdateConfigNode(context.Context, *connect_go.Request[v1beta1.UpdateConfigNodeRequest]) (*connect_go.Response[v1beta1.UpdateConfigNodeResponse], error)
	// DeleteConfigNode by ID with optional etag, to prevent deleting configuration object currently changed by others.
	DeleteConfigNode(context.Context, *connect_go.Request[v1beta1.DeleteConfigNodeRequest]) (*connect_go.Response[v1beta1.DeleteConfigNodeResponse], error)
	// ListConfigNodeVersions list previous versions of a given ConfigNode.
	ListConfigNodeVersions(context.Context, *connect_go.Request[v1beta1.ListConfigNodeVersionsRequest]) (*connect_go.Response[v1beta1.ListConfigNodeVersionsResponse], error)
	// AssignPermissions to a digital twin.
	AssignPermissions(context.Context, *connect_go.Request[v1beta1.AssignPermissionsRequest]) (*connect_go.Response[v1beta1.AssignPermissionsResponse], error)
	// RevokePermissions for a digital twin.
	RevokePermissions(context.Context, *connect_go.Request[v1beta1.RevokePermissionsRequest]) (*connect_go.Response[v1beta1.RevokePermissionsResponse], error)
	// ListPermissions of Digital twins and service accounts related to a customer.
	ListPermissions(context.Context, *connect_go.Request[v1beta1.ListPermissionsRequest]) (*connect_go.Response[v1beta1.ListPermissionsResponse], error)
}

ConfigManagementAPIHandler is an implementation of the indykite.config.v1beta1.ConfigManagementAPI service.

type UnimplementedConfigManagementAPIHandler

type UnimplementedConfigManagementAPIHandler struct{}

UnimplementedConfigManagementAPIHandler returns CodeUnimplemented from all methods.

func (UnimplementedConfigManagementAPIHandler) AssignPermissions

func (UnimplementedConfigManagementAPIHandler) CreateApplication

func (UnimplementedConfigManagementAPIHandler) CreateApplicationAgent

func (UnimplementedConfigManagementAPIHandler) CreateApplicationSpace

func (UnimplementedConfigManagementAPIHandler) CreateConfigNode

func (UnimplementedConfigManagementAPIHandler) CreateServiceAccount

func (UnimplementedConfigManagementAPIHandler) DeleteApplication

func (UnimplementedConfigManagementAPIHandler) DeleteApplicationAgent

func (UnimplementedConfigManagementAPIHandler) DeleteApplicationAgentCredential

func (UnimplementedConfigManagementAPIHandler) DeleteApplicationSpace

func (UnimplementedConfigManagementAPIHandler) DeleteConfigNode

func (UnimplementedConfigManagementAPIHandler) DeleteServiceAccount

func (UnimplementedConfigManagementAPIHandler) DeleteServiceAccountCredential

func (UnimplementedConfigManagementAPIHandler) ListApplicationAgents

func (UnimplementedConfigManagementAPIHandler) ListApplicationSpaces

func (UnimplementedConfigManagementAPIHandler) ListApplications

func (UnimplementedConfigManagementAPIHandler) ListConfigNodeVersions

func (UnimplementedConfigManagementAPIHandler) ListPermissions

func (UnimplementedConfigManagementAPIHandler) ReadApplication

func (UnimplementedConfigManagementAPIHandler) ReadApplicationAgent

func (UnimplementedConfigManagementAPIHandler) ReadApplicationAgentCredential

func (UnimplementedConfigManagementAPIHandler) ReadApplicationSpace

func (UnimplementedConfigManagementAPIHandler) ReadConfigNode

func (UnimplementedConfigManagementAPIHandler) ReadCustomer

func (UnimplementedConfigManagementAPIHandler) ReadServiceAccount

func (UnimplementedConfigManagementAPIHandler) ReadServiceAccountCredential

func (UnimplementedConfigManagementAPIHandler) RegisterApplicationAgentCredential

func (UnimplementedConfigManagementAPIHandler) RegisterServiceAccountCredential

func (UnimplementedConfigManagementAPIHandler) RevokePermissions

func (UnimplementedConfigManagementAPIHandler) UpdateApplication

func (UnimplementedConfigManagementAPIHandler) UpdateApplicationAgent

func (UnimplementedConfigManagementAPIHandler) UpdateApplicationSpace

func (UnimplementedConfigManagementAPIHandler) UpdateConfigNode

func (UnimplementedConfigManagementAPIHandler) UpdateServiceAccount

Source Files

  • config_management_api.connect.go

Jump to