ingestv1beta3connect

package
v1.10.0-20260616014004... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	// IngestAPIStreamRecordsProcedure is the fully-qualified name of the IngestAPI's StreamRecords RPC.
	IngestAPIStreamRecordsProcedure = "/indykite.ingest.v1beta3.IngestAPI/StreamRecords"
	// IngestAPIIngestRecordProcedure is the fully-qualified name of the IngestAPI's IngestRecord RPC.
	IngestAPIIngestRecordProcedure = "/indykite.ingest.v1beta3.IngestAPI/IngestRecord"
	// IngestAPIBatchIngestRecordProcedure is the fully-qualified name of the IngestAPI's
	// BatchIngestRecord RPC.
	IngestAPIBatchIngestRecordProcedure = "/indykite.ingest.v1beta3.IngestAPI/BatchIngestRecord"
	// IngestAPIBatchUpsertNodesProcedure is the fully-qualified name of the IngestAPI's
	// BatchUpsertNodes RPC.
	IngestAPIBatchUpsertNodesProcedure = "/indykite.ingest.v1beta3.IngestAPI/BatchUpsertNodes"
	// IngestAPIBatchUpsertRelationshipsProcedure is the fully-qualified name of the IngestAPI's
	// BatchUpsertRelationships RPC.
	IngestAPIBatchUpsertRelationshipsProcedure = "/indykite.ingest.v1beta3.IngestAPI/BatchUpsertRelationships"
	// IngestAPIBatchDeleteNodesProcedure is the fully-qualified name of the IngestAPI's
	// BatchDeleteNodes RPC.
	IngestAPIBatchDeleteNodesProcedure = "/indykite.ingest.v1beta3.IngestAPI/BatchDeleteNodes"
	// IngestAPIBatchDeleteRelationshipsProcedure is the fully-qualified name of the IngestAPI's
	// BatchDeleteRelationships RPC.
	IngestAPIBatchDeleteRelationshipsProcedure = "/indykite.ingest.v1beta3.IngestAPI/BatchDeleteRelationships"
	// IngestAPIBatchDeleteNodePropertiesProcedure is the fully-qualified name of the IngestAPI's
	// BatchDeleteNodeProperties RPC.
	IngestAPIBatchDeleteNodePropertiesProcedure = "/indykite.ingest.v1beta3.IngestAPI/BatchDeleteNodeProperties"
	// IngestAPIBatchDeleteRelationshipPropertiesProcedure is the fully-qualified name of the
	// IngestAPI's BatchDeleteRelationshipProperties RPC.
	IngestAPIBatchDeleteRelationshipPropertiesProcedure = "/indykite.ingest.v1beta3.IngestAPI/BatchDeleteRelationshipProperties"
	// IngestAPIBatchDeleteNodeTagsProcedure is the fully-qualified name of the IngestAPI's
	// BatchDeleteNodeTags RPC.
	IngestAPIBatchDeleteNodeTagsProcedure = "/indykite.ingest.v1beta3.IngestAPI/BatchDeleteNodeTags"
)

These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.

Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.

const (
	// IngestAPIName is the fully-qualified name of the IngestAPI service.
	IngestAPIName = "indykite.ingest.v1beta3.IngestAPI"
)

Variables

This section is empty.

Functions

func NewIngestAPIHandler

func NewIngestAPIHandler(svc IngestAPIHandler, opts ...connect_go.HandlerOption) (string, http.Handler)

NewIngestAPIHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.

By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.

Types

type IngestAPIClient

type IngestAPIClient interface {
	// Deprecated: do not use.
	StreamRecords(context.Context) *connect_go.BidiStreamForClient[v1beta3.StreamRecordsRequest, v1beta3.StreamRecordsResponse]
	// Deprecated: do not use.
	IngestRecord(context.Context, *connect_go.Request[v1beta3.IngestRecordRequest]) (*connect_go.Response[v1beta3.IngestRecordResponse], error)
	BatchIngestRecord(context.Context, *connect_go.Request[v1beta3.BatchIngestRecordRequest]) (*connect_go.Response[v1beta3.BatchIngestRecordResponse], error)
	// Deprecated: do not use.
	BatchUpsertNodes(context.Context, *connect_go.Request[v1beta3.BatchUpsertNodesRequest]) (*connect_go.Response[v1beta3.BatchUpsertNodesResponse], error)
	// Deprecated: do not use.
	BatchUpsertRelationships(context.Context, *connect_go.Request[v1beta3.BatchUpsertRelationshipsRequest]) (*connect_go.Response[v1beta3.BatchUpsertRelationshipsResponse], error)
	// Deprecated: do not use.
	BatchDeleteNodes(context.Context, *connect_go.Request[v1beta3.BatchDeleteNodesRequest]) (*connect_go.Response[v1beta3.BatchDeleteNodesResponse], error)
	// Deprecated: do not use.
	BatchDeleteRelationships(context.Context, *connect_go.Request[v1beta3.BatchDeleteRelationshipsRequest]) (*connect_go.Response[v1beta3.BatchDeleteRelationshipsResponse], error)
	// Deprecated: do not use.
	BatchDeleteNodeProperties(context.Context, *connect_go.Request[v1beta3.BatchDeleteNodePropertiesRequest]) (*connect_go.Response[v1beta3.BatchDeleteNodePropertiesResponse], error)
	// Deprecated: do not use.
	BatchDeleteRelationshipProperties(context.Context, *connect_go.Request[v1beta3.BatchDeleteRelationshipPropertiesRequest]) (*connect_go.Response[v1beta3.BatchDeleteRelationshipPropertiesResponse], error)
	// Deprecated: do not use.
	BatchDeleteNodeTags(context.Context, *connect_go.Request[v1beta3.BatchDeleteNodeTagsRequest]) (*connect_go.Response[v1beta3.BatchDeleteNodeTagsResponse], error)
}

IngestAPIClient is a client for the indykite.ingest.v1beta3.IngestAPI service.

func NewIngestAPIClient

func NewIngestAPIClient(httpClient connect_go.HTTPClient, baseURL string, opts ...connect_go.ClientOption) IngestAPIClient

NewIngestAPIClient constructs a client for the indykite.ingest.v1beta3.IngestAPI service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.

The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).

type IngestAPIHandler

type IngestAPIHandler interface {
	// Deprecated: do not use.
	StreamRecords(context.Context, *connect_go.BidiStream[v1beta3.StreamRecordsRequest, v1beta3.StreamRecordsResponse]) error
	// Deprecated: do not use.
	IngestRecord(context.Context, *connect_go.Request[v1beta3.IngestRecordRequest]) (*connect_go.Response[v1beta3.IngestRecordResponse], error)
	BatchIngestRecord(context.Context, *connect_go.Request[v1beta3.BatchIngestRecordRequest]) (*connect_go.Response[v1beta3.BatchIngestRecordResponse], error)
	// Deprecated: do not use.
	BatchUpsertNodes(context.Context, *connect_go.Request[v1beta3.BatchUpsertNodesRequest]) (*connect_go.Response[v1beta3.BatchUpsertNodesResponse], error)
	// Deprecated: do not use.
	BatchUpsertRelationships(context.Context, *connect_go.Request[v1beta3.BatchUpsertRelationshipsRequest]) (*connect_go.Response[v1beta3.BatchUpsertRelationshipsResponse], error)
	// Deprecated: do not use.
	BatchDeleteNodes(context.Context, *connect_go.Request[v1beta3.BatchDeleteNodesRequest]) (*connect_go.Response[v1beta3.BatchDeleteNodesResponse], error)
	// Deprecated: do not use.
	BatchDeleteRelationships(context.Context, *connect_go.Request[v1beta3.BatchDeleteRelationshipsRequest]) (*connect_go.Response[v1beta3.BatchDeleteRelationshipsResponse], error)
	// Deprecated: do not use.
	BatchDeleteNodeProperties(context.Context, *connect_go.Request[v1beta3.BatchDeleteNodePropertiesRequest]) (*connect_go.Response[v1beta3.BatchDeleteNodePropertiesResponse], error)
	// Deprecated: do not use.
	BatchDeleteRelationshipProperties(context.Context, *connect_go.Request[v1beta3.BatchDeleteRelationshipPropertiesRequest]) (*connect_go.Response[v1beta3.BatchDeleteRelationshipPropertiesResponse], error)
	// Deprecated: do not use.
	BatchDeleteNodeTags(context.Context, *connect_go.Request[v1beta3.BatchDeleteNodeTagsRequest]) (*connect_go.Response[v1beta3.BatchDeleteNodeTagsResponse], error)
}

IngestAPIHandler is an implementation of the indykite.ingest.v1beta3.IngestAPI service.

type UnimplementedIngestAPIHandler

type UnimplementedIngestAPIHandler struct{}

UnimplementedIngestAPIHandler returns CodeUnimplemented from all methods.

func (UnimplementedIngestAPIHandler) BatchDeleteNodeProperties

func (UnimplementedIngestAPIHandler) BatchDeleteNodeTags

func (UnimplementedIngestAPIHandler) BatchDeleteNodes

func (UnimplementedIngestAPIHandler) BatchDeleteRelationshipProperties

func (UnimplementedIngestAPIHandler) BatchDeleteRelationships

func (UnimplementedIngestAPIHandler) BatchIngestRecord

func (UnimplementedIngestAPIHandler) BatchUpsertNodes

func (UnimplementedIngestAPIHandler) BatchUpsertRelationships

func (UnimplementedIngestAPIHandler) IngestRecord

func (UnimplementedIngestAPIHandler) StreamRecords

Source Files

  • ingest_api.connect.go

Jump to