knowledgev1beta2connect

package
v1.10.0-20260116133316... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	// IdentityKnowledgeAPIIdentityKnowledgeReadProcedure is the fully-qualified name of the
	// IdentityKnowledgeAPI's IdentityKnowledgeRead RPC.
	IdentityKnowledgeAPIIdentityKnowledgeReadProcedure = "/indykite.knowledge.v1beta2.IdentityKnowledgeAPI/IdentityKnowledgeRead"
)

These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.

Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.

const (
	// IdentityKnowledgeAPIName is the fully-qualified name of the IdentityKnowledgeAPI service.
	IdentityKnowledgeAPIName = "indykite.knowledge.v1beta2.IdentityKnowledgeAPI"
)

Variables

This section is empty.

Functions

func NewIdentityKnowledgeAPIHandler

func NewIdentityKnowledgeAPIHandler(svc IdentityKnowledgeAPIHandler, opts ...connect_go.HandlerOption) (string, http.Handler)

NewIdentityKnowledgeAPIHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.

By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.

Types

type IdentityKnowledgeAPIClient

type IdentityKnowledgeAPIClient interface {
	// Deprecated: do not use.
	IdentityKnowledgeRead(context.Context, *connect_go.Request[v1beta2.IdentityKnowledgeReadRequest]) (*connect_go.Response[v1beta2.IdentityKnowledgeReadResponse], error)
}

IdentityKnowledgeAPIClient is a client for the indykite.knowledge.v1beta2.IdentityKnowledgeAPI service.

func NewIdentityKnowledgeAPIClient

func NewIdentityKnowledgeAPIClient(httpClient connect_go.HTTPClient, baseURL string, opts ...connect_go.ClientOption) IdentityKnowledgeAPIClient

NewIdentityKnowledgeAPIClient constructs a client for the indykite.knowledge.v1beta2.IdentityKnowledgeAPI service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.

The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).

type IdentityKnowledgeAPIHandler

type IdentityKnowledgeAPIHandler interface {
	// Deprecated: do not use.
	IdentityKnowledgeRead(context.Context, *connect_go.Request[v1beta2.IdentityKnowledgeReadRequest]) (*connect_go.Response[v1beta2.IdentityKnowledgeReadResponse], error)
}

IdentityKnowledgeAPIHandler is an implementation of the indykite.knowledge.v1beta2.IdentityKnowledgeAPI service.

type UnimplementedIdentityKnowledgeAPIHandler

type UnimplementedIdentityKnowledgeAPIHandler struct{}

UnimplementedIdentityKnowledgeAPIHandler returns CodeUnimplemented from all methods.

func (UnimplementedIdentityKnowledgeAPIHandler) IdentityKnowledgeRead

Source Files

  • identity_knowledge_api.connect.go

Jump to