authorizationv1beta1

package
v1.36.11-2026020416421... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 9 Imported by: 1

Documentation

Index

Constants

const InputParam_ArrayValue_case case_InputParam_Value = 7
const InputParam_BoolValue_case case_InputParam_Value = 2
const InputParam_DoubleValue_case case_InputParam_Value = 4
const InputParam_DurationValue_case case_InputParam_Value = 6
const InputParam_IntegerValue_case case_InputParam_Value = 3
const InputParam_MapValue_case case_InputParam_Value = 8
const InputParam_StringValue_case case_InputParam_Value = 1
const InputParam_TimeValue_case case_InputParam_Value = 5
const InputParam_Value_not_set_case case_InputParam_Value = 0
const Subject_AccessToken_case case_Subject_Subject = 4
const Subject_DigitalTwinId_case case_Subject_Subject = 2
const Subject_DigitalTwinProperty_case case_Subject_Subject = 3
const Subject_ExternalId_case case_Subject_Subject = 5
const Subject_Subject_not_set_case case_Subject_Subject = 0

Variables

var File_indykite_authorization_v1beta1_authorization_service_proto protoreflect.FileDescriptor
var File_indykite_authorization_v1beta1_model_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type DigitalTwin

type DigitalTwin struct {

	// Id the unique credential identifier.
	Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	// contains filtered or unexported fields
}

DigitalTwin represents a digital entity.

func (*DigitalTwin) GetId

func (x *DigitalTwin) GetId() string

func (*DigitalTwin) ProtoMessage

func (*DigitalTwin) ProtoMessage()

func (*DigitalTwin) ProtoReflect

func (x *DigitalTwin) ProtoReflect() protoreflect.Message

func (*DigitalTwin) Reset

func (x *DigitalTwin) Reset()

func (*DigitalTwin) SetId

func (x *DigitalTwin) SetId(v string)

func (*DigitalTwin) String

func (x *DigitalTwin) String() string

type DigitalTwin_builder

type DigitalTwin_builder struct {

	// Id the unique credential identifier.
	Id string
	// contains filtered or unexported fields
}

func (DigitalTwin_builder) Build

func (b0 DigitalTwin_builder) Build() *DigitalTwin

type ExternalID

type ExternalID struct {
	Type       string `protobuf:"bytes,1,opt,name=type,proto3" json:"type,omitempty"`
	ExternalId string `protobuf:"bytes,2,opt,name=external_id,json=externalId,proto3" json:"external_id,omitempty"`
	// contains filtered or unexported fields
}

func (*ExternalID) GetExternalId

func (x *ExternalID) GetExternalId() string

func (*ExternalID) GetType

func (x *ExternalID) GetType() string

func (*ExternalID) ProtoMessage

func (*ExternalID) ProtoMessage()

func (*ExternalID) ProtoReflect

func (x *ExternalID) ProtoReflect() protoreflect.Message

func (*ExternalID) Reset

func (x *ExternalID) Reset()

func (*ExternalID) SetExternalId

func (x *ExternalID) SetExternalId(v string)

func (*ExternalID) SetType

func (x *ExternalID) SetType(v string)

func (*ExternalID) String

func (x *ExternalID) String() string

type ExternalID_builder

type ExternalID_builder struct {
	Type       string
	ExternalId string
	// contains filtered or unexported fields
}

func (ExternalID_builder) Build

func (b0 ExternalID_builder) Build() *ExternalID

type InputParam

type InputParam struct {

	// Types that are valid to be assigned to Value:
	//
	//	*InputParam_StringValue
	//	*InputParam_BoolValue
	//	*InputParam_IntegerValue
	//	*InputParam_DoubleValue
	//	*InputParam_TimeValue
	//	*InputParam_DurationValue
	//	*InputParam_ArrayValue
	//	*InputParam_MapValue
	Value isInputParam_Value `protobuf_oneof:"value"`
	// contains filtered or unexported fields
}

func (*InputParam) ClearArrayValue

func (x *InputParam) ClearArrayValue()

func (*InputParam) ClearBoolValue

func (x *InputParam) ClearBoolValue()

func (*InputParam) ClearDoubleValue

func (x *InputParam) ClearDoubleValue()

func (*InputParam) ClearDurationValue

func (x *InputParam) ClearDurationValue()

func (*InputParam) ClearIntegerValue

func (x *InputParam) ClearIntegerValue()

func (*InputParam) ClearMapValue

func (x *InputParam) ClearMapValue()

func (*InputParam) ClearStringValue

func (x *InputParam) ClearStringValue()

func (*InputParam) ClearTimeValue

func (x *InputParam) ClearTimeValue()

func (*InputParam) ClearValue

func (x *InputParam) ClearValue()

func (*InputParam) GetArrayValue

func (x *InputParam) GetArrayValue() *v1beta2.Array

func (*InputParam) GetBoolValue

func (x *InputParam) GetBoolValue() bool

func (*InputParam) GetDoubleValue

func (x *InputParam) GetDoubleValue() float64

func (*InputParam) GetDurationValue

func (x *InputParam) GetDurationValue() *durationpb.Duration

func (*InputParam) GetIntegerValue

func (x *InputParam) GetIntegerValue() int64

func (*InputParam) GetMapValue

func (x *InputParam) GetMapValue() *v1beta2.Map

func (*InputParam) GetStringValue

func (x *InputParam) GetStringValue() string

func (*InputParam) GetTimeValue

func (x *InputParam) GetTimeValue() *timestamppb.Timestamp

func (*InputParam) GetValue

func (x *InputParam) GetValue() isInputParam_Value

func (*InputParam) HasArrayValue

func (x *InputParam) HasArrayValue() bool

func (*InputParam) HasBoolValue

func (x *InputParam) HasBoolValue() bool

func (*InputParam) HasDoubleValue

func (x *InputParam) HasDoubleValue() bool

func (*InputParam) HasDurationValue

func (x *InputParam) HasDurationValue() bool

func (*InputParam) HasIntegerValue

func (x *InputParam) HasIntegerValue() bool

func (*InputParam) HasMapValue

func (x *InputParam) HasMapValue() bool

func (*InputParam) HasStringValue

func (x *InputParam) HasStringValue() bool

func (*InputParam) HasTimeValue

func (x *InputParam) HasTimeValue() bool

func (*InputParam) HasValue

func (x *InputParam) HasValue() bool

func (*InputParam) ProtoMessage

func (*InputParam) ProtoMessage()

func (*InputParam) ProtoReflect

func (x *InputParam) ProtoReflect() protoreflect.Message

func (*InputParam) Reset

func (x *InputParam) Reset()

func (*InputParam) SetArrayValue

func (x *InputParam) SetArrayValue(v *v1beta2.Array)

func (*InputParam) SetBoolValue

func (x *InputParam) SetBoolValue(v bool)

func (*InputParam) SetDoubleValue

func (x *InputParam) SetDoubleValue(v float64)

func (*InputParam) SetDurationValue

func (x *InputParam) SetDurationValue(v *durationpb.Duration)

func (*InputParam) SetIntegerValue

func (x *InputParam) SetIntegerValue(v int64)

func (*InputParam) SetMapValue

func (x *InputParam) SetMapValue(v *v1beta2.Map)

func (*InputParam) SetStringValue

func (x *InputParam) SetStringValue(v string)

func (*InputParam) SetTimeValue

func (x *InputParam) SetTimeValue(v *timestamppb.Timestamp)

func (*InputParam) String

func (x *InputParam) String() string

func (*InputParam) WhichValue

func (x *InputParam) WhichValue() case_InputParam_Value

type InputParam_ArrayValue

type InputParam_ArrayValue struct {
	// An array value.
	ArrayValue *v1beta2.Array `protobuf:"bytes,7,opt,name=array_value,json=arrayValue,proto3,oneof"`
}

type InputParam_BoolValue

type InputParam_BoolValue struct {
	// A boolean value.
	BoolValue bool `protobuf:"varint,2,opt,name=bool_value,json=boolValue,proto3,oneof"`
}

type InputParam_DoubleValue

type InputParam_DoubleValue struct {
	// A double value.
	DoubleValue float64 `protobuf:"fixed64,4,opt,name=double_value,json=doubleValue,proto3,oneof"`
}

type InputParam_DurationValue

type InputParam_DurationValue struct {
	// A duration value.
	DurationValue *durationpb.Duration `protobuf:"bytes,6,opt,name=duration_value,json=durationValue,proto3,oneof"`
}

type InputParam_IntegerValue

type InputParam_IntegerValue struct {
	// An integer value.
	IntegerValue int64 `protobuf:"varint,3,opt,name=integer_value,json=integerValue,proto3,oneof"`
}

type InputParam_MapValue

type InputParam_MapValue struct {
	// A map value.
	MapValue *v1beta2.Map `protobuf:"bytes,8,opt,name=map_value,json=mapValue,proto3,oneof"`
}

type InputParam_StringValue

type InputParam_StringValue struct {
	// A string value.
	StringValue string `protobuf:"bytes,1,opt,name=string_value,json=stringValue,proto3,oneof"`
}

type InputParam_TimeValue

type InputParam_TimeValue struct {
	// A timestamp value.
	TimeValue *timestamppb.Timestamp `protobuf:"bytes,5,opt,name=time_value,json=timeValue,proto3,oneof"`
}

type InputParam_builder

type InputParam_builder struct {

	// Fields of oneof Value:
	// A string value.
	StringValue *string
	// A boolean value.
	BoolValue *bool
	// An integer value.
	IntegerValue *int64
	// A double value.
	DoubleValue *float64
	// A timestamp value.
	TimeValue *timestamppb.Timestamp
	// A duration value.
	DurationValue *durationpb.Duration
	// An array value.
	ArrayValue *v1beta2.Array
	// A map value.
	MapValue *v1beta2.Map
	// contains filtered or unexported fields
}

func (InputParam_builder) Build

func (b0 InputParam_builder) Build() *InputParam

type IsAuthorizedRequest

type IsAuthorizedRequest struct {

	// Subject to check if is authorized to perform given actions.
	Subject *Subject `protobuf:"bytes,1,opt,name=subject,proto3" json:"subject,omitempty"`
	// A list of resources to authorize against.
	Resources []*IsAuthorizedRequest_Resource `protobuf:"bytes,2,rep,name=resources,proto3" json:"resources,omitempty"`
	// Policy input params
	InputParams map[string]*InputParam `` /* 168-byte string literal not displayed */
	// Only evaluate polices containing provided tags
	PolicyTags []string `protobuf:"bytes,4,rep,name=policy_tags,json=policyTags,proto3" json:"policy_tags,omitempty"`
	// contains filtered or unexported fields
}

func (*IsAuthorizedRequest) ClearSubject

func (x *IsAuthorizedRequest) ClearSubject()

func (*IsAuthorizedRequest) GetInputParams

func (x *IsAuthorizedRequest) GetInputParams() map[string]*InputParam

func (*IsAuthorizedRequest) GetPolicyTags

func (x *IsAuthorizedRequest) GetPolicyTags() []string

func (*IsAuthorizedRequest) GetResources

func (*IsAuthorizedRequest) GetSubject

func (x *IsAuthorizedRequest) GetSubject() *Subject

func (*IsAuthorizedRequest) HasSubject

func (x *IsAuthorizedRequest) HasSubject() bool

func (*IsAuthorizedRequest) ProtoMessage

func (*IsAuthorizedRequest) ProtoMessage()

func (*IsAuthorizedRequest) ProtoReflect

func (x *IsAuthorizedRequest) ProtoReflect() protoreflect.Message

func (*IsAuthorizedRequest) Reset

func (x *IsAuthorizedRequest) Reset()

func (*IsAuthorizedRequest) SetInputParams

func (x *IsAuthorizedRequest) SetInputParams(v map[string]*InputParam)

func (*IsAuthorizedRequest) SetPolicyTags

func (x *IsAuthorizedRequest) SetPolicyTags(v []string)

func (*IsAuthorizedRequest) SetResources

func (x *IsAuthorizedRequest) SetResources(v []*IsAuthorizedRequest_Resource)

func (*IsAuthorizedRequest) SetSubject

func (x *IsAuthorizedRequest) SetSubject(v *Subject)

func (*IsAuthorizedRequest) String

func (x *IsAuthorizedRequest) String() string

type IsAuthorizedRequest_Resource

type IsAuthorizedRequest_Resource struct {

	// Resource external id.
	ExternalId string `protobuf:"bytes,1,opt,name=external_id,json=externalId,proto3" json:"external_id,omitempty"`
	// Resource type.
	Type string `protobuf:"bytes,2,opt,name=type,proto3" json:"type,omitempty"`
	// A list of actions the subject want to perform.
	Actions []string `protobuf:"bytes,3,rep,name=actions,proto3" json:"actions,omitempty"`
	// contains filtered or unexported fields
}

Resource to authorize against.

func (*IsAuthorizedRequest_Resource) GetActions

func (x *IsAuthorizedRequest_Resource) GetActions() []string

func (*IsAuthorizedRequest_Resource) GetExternalId

func (x *IsAuthorizedRequest_Resource) GetExternalId() string

func (*IsAuthorizedRequest_Resource) GetType

func (x *IsAuthorizedRequest_Resource) GetType() string

func (*IsAuthorizedRequest_Resource) ProtoMessage

func (*IsAuthorizedRequest_Resource) ProtoMessage()

func (*IsAuthorizedRequest_Resource) ProtoReflect

func (*IsAuthorizedRequest_Resource) Reset

func (x *IsAuthorizedRequest_Resource) Reset()

func (*IsAuthorizedRequest_Resource) SetActions

func (x *IsAuthorizedRequest_Resource) SetActions(v []string)

func (*IsAuthorizedRequest_Resource) SetExternalId

func (x *IsAuthorizedRequest_Resource) SetExternalId(v string)

func (*IsAuthorizedRequest_Resource) SetType

func (x *IsAuthorizedRequest_Resource) SetType(v string)

func (*IsAuthorizedRequest_Resource) String

type IsAuthorizedRequest_Resource_builder

type IsAuthorizedRequest_Resource_builder struct {

	// Resource external id.
	ExternalId string
	// Resource type.
	Type string
	// A list of actions the subject want to perform.
	Actions []string
	// contains filtered or unexported fields
}

func (IsAuthorizedRequest_Resource_builder) Build

type IsAuthorizedRequest_builder

type IsAuthorizedRequest_builder struct {

	// Subject to check if is authorized to perform given actions.
	Subject *Subject
	// A list of resources to authorize against.
	Resources []*IsAuthorizedRequest_Resource
	// Policy input params
	InputParams map[string]*InputParam
	// Only evaluate polices containing provided tags
	PolicyTags []string
	// contains filtered or unexported fields
}

func (IsAuthorizedRequest_builder) Build

type IsAuthorizedResponse

type IsAuthorizedResponse struct {

	// Time the decision was made.
	DecisionTime *timestamppb.Timestamp `protobuf:"bytes,1,opt,name=decision_time,json=decisionTime,proto3" json:"decision_time,omitempty"`
	// Map with resource type as key.
	Decisions map[string]*IsAuthorizedResponse_ResourceType `` /* 145-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*IsAuthorizedResponse) ClearDecisionTime

func (x *IsAuthorizedResponse) ClearDecisionTime()

func (*IsAuthorizedResponse) GetDecisionTime

func (x *IsAuthorizedResponse) GetDecisionTime() *timestamppb.Timestamp

func (*IsAuthorizedResponse) GetDecisions

func (*IsAuthorizedResponse) HasDecisionTime

func (x *IsAuthorizedResponse) HasDecisionTime() bool

func (*IsAuthorizedResponse) ProtoMessage

func (*IsAuthorizedResponse) ProtoMessage()

func (*IsAuthorizedResponse) ProtoReflect

func (x *IsAuthorizedResponse) ProtoReflect() protoreflect.Message

func (*IsAuthorizedResponse) Reset

func (x *IsAuthorizedResponse) Reset()

func (*IsAuthorizedResponse) SetDecisionTime

func (x *IsAuthorizedResponse) SetDecisionTime(v *timestamppb.Timestamp)

func (*IsAuthorizedResponse) SetDecisions

func (*IsAuthorizedResponse) String

func (x *IsAuthorizedResponse) String() string

type IsAuthorizedResponse_Action

type IsAuthorizedResponse_Action struct {

	// Decision if action is allowed.
	Allow bool `protobuf:"varint,1,opt,name=allow,proto3" json:"allow,omitempty"`
	// List of Advice.
	Advices []*IsAuthorizedResponse_Advice `protobuf:"bytes,2,rep,name=advices,proto3" json:"advices,omitempty"`
	// contains filtered or unexported fields
}

func (*IsAuthorizedResponse_Action) GetAdvices

func (*IsAuthorizedResponse_Action) GetAllow

func (x *IsAuthorizedResponse_Action) GetAllow() bool

func (*IsAuthorizedResponse_Action) ProtoMessage

func (*IsAuthorizedResponse_Action) ProtoMessage()

func (*IsAuthorizedResponse_Action) ProtoReflect

func (*IsAuthorizedResponse_Action) Reset

func (x *IsAuthorizedResponse_Action) Reset()

func (*IsAuthorizedResponse_Action) SetAdvices

func (*IsAuthorizedResponse_Action) SetAllow

func (x *IsAuthorizedResponse_Action) SetAllow(v bool)

func (*IsAuthorizedResponse_Action) String

func (x *IsAuthorizedResponse_Action) String() string

type IsAuthorizedResponse_Action_builder

type IsAuthorizedResponse_Action_builder struct {

	// Decision if action is allowed.
	Allow bool
	// List of Advice.
	Advices []*IsAuthorizedResponse_Advice
	// contains filtered or unexported fields
}

func (IsAuthorizedResponse_Action_builder) Build

type IsAuthorizedResponse_Advice

type IsAuthorizedResponse_Advice struct {

	// error code (e.g. `"insufficient_user_authentication"`)
	Error string `protobuf:"bytes,1,opt,name=error,proto3" json:"error,omitempty"`
	// error description (e.g. `"A different authentication level is required"`)
	Description string `protobuf:"bytes,2,opt,name=description,proto3" json:"description,omitempty"`
	// map of additional values (e.g. `{"acr_values":"ACR1 ACR2"}`)
	Values map[string]string `` /* 139-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*IsAuthorizedResponse_Advice) GetDescription

func (x *IsAuthorizedResponse_Advice) GetDescription() string

func (*IsAuthorizedResponse_Advice) GetError

func (x *IsAuthorizedResponse_Advice) GetError() string

func (*IsAuthorizedResponse_Advice) GetValues

func (x *IsAuthorizedResponse_Advice) GetValues() map[string]string

func (*IsAuthorizedResponse_Advice) ProtoMessage

func (*IsAuthorizedResponse_Advice) ProtoMessage()

func (*IsAuthorizedResponse_Advice) ProtoReflect

func (*IsAuthorizedResponse_Advice) Reset

func (x *IsAuthorizedResponse_Advice) Reset()

func (*IsAuthorizedResponse_Advice) SetDescription

func (x *IsAuthorizedResponse_Advice) SetDescription(v string)

func (*IsAuthorizedResponse_Advice) SetError

func (x *IsAuthorizedResponse_Advice) SetError(v string)

func (*IsAuthorizedResponse_Advice) SetValues

func (x *IsAuthorizedResponse_Advice) SetValues(v map[string]string)

func (*IsAuthorizedResponse_Advice) String

func (x *IsAuthorizedResponse_Advice) String() string

type IsAuthorizedResponse_Advice_builder

type IsAuthorizedResponse_Advice_builder struct {

	// error code (e.g. `"insufficient_user_authentication"`)
	Error string
	// error description (e.g. `"A different authentication level is required"`)
	Description string
	// map of additional values (e.g. `{"acr_values":"ACR1 ACR2"}`)
	Values map[string]string
	// contains filtered or unexported fields
}

func (IsAuthorizedResponse_Advice_builder) Build

type IsAuthorizedResponse_Resource

type IsAuthorizedResponse_Resource struct {

	// Map with action as key.
	Actions map[string]*IsAuthorizedResponse_Action `` /* 141-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*IsAuthorizedResponse_Resource) GetActions

func (*IsAuthorizedResponse_Resource) ProtoMessage

func (*IsAuthorizedResponse_Resource) ProtoMessage()

func (*IsAuthorizedResponse_Resource) ProtoReflect

func (*IsAuthorizedResponse_Resource) Reset

func (x *IsAuthorizedResponse_Resource) Reset()

func (*IsAuthorizedResponse_Resource) SetActions

func (*IsAuthorizedResponse_Resource) String

type IsAuthorizedResponse_ResourceType

type IsAuthorizedResponse_ResourceType struct {

	// Map with resource external id as key.
	Resources map[string]*IsAuthorizedResponse_Resource `` /* 145-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*IsAuthorizedResponse_ResourceType) GetResources

func (*IsAuthorizedResponse_ResourceType) ProtoMessage

func (*IsAuthorizedResponse_ResourceType) ProtoMessage()

func (*IsAuthorizedResponse_ResourceType) ProtoReflect

func (*IsAuthorizedResponse_ResourceType) Reset

func (*IsAuthorizedResponse_ResourceType) SetResources

func (*IsAuthorizedResponse_ResourceType) String

type IsAuthorizedResponse_ResourceType_builder

type IsAuthorizedResponse_ResourceType_builder struct {

	// Map with resource external id as key.
	Resources map[string]*IsAuthorizedResponse_Resource
	// contains filtered or unexported fields
}

func (IsAuthorizedResponse_ResourceType_builder) Build

type IsAuthorizedResponse_Resource_builder

type IsAuthorizedResponse_Resource_builder struct {

	// Map with action as key.
	Actions map[string]*IsAuthorizedResponse_Action
	// contains filtered or unexported fields
}

func (IsAuthorizedResponse_Resource_builder) Build

type IsAuthorizedResponse_builder

type IsAuthorizedResponse_builder struct {

	// Time the decision was made.
	DecisionTime *timestamppb.Timestamp
	// Map with resource type as key.
	Decisions map[string]*IsAuthorizedResponse_ResourceType
	// contains filtered or unexported fields
}

func (IsAuthorizedResponse_builder) Build

type Property

type Property struct {
	Type  string         `protobuf:"bytes,1,opt,name=type,proto3" json:"type,omitempty"`
	Value *v1beta1.Value `protobuf:"bytes,2,opt,name=value,proto3" json:"value,omitempty"`
	// contains filtered or unexported fields
}

func (*Property) ClearValue

func (x *Property) ClearValue()

func (*Property) GetType

func (x *Property) GetType() string

func (*Property) GetValue

func (x *Property) GetValue() *v1beta1.Value

func (*Property) HasValue

func (x *Property) HasValue() bool

func (*Property) ProtoMessage

func (*Property) ProtoMessage()

func (*Property) ProtoReflect

func (x *Property) ProtoReflect() protoreflect.Message

func (*Property) Reset

func (x *Property) Reset()

func (*Property) SetType

func (x *Property) SetType(v string)

func (*Property) SetValue

func (x *Property) SetValue(v *v1beta1.Value)

func (*Property) String

func (x *Property) String() string

type Property_builder

type Property_builder struct {
	Type  string
	Value *v1beta1.Value
	// contains filtered or unexported fields
}

func (Property_builder) Build

func (b0 Property_builder) Build() *Property

type Subject

type Subject struct {

	// Types that are valid to be assigned to Subject:
	//
	//	*Subject_DigitalTwinId
	//	*Subject_DigitalTwinProperty
	//	*Subject_AccessToken
	//	*Subject_ExternalId
	Subject isSubject_Subject `protobuf_oneof:"subject"`
	// contains filtered or unexported fields
}

Subject to check if is authorized.

func (*Subject) ClearAccessToken

func (x *Subject) ClearAccessToken()

func (*Subject) ClearDigitalTwinId

func (x *Subject) ClearDigitalTwinId()

func (*Subject) ClearDigitalTwinProperty

func (x *Subject) ClearDigitalTwinProperty()

func (*Subject) ClearExternalId

func (x *Subject) ClearExternalId()

func (*Subject) ClearSubject

func (x *Subject) ClearSubject()

func (*Subject) GetAccessToken

func (x *Subject) GetAccessToken() string

func (*Subject) GetDigitalTwinId

func (x *Subject) GetDigitalTwinId() *DigitalTwin

func (*Subject) GetDigitalTwinProperty

func (x *Subject) GetDigitalTwinProperty() *Property

func (*Subject) GetExternalId

func (x *Subject) GetExternalId() *ExternalID

func (*Subject) GetSubject

func (x *Subject) GetSubject() isSubject_Subject

func (*Subject) HasAccessToken

func (x *Subject) HasAccessToken() bool

func (*Subject) HasDigitalTwinId

func (x *Subject) HasDigitalTwinId() bool

func (*Subject) HasDigitalTwinProperty

func (x *Subject) HasDigitalTwinProperty() bool

func (*Subject) HasExternalId

func (x *Subject) HasExternalId() bool

func (*Subject) HasSubject

func (x *Subject) HasSubject() bool

func (*Subject) ProtoMessage

func (*Subject) ProtoMessage()

func (*Subject) ProtoReflect

func (x *Subject) ProtoReflect() protoreflect.Message

func (*Subject) Reset

func (x *Subject) Reset()

func (*Subject) SetAccessToken

func (x *Subject) SetAccessToken(v string)

func (*Subject) SetDigitalTwinId

func (x *Subject) SetDigitalTwinId(v *DigitalTwin)

func (*Subject) SetDigitalTwinProperty

func (x *Subject) SetDigitalTwinProperty(v *Property)

func (*Subject) SetExternalId

func (x *Subject) SetExternalId(v *ExternalID)

func (*Subject) String

func (x *Subject) String() string

func (*Subject) WhichSubject

func (x *Subject) WhichSubject() case_Subject_Subject

type Subject_AccessToken

type Subject_AccessToken struct {
	AccessToken string `protobuf:"bytes,4,opt,name=access_token,json=accessToken,proto3,oneof"`
}

type Subject_DigitalTwinId

type Subject_DigitalTwinId struct {
	DigitalTwinId *DigitalTwin `protobuf:"bytes,2,opt,name=digital_twin_id,json=digitalTwinId,proto3,oneof"`
}

type Subject_DigitalTwinProperty

type Subject_DigitalTwinProperty struct {
	DigitalTwinProperty *Property `protobuf:"bytes,3,opt,name=digital_twin_property,json=digitalTwinProperty,proto3,oneof"`
}

type Subject_ExternalId

type Subject_ExternalId struct {
	ExternalId *ExternalID `protobuf:"bytes,5,opt,name=external_id,json=externalId,proto3,oneof"`
}

type Subject_builder

type Subject_builder struct {

	// Fields of oneof Subject:
	DigitalTwinId       *DigitalTwin
	DigitalTwinProperty *Property
	AccessToken         *string
	ExternalId          *ExternalID
	// contains filtered or unexported fields
}

func (Subject_builder) Build

func (b0 Subject_builder) Build() *Subject

type WhatAuthorizedRequest

type WhatAuthorizedRequest struct {

	// Subject to check if is authorized to perform given actions.
	Subject *Subject `protobuf:"bytes,1,opt,name=subject,proto3" json:"subject,omitempty"`
	// A list of resources types that should be checked against.
	ResourceTypes []*WhatAuthorizedRequest_ResourceType `protobuf:"bytes,2,rep,name=resource_types,json=resourceTypes,proto3" json:"resource_types,omitempty"`
	// Policy input params
	InputParams map[string]*InputParam `` /* 168-byte string literal not displayed */
	// Only evaluate polices containing provided tags
	PolicyTags []string `protobuf:"bytes,4,rep,name=policy_tags,json=policyTags,proto3" json:"policy_tags,omitempty"`
	// contains filtered or unexported fields
}

func (*WhatAuthorizedRequest) ClearSubject

func (x *WhatAuthorizedRequest) ClearSubject()

func (*WhatAuthorizedRequest) GetInputParams

func (x *WhatAuthorizedRequest) GetInputParams() map[string]*InputParam

func (*WhatAuthorizedRequest) GetPolicyTags

func (x *WhatAuthorizedRequest) GetPolicyTags() []string

func (*WhatAuthorizedRequest) GetResourceTypes

func (*WhatAuthorizedRequest) GetSubject

func (x *WhatAuthorizedRequest) GetSubject() *Subject

func (*WhatAuthorizedRequest) HasSubject

func (x *WhatAuthorizedRequest) HasSubject() bool

func (*WhatAuthorizedRequest) ProtoMessage

func (*WhatAuthorizedRequest) ProtoMessage()

func (*WhatAuthorizedRequest) ProtoReflect

func (x *WhatAuthorizedRequest) ProtoReflect() protoreflect.Message

func (*WhatAuthorizedRequest) Reset

func (x *WhatAuthorizedRequest) Reset()

func (*WhatAuthorizedRequest) SetInputParams

func (x *WhatAuthorizedRequest) SetInputParams(v map[string]*InputParam)

func (*WhatAuthorizedRequest) SetPolicyTags

func (x *WhatAuthorizedRequest) SetPolicyTags(v []string)

func (*WhatAuthorizedRequest) SetResourceTypes

func (*WhatAuthorizedRequest) SetSubject

func (x *WhatAuthorizedRequest) SetSubject(v *Subject)

func (*WhatAuthorizedRequest) String

func (x *WhatAuthorizedRequest) String() string

type WhatAuthorizedRequest_ResourceType

type WhatAuthorizedRequest_ResourceType struct {

	// Resource type
	Type string `protobuf:"bytes,1,opt,name=type,proto3" json:"type,omitempty"`
	// Optional - A list of actions the subject want to perform.
	Actions []string `protobuf:"bytes,3,rep,name=actions,proto3" json:"actions,omitempty"`
	// contains filtered or unexported fields
}

Resource type to authorize against.

func (*WhatAuthorizedRequest_ResourceType) GetActions

func (x *WhatAuthorizedRequest_ResourceType) GetActions() []string

func (*WhatAuthorizedRequest_ResourceType) GetType

func (*WhatAuthorizedRequest_ResourceType) ProtoMessage

func (*WhatAuthorizedRequest_ResourceType) ProtoMessage()

func (*WhatAuthorizedRequest_ResourceType) ProtoReflect

func (*WhatAuthorizedRequest_ResourceType) Reset

func (*WhatAuthorizedRequest_ResourceType) SetActions

func (x *WhatAuthorizedRequest_ResourceType) SetActions(v []string)

func (*WhatAuthorizedRequest_ResourceType) SetType

func (*WhatAuthorizedRequest_ResourceType) String

type WhatAuthorizedRequest_ResourceType_builder

type WhatAuthorizedRequest_ResourceType_builder struct {

	// Resource type
	Type string
	// Optional - A list of actions the subject want to perform.
	Actions []string
	// contains filtered or unexported fields
}

func (WhatAuthorizedRequest_ResourceType_builder) Build

type WhatAuthorizedRequest_builder

type WhatAuthorizedRequest_builder struct {

	// Subject to check if is authorized to perform given actions.
	Subject *Subject
	// A list of resources types that should be checked against.
	ResourceTypes []*WhatAuthorizedRequest_ResourceType
	// Policy input params
	InputParams map[string]*InputParam
	// Only evaluate polices containing provided tags
	PolicyTags []string
	// contains filtered or unexported fields
}

func (WhatAuthorizedRequest_builder) Build

type WhatAuthorizedResponse

type WhatAuthorizedResponse struct {

	// Time the decision was made
	DecisionTime *timestamppb.Timestamp `protobuf:"bytes,1,opt,name=decision_time,json=decisionTime,proto3" json:"decision_time,omitempty"`
	// Map with resource type as key
	Decisions map[string]*WhatAuthorizedResponse_ResourceType `` /* 145-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*WhatAuthorizedResponse) ClearDecisionTime

func (x *WhatAuthorizedResponse) ClearDecisionTime()

func (*WhatAuthorizedResponse) GetDecisionTime

func (x *WhatAuthorizedResponse) GetDecisionTime() *timestamppb.Timestamp

func (*WhatAuthorizedResponse) GetDecisions

func (*WhatAuthorizedResponse) HasDecisionTime

func (x *WhatAuthorizedResponse) HasDecisionTime() bool

func (*WhatAuthorizedResponse) ProtoMessage

func (*WhatAuthorizedResponse) ProtoMessage()

func (*WhatAuthorizedResponse) ProtoReflect

func (x *WhatAuthorizedResponse) ProtoReflect() protoreflect.Message

func (*WhatAuthorizedResponse) Reset

func (x *WhatAuthorizedResponse) Reset()

func (*WhatAuthorizedResponse) SetDecisionTime

func (x *WhatAuthorizedResponse) SetDecisionTime(v *timestamppb.Timestamp)

func (*WhatAuthorizedResponse) SetDecisions

func (*WhatAuthorizedResponse) String

func (x *WhatAuthorizedResponse) String() string

type WhatAuthorizedResponse_Action

type WhatAuthorizedResponse_Action struct {

	// List of resources
	Resources []*WhatAuthorizedResponse_Resource `protobuf:"bytes,1,rep,name=resources,proto3" json:"resources,omitempty"`
	// contains filtered or unexported fields
}

func (*WhatAuthorizedResponse_Action) GetResources

func (*WhatAuthorizedResponse_Action) ProtoMessage

func (*WhatAuthorizedResponse_Action) ProtoMessage()

func (*WhatAuthorizedResponse_Action) ProtoReflect

func (*WhatAuthorizedResponse_Action) Reset

func (x *WhatAuthorizedResponse_Action) Reset()

func (*WhatAuthorizedResponse_Action) SetResources

func (*WhatAuthorizedResponse_Action) String

type WhatAuthorizedResponse_Action_builder

type WhatAuthorizedResponse_Action_builder struct {

	// List of resources
	Resources []*WhatAuthorizedResponse_Resource
	// contains filtered or unexported fields
}

func (WhatAuthorizedResponse_Action_builder) Build

type WhatAuthorizedResponse_Resource

type WhatAuthorizedResponse_Resource struct {

	// Resource external identifier
	ExternalId string `protobuf:"bytes,1,opt,name=external_id,json=externalId,proto3" json:"external_id,omitempty"`
	// contains filtered or unexported fields
}

func (*WhatAuthorizedResponse_Resource) GetExternalId

func (x *WhatAuthorizedResponse_Resource) GetExternalId() string

func (*WhatAuthorizedResponse_Resource) ProtoMessage

func (*WhatAuthorizedResponse_Resource) ProtoMessage()

func (*WhatAuthorizedResponse_Resource) ProtoReflect

func (*WhatAuthorizedResponse_Resource) Reset

func (*WhatAuthorizedResponse_Resource) SetExternalId

func (x *WhatAuthorizedResponse_Resource) SetExternalId(v string)

func (*WhatAuthorizedResponse_Resource) String

type WhatAuthorizedResponse_ResourceType

type WhatAuthorizedResponse_ResourceType struct {

	// Map with action as key
	Actions map[string]*WhatAuthorizedResponse_Action `` /* 141-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*WhatAuthorizedResponse_ResourceType) GetActions

func (*WhatAuthorizedResponse_ResourceType) ProtoMessage

func (*WhatAuthorizedResponse_ResourceType) ProtoMessage()

func (*WhatAuthorizedResponse_ResourceType) ProtoReflect

func (*WhatAuthorizedResponse_ResourceType) Reset

func (*WhatAuthorizedResponse_ResourceType) SetActions

func (*WhatAuthorizedResponse_ResourceType) String

type WhatAuthorizedResponse_ResourceType_builder

type WhatAuthorizedResponse_ResourceType_builder struct {

	// Map with action as key
	Actions map[string]*WhatAuthorizedResponse_Action
	// contains filtered or unexported fields
}

func (WhatAuthorizedResponse_ResourceType_builder) Build

type WhatAuthorizedResponse_Resource_builder

type WhatAuthorizedResponse_Resource_builder struct {

	// Resource external identifier
	ExternalId string
	// contains filtered or unexported fields
}

func (WhatAuthorizedResponse_Resource_builder) Build

type WhatAuthorizedResponse_builder

type WhatAuthorizedResponse_builder struct {

	// Time the decision was made
	DecisionTime *timestamppb.Timestamp
	// Map with resource type as key
	Decisions map[string]*WhatAuthorizedResponse_ResourceType
	// contains filtered or unexported fields
}

func (WhatAuthorizedResponse_builder) Build

type WhoAuthorizedRequest

type WhoAuthorizedRequest struct {

	// A list of resources to authorize against.
	Resources []*WhoAuthorizedRequest_Resource `protobuf:"bytes,1,rep,name=resources,proto3" json:"resources,omitempty"`
	// Policy input params
	InputParams map[string]*InputParam `` /* 168-byte string literal not displayed */
	// Only evaluate polices containing provided tags
	PolicyTags []string `protobuf:"bytes,3,rep,name=policy_tags,json=policyTags,proto3" json:"policy_tags,omitempty"`
	// contains filtered or unexported fields
}

func (*WhoAuthorizedRequest) GetInputParams

func (x *WhoAuthorizedRequest) GetInputParams() map[string]*InputParam

func (*WhoAuthorizedRequest) GetPolicyTags

func (x *WhoAuthorizedRequest) GetPolicyTags() []string

func (*WhoAuthorizedRequest) GetResources

func (*WhoAuthorizedRequest) ProtoMessage

func (*WhoAuthorizedRequest) ProtoMessage()

func (*WhoAuthorizedRequest) ProtoReflect

func (x *WhoAuthorizedRequest) ProtoReflect() protoreflect.Message

func (*WhoAuthorizedRequest) Reset

func (x *WhoAuthorizedRequest) Reset()

func (*WhoAuthorizedRequest) SetInputParams

func (x *WhoAuthorizedRequest) SetInputParams(v map[string]*InputParam)

func (*WhoAuthorizedRequest) SetPolicyTags

func (x *WhoAuthorizedRequest) SetPolicyTags(v []string)

func (*WhoAuthorizedRequest) SetResources

func (*WhoAuthorizedRequest) String

func (x *WhoAuthorizedRequest) String() string

type WhoAuthorizedRequest_Resource

type WhoAuthorizedRequest_Resource struct {

	// Resource external id.
	ExternalId string `protobuf:"bytes,1,opt,name=external_id,json=externalId,proto3" json:"external_id,omitempty"`
	// Resource type.
	Type string `protobuf:"bytes,2,opt,name=type,proto3" json:"type,omitempty"`
	// A list of actions the subject want to perform.
	Actions []string `protobuf:"bytes,3,rep,name=actions,proto3" json:"actions,omitempty"`
	// contains filtered or unexported fields
}

Resource to authorize against.

func (*WhoAuthorizedRequest_Resource) GetActions

func (x *WhoAuthorizedRequest_Resource) GetActions() []string

func (*WhoAuthorizedRequest_Resource) GetExternalId

func (x *WhoAuthorizedRequest_Resource) GetExternalId() string

func (*WhoAuthorizedRequest_Resource) GetType

func (*WhoAuthorizedRequest_Resource) ProtoMessage

func (*WhoAuthorizedRequest_Resource) ProtoMessage()

func (*WhoAuthorizedRequest_Resource) ProtoReflect

func (*WhoAuthorizedRequest_Resource) Reset

func (x *WhoAuthorizedRequest_Resource) Reset()

func (*WhoAuthorizedRequest_Resource) SetActions

func (x *WhoAuthorizedRequest_Resource) SetActions(v []string)

func (*WhoAuthorizedRequest_Resource) SetExternalId

func (x *WhoAuthorizedRequest_Resource) SetExternalId(v string)

func (*WhoAuthorizedRequest_Resource) SetType

func (x *WhoAuthorizedRequest_Resource) SetType(v string)

func (*WhoAuthorizedRequest_Resource) String

type WhoAuthorizedRequest_Resource_builder

type WhoAuthorizedRequest_Resource_builder struct {

	// Resource external id.
	ExternalId string
	// Resource type.
	Type string
	// A list of actions the subject want to perform.
	Actions []string
	// contains filtered or unexported fields
}

func (WhoAuthorizedRequest_Resource_builder) Build

type WhoAuthorizedRequest_builder

type WhoAuthorizedRequest_builder struct {

	// A list of resources to authorize against.
	Resources []*WhoAuthorizedRequest_Resource
	// Policy input params
	InputParams map[string]*InputParam
	// Only evaluate polices containing provided tags
	PolicyTags []string
	// contains filtered or unexported fields
}

func (WhoAuthorizedRequest_builder) Build

type WhoAuthorizedResponse

type WhoAuthorizedResponse struct {

	// Time the decision was made.
	DecisionTime *timestamppb.Timestamp `protobuf:"bytes,1,opt,name=decision_time,json=decisionTime,proto3" json:"decision_time,omitempty"`
	// Map with resource type as key.
	Decisions map[string]*WhoAuthorizedResponse_ResourceType `` /* 145-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*WhoAuthorizedResponse) ClearDecisionTime

func (x *WhoAuthorizedResponse) ClearDecisionTime()

func (*WhoAuthorizedResponse) GetDecisionTime

func (x *WhoAuthorizedResponse) GetDecisionTime() *timestamppb.Timestamp

func (*WhoAuthorizedResponse) GetDecisions

func (*WhoAuthorizedResponse) HasDecisionTime

func (x *WhoAuthorizedResponse) HasDecisionTime() bool

func (*WhoAuthorizedResponse) ProtoMessage

func (*WhoAuthorizedResponse) ProtoMessage()

func (*WhoAuthorizedResponse) ProtoReflect

func (x *WhoAuthorizedResponse) ProtoReflect() protoreflect.Message

func (*WhoAuthorizedResponse) Reset

func (x *WhoAuthorizedResponse) Reset()

func (*WhoAuthorizedResponse) SetDecisionTime

func (x *WhoAuthorizedResponse) SetDecisionTime(v *timestamppb.Timestamp)

func (*WhoAuthorizedResponse) SetDecisions

func (*WhoAuthorizedResponse) String

func (x *WhoAuthorizedResponse) String() string

type WhoAuthorizedResponse_Action

type WhoAuthorizedResponse_Action struct {

	// List of subjects.
	Subjects []*WhoAuthorizedResponse_Subject `protobuf:"bytes,1,rep,name=subjects,proto3" json:"subjects,omitempty"`
	// contains filtered or unexported fields
}

func (*WhoAuthorizedResponse_Action) GetSubjects

func (*WhoAuthorizedResponse_Action) ProtoMessage

func (*WhoAuthorizedResponse_Action) ProtoMessage()

func (*WhoAuthorizedResponse_Action) ProtoReflect

func (*WhoAuthorizedResponse_Action) Reset

func (x *WhoAuthorizedResponse_Action) Reset()

func (*WhoAuthorizedResponse_Action) SetSubjects

func (*WhoAuthorizedResponse_Action) String

type WhoAuthorizedResponse_Action_builder

type WhoAuthorizedResponse_Action_builder struct {

	// List of subjects.
	Subjects []*WhoAuthorizedResponse_Subject
	// contains filtered or unexported fields
}

func (WhoAuthorizedResponse_Action_builder) Build

type WhoAuthorizedResponse_Resource

type WhoAuthorizedResponse_Resource struct {

	// Map with actions as key.
	Actions map[string]*WhoAuthorizedResponse_Action `` /* 141-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*WhoAuthorizedResponse_Resource) GetActions

func (*WhoAuthorizedResponse_Resource) ProtoMessage

func (*WhoAuthorizedResponse_Resource) ProtoMessage()

func (*WhoAuthorizedResponse_Resource) ProtoReflect

func (*WhoAuthorizedResponse_Resource) Reset

func (x *WhoAuthorizedResponse_Resource) Reset()

func (*WhoAuthorizedResponse_Resource) SetActions

func (*WhoAuthorizedResponse_Resource) String

type WhoAuthorizedResponse_ResourceType

type WhoAuthorizedResponse_ResourceType struct {

	// Map with resource external id as key.
	Resources map[string]*WhoAuthorizedResponse_Resource `` /* 145-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*WhoAuthorizedResponse_ResourceType) GetResources

func (*WhoAuthorizedResponse_ResourceType) ProtoMessage

func (*WhoAuthorizedResponse_ResourceType) ProtoMessage()

func (*WhoAuthorizedResponse_ResourceType) ProtoReflect

func (*WhoAuthorizedResponse_ResourceType) Reset

func (*WhoAuthorizedResponse_ResourceType) SetResources

func (*WhoAuthorizedResponse_ResourceType) String

type WhoAuthorizedResponse_ResourceType_builder

type WhoAuthorizedResponse_ResourceType_builder struct {

	// Map with resource external id as key.
	Resources map[string]*WhoAuthorizedResponse_Resource
	// contains filtered or unexported fields
}

func (WhoAuthorizedResponse_ResourceType_builder) Build

type WhoAuthorizedResponse_Resource_builder

type WhoAuthorizedResponse_Resource_builder struct {

	// Map with actions as key.
	Actions map[string]*WhoAuthorizedResponse_Action
	// contains filtered or unexported fields
}

func (WhoAuthorizedResponse_Resource_builder) Build

type WhoAuthorizedResponse_Subject

type WhoAuthorizedResponse_Subject struct {

	// External identifier.
	ExternalId string `protobuf:"bytes,1,opt,name=external_id,json=externalId,proto3" json:"external_id,omitempty"`
	// Subject type.
	Type string `protobuf:"bytes,2,opt,name=type,proto3" json:"type,omitempty"`
	// contains filtered or unexported fields
}

func (*WhoAuthorizedResponse_Subject) GetExternalId

func (x *WhoAuthorizedResponse_Subject) GetExternalId() string

func (*WhoAuthorizedResponse_Subject) GetType

func (*WhoAuthorizedResponse_Subject) ProtoMessage

func (*WhoAuthorizedResponse_Subject) ProtoMessage()

func (*WhoAuthorizedResponse_Subject) ProtoReflect

func (*WhoAuthorizedResponse_Subject) Reset

func (x *WhoAuthorizedResponse_Subject) Reset()

func (*WhoAuthorizedResponse_Subject) SetExternalId

func (x *WhoAuthorizedResponse_Subject) SetExternalId(v string)

func (*WhoAuthorizedResponse_Subject) SetType

func (x *WhoAuthorizedResponse_Subject) SetType(v string)

func (*WhoAuthorizedResponse_Subject) String

type WhoAuthorizedResponse_Subject_builder

type WhoAuthorizedResponse_Subject_builder struct {

	// External identifier.
	ExternalId string
	// Subject type.
	Type string
	// contains filtered or unexported fields
}

func (WhoAuthorizedResponse_Subject_builder) Build

type WhoAuthorizedResponse_builder

type WhoAuthorizedResponse_builder struct {

	// Time the decision was made.
	DecisionTime *timestamppb.Timestamp
	// Map with resource type as key.
	Decisions map[string]*WhoAuthorizedResponse_ResourceType
	// contains filtered or unexported fields
}

func (WhoAuthorizedResponse_builder) Build

Source Files

  • authorization_service.pb.go
  • model.pb.go

Jump to