ingestv1beta3

package
v1.36.11-2026020416421... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 7 Imported by: 2

Documentation

Index

Constants

const DeleteData_Data_not_set_case case_DeleteData_Data = 0
const DeleteData_NodeProperty_case case_DeleteData_Data = 3
const DeleteData_NodeTags_case case_DeleteData_Data = 5
const DeleteData_Node_case case_DeleteData_Data = 1
const DeleteData_RelationshipProperty_case case_DeleteData_Data = 4
const DeleteData_Relationship_case case_DeleteData_Data = 2
const Entity_Data_not_set_case case_Entity_Data = 0
const Entity_NodeMatch_case case_Entity_Data = 3
const Entity_Node_case case_Entity_Data = 1
const Entity_Relationship_case case_Entity_Data = 2
const Record_Delete_case case_Record_Operation = 3
const Record_Operation_not_set_case case_Record_Operation = 0
const Record_Upsert_case case_Record_Operation = 2
const StreamRecordsResponse_Error_not_set_case case_StreamRecordsResponse_Error = 0
const StreamRecordsResponse_RecordError_case case_StreamRecordsResponse_Error = 3
const StreamRecordsResponse_StatusError_case case_StreamRecordsResponse_Error = 4
const UpsertData_Data_not_set_case case_UpsertData_Data = 0
const UpsertData_Node_case case_UpsertData_Data = 1
const UpsertData_Relationship_case case_UpsertData_Data = 2

Variables

var (
	DataType_name = map[int32]string{
		0: "DATA_TYPE_INVALID",
		1: "DATA_TYPE_NODE",
		3: "DATA_TYPE_RELATIONSHIP",
	}
	DataType_value = map[string]int32{
		"DATA_TYPE_INVALID":      0,
		"DATA_TYPE_NODE":         1,
		"DATA_TYPE_RELATIONSHIP": 3,
	}
)

Enum value maps for DataType.

var File_indykite_ingest_v1beta3_ingest_api_proto protoreflect.FileDescriptor
var File_indykite_ingest_v1beta3_model_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type BatchDeleteNodePropertiesRequest

type BatchDeleteNodePropertiesRequest struct {
	NodeProperties []*DeleteData_NodePropertyMatch `protobuf:"bytes,1,rep,name=node_properties,json=nodeProperties,proto3" json:"node_properties,omitempty"`
	// contains filtered or unexported fields
}

func (*BatchDeleteNodePropertiesRequest) GetNodeProperties

func (*BatchDeleteNodePropertiesRequest) ProtoMessage

func (*BatchDeleteNodePropertiesRequest) ProtoMessage()

func (*BatchDeleteNodePropertiesRequest) ProtoReflect

func (*BatchDeleteNodePropertiesRequest) Reset

func (*BatchDeleteNodePropertiesRequest) SetNodeProperties

func (*BatchDeleteNodePropertiesRequest) String

type BatchDeleteNodePropertiesRequest_builder

type BatchDeleteNodePropertiesRequest_builder struct {
	NodeProperties []*DeleteData_NodePropertyMatch
	// contains filtered or unexported fields
}

func (BatchDeleteNodePropertiesRequest_builder) Build

type BatchDeleteNodePropertiesResponse

type BatchDeleteNodePropertiesResponse struct {
	Results []*Info `protobuf:"bytes,1,rep,name=results,proto3" json:"results,omitempty"`
	// contains filtered or unexported fields
}

func (*BatchDeleteNodePropertiesResponse) GetResults

func (x *BatchDeleteNodePropertiesResponse) GetResults() []*Info

func (*BatchDeleteNodePropertiesResponse) ProtoMessage

func (*BatchDeleteNodePropertiesResponse) ProtoMessage()

func (*BatchDeleteNodePropertiesResponse) ProtoReflect

func (*BatchDeleteNodePropertiesResponse) Reset

func (*BatchDeleteNodePropertiesResponse) SetResults

func (x *BatchDeleteNodePropertiesResponse) SetResults(v []*Info)

func (*BatchDeleteNodePropertiesResponse) String

type BatchDeleteNodePropertiesResponse_builder

type BatchDeleteNodePropertiesResponse_builder struct {
	Results []*Info
	// contains filtered or unexported fields
}

func (BatchDeleteNodePropertiesResponse_builder) Build

type BatchDeleteNodeTagsRequest

type BatchDeleteNodeTagsRequest struct {
	NodeTags []*DeleteData_NodeTagMatch `protobuf:"bytes,1,rep,name=node_tags,json=nodeTags,proto3" json:"node_tags,omitempty"`
	// contains filtered or unexported fields
}

func (*BatchDeleteNodeTagsRequest) GetNodeTags

func (*BatchDeleteNodeTagsRequest) ProtoMessage

func (*BatchDeleteNodeTagsRequest) ProtoMessage()

func (*BatchDeleteNodeTagsRequest) ProtoReflect

func (*BatchDeleteNodeTagsRequest) Reset

func (x *BatchDeleteNodeTagsRequest) Reset()

func (*BatchDeleteNodeTagsRequest) SetNodeTags

func (*BatchDeleteNodeTagsRequest) String

func (x *BatchDeleteNodeTagsRequest) String() string

type BatchDeleteNodeTagsRequest_builder

type BatchDeleteNodeTagsRequest_builder struct {
	NodeTags []*DeleteData_NodeTagMatch
	// contains filtered or unexported fields
}

func (BatchDeleteNodeTagsRequest_builder) Build

type BatchDeleteNodeTagsResponse

type BatchDeleteNodeTagsResponse struct {
	Results []*Info `protobuf:"bytes,1,rep,name=results,proto3" json:"results,omitempty"`
	// contains filtered or unexported fields
}

func (*BatchDeleteNodeTagsResponse) GetResults

func (x *BatchDeleteNodeTagsResponse) GetResults() []*Info

func (*BatchDeleteNodeTagsResponse) ProtoMessage

func (*BatchDeleteNodeTagsResponse) ProtoMessage()

func (*BatchDeleteNodeTagsResponse) ProtoReflect

func (*BatchDeleteNodeTagsResponse) Reset

func (x *BatchDeleteNodeTagsResponse) Reset()

func (*BatchDeleteNodeTagsResponse) SetResults

func (x *BatchDeleteNodeTagsResponse) SetResults(v []*Info)

func (*BatchDeleteNodeTagsResponse) String

func (x *BatchDeleteNodeTagsResponse) String() string

type BatchDeleteNodeTagsResponse_builder

type BatchDeleteNodeTagsResponse_builder struct {
	Results []*Info
	// contains filtered or unexported fields
}

func (BatchDeleteNodeTagsResponse_builder) Build

type BatchDeleteNodesRequest

type BatchDeleteNodesRequest struct {
	Nodes []*NodeMatch `protobuf:"bytes,1,rep,name=nodes,proto3" json:"nodes,omitempty"`
	// contains filtered or unexported fields
}

func (*BatchDeleteNodesRequest) GetNodes

func (x *BatchDeleteNodesRequest) GetNodes() []*NodeMatch

func (*BatchDeleteNodesRequest) ProtoMessage

func (*BatchDeleteNodesRequest) ProtoMessage()

func (*BatchDeleteNodesRequest) ProtoReflect

func (x *BatchDeleteNodesRequest) ProtoReflect() protoreflect.Message

func (*BatchDeleteNodesRequest) Reset

func (x *BatchDeleteNodesRequest) Reset()

func (*BatchDeleteNodesRequest) SetNodes

func (x *BatchDeleteNodesRequest) SetNodes(v []*NodeMatch)

func (*BatchDeleteNodesRequest) String

func (x *BatchDeleteNodesRequest) String() string

type BatchDeleteNodesRequest_builder

type BatchDeleteNodesRequest_builder struct {
	Nodes []*NodeMatch
	// contains filtered or unexported fields
}

func (BatchDeleteNodesRequest_builder) Build

type BatchDeleteNodesResponse

type BatchDeleteNodesResponse struct {
	Results []*Info `protobuf:"bytes,1,rep,name=results,proto3" json:"results,omitempty"`
	// contains filtered or unexported fields
}

func (*BatchDeleteNodesResponse) GetResults

func (x *BatchDeleteNodesResponse) GetResults() []*Info

func (*BatchDeleteNodesResponse) ProtoMessage

func (*BatchDeleteNodesResponse) ProtoMessage()

func (*BatchDeleteNodesResponse) ProtoReflect

func (x *BatchDeleteNodesResponse) ProtoReflect() protoreflect.Message

func (*BatchDeleteNodesResponse) Reset

func (x *BatchDeleteNodesResponse) Reset()

func (*BatchDeleteNodesResponse) SetResults

func (x *BatchDeleteNodesResponse) SetResults(v []*Info)

func (*BatchDeleteNodesResponse) String

func (x *BatchDeleteNodesResponse) String() string

type BatchDeleteNodesResponse_builder

type BatchDeleteNodesResponse_builder struct {
	Results []*Info
	// contains filtered or unexported fields
}

func (BatchDeleteNodesResponse_builder) Build

type BatchDeleteRelationshipPropertiesRequest

type BatchDeleteRelationshipPropertiesRequest struct {
	RelationshipProperties []*DeleteData_RelationshipPropertyMatch `` /* 127-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*BatchDeleteRelationshipPropertiesRequest) GetRelationshipProperties

func (*BatchDeleteRelationshipPropertiesRequest) ProtoMessage

func (*BatchDeleteRelationshipPropertiesRequest) ProtoReflect

func (*BatchDeleteRelationshipPropertiesRequest) Reset

func (*BatchDeleteRelationshipPropertiesRequest) SetRelationshipProperties

func (*BatchDeleteRelationshipPropertiesRequest) String

type BatchDeleteRelationshipPropertiesRequest_builder

type BatchDeleteRelationshipPropertiesRequest_builder struct {
	RelationshipProperties []*DeleteData_RelationshipPropertyMatch
	// contains filtered or unexported fields
}

func (BatchDeleteRelationshipPropertiesRequest_builder) Build

type BatchDeleteRelationshipPropertiesResponse

type BatchDeleteRelationshipPropertiesResponse struct {
	Results []*Info `protobuf:"bytes,1,rep,name=results,proto3" json:"results,omitempty"`
	// contains filtered or unexported fields
}

func (*BatchDeleteRelationshipPropertiesResponse) GetResults

func (*BatchDeleteRelationshipPropertiesResponse) ProtoMessage

func (*BatchDeleteRelationshipPropertiesResponse) ProtoReflect

func (*BatchDeleteRelationshipPropertiesResponse) Reset

func (*BatchDeleteRelationshipPropertiesResponse) SetResults

func (x *BatchDeleteRelationshipPropertiesResponse) SetResults(v []*Info)

func (*BatchDeleteRelationshipPropertiesResponse) String

type BatchDeleteRelationshipPropertiesResponse_builder

type BatchDeleteRelationshipPropertiesResponse_builder struct {
	Results []*Info
	// contains filtered or unexported fields
}

func (BatchDeleteRelationshipPropertiesResponse_builder) Build

type BatchDeleteRelationshipsRequest

type BatchDeleteRelationshipsRequest struct {
	Relationships []*Relationship `protobuf:"bytes,1,rep,name=relationships,proto3" json:"relationships,omitempty"`
	// contains filtered or unexported fields
}

func (*BatchDeleteRelationshipsRequest) GetRelationships

func (x *BatchDeleteRelationshipsRequest) GetRelationships() []*Relationship

func (*BatchDeleteRelationshipsRequest) ProtoMessage

func (*BatchDeleteRelationshipsRequest) ProtoMessage()

func (*BatchDeleteRelationshipsRequest) ProtoReflect

func (*BatchDeleteRelationshipsRequest) Reset

func (*BatchDeleteRelationshipsRequest) SetRelationships

func (x *BatchDeleteRelationshipsRequest) SetRelationships(v []*Relationship)

func (*BatchDeleteRelationshipsRequest) String

type BatchDeleteRelationshipsRequest_builder

type BatchDeleteRelationshipsRequest_builder struct {
	Relationships []*Relationship
	// contains filtered or unexported fields
}

func (BatchDeleteRelationshipsRequest_builder) Build

type BatchDeleteRelationshipsResponse

type BatchDeleteRelationshipsResponse struct {
	Results []*Info `protobuf:"bytes,1,rep,name=results,proto3" json:"results,omitempty"`
	// contains filtered or unexported fields
}

func (*BatchDeleteRelationshipsResponse) GetResults

func (x *BatchDeleteRelationshipsResponse) GetResults() []*Info

func (*BatchDeleteRelationshipsResponse) ProtoMessage

func (*BatchDeleteRelationshipsResponse) ProtoMessage()

func (*BatchDeleteRelationshipsResponse) ProtoReflect

func (*BatchDeleteRelationshipsResponse) Reset

func (*BatchDeleteRelationshipsResponse) SetResults

func (x *BatchDeleteRelationshipsResponse) SetResults(v []*Info)

func (*BatchDeleteRelationshipsResponse) String

type BatchDeleteRelationshipsResponse_builder

type BatchDeleteRelationshipsResponse_builder struct {
	Results []*Info
	// contains filtered or unexported fields
}

func (BatchDeleteRelationshipsResponse_builder) Build

type BatchIngestRecordRequest

type BatchIngestRecordRequest struct {
	AppSpaceId []byte       `protobuf:"bytes,1,opt,name=app_space_id,json=appSpaceId,proto3" json:"app_space_id,omitempty"`
	AppAgentId []byte       `protobuf:"bytes,2,opt,name=app_agent_id,json=appAgentId,proto3" json:"app_agent_id,omitempty"`
	Operation  string       `protobuf:"bytes,3,opt,name=operation,proto3" json:"operation,omitempty"`
	Records    *BatchRecord `protobuf:"bytes,4,opt,name=records,proto3" json:"records,omitempty"`
	// contains filtered or unexported fields
}

func (*BatchIngestRecordRequest) ClearRecords

func (x *BatchIngestRecordRequest) ClearRecords()

func (*BatchIngestRecordRequest) GetAppAgentId

func (x *BatchIngestRecordRequest) GetAppAgentId() []byte

func (*BatchIngestRecordRequest) GetAppSpaceId

func (x *BatchIngestRecordRequest) GetAppSpaceId() []byte

func (*BatchIngestRecordRequest) GetOperation

func (x *BatchIngestRecordRequest) GetOperation() string

func (*BatchIngestRecordRequest) GetRecords

func (x *BatchIngestRecordRequest) GetRecords() *BatchRecord

func (*BatchIngestRecordRequest) HasRecords

func (x *BatchIngestRecordRequest) HasRecords() bool

func (*BatchIngestRecordRequest) ProtoMessage

func (*BatchIngestRecordRequest) ProtoMessage()

func (*BatchIngestRecordRequest) ProtoReflect

func (x *BatchIngestRecordRequest) ProtoReflect() protoreflect.Message

func (*BatchIngestRecordRequest) Reset

func (x *BatchIngestRecordRequest) Reset()

func (*BatchIngestRecordRequest) SetAppAgentId

func (x *BatchIngestRecordRequest) SetAppAgentId(v []byte)

func (*BatchIngestRecordRequest) SetAppSpaceId

func (x *BatchIngestRecordRequest) SetAppSpaceId(v []byte)

func (*BatchIngestRecordRequest) SetOperation

func (x *BatchIngestRecordRequest) SetOperation(v string)

func (*BatchIngestRecordRequest) SetRecords

func (x *BatchIngestRecordRequest) SetRecords(v *BatchRecord)

func (*BatchIngestRecordRequest) String

func (x *BatchIngestRecordRequest) String() string

type BatchIngestRecordRequest_builder

type BatchIngestRecordRequest_builder struct {
	AppSpaceId []byte
	AppAgentId []byte
	Operation  string
	Records    *BatchRecord
	// contains filtered or unexported fields
}

func (BatchIngestRecordRequest_builder) Build

type BatchIngestRecordResponse

type BatchIngestRecordResponse struct {

	// Return IDs for each ingested record (order aligned with request).
	Ids []string `protobuf:"bytes,1,rep,name=ids,proto3" json:"ids,omitempty"`
	// contains filtered or unexported fields
}

func (*BatchIngestRecordResponse) GetIds

func (x *BatchIngestRecordResponse) GetIds() []string

func (*BatchIngestRecordResponse) ProtoMessage

func (*BatchIngestRecordResponse) ProtoMessage()

func (*BatchIngestRecordResponse) ProtoReflect

func (*BatchIngestRecordResponse) Reset

func (x *BatchIngestRecordResponse) Reset()

func (*BatchIngestRecordResponse) SetIds

func (x *BatchIngestRecordResponse) SetIds(v []string)

func (*BatchIngestRecordResponse) String

func (x *BatchIngestRecordResponse) String() string

type BatchIngestRecordResponse_builder

type BatchIngestRecordResponse_builder struct {

	// Return IDs for each ingested record (order aligned with request).
	Ids []string
	// contains filtered or unexported fields
}

func (BatchIngestRecordResponse_builder) Build

type BatchRecord

type BatchRecord struct {
	Id       string    `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	Entities []*Entity `protobuf:"bytes,2,rep,name=entities,proto3" json:"entities,omitempty"`
	// contains filtered or unexported fields
}

func (*BatchRecord) GetEntities

func (x *BatchRecord) GetEntities() []*Entity

func (*BatchRecord) GetId

func (x *BatchRecord) GetId() string

func (*BatchRecord) ProtoMessage

func (*BatchRecord) ProtoMessage()

func (*BatchRecord) ProtoReflect

func (x *BatchRecord) ProtoReflect() protoreflect.Message

func (*BatchRecord) Reset

func (x *BatchRecord) Reset()

func (*BatchRecord) SetEntities

func (x *BatchRecord) SetEntities(v []*Entity)

func (*BatchRecord) SetId

func (x *BatchRecord) SetId(v string)

func (*BatchRecord) String

func (x *BatchRecord) String() string

type BatchRecord_builder

type BatchRecord_builder struct {
	Id       string
	Entities []*Entity
	// contains filtered or unexported fields
}

func (BatchRecord_builder) Build

func (b0 BatchRecord_builder) Build() *BatchRecord

type BatchUpsertNodesRequest

type BatchUpsertNodesRequest struct {
	Nodes []*v1beta1.Node `protobuf:"bytes,1,rep,name=nodes,proto3" json:"nodes,omitempty"`
	// contains filtered or unexported fields
}

func (*BatchUpsertNodesRequest) GetNodes

func (x *BatchUpsertNodesRequest) GetNodes() []*v1beta1.Node

func (*BatchUpsertNodesRequest) ProtoMessage

func (*BatchUpsertNodesRequest) ProtoMessage()

func (*BatchUpsertNodesRequest) ProtoReflect

func (x *BatchUpsertNodesRequest) ProtoReflect() protoreflect.Message

func (*BatchUpsertNodesRequest) Reset

func (x *BatchUpsertNodesRequest) Reset()

func (*BatchUpsertNodesRequest) SetNodes

func (x *BatchUpsertNodesRequest) SetNodes(v []*v1beta1.Node)

func (*BatchUpsertNodesRequest) String

func (x *BatchUpsertNodesRequest) String() string

type BatchUpsertNodesRequest_builder

type BatchUpsertNodesRequest_builder struct {
	Nodes []*v1beta1.Node
	// contains filtered or unexported fields
}

func (BatchUpsertNodesRequest_builder) Build

type BatchUpsertNodesResponse

type BatchUpsertNodesResponse struct {
	Results []*Info `protobuf:"bytes,1,rep,name=results,proto3" json:"results,omitempty"`
	// contains filtered or unexported fields
}

func (*BatchUpsertNodesResponse) GetResults

func (x *BatchUpsertNodesResponse) GetResults() []*Info

func (*BatchUpsertNodesResponse) ProtoMessage

func (*BatchUpsertNodesResponse) ProtoMessage()

func (*BatchUpsertNodesResponse) ProtoReflect

func (x *BatchUpsertNodesResponse) ProtoReflect() protoreflect.Message

func (*BatchUpsertNodesResponse) Reset

func (x *BatchUpsertNodesResponse) Reset()

func (*BatchUpsertNodesResponse) SetResults

func (x *BatchUpsertNodesResponse) SetResults(v []*Info)

func (*BatchUpsertNodesResponse) String

func (x *BatchUpsertNodesResponse) String() string

type BatchUpsertNodesResponse_builder

type BatchUpsertNodesResponse_builder struct {
	Results []*Info
	// contains filtered or unexported fields
}

func (BatchUpsertNodesResponse_builder) Build

type BatchUpsertRelationshipsRequest

type BatchUpsertRelationshipsRequest struct {
	Relationships []*Relationship `protobuf:"bytes,1,rep,name=relationships,proto3" json:"relationships,omitempty"`
	// contains filtered or unexported fields
}

func (*BatchUpsertRelationshipsRequest) GetRelationships

func (x *BatchUpsertRelationshipsRequest) GetRelationships() []*Relationship

func (*BatchUpsertRelationshipsRequest) ProtoMessage

func (*BatchUpsertRelationshipsRequest) ProtoMessage()

func (*BatchUpsertRelationshipsRequest) ProtoReflect

func (*BatchUpsertRelationshipsRequest) Reset

func (*BatchUpsertRelationshipsRequest) SetRelationships

func (x *BatchUpsertRelationshipsRequest) SetRelationships(v []*Relationship)

func (*BatchUpsertRelationshipsRequest) String

type BatchUpsertRelationshipsRequest_builder

type BatchUpsertRelationshipsRequest_builder struct {
	Relationships []*Relationship
	// contains filtered or unexported fields
}

func (BatchUpsertRelationshipsRequest_builder) Build

type BatchUpsertRelationshipsResponse

type BatchUpsertRelationshipsResponse struct {
	Results []*Info `protobuf:"bytes,1,rep,name=results,proto3" json:"results,omitempty"`
	// contains filtered or unexported fields
}

func (*BatchUpsertRelationshipsResponse) GetResults

func (x *BatchUpsertRelationshipsResponse) GetResults() []*Info

func (*BatchUpsertRelationshipsResponse) ProtoMessage

func (*BatchUpsertRelationshipsResponse) ProtoMessage()

func (*BatchUpsertRelationshipsResponse) ProtoReflect

func (*BatchUpsertRelationshipsResponse) Reset

func (*BatchUpsertRelationshipsResponse) SetResults

func (x *BatchUpsertRelationshipsResponse) SetResults(v []*Info)

func (*BatchUpsertRelationshipsResponse) String

type BatchUpsertRelationshipsResponse_builder

type BatchUpsertRelationshipsResponse_builder struct {
	Results []*Info
	// contains filtered or unexported fields
}

func (BatchUpsertRelationshipsResponse_builder) Build

type Change

type Change struct {
	Id       string   `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	DataType DataType `protobuf:"varint,2,opt,name=data_type,json=dataType,proto3,enum=indykite.ingest.v1beta3.DataType" json:"data_type,omitempty"`
	// contains filtered or unexported fields
}

func (*Change) GetDataType

func (x *Change) GetDataType() DataType

func (*Change) GetId

func (x *Change) GetId() string

func (*Change) ProtoMessage

func (*Change) ProtoMessage()

func (*Change) ProtoReflect

func (x *Change) ProtoReflect() protoreflect.Message

func (*Change) Reset

func (x *Change) Reset()

func (*Change) SetDataType

func (x *Change) SetDataType(v DataType)

func (*Change) SetId

func (x *Change) SetId(v string)

func (*Change) String

func (x *Change) String() string

type Change_builder

type Change_builder struct {
	Id       string
	DataType DataType
	// contains filtered or unexported fields
}

func (Change_builder) Build

func (b0 Change_builder) Build() *Change

type DataType

type DataType int32
const (
	DataType_DATA_TYPE_INVALID      DataType = 0
	DataType_DATA_TYPE_NODE         DataType = 1
	DataType_DATA_TYPE_RELATIONSHIP DataType = 3
)

func (DataType) Descriptor

func (DataType) Descriptor() protoreflect.EnumDescriptor

func (DataType) Enum

func (x DataType) Enum() *DataType

func (DataType) Number

func (x DataType) Number() protoreflect.EnumNumber

func (DataType) String

func (x DataType) String() string

func (DataType) Type

type DeleteData

type DeleteData struct {

	// Types that are valid to be assigned to Data:
	//
	//	*DeleteData_Node
	//	*DeleteData_Relationship
	//	*DeleteData_NodeProperty
	//	*DeleteData_RelationshipProperty
	//	*DeleteData_NodeTags
	Data isDeleteData_Data `protobuf_oneof:"data"`
	// contains filtered or unexported fields
}

func (*DeleteData) ClearData

func (x *DeleteData) ClearData()

func (*DeleteData) ClearNode

func (x *DeleteData) ClearNode()

func (*DeleteData) ClearNodeProperty

func (x *DeleteData) ClearNodeProperty()

func (*DeleteData) ClearNodeTags

func (x *DeleteData) ClearNodeTags()

func (*DeleteData) ClearRelationship

func (x *DeleteData) ClearRelationship()

func (*DeleteData) ClearRelationshipProperty

func (x *DeleteData) ClearRelationshipProperty()

func (*DeleteData) GetData

func (x *DeleteData) GetData() isDeleteData_Data

func (*DeleteData) GetNode

func (x *DeleteData) GetNode() *NodeMatch

func (*DeleteData) GetNodeProperty

func (x *DeleteData) GetNodeProperty() *DeleteData_NodePropertyMatch

func (*DeleteData) GetNodeTags

func (x *DeleteData) GetNodeTags() *DeleteData_NodeTagMatch

func (*DeleteData) GetRelationship

func (x *DeleteData) GetRelationship() *Relationship

func (*DeleteData) GetRelationshipProperty

func (x *DeleteData) GetRelationshipProperty() *DeleteData_RelationshipPropertyMatch

func (*DeleteData) HasData

func (x *DeleteData) HasData() bool

func (*DeleteData) HasNode

func (x *DeleteData) HasNode() bool

func (*DeleteData) HasNodeProperty

func (x *DeleteData) HasNodeProperty() bool

func (*DeleteData) HasNodeTags

func (x *DeleteData) HasNodeTags() bool

func (*DeleteData) HasRelationship

func (x *DeleteData) HasRelationship() bool

func (*DeleteData) HasRelationshipProperty

func (x *DeleteData) HasRelationshipProperty() bool

func (*DeleteData) ProtoMessage

func (*DeleteData) ProtoMessage()

func (*DeleteData) ProtoReflect

func (x *DeleteData) ProtoReflect() protoreflect.Message

func (*DeleteData) Reset

func (x *DeleteData) Reset()

func (*DeleteData) SetNode

func (x *DeleteData) SetNode(v *NodeMatch)

func (*DeleteData) SetNodeProperty

func (x *DeleteData) SetNodeProperty(v *DeleteData_NodePropertyMatch)

func (*DeleteData) SetNodeTags

func (x *DeleteData) SetNodeTags(v *DeleteData_NodeTagMatch)

func (*DeleteData) SetRelationship

func (x *DeleteData) SetRelationship(v *Relationship)

func (*DeleteData) SetRelationshipProperty

func (x *DeleteData) SetRelationshipProperty(v *DeleteData_RelationshipPropertyMatch)

func (*DeleteData) String

func (x *DeleteData) String() string

func (*DeleteData) WhichData

func (x *DeleteData) WhichData() case_DeleteData_Data

type DeleteData_Node

type DeleteData_Node struct {
	Node *NodeMatch `protobuf:"bytes,1,opt,name=node,proto3,oneof"`
}

type DeleteData_NodeProperty

type DeleteData_NodeProperty struct {
	NodeProperty *DeleteData_NodePropertyMatch `protobuf:"bytes,3,opt,name=node_property,json=nodeProperty,proto3,oneof"`
}

type DeleteData_NodePropertyMatch

type DeleteData_NodePropertyMatch struct {
	Match        *NodeMatch `protobuf:"bytes,1,opt,name=match,proto3" json:"match,omitempty"`
	PropertyType string     `protobuf:"bytes,2,opt,name=property_type,json=propertyType,proto3" json:"property_type,omitempty"`
	// contains filtered or unexported fields
}

func (*DeleteData_NodePropertyMatch) ClearMatch

func (x *DeleteData_NodePropertyMatch) ClearMatch()

func (*DeleteData_NodePropertyMatch) GetMatch

func (x *DeleteData_NodePropertyMatch) GetMatch() *NodeMatch

func (*DeleteData_NodePropertyMatch) GetPropertyType

func (x *DeleteData_NodePropertyMatch) GetPropertyType() string

func (*DeleteData_NodePropertyMatch) HasMatch

func (x *DeleteData_NodePropertyMatch) HasMatch() bool

func (*DeleteData_NodePropertyMatch) ProtoMessage

func (*DeleteData_NodePropertyMatch) ProtoMessage()

func (*DeleteData_NodePropertyMatch) ProtoReflect

func (*DeleteData_NodePropertyMatch) Reset

func (x *DeleteData_NodePropertyMatch) Reset()

func (*DeleteData_NodePropertyMatch) SetMatch

func (x *DeleteData_NodePropertyMatch) SetMatch(v *NodeMatch)

func (*DeleteData_NodePropertyMatch) SetPropertyType

func (x *DeleteData_NodePropertyMatch) SetPropertyType(v string)

func (*DeleteData_NodePropertyMatch) String

type DeleteData_NodePropertyMatch_builder

type DeleteData_NodePropertyMatch_builder struct {
	Match        *NodeMatch
	PropertyType string
	// contains filtered or unexported fields
}

func (DeleteData_NodePropertyMatch_builder) Build

type DeleteData_NodeTagMatch

type DeleteData_NodeTagMatch struct {
	Match *NodeMatch `protobuf:"bytes,1,opt,name=match,proto3" json:"match,omitempty"`
	Tags  []string   `protobuf:"bytes,2,rep,name=tags,proto3" json:"tags,omitempty"`
	// contains filtered or unexported fields
}

func (*DeleteData_NodeTagMatch) ClearMatch

func (x *DeleteData_NodeTagMatch) ClearMatch()

func (*DeleteData_NodeTagMatch) GetMatch

func (x *DeleteData_NodeTagMatch) GetMatch() *NodeMatch

func (*DeleteData_NodeTagMatch) GetTags

func (x *DeleteData_NodeTagMatch) GetTags() []string

func (*DeleteData_NodeTagMatch) HasMatch

func (x *DeleteData_NodeTagMatch) HasMatch() bool

func (*DeleteData_NodeTagMatch) ProtoMessage

func (*DeleteData_NodeTagMatch) ProtoMessage()

func (*DeleteData_NodeTagMatch) ProtoReflect

func (x *DeleteData_NodeTagMatch) ProtoReflect() protoreflect.Message

func (*DeleteData_NodeTagMatch) Reset

func (x *DeleteData_NodeTagMatch) Reset()

func (*DeleteData_NodeTagMatch) SetMatch

func (x *DeleteData_NodeTagMatch) SetMatch(v *NodeMatch)

func (*DeleteData_NodeTagMatch) SetTags

func (x *DeleteData_NodeTagMatch) SetTags(v []string)

func (*DeleteData_NodeTagMatch) String

func (x *DeleteData_NodeTagMatch) String() string

type DeleteData_NodeTagMatch_builder

type DeleteData_NodeTagMatch_builder struct {
	Match *NodeMatch
	Tags  []string
	// contains filtered or unexported fields
}

func (DeleteData_NodeTagMatch_builder) Build

type DeleteData_NodeTags

type DeleteData_NodeTags struct {
	NodeTags *DeleteData_NodeTagMatch `protobuf:"bytes,5,opt,name=node_tags,json=nodeTags,proto3,oneof"`
}

type DeleteData_Relationship

type DeleteData_Relationship struct {
	Relationship *Relationship `protobuf:"bytes,2,opt,name=relationship,proto3,oneof"`
}

type DeleteData_RelationshipProperty

type DeleteData_RelationshipProperty struct {
	RelationshipProperty *DeleteData_RelationshipPropertyMatch `protobuf:"bytes,4,opt,name=relationship_property,json=relationshipProperty,proto3,oneof"`
}

type DeleteData_RelationshipPropertyMatch

type DeleteData_RelationshipPropertyMatch struct {
	Source       *NodeMatch `protobuf:"bytes,1,opt,name=source,proto3" json:"source,omitempty"`
	Target       *NodeMatch `protobuf:"bytes,2,opt,name=target,proto3" json:"target,omitempty"`
	Type         string     `protobuf:"bytes,3,opt,name=type,proto3" json:"type,omitempty"`
	PropertyType string     `protobuf:"bytes,4,opt,name=property_type,json=propertyType,proto3" json:"property_type,omitempty"`
	// contains filtered or unexported fields
}

func (*DeleteData_RelationshipPropertyMatch) ClearSource

func (x *DeleteData_RelationshipPropertyMatch) ClearSource()

func (*DeleteData_RelationshipPropertyMatch) ClearTarget

func (x *DeleteData_RelationshipPropertyMatch) ClearTarget()

func (*DeleteData_RelationshipPropertyMatch) GetPropertyType

func (x *DeleteData_RelationshipPropertyMatch) GetPropertyType() string

func (*DeleteData_RelationshipPropertyMatch) GetSource

func (*DeleteData_RelationshipPropertyMatch) GetTarget

func (*DeleteData_RelationshipPropertyMatch) GetType

func (*DeleteData_RelationshipPropertyMatch) HasSource

func (*DeleteData_RelationshipPropertyMatch) HasTarget

func (*DeleteData_RelationshipPropertyMatch) ProtoMessage

func (*DeleteData_RelationshipPropertyMatch) ProtoMessage()

func (*DeleteData_RelationshipPropertyMatch) ProtoReflect

func (*DeleteData_RelationshipPropertyMatch) Reset

func (*DeleteData_RelationshipPropertyMatch) SetPropertyType

func (x *DeleteData_RelationshipPropertyMatch) SetPropertyType(v string)

func (*DeleteData_RelationshipPropertyMatch) SetSource

func (*DeleteData_RelationshipPropertyMatch) SetTarget

func (*DeleteData_RelationshipPropertyMatch) SetType

func (*DeleteData_RelationshipPropertyMatch) String

type DeleteData_RelationshipPropertyMatch_builder

type DeleteData_RelationshipPropertyMatch_builder struct {
	Source       *NodeMatch
	Target       *NodeMatch
	Type         string
	PropertyType string
	// contains filtered or unexported fields
}

func (DeleteData_RelationshipPropertyMatch_builder) Build

type DeleteData_builder

type DeleteData_builder struct {

	// Fields of oneof Data:
	Node                 *NodeMatch
	Relationship         *Relationship
	NodeProperty         *DeleteData_NodePropertyMatch
	RelationshipProperty *DeleteData_RelationshipPropertyMatch
	NodeTags             *DeleteData_NodeTagMatch
	// contains filtered or unexported fields
}

func (DeleteData_builder) Build

func (b0 DeleteData_builder) Build() *DeleteData

type Entity

type Entity struct {

	// Types that are valid to be assigned to Data:
	//
	//	*Entity_Node
	//	*Entity_Relationship
	//	*Entity_NodeMatch
	Data isEntity_Data `protobuf_oneof:"data"`
	// contains filtered or unexported fields
}

func (*Entity) ClearData

func (x *Entity) ClearData()

func (*Entity) ClearNode

func (x *Entity) ClearNode()

func (*Entity) ClearNodeMatch

func (x *Entity) ClearNodeMatch()

func (*Entity) ClearRelationship

func (x *Entity) ClearRelationship()

func (*Entity) GetData

func (x *Entity) GetData() isEntity_Data

func (*Entity) GetNode

func (x *Entity) GetNode() *v1beta1.Node

func (*Entity) GetNodeMatch

func (x *Entity) GetNodeMatch() *NodeMatch

func (*Entity) GetRelationship

func (x *Entity) GetRelationship() *Relationship

func (*Entity) HasData

func (x *Entity) HasData() bool

func (*Entity) HasNode

func (x *Entity) HasNode() bool

func (*Entity) HasNodeMatch

func (x *Entity) HasNodeMatch() bool

func (*Entity) HasRelationship

func (x *Entity) HasRelationship() bool

func (*Entity) ProtoMessage

func (*Entity) ProtoMessage()

func (*Entity) ProtoReflect

func (x *Entity) ProtoReflect() protoreflect.Message

func (*Entity) Reset

func (x *Entity) Reset()

func (*Entity) SetNode

func (x *Entity) SetNode(v *v1beta1.Node)

func (*Entity) SetNodeMatch

func (x *Entity) SetNodeMatch(v *NodeMatch)

func (*Entity) SetRelationship

func (x *Entity) SetRelationship(v *Relationship)

func (*Entity) String

func (x *Entity) String() string

func (*Entity) WhichData

func (x *Entity) WhichData() case_Entity_Data

type Entity_Node

type Entity_Node struct {
	Node *v1beta1.Node `protobuf:"bytes,1,opt,name=node,proto3,oneof"`
}

type Entity_NodeMatch

type Entity_NodeMatch struct {
	NodeMatch *NodeMatch `protobuf:"bytes,3,opt,name=node_match,json=nodeMatch,proto3,oneof"`
}

type Entity_Relationship

type Entity_Relationship struct {
	Relationship *Relationship `protobuf:"bytes,2,opt,name=relationship,proto3,oneof"`
}

type Entity_builder

type Entity_builder struct {

	// Fields of oneof Data:
	Node         *v1beta1.Node
	Relationship *Relationship
	NodeMatch    *NodeMatch
	// contains filtered or unexported fields
}

func (Entity_builder) Build

func (b0 Entity_builder) Build() *Entity

type Info

type Info struct {
	Changes []*Change `protobuf:"bytes,1,rep,name=changes,proto3" json:"changes,omitempty"`
	// contains filtered or unexported fields
}

func (*Info) GetChanges

func (x *Info) GetChanges() []*Change

func (*Info) ProtoMessage

func (*Info) ProtoMessage()

func (*Info) ProtoReflect

func (x *Info) ProtoReflect() protoreflect.Message

func (*Info) Reset

func (x *Info) Reset()

func (*Info) SetChanges

func (x *Info) SetChanges(v []*Change)

func (*Info) String

func (x *Info) String() string

type Info_builder

type Info_builder struct {
	Changes []*Change
	// contains filtered or unexported fields
}

func (Info_builder) Build

func (b0 Info_builder) Build() *Info

type IngestRecordRequest

type IngestRecordRequest struct {
	Record *Record `protobuf:"bytes,1,opt,name=record,proto3" json:"record,omitempty"`
	// contains filtered or unexported fields
}

func (*IngestRecordRequest) ClearRecord

func (x *IngestRecordRequest) ClearRecord()

func (*IngestRecordRequest) GetRecord

func (x *IngestRecordRequest) GetRecord() *Record

func (*IngestRecordRequest) HasRecord

func (x *IngestRecordRequest) HasRecord() bool

func (*IngestRecordRequest) ProtoMessage

func (*IngestRecordRequest) ProtoMessage()

func (*IngestRecordRequest) ProtoReflect

func (x *IngestRecordRequest) ProtoReflect() protoreflect.Message

func (*IngestRecordRequest) Reset

func (x *IngestRecordRequest) Reset()

func (*IngestRecordRequest) SetRecord

func (x *IngestRecordRequest) SetRecord(v *Record)

func (*IngestRecordRequest) String

func (x *IngestRecordRequest) String() string

type IngestRecordRequest_builder

type IngestRecordRequest_builder struct {
	Record *Record
	// contains filtered or unexported fields
}

func (IngestRecordRequest_builder) Build

type IngestRecordResponse

type IngestRecordResponse struct {
	RecordId string `protobuf:"bytes,1,opt,name=record_id,json=recordId,proto3" json:"record_id,omitempty"`
	Info     *Info  `protobuf:"bytes,5,opt,name=info,proto3" json:"info,omitempty"`
	// contains filtered or unexported fields
}

func (*IngestRecordResponse) ClearInfo

func (x *IngestRecordResponse) ClearInfo()

func (*IngestRecordResponse) GetInfo

func (x *IngestRecordResponse) GetInfo() *Info

func (*IngestRecordResponse) GetRecordId

func (x *IngestRecordResponse) GetRecordId() string

func (*IngestRecordResponse) HasInfo

func (x *IngestRecordResponse) HasInfo() bool

func (*IngestRecordResponse) ProtoMessage

func (*IngestRecordResponse) ProtoMessage()

func (*IngestRecordResponse) ProtoReflect

func (x *IngestRecordResponse) ProtoReflect() protoreflect.Message

func (*IngestRecordResponse) Reset

func (x *IngestRecordResponse) Reset()

func (*IngestRecordResponse) SetInfo

func (x *IngestRecordResponse) SetInfo(v *Info)

func (*IngestRecordResponse) SetRecordId

func (x *IngestRecordResponse) SetRecordId(v string)

func (*IngestRecordResponse) String

func (x *IngestRecordResponse) String() string

type IngestRecordResponse_builder

type IngestRecordResponse_builder struct {
	RecordId string
	Info     *Info
	// contains filtered or unexported fields
}

func (IngestRecordResponse_builder) Build

type NodeMatch

type NodeMatch struct {
	ExternalId    string         `protobuf:"bytes,1,opt,name=external_id,json=externalId,proto3" json:"external_id,omitempty"`
	Type          string         `protobuf:"bytes,2,opt,name=type,proto3" json:"type,omitempty"`
	PropertyTypes []string       `protobuf:"bytes,3,rep,name=property_types,json=propertyTypes,proto3" json:"property_types,omitempty"`
	PropertyMatch *PropertyMatch `protobuf:"bytes,4,opt,name=property_match,json=propertyMatch,proto3" json:"property_match,omitempty"`
	// contains filtered or unexported fields
}

func (*NodeMatch) ClearPropertyMatch

func (x *NodeMatch) ClearPropertyMatch()

func (*NodeMatch) GetExternalId

func (x *NodeMatch) GetExternalId() string

func (*NodeMatch) GetPropertyMatch

func (x *NodeMatch) GetPropertyMatch() *PropertyMatch

func (*NodeMatch) GetPropertyTypes

func (x *NodeMatch) GetPropertyTypes() []string

func (*NodeMatch) GetType

func (x *NodeMatch) GetType() string

func (*NodeMatch) HasPropertyMatch

func (x *NodeMatch) HasPropertyMatch() bool

func (*NodeMatch) ProtoMessage

func (*NodeMatch) ProtoMessage()

func (*NodeMatch) ProtoReflect

func (x *NodeMatch) ProtoReflect() protoreflect.Message

func (*NodeMatch) Reset

func (x *NodeMatch) Reset()

func (*NodeMatch) SetExternalId

func (x *NodeMatch) SetExternalId(v string)

func (*NodeMatch) SetPropertyMatch

func (x *NodeMatch) SetPropertyMatch(v *PropertyMatch)

func (*NodeMatch) SetPropertyTypes

func (x *NodeMatch) SetPropertyTypes(v []string)

func (*NodeMatch) SetType

func (x *NodeMatch) SetType(v string)

func (*NodeMatch) String

func (x *NodeMatch) String() string

type NodeMatch_builder

type NodeMatch_builder struct {
	ExternalId    string
	Type          string
	PropertyTypes []string
	PropertyMatch *PropertyMatch
	// contains filtered or unexported fields
}

func (NodeMatch_builder) Build

func (b0 NodeMatch_builder) Build() *NodeMatch

type PropertyMatch

type PropertyMatch struct {
	PropertyType   string   `protobuf:"bytes,1,opt,name=property_type,json=propertyType,proto3" json:"property_type,omitempty"`
	MetadataFields []string `protobuf:"bytes,5,rep,name=metadata_fields,json=metadataFields,proto3" json:"metadata_fields,omitempty"`
	// contains filtered or unexported fields
}

func (*PropertyMatch) GetMetadataFields

func (x *PropertyMatch) GetMetadataFields() []string

func (*PropertyMatch) GetPropertyType

func (x *PropertyMatch) GetPropertyType() string

func (*PropertyMatch) ProtoMessage

func (*PropertyMatch) ProtoMessage()

func (*PropertyMatch) ProtoReflect

func (x *PropertyMatch) ProtoReflect() protoreflect.Message

func (*PropertyMatch) Reset

func (x *PropertyMatch) Reset()

func (*PropertyMatch) SetMetadataFields

func (x *PropertyMatch) SetMetadataFields(v []string)

func (*PropertyMatch) SetPropertyType

func (x *PropertyMatch) SetPropertyType(v string)

func (*PropertyMatch) String

func (x *PropertyMatch) String() string

type PropertyMatch_builder

type PropertyMatch_builder struct {
	PropertyType   string
	MetadataFields []string
	// contains filtered or unexported fields
}

func (PropertyMatch_builder) Build

type Record

type Record struct {

	// Unique identifier of the record, for client side reference
	Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	// Types that are valid to be assigned to Operation:
	//
	//	*Record_Upsert
	//	*Record_Delete
	Operation isRecord_Operation `protobuf_oneof:"operation"`
	// contains filtered or unexported fields
}

func (*Record) ClearDelete

func (x *Record) ClearDelete()

func (*Record) ClearOperation

func (x *Record) ClearOperation()

func (*Record) ClearUpsert

func (x *Record) ClearUpsert()

func (*Record) GetDelete

func (x *Record) GetDelete() *DeleteData

func (*Record) GetId

func (x *Record) GetId() string

func (*Record) GetOperation

func (x *Record) GetOperation() isRecord_Operation

func (*Record) GetUpsert

func (x *Record) GetUpsert() *UpsertData

func (*Record) HasDelete

func (x *Record) HasDelete() bool

func (*Record) HasOperation

func (x *Record) HasOperation() bool

func (*Record) HasUpsert

func (x *Record) HasUpsert() bool

func (*Record) ProtoMessage

func (*Record) ProtoMessage()

func (*Record) ProtoReflect

func (x *Record) ProtoReflect() protoreflect.Message

func (*Record) Reset

func (x *Record) Reset()

func (*Record) SetDelete

func (x *Record) SetDelete(v *DeleteData)

func (*Record) SetId

func (x *Record) SetId(v string)

func (*Record) SetUpsert

func (x *Record) SetUpsert(v *UpsertData)

func (*Record) String

func (x *Record) String() string

func (*Record) WhichOperation

func (x *Record) WhichOperation() case_Record_Operation

type RecordError

type RecordError struct {
	Error string `protobuf:"bytes,1,opt,name=error,proto3" json:"error,omitempty"`
	// contains filtered or unexported fields
}

func (*RecordError) GetError

func (x *RecordError) GetError() string

func (*RecordError) ProtoMessage

func (*RecordError) ProtoMessage()

func (*RecordError) ProtoReflect

func (x *RecordError) ProtoReflect() protoreflect.Message

func (*RecordError) Reset

func (x *RecordError) Reset()

func (*RecordError) SetError

func (x *RecordError) SetError(v string)

func (*RecordError) String

func (x *RecordError) String() string

type RecordError_builder

type RecordError_builder struct {
	Error string
	// contains filtered or unexported fields
}

func (RecordError_builder) Build

func (b0 RecordError_builder) Build() *RecordError

type Record_Delete

type Record_Delete struct {
	Delete *DeleteData `protobuf:"bytes,3,opt,name=delete,proto3,oneof"`
}

type Record_Upsert

type Record_Upsert struct {
	Upsert *UpsertData `protobuf:"bytes,2,opt,name=upsert,proto3,oneof"`
}

type Record_builder

type Record_builder struct {

	// Unique identifier of the record, for client side reference
	Id string
	// Fields of oneof Operation:
	Upsert *UpsertData
	Delete *DeleteData
	// contains filtered or unexported fields
}

func (Record_builder) Build

func (b0 Record_builder) Build() *Record

type Relationship

type Relationship struct {
	Source        *NodeMatch          `protobuf:"bytes,1,opt,name=source,proto3" json:"source,omitempty"`
	Target        *NodeMatch          `protobuf:"bytes,2,opt,name=target,proto3" json:"target,omitempty"`
	Type          string              `protobuf:"bytes,3,opt,name=type,proto3" json:"type,omitempty"`
	Properties    []*v1beta1.Property `protobuf:"bytes,4,rep,name=properties,proto3" json:"properties,omitempty"`
	PropertyTypes []string            `protobuf:"bytes,5,rep,name=property_types,json=propertyTypes,proto3" json:"property_types,omitempty"`
	// contains filtered or unexported fields
}

func (*Relationship) ClearSource

func (x *Relationship) ClearSource()

func (*Relationship) ClearTarget

func (x *Relationship) ClearTarget()

func (*Relationship) GetProperties

func (x *Relationship) GetProperties() []*v1beta1.Property

func (*Relationship) GetPropertyTypes

func (x *Relationship) GetPropertyTypes() []string

func (*Relationship) GetSource

func (x *Relationship) GetSource() *NodeMatch

func (*Relationship) GetTarget

func (x *Relationship) GetTarget() *NodeMatch

func (*Relationship) GetType

func (x *Relationship) GetType() string

func (*Relationship) HasSource

func (x *Relationship) HasSource() bool

func (*Relationship) HasTarget

func (x *Relationship) HasTarget() bool

func (*Relationship) ProtoMessage

func (*Relationship) ProtoMessage()

func (*Relationship) ProtoReflect

func (x *Relationship) ProtoReflect() protoreflect.Message

func (*Relationship) Reset

func (x *Relationship) Reset()

func (*Relationship) SetProperties

func (x *Relationship) SetProperties(v []*v1beta1.Property)

func (*Relationship) SetPropertyTypes

func (x *Relationship) SetPropertyTypes(v []string)

func (*Relationship) SetSource

func (x *Relationship) SetSource(v *NodeMatch)

func (*Relationship) SetTarget

func (x *Relationship) SetTarget(v *NodeMatch)

func (*Relationship) SetType

func (x *Relationship) SetType(v string)

func (*Relationship) String

func (x *Relationship) String() string

type Relationship_builder

type Relationship_builder struct {
	Source        *NodeMatch
	Target        *NodeMatch
	Type          string
	Properties    []*v1beta1.Property
	PropertyTypes []string
	// contains filtered or unexported fields
}

func (Relationship_builder) Build

func (b0 Relationship_builder) Build() *Relationship

type StreamRecordsRequest

type StreamRecordsRequest struct {
	Record *Record `protobuf:"bytes,1,opt,name=record,proto3" json:"record,omitempty"`
	// contains filtered or unexported fields
}

func (*StreamRecordsRequest) ClearRecord

func (x *StreamRecordsRequest) ClearRecord()

func (*StreamRecordsRequest) GetRecord

func (x *StreamRecordsRequest) GetRecord() *Record

func (*StreamRecordsRequest) HasRecord

func (x *StreamRecordsRequest) HasRecord() bool

func (*StreamRecordsRequest) ProtoMessage

func (*StreamRecordsRequest) ProtoMessage()

func (*StreamRecordsRequest) ProtoReflect

func (x *StreamRecordsRequest) ProtoReflect() protoreflect.Message

func (*StreamRecordsRequest) Reset

func (x *StreamRecordsRequest) Reset()

func (*StreamRecordsRequest) SetRecord

func (x *StreamRecordsRequest) SetRecord(v *Record)

func (*StreamRecordsRequest) String

func (x *StreamRecordsRequest) String() string

type StreamRecordsRequest_builder

type StreamRecordsRequest_builder struct {
	Record *Record
	// contains filtered or unexported fields
}

func (StreamRecordsRequest_builder) Build

type StreamRecordsResponse

type StreamRecordsResponse struct {
	RecordId    string `protobuf:"bytes,1,opt,name=record_id,json=recordId,proto3" json:"record_id,omitempty"`
	RecordIndex uint32 `protobuf:"varint,2,opt,name=record_index,json=recordIndex,proto3" json:"record_index,omitempty"`
	// Types that are valid to be assigned to Error:
	//
	//	*StreamRecordsResponse_RecordError
	//	*StreamRecordsResponse_StatusError
	Error isStreamRecordsResponse_Error `protobuf_oneof:"error"`
	Info  *Info                         `protobuf:"bytes,5,opt,name=info,proto3" json:"info,omitempty"`
	// contains filtered or unexported fields
}

func (*StreamRecordsResponse) ClearError

func (x *StreamRecordsResponse) ClearError()

func (*StreamRecordsResponse) ClearInfo

func (x *StreamRecordsResponse) ClearInfo()

func (*StreamRecordsResponse) ClearRecordError

func (x *StreamRecordsResponse) ClearRecordError()

func (*StreamRecordsResponse) ClearStatusError

func (x *StreamRecordsResponse) ClearStatusError()

func (*StreamRecordsResponse) GetError

func (x *StreamRecordsResponse) GetError() isStreamRecordsResponse_Error

func (*StreamRecordsResponse) GetInfo

func (x *StreamRecordsResponse) GetInfo() *Info

func (*StreamRecordsResponse) GetRecordError

func (x *StreamRecordsResponse) GetRecordError() *RecordError

func (*StreamRecordsResponse) GetRecordId

func (x *StreamRecordsResponse) GetRecordId() string

func (*StreamRecordsResponse) GetRecordIndex

func (x *StreamRecordsResponse) GetRecordIndex() uint32

func (*StreamRecordsResponse) GetStatusError

func (x *StreamRecordsResponse) GetStatusError() *status.Status

func (*StreamRecordsResponse) HasError

func (x *StreamRecordsResponse) HasError() bool

func (*StreamRecordsResponse) HasInfo

func (x *StreamRecordsResponse) HasInfo() bool

func (*StreamRecordsResponse) HasRecordError

func (x *StreamRecordsResponse) HasRecordError() bool

func (*StreamRecordsResponse) HasStatusError

func (x *StreamRecordsResponse) HasStatusError() bool

func (*StreamRecordsResponse) ProtoMessage

func (*StreamRecordsResponse) ProtoMessage()

func (*StreamRecordsResponse) ProtoReflect

func (x *StreamRecordsResponse) ProtoReflect() protoreflect.Message

func (*StreamRecordsResponse) Reset

func (x *StreamRecordsResponse) Reset()

func (*StreamRecordsResponse) SetInfo

func (x *StreamRecordsResponse) SetInfo(v *Info)

func (*StreamRecordsResponse) SetRecordError

func (x *StreamRecordsResponse) SetRecordError(v *RecordError)

func (*StreamRecordsResponse) SetRecordId

func (x *StreamRecordsResponse) SetRecordId(v string)

func (*StreamRecordsResponse) SetRecordIndex

func (x *StreamRecordsResponse) SetRecordIndex(v uint32)

func (*StreamRecordsResponse) SetStatusError

func (x *StreamRecordsResponse) SetStatusError(v *status.Status)

func (*StreamRecordsResponse) String

func (x *StreamRecordsResponse) String() string

func (*StreamRecordsResponse) WhichError

func (x *StreamRecordsResponse) WhichError() case_StreamRecordsResponse_Error

type StreamRecordsResponse_RecordError

type StreamRecordsResponse_RecordError struct {
	RecordError *RecordError `protobuf:"bytes,3,opt,name=record_error,json=recordError,proto3,oneof"`
}

type StreamRecordsResponse_StatusError

type StreamRecordsResponse_StatusError struct {
	StatusError *status.Status `protobuf:"bytes,4,opt,name=status_error,json=statusError,proto3,oneof"`
}

type StreamRecordsResponse_builder

type StreamRecordsResponse_builder struct {
	RecordId    string
	RecordIndex uint32
	// Fields of oneof Error:
	RecordError *RecordError
	StatusError *status.Status
	// -- end of Error
	Info *Info
	// contains filtered or unexported fields
}

func (StreamRecordsResponse_builder) Build

type UpsertData

type UpsertData struct {

	// Types that are valid to be assigned to Data:
	//
	//	*UpsertData_Node
	//	*UpsertData_Relationship
	Data isUpsertData_Data `protobuf_oneof:"data"`
	// contains filtered or unexported fields
}

func (*UpsertData) ClearData

func (x *UpsertData) ClearData()

func (*UpsertData) ClearNode

func (x *UpsertData) ClearNode()

func (*UpsertData) ClearRelationship

func (x *UpsertData) ClearRelationship()

func (*UpsertData) GetData

func (x *UpsertData) GetData() isUpsertData_Data

func (*UpsertData) GetNode

func (x *UpsertData) GetNode() *v1beta1.Node

func (*UpsertData) GetRelationship

func (x *UpsertData) GetRelationship() *Relationship

func (*UpsertData) HasData

func (x *UpsertData) HasData() bool

func (*UpsertData) HasNode

func (x *UpsertData) HasNode() bool

func (*UpsertData) HasRelationship

func (x *UpsertData) HasRelationship() bool

func (*UpsertData) ProtoMessage

func (*UpsertData) ProtoMessage()

func (*UpsertData) ProtoReflect

func (x *UpsertData) ProtoReflect() protoreflect.Message

func (*UpsertData) Reset

func (x *UpsertData) Reset()

func (*UpsertData) SetNode

func (x *UpsertData) SetNode(v *v1beta1.Node)

func (*UpsertData) SetRelationship

func (x *UpsertData) SetRelationship(v *Relationship)

func (*UpsertData) String

func (x *UpsertData) String() string

func (*UpsertData) WhichData

func (x *UpsertData) WhichData() case_UpsertData_Data

type UpsertData_Node

type UpsertData_Node struct {
	Node *v1beta1.Node `protobuf:"bytes,1,opt,name=node,proto3,oneof"`
}

type UpsertData_Relationship

type UpsertData_Relationship struct {
	Relationship *Relationship `protobuf:"bytes,2,opt,name=relationship,proto3,oneof"`
}

type UpsertData_builder

type UpsertData_builder struct {

	// Fields of oneof Data:
	Node         *v1beta1.Node
	Relationship *Relationship
	// contains filtered or unexported fields
}

func (UpsertData_builder) Build

func (b0 UpsertData_builder) Build() *UpsertData

Source Files

  • ingest_api.pb.go
  • model.pb.go

Jump to