objectsv1beta1

package
v1.36.11-2026011218094... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 8 Imported by: 1

Documentation

Index

Constants

const ExternalValue_Id_case case_ExternalValue_Resolver = 1
const ExternalValue_Name_case case_ExternalValue_Resolver = 2
const ExternalValue_Resolver_not_set_case case_ExternalValue_Resolver = 0
const User_ExternalId_case case_User_User = 5
const User_Property_case case_User_User = 3
const User_ThirdPartyToken_case case_User_User = 6
const User_UserId_case case_User_User = 1
const User_User_not_set_case case_User_User = 0

Variables

var File_indykite_knowledge_objects_v1beta1_ikg_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type ExternalValue

type ExternalValue struct {

	// Types that are valid to be assigned to Resolver:
	//
	//	*ExternalValue_Id
	//	*ExternalValue_Name
	Resolver isExternalValue_Resolver `protobuf_oneof:"resolver"`
	// contains filtered or unexported fields
}

func (*ExternalValue) ClearId

func (x *ExternalValue) ClearId()

func (*ExternalValue) ClearName

func (x *ExternalValue) ClearName()

func (*ExternalValue) ClearResolver

func (x *ExternalValue) ClearResolver()

func (*ExternalValue) GetId

func (x *ExternalValue) GetId() string

func (*ExternalValue) GetName

func (x *ExternalValue) GetName() string

func (*ExternalValue) GetResolver

func (x *ExternalValue) GetResolver() isExternalValue_Resolver

func (*ExternalValue) HasId

func (x *ExternalValue) HasId() bool

func (*ExternalValue) HasName

func (x *ExternalValue) HasName() bool

func (*ExternalValue) HasResolver

func (x *ExternalValue) HasResolver() bool

func (*ExternalValue) ProtoMessage

func (*ExternalValue) ProtoMessage()

func (*ExternalValue) ProtoReflect

func (x *ExternalValue) ProtoReflect() protoreflect.Message

func (*ExternalValue) Reset

func (x *ExternalValue) Reset()

func (*ExternalValue) SetId

func (x *ExternalValue) SetId(v string)

func (*ExternalValue) SetName

func (x *ExternalValue) SetName(v string)

func (*ExternalValue) String

func (x *ExternalValue) String() string

func (*ExternalValue) WhichResolver

func (x *ExternalValue) WhichResolver() case_ExternalValue_Resolver

type ExternalValue_Id

type ExternalValue_Id struct {
	Id string `protobuf:"bytes,1,opt,name=id,proto3,oneof"`
}

type ExternalValue_Name

type ExternalValue_Name struct {
	Name string `protobuf:"bytes,2,opt,name=name,proto3,oneof"`
}

type ExternalValue_builder

type ExternalValue_builder struct {

	// Fields of oneof Resolver:
	Id   *string
	Name *string
	// contains filtered or unexported fields
}

func (ExternalValue_builder) Build

type Metadata

type Metadata struct {
	AssuranceLevel   int32                     `protobuf:"varint,1,opt,name=assurance_level,json=assuranceLevel,proto3" json:"assurance_level,omitempty"`
	VerificationTime *timestamppb.Timestamp    `protobuf:"bytes,2,opt,name=verification_time,json=verificationTime,proto3" json:"verification_time,omitempty"`
	Source           string                    `protobuf:"bytes,3,opt,name=source,proto3" json:"source,omitempty"`
	CustomMetadata   map[string]*v1beta2.Value `` /* 177-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*Metadata) ClearVerificationTime

func (x *Metadata) ClearVerificationTime()

func (*Metadata) GetAssuranceLevel

func (x *Metadata) GetAssuranceLevel() int32

func (*Metadata) GetCustomMetadata

func (x *Metadata) GetCustomMetadata() map[string]*v1beta2.Value

func (*Metadata) GetSource

func (x *Metadata) GetSource() string

func (*Metadata) GetVerificationTime

func (x *Metadata) GetVerificationTime() *timestamppb.Timestamp

func (*Metadata) HasVerificationTime

func (x *Metadata) HasVerificationTime() bool

func (*Metadata) ProtoMessage

func (*Metadata) ProtoMessage()

func (*Metadata) ProtoReflect

func (x *Metadata) ProtoReflect() protoreflect.Message

func (*Metadata) Reset

func (x *Metadata) Reset()

func (*Metadata) SetAssuranceLevel

func (x *Metadata) SetAssuranceLevel(v int32)

func (*Metadata) SetCustomMetadata

func (x *Metadata) SetCustomMetadata(v map[string]*v1beta2.Value)

func (*Metadata) SetSource

func (x *Metadata) SetSource(v string)

func (*Metadata) SetVerificationTime

func (x *Metadata) SetVerificationTime(v *timestamppb.Timestamp)

func (*Metadata) String

func (x *Metadata) String() string

type Metadata_builder

type Metadata_builder struct {
	AssuranceLevel   int32
	VerificationTime *timestamppb.Timestamp
	Source           string
	CustomMetadata   map[string]*v1beta2.Value
	// contains filtered or unexported fields
}

func (Metadata_builder) Build

func (b0 Metadata_builder) Build() *Metadata

type Node

type Node struct {
	Id         string                 `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"` // read-only
	ExternalId string                 `protobuf:"bytes,2,opt,name=external_id,json=externalId,proto3" json:"external_id,omitempty"`
	Type       string                 `protobuf:"bytes,3,opt,name=type,proto3" json:"type,omitempty"`
	Tags       []string               `protobuf:"bytes,4,rep,name=tags,proto3" json:"tags,omitempty"`
	CreateTime *timestamppb.Timestamp `protobuf:"bytes,5,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"` // read-only
	UpdateTime *timestamppb.Timestamp `protobuf:"bytes,6,opt,name=update_time,json=updateTime,proto3" json:"update_time,omitempty"` // read-only
	Properties []*Property            `protobuf:"bytes,7,rep,name=properties,proto3" json:"properties,omitempty"`
	IsIdentity bool                   `protobuf:"varint,8,opt,name=is_identity,json=isIdentity,proto3" json:"is_identity,omitempty"`
	// contains filtered or unexported fields
}

func (*Node) ClearCreateTime

func (x *Node) ClearCreateTime()

func (*Node) ClearUpdateTime

func (x *Node) ClearUpdateTime()

func (*Node) GetCreateTime

func (x *Node) GetCreateTime() *timestamppb.Timestamp

func (*Node) GetExternalId

func (x *Node) GetExternalId() string

func (*Node) GetId

func (x *Node) GetId() string

func (*Node) GetIsIdentity

func (x *Node) GetIsIdentity() bool

func (*Node) GetProperties

func (x *Node) GetProperties() []*Property

func (*Node) GetTags

func (x *Node) GetTags() []string

func (*Node) GetType

func (x *Node) GetType() string

func (*Node) GetUpdateTime

func (x *Node) GetUpdateTime() *timestamppb.Timestamp

func (*Node) HasCreateTime

func (x *Node) HasCreateTime() bool

func (*Node) HasUpdateTime

func (x *Node) HasUpdateTime() bool

func (*Node) ProtoMessage

func (*Node) ProtoMessage()

func (*Node) ProtoReflect

func (x *Node) ProtoReflect() protoreflect.Message

func (*Node) Reset

func (x *Node) Reset()

func (*Node) SetCreateTime

func (x *Node) SetCreateTime(v *timestamppb.Timestamp)

func (*Node) SetExternalId

func (x *Node) SetExternalId(v string)

func (*Node) SetId

func (x *Node) SetId(v string)

func (*Node) SetIsIdentity

func (x *Node) SetIsIdentity(v bool)

func (*Node) SetProperties

func (x *Node) SetProperties(v []*Property)

func (*Node) SetTags

func (x *Node) SetTags(v []string)

func (*Node) SetType

func (x *Node) SetType(v string)

func (*Node) SetUpdateTime

func (x *Node) SetUpdateTime(v *timestamppb.Timestamp)

func (*Node) String

func (x *Node) String() string

type Node_builder

type Node_builder struct {
	Id         string
	ExternalId string
	Type       string
	Tags       []string
	CreateTime *timestamppb.Timestamp
	UpdateTime *timestamppb.Timestamp
	Properties []*Property
	IsIdentity bool
	// contains filtered or unexported fields
}

func (Node_builder) Build

func (b0 Node_builder) Build() *Node

type Property

type Property struct {
	Type          string         `protobuf:"bytes,1,opt,name=type,proto3" json:"type,omitempty"`
	Value         *v1beta2.Value `protobuf:"bytes,2,opt,name=value,proto3" json:"value,omitempty"`
	ExternalValue *ExternalValue `protobuf:"bytes,4,opt,name=external_value,json=externalValue,proto3" json:"external_value,omitempty"`
	Metadata      *Metadata      `protobuf:"bytes,3,opt,name=metadata,proto3" json:"metadata,omitempty"`
	// contains filtered or unexported fields
}

func (*Property) ClearExternalValue

func (x *Property) ClearExternalValue()

func (*Property) ClearMetadata

func (x *Property) ClearMetadata()

func (*Property) ClearValue

func (x *Property) ClearValue()

func (*Property) GetExternalValue

func (x *Property) GetExternalValue() *ExternalValue

func (*Property) GetMetadata

func (x *Property) GetMetadata() *Metadata

func (*Property) GetType

func (x *Property) GetType() string

func (*Property) GetValue

func (x *Property) GetValue() *v1beta2.Value

func (*Property) HasExternalValue

func (x *Property) HasExternalValue() bool

func (*Property) HasMetadata

func (x *Property) HasMetadata() bool

func (*Property) HasValue

func (x *Property) HasValue() bool

func (*Property) ProtoMessage

func (*Property) ProtoMessage()

func (*Property) ProtoReflect

func (x *Property) ProtoReflect() protoreflect.Message

func (*Property) Reset

func (x *Property) Reset()

func (*Property) SetExternalValue

func (x *Property) SetExternalValue(v *ExternalValue)

func (*Property) SetMetadata

func (x *Property) SetMetadata(v *Metadata)

func (*Property) SetType

func (x *Property) SetType(v string)

func (*Property) SetValue

func (x *Property) SetValue(v *v1beta2.Value)

func (*Property) String

func (x *Property) String() string

type Property_builder

type Property_builder struct {
	Type          string
	Value         *v1beta2.Value
	ExternalValue *ExternalValue
	Metadata      *Metadata
	// contains filtered or unexported fields
}

func (Property_builder) Build

func (b0 Property_builder) Build() *Property

type Relationship

type Relationship struct {
	Id         string                    `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"` // read-only
	Type       string                    `protobuf:"bytes,2,opt,name=type,proto3" json:"type,omitempty"`
	Source     string                    `protobuf:"bytes,3,opt,name=source,proto3" json:"source,omitempty"`
	Target     string                    `protobuf:"bytes,4,opt,name=target,proto3" json:"target,omitempty"`
	CreateTime *timestamppb.Timestamp    `protobuf:"bytes,5,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"` // read-only
	UpdateTime *timestamppb.Timestamp    `protobuf:"bytes,6,opt,name=update_time,json=updateTime,proto3" json:"update_time,omitempty"` // read-only
	Properties map[string]*v1beta2.Value ``                                                                                            /* 147-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*Relationship) ClearCreateTime

func (x *Relationship) ClearCreateTime()

func (*Relationship) ClearUpdateTime

func (x *Relationship) ClearUpdateTime()

func (*Relationship) GetCreateTime

func (x *Relationship) GetCreateTime() *timestamppb.Timestamp

func (*Relationship) GetId

func (x *Relationship) GetId() string

func (*Relationship) GetProperties

func (x *Relationship) GetProperties() map[string]*v1beta2.Value

func (*Relationship) GetSource

func (x *Relationship) GetSource() string

func (*Relationship) GetTarget

func (x *Relationship) GetTarget() string

func (*Relationship) GetType

func (x *Relationship) GetType() string

func (*Relationship) GetUpdateTime

func (x *Relationship) GetUpdateTime() *timestamppb.Timestamp

func (*Relationship) HasCreateTime

func (x *Relationship) HasCreateTime() bool

func (*Relationship) HasUpdateTime

func (x *Relationship) HasUpdateTime() bool

func (*Relationship) ProtoMessage

func (*Relationship) ProtoMessage()

func (*Relationship) ProtoReflect

func (x *Relationship) ProtoReflect() protoreflect.Message

func (*Relationship) Reset

func (x *Relationship) Reset()

func (*Relationship) SetCreateTime

func (x *Relationship) SetCreateTime(v *timestamppb.Timestamp)

func (*Relationship) SetId

func (x *Relationship) SetId(v string)

func (*Relationship) SetProperties

func (x *Relationship) SetProperties(v map[string]*v1beta2.Value)

func (*Relationship) SetSource

func (x *Relationship) SetSource(v string)

func (*Relationship) SetTarget

func (x *Relationship) SetTarget(v string)

func (*Relationship) SetType

func (x *Relationship) SetType(v string)

func (*Relationship) SetUpdateTime

func (x *Relationship) SetUpdateTime(v *timestamppb.Timestamp)

func (*Relationship) String

func (x *Relationship) String() string

type Relationship_builder

type Relationship_builder struct {
	Id         string
	Type       string
	Source     string
	Target     string
	CreateTime *timestamppb.Timestamp
	UpdateTime *timestamppb.Timestamp
	Properties map[string]*v1beta2.Value
	// contains filtered or unexported fields
}

func (Relationship_builder) Build

func (b0 Relationship_builder) Build() *Relationship

type User

type User struct {

	// Types that are valid to be assigned to User:
	//
	//	*User_UserId
	//	*User_Property_
	//	*User_ExternalId
	//	*User_ThirdPartyToken
	User isUser_User `protobuf_oneof:"user"`
	// contains filtered or unexported fields
}

User to look up in the Identity Knowledge Graph.

func (*User) ClearExternalId

func (x *User) ClearExternalId()

func (*User) ClearProperty

func (x *User) ClearProperty()

func (*User) ClearThirdPartyToken

func (x *User) ClearThirdPartyToken()

func (*User) ClearUser

func (x *User) ClearUser()

func (*User) ClearUserId

func (x *User) ClearUserId()

func (*User) GetExternalId

func (x *User) GetExternalId() *User_ExternalID

func (*User) GetProperty

func (x *User) GetProperty() *User_Property

func (*User) GetThirdPartyToken

func (x *User) GetThirdPartyToken() string

func (*User) GetUser

func (x *User) GetUser() isUser_User

func (*User) GetUserId

func (x *User) GetUserId() string

func (*User) HasExternalId

func (x *User) HasExternalId() bool

func (*User) HasProperty

func (x *User) HasProperty() bool

func (*User) HasThirdPartyToken

func (x *User) HasThirdPartyToken() bool

func (*User) HasUser

func (x *User) HasUser() bool

func (*User) HasUserId

func (x *User) HasUserId() bool

func (*User) ProtoMessage

func (*User) ProtoMessage()

func (*User) ProtoReflect

func (x *User) ProtoReflect() protoreflect.Message

func (*User) Reset

func (x *User) Reset()

func (*User) SetExternalId

func (x *User) SetExternalId(v *User_ExternalID)

func (*User) SetProperty

func (x *User) SetProperty(v *User_Property)

func (*User) SetThirdPartyToken

func (x *User) SetThirdPartyToken(v string)

func (*User) SetUserId

func (x *User) SetUserId(v string)

func (*User) String

func (x *User) String() string

func (*User) WhichUser

func (x *User) WhichUser() case_User_User

type User_ExternalID

type User_ExternalID struct {
	Type       string `protobuf:"bytes,1,opt,name=type,proto3" json:"type,omitempty"`
	ExternalId string `protobuf:"bytes,2,opt,name=external_id,json=externalId,proto3" json:"external_id,omitempty"`
	// contains filtered or unexported fields
}

func (*User_ExternalID) GetExternalId

func (x *User_ExternalID) GetExternalId() string

func (*User_ExternalID) GetType

func (x *User_ExternalID) GetType() string

func (*User_ExternalID) ProtoMessage

func (*User_ExternalID) ProtoMessage()

func (*User_ExternalID) ProtoReflect

func (x *User_ExternalID) ProtoReflect() protoreflect.Message

func (*User_ExternalID) Reset

func (x *User_ExternalID) Reset()

func (*User_ExternalID) SetExternalId

func (x *User_ExternalID) SetExternalId(v string)

func (*User_ExternalID) SetType

func (x *User_ExternalID) SetType(v string)

func (*User_ExternalID) String

func (x *User_ExternalID) String() string

type User_ExternalID_builder

type User_ExternalID_builder struct {
	Type       string
	ExternalId string
	// contains filtered or unexported fields
}

func (User_ExternalID_builder) Build

type User_ExternalId

type User_ExternalId struct {
	ExternalId *User_ExternalID `protobuf:"bytes,5,opt,name=external_id,json=externalId,proto3,oneof"`
}

type User_Property

type User_Property struct {
	Type  string         `protobuf:"bytes,1,opt,name=type,proto3" json:"type,omitempty"`
	Value *v1beta1.Value `protobuf:"bytes,2,opt,name=value,proto3" json:"value,omitempty"`
	// contains filtered or unexported fields
}

func (*User_Property) ClearValue

func (x *User_Property) ClearValue()

func (*User_Property) GetType

func (x *User_Property) GetType() string

func (*User_Property) GetValue

func (x *User_Property) GetValue() *v1beta1.Value

func (*User_Property) HasValue

func (x *User_Property) HasValue() bool

func (*User_Property) ProtoMessage

func (*User_Property) ProtoMessage()

func (*User_Property) ProtoReflect

func (x *User_Property) ProtoReflect() protoreflect.Message

func (*User_Property) Reset

func (x *User_Property) Reset()

func (*User_Property) SetType

func (x *User_Property) SetType(v string)

func (*User_Property) SetValue

func (x *User_Property) SetValue(v *v1beta1.Value)

func (*User_Property) String

func (x *User_Property) String() string

type User_Property_

type User_Property_ struct {
	Property *User_Property `protobuf:"bytes,3,opt,name=property,proto3,oneof"`
}

type User_Property_builder

type User_Property_builder struct {
	Type  string
	Value *v1beta1.Value
	// contains filtered or unexported fields
}

func (User_Property_builder) Build

type User_ThirdPartyToken

type User_ThirdPartyToken struct {
	ThirdPartyToken string `protobuf:"bytes,6,opt,name=third_party_token,json=thirdPartyToken,proto3,oneof"`
}

type User_UserId

type User_UserId struct {
	// Gid, unique identifier for the user
	UserId string `protobuf:"bytes,1,opt,name=user_id,json=userId,proto3,oneof"`
}

type User_builder

type User_builder struct {

	// Fields of oneof User:
	// Gid, unique identifier for the user
	UserId          *string
	Property        *User_Property
	ExternalId      *User_ExternalID
	ThirdPartyToken *string
	// contains filtered or unexported fields
}

func (User_builder) Build

func (b0 User_builder) Build() *User

Source Files

  • ikg.pb.go

Jump to