objectsv1beta2

package
v1.36.11-2026020416421... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 7 Imported by: 3

Documentation

Index

Constants

const Value_ArrayValue_case case_Value_Type = 8
const Value_BoolValue_case case_Value_Type = 1
const Value_BytesValue_case case_Value_Type = 7
const Value_DoubleValue_case case_Value_Type = 3
const Value_DurationValue_case case_Value_Type = 5
const Value_IntegerValue_case case_Value_Type = 2
const Value_MapValue_case case_Value_Type = 9
const Value_StringValue_case case_Value_Type = 6
const Value_TimeValue_case case_Value_Type = 4
const Value_Type_not_set_case case_Value_Type = 0

Variables

var File_indykite_objects_v1beta2_value_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type Array

type Array struct {

	// Values in the array.
	Values []*Value `protobuf:"bytes,1,rep,name=values,proto3" json:"values,omitempty"`
	// contains filtered or unexported fields
}

An array value.

func (*Array) GetValues

func (x *Array) GetValues() []*Value

func (*Array) ProtoMessage

func (*Array) ProtoMessage()

func (*Array) ProtoReflect

func (x *Array) ProtoReflect() protoreflect.Message

func (*Array) Reset

func (x *Array) Reset()

func (*Array) SetValues

func (x *Array) SetValues(v []*Value)

func (*Array) String

func (x *Array) String() string

type Array_builder

type Array_builder struct {

	// Values in the array.
	Values []*Value
	// contains filtered or unexported fields
}

func (Array_builder) Build

func (b0 Array_builder) Build() *Array

type Map

type Map struct {

	// The map's keys and values.
	Fields map[string]*Value `` /* 139-byte string literal not displayed */
	// contains filtered or unexported fields
}

A map value.

func (*Map) GetFields

func (x *Map) GetFields() map[string]*Value

func (*Map) ProtoMessage

func (*Map) ProtoMessage()

func (*Map) ProtoReflect

func (x *Map) ProtoReflect() protoreflect.Message

func (*Map) Reset

func (x *Map) Reset()

func (*Map) SetFields

func (x *Map) SetFields(v map[string]*Value)

func (*Map) String

func (x *Map) String() string

type Map_builder

type Map_builder struct {

	// The map's keys and values.
	Fields map[string]*Value
	// contains filtered or unexported fields
}

func (Map_builder) Build

func (b0 Map_builder) Build() *Map

type Value

type Value struct {

	// Must have a value set.
	//
	// Types that are valid to be assigned to Type:
	//
	//	*Value_BoolValue
	//	*Value_IntegerValue
	//	*Value_DoubleValue
	//	*Value_TimeValue
	//	*Value_DurationValue
	//	*Value_StringValue
	//	*Value_BytesValue
	//	*Value_ArrayValue
	//	*Value_MapValue
	Type isValue_Type `protobuf_oneof:"type"`
	// contains filtered or unexported fields
}

A message that can hold any of the supported value types.

func (*Value) ClearArrayValue

func (x *Value) ClearArrayValue()

func (*Value) ClearBoolValue

func (x *Value) ClearBoolValue()

func (*Value) ClearBytesValue

func (x *Value) ClearBytesValue()

func (*Value) ClearDoubleValue

func (x *Value) ClearDoubleValue()

func (*Value) ClearDurationValue

func (x *Value) ClearDurationValue()

func (*Value) ClearIntegerValue

func (x *Value) ClearIntegerValue()

func (*Value) ClearMapValue

func (x *Value) ClearMapValue()

func (*Value) ClearStringValue

func (x *Value) ClearStringValue()

func (*Value) ClearTimeValue

func (x *Value) ClearTimeValue()

func (*Value) ClearType

func (x *Value) ClearType()

func (*Value) GetArrayValue

func (x *Value) GetArrayValue() *Array

func (*Value) GetBoolValue

func (x *Value) GetBoolValue() bool

func (*Value) GetBytesValue

func (x *Value) GetBytesValue() []byte

func (*Value) GetDoubleValue

func (x *Value) GetDoubleValue() float64

func (*Value) GetDurationValue

func (x *Value) GetDurationValue() *durationpb.Duration

func (*Value) GetIntegerValue

func (x *Value) GetIntegerValue() int64

func (*Value) GetMapValue

func (x *Value) GetMapValue() *Map

func (*Value) GetStringValue

func (x *Value) GetStringValue() string

func (*Value) GetTimeValue

func (x *Value) GetTimeValue() *timestamppb.Timestamp

func (*Value) GetType

func (x *Value) GetType() isValue_Type

func (*Value) HasArrayValue

func (x *Value) HasArrayValue() bool

func (*Value) HasBoolValue

func (x *Value) HasBoolValue() bool

func (*Value) HasBytesValue

func (x *Value) HasBytesValue() bool

func (*Value) HasDoubleValue

func (x *Value) HasDoubleValue() bool

func (*Value) HasDurationValue

func (x *Value) HasDurationValue() bool

func (*Value) HasIntegerValue

func (x *Value) HasIntegerValue() bool

func (*Value) HasMapValue

func (x *Value) HasMapValue() bool

func (*Value) HasStringValue

func (x *Value) HasStringValue() bool

func (*Value) HasTimeValue

func (x *Value) HasTimeValue() bool

func (*Value) HasType

func (x *Value) HasType() bool

func (*Value) ProtoMessage

func (*Value) ProtoMessage()

func (*Value) ProtoReflect

func (x *Value) ProtoReflect() protoreflect.Message

func (*Value) Reset

func (x *Value) Reset()

func (*Value) SetArrayValue

func (x *Value) SetArrayValue(v *Array)

func (*Value) SetBoolValue

func (x *Value) SetBoolValue(v bool)

func (*Value) SetBytesValue

func (x *Value) SetBytesValue(v []byte)

func (*Value) SetDoubleValue

func (x *Value) SetDoubleValue(v float64)

func (*Value) SetDurationValue

func (x *Value) SetDurationValue(v *durationpb.Duration)

func (*Value) SetIntegerValue

func (x *Value) SetIntegerValue(v int64)

func (*Value) SetMapValue

func (x *Value) SetMapValue(v *Map)

func (*Value) SetStringValue

func (x *Value) SetStringValue(v string)

func (*Value) SetTimeValue

func (x *Value) SetTimeValue(v *timestamppb.Timestamp)

func (*Value) String

func (x *Value) String() string

func (*Value) WhichType

func (x *Value) WhichType() case_Value_Type

type Value_ArrayValue

type Value_ArrayValue struct {
	// An array value.
	ArrayValue *Array `protobuf:"bytes,8,opt,name=array_value,json=arrayValue,proto3,oneof"`
}

type Value_BoolValue

type Value_BoolValue struct {
	// A boolean value.
	BoolValue bool `protobuf:"varint,1,opt,name=bool_value,json=boolValue,proto3,oneof"`
}

type Value_BytesValue

type Value_BytesValue struct {
	// A bytes value.
	BytesValue []byte `protobuf:"bytes,7,opt,name=bytes_value,json=bytesValue,proto3,oneof"`
}

type Value_DoubleValue

type Value_DoubleValue struct {
	// A double value.
	DoubleValue float64 `protobuf:"fixed64,3,opt,name=double_value,json=doubleValue,proto3,oneof"`
}

type Value_DurationValue

type Value_DurationValue struct {
	// A duration value.
	DurationValue *durationpb.Duration `protobuf:"bytes,5,opt,name=duration_value,json=durationValue,proto3,oneof"`
}

type Value_IntegerValue

type Value_IntegerValue struct {
	// An integer value.
	IntegerValue int64 `protobuf:"varint,2,opt,name=integer_value,json=integerValue,proto3,oneof"`
}

type Value_MapValue

type Value_MapValue struct {
	// A map value.
	MapValue *Map `protobuf:"bytes,9,opt,name=map_value,json=mapValue,proto3,oneof"`
}

type Value_StringValue

type Value_StringValue struct {
	// A string value.
	StringValue string `protobuf:"bytes,6,opt,name=string_value,json=stringValue,proto3,oneof"`
}

type Value_TimeValue

type Value_TimeValue struct {
	// A timestamp value.
	TimeValue *timestamppb.Timestamp `protobuf:"bytes,4,opt,name=time_value,json=timeValue,proto3,oneof"`
}

type Value_builder

type Value_builder struct {

	// Fields of oneof Type:
	// A boolean value.
	BoolValue *bool
	// An integer value.
	IntegerValue *int64
	// A double value.
	DoubleValue *float64
	// A timestamp value.
	TimeValue *timestamppb.Timestamp
	// A duration value.
	DurationValue *durationpb.Duration
	// A string value.
	StringValue *string
	// A bytes value.
	BytesValue []byte
	// An array value.
	ArrayValue *Array
	// A map value.
	MapValue *Map
	// contains filtered or unexported fields
}

func (Value_builder) Build

func (b0 Value_builder) Build() *Value

Source Files

  • value.pb.go

Jump to