tdav1beta1

package
v1.36.10-2025101713253... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 7 Imported by: 1

Documentation

Index

Constants

This section is empty.

Variables

var File_indykite_tda_v1beta1_model_proto protoreflect.FileDescriptor
var File_indykite_tda_v1beta1_trusted_data_access_api_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type Consent struct {

	// Unique identifier for the consent
	Id         string   `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	Properties []string `protobuf:"bytes,2,rep,name=properties,proto3" json:"properties,omitempty"`
	// contains filtered or unexported fields
}

func (*Consent) GetId

func (x *Consent) GetId() string

func (*Consent) GetProperties

func (x *Consent) GetProperties() []string

func (*Consent) ProtoMessage

func (*Consent) ProtoMessage()

func (*Consent) ProtoReflect

func (x *Consent) ProtoReflect() protoreflect.Message

func (*Consent) Reset

func (x *Consent) Reset()

func (*Consent) SetId

func (x *Consent) SetId(v string)

func (*Consent) SetProperties

func (x *Consent) SetProperties(v []string)

func (*Consent) String

func (x *Consent) String() string
type Consent_builder struct {

	// Unique identifier for the consent
	Id         string
	Properties []string
	// contains filtered or unexported fields
}
func (b0 Consent_builder) Build() *Consent

type DataAccessRequest

type DataAccessRequest struct {

	// Unique identifier for the consent
	ConsentId string `protobuf:"bytes,1,opt,name=consent_id,json=consentId,proto3" json:"consent_id,omitempty"`
	// ApplicationId is the id of the application that the consent is for.
	ApplicationId string `protobuf:"bytes,2,opt,name=application_id,json=applicationId,proto3" json:"application_id,omitempty"`
	// Optional, unique identifier for the user.
	User *v1beta1.User `protobuf:"bytes,3,opt,name=user,proto3" json:"user,omitempty"`
	// contains filtered or unexported fields
}

func (*DataAccessRequest) ClearUser

func (x *DataAccessRequest) ClearUser()

func (*DataAccessRequest) GetApplicationId

func (x *DataAccessRequest) GetApplicationId() string

func (*DataAccessRequest) GetConsentId

func (x *DataAccessRequest) GetConsentId() string

func (*DataAccessRequest) GetUser

func (x *DataAccessRequest) GetUser() *v1beta1.User

func (*DataAccessRequest) HasUser

func (x *DataAccessRequest) HasUser() bool

func (*DataAccessRequest) ProtoMessage

func (*DataAccessRequest) ProtoMessage()

func (*DataAccessRequest) ProtoReflect

func (x *DataAccessRequest) ProtoReflect() protoreflect.Message

func (*DataAccessRequest) Reset

func (x *DataAccessRequest) Reset()

func (*DataAccessRequest) SetApplicationId

func (x *DataAccessRequest) SetApplicationId(v string)

func (*DataAccessRequest) SetConsentId

func (x *DataAccessRequest) SetConsentId(v string)

func (*DataAccessRequest) SetUser

func (x *DataAccessRequest) SetUser(v *v1beta1.User)

func (*DataAccessRequest) String

func (x *DataAccessRequest) String() string

type DataAccessRequest_builder

type DataAccessRequest_builder struct {

	// Unique identifier for the consent
	ConsentId string
	// ApplicationId is the id of the application that the consent is for.
	ApplicationId string
	// Optional, unique identifier for the user.
	User *v1beta1.User
	// contains filtered or unexported fields
}

func (DataAccessRequest_builder) Build

type DataAccessResponse

type DataAccessResponse struct {
	Nodes []*TrustedDataNode `protobuf:"bytes,1,rep,name=nodes,proto3" json:"nodes,omitempty"`
	// contains filtered or unexported fields
}

func (*DataAccessResponse) GetNodes

func (x *DataAccessResponse) GetNodes() []*TrustedDataNode

func (*DataAccessResponse) ProtoMessage

func (*DataAccessResponse) ProtoMessage()

func (*DataAccessResponse) ProtoReflect

func (x *DataAccessResponse) ProtoReflect() protoreflect.Message

func (*DataAccessResponse) Reset

func (x *DataAccessResponse) Reset()

func (*DataAccessResponse) SetNodes

func (x *DataAccessResponse) SetNodes(v []*TrustedDataNode)

func (*DataAccessResponse) String

func (x *DataAccessResponse) String() string

type DataAccessResponse_builder

type DataAccessResponse_builder struct {
	Nodes []*TrustedDataNode
	// contains filtered or unexported fields
}

func (DataAccessResponse_builder) Build

type GrantConsentRequest

type GrantConsentRequest struct {

	// Unique identifier for the user
	User *v1beta1.User `protobuf:"bytes,1,opt,name=user,proto3" json:"user,omitempty"`
	// Unique identifier for the consent
	ConsentId string `protobuf:"bytes,2,opt,name=consent_id,json=consentId,proto3" json:"consent_id,omitempty"`
	// Optional: Specifies the duration in second that the consent remains valid, ranging from 1 day to 2 years.
	// Should be lower or equal to the consent's configuration.
	ValidityPeriod uint64 `protobuf:"varint,4,opt,name=validity_period,json=validityPeriod,proto3" json:"validity_period,omitempty"`
	// contains filtered or unexported fields
}

The request to grant consent

func (*GrantConsentRequest) ClearUser

func (x *GrantConsentRequest) ClearUser()

func (*GrantConsentRequest) GetConsentId

func (x *GrantConsentRequest) GetConsentId() string

func (*GrantConsentRequest) GetUser

func (x *GrantConsentRequest) GetUser() *v1beta1.User

func (*GrantConsentRequest) GetValidityPeriod

func (x *GrantConsentRequest) GetValidityPeriod() uint64

func (*GrantConsentRequest) HasUser

func (x *GrantConsentRequest) HasUser() bool

func (*GrantConsentRequest) ProtoMessage

func (*GrantConsentRequest) ProtoMessage()

func (*GrantConsentRequest) ProtoReflect

func (x *GrantConsentRequest) ProtoReflect() protoreflect.Message

func (*GrantConsentRequest) Reset

func (x *GrantConsentRequest) Reset()

func (*GrantConsentRequest) SetConsentId

func (x *GrantConsentRequest) SetConsentId(v string)

func (*GrantConsentRequest) SetUser

func (x *GrantConsentRequest) SetUser(v *v1beta1.User)

func (*GrantConsentRequest) SetValidityPeriod

func (x *GrantConsentRequest) SetValidityPeriod(v uint64)

func (*GrantConsentRequest) String

func (x *GrantConsentRequest) String() string

type GrantConsentRequest_builder

type GrantConsentRequest_builder struct {

	// Unique identifier for the user
	User *v1beta1.User
	// Unique identifier for the consent
	ConsentId string
	// Optional: Specifies the duration in second that the consent remains valid, ranging from 1 day to 2 years.
	// Should be lower or equal to the consent's configuration.
	ValidityPeriod uint64
	// contains filtered or unexported fields
}

func (GrantConsentRequest_builder) Build

type GrantConsentResponse

type GrantConsentResponse struct {
	PropertiesGrantedCount uint64 `` /* 130-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*GrantConsentResponse) GetPropertiesGrantedCount

func (x *GrantConsentResponse) GetPropertiesGrantedCount() uint64

func (*GrantConsentResponse) ProtoMessage

func (*GrantConsentResponse) ProtoMessage()

func (*GrantConsentResponse) ProtoReflect

func (x *GrantConsentResponse) ProtoReflect() protoreflect.Message

func (*GrantConsentResponse) Reset

func (x *GrantConsentResponse) Reset()

func (*GrantConsentResponse) SetPropertiesGrantedCount

func (x *GrantConsentResponse) SetPropertiesGrantedCount(v uint64)

func (*GrantConsentResponse) String

func (x *GrantConsentResponse) String() string

type GrantConsentResponse_builder

type GrantConsentResponse_builder struct {
	PropertiesGrantedCount uint64
	// contains filtered or unexported fields
}

func (GrantConsentResponse_builder) Build

type ListConsentsRequest

type ListConsentsRequest struct {

	// Unique identifier for the user.
	User *v1beta1.User `protobuf:"bytes,1,opt,name=user,proto3" json:"user,omitempty"`
	// ApplicationId is the id of the application that the consent is for.
	ApplicationId string `protobuf:"bytes,2,opt,name=application_id,json=applicationId,proto3" json:"application_id,omitempty"`
	// contains filtered or unexported fields
}

func (*ListConsentsRequest) ClearUser

func (x *ListConsentsRequest) ClearUser()

func (*ListConsentsRequest) GetApplicationId

func (x *ListConsentsRequest) GetApplicationId() string

func (*ListConsentsRequest) GetUser

func (x *ListConsentsRequest) GetUser() *v1beta1.User

func (*ListConsentsRequest) HasUser

func (x *ListConsentsRequest) HasUser() bool

func (*ListConsentsRequest) ProtoMessage

func (*ListConsentsRequest) ProtoMessage()

func (*ListConsentsRequest) ProtoReflect

func (x *ListConsentsRequest) ProtoReflect() protoreflect.Message

func (*ListConsentsRequest) Reset

func (x *ListConsentsRequest) Reset()

func (*ListConsentsRequest) SetApplicationId

func (x *ListConsentsRequest) SetApplicationId(v string)

func (*ListConsentsRequest) SetUser

func (x *ListConsentsRequest) SetUser(v *v1beta1.User)

func (*ListConsentsRequest) String

func (x *ListConsentsRequest) String() string

type ListConsentsRequest_builder

type ListConsentsRequest_builder struct {

	// Unique identifier for the user.
	User *v1beta1.User
	// ApplicationId is the id of the application that the consent is for.
	ApplicationId string
	// contains filtered or unexported fields
}

func (ListConsentsRequest_builder) Build

type ListConsentsResponse

type ListConsentsResponse struct {
	Consents []*Consent `protobuf:"bytes,1,rep,name=consents,proto3" json:"consents,omitempty"`
	// contains filtered or unexported fields
}

func (*ListConsentsResponse) GetConsents

func (x *ListConsentsResponse) GetConsents() []*Consent

func (*ListConsentsResponse) ProtoMessage

func (*ListConsentsResponse) ProtoMessage()

func (*ListConsentsResponse) ProtoReflect

func (x *ListConsentsResponse) ProtoReflect() protoreflect.Message

func (*ListConsentsResponse) Reset

func (x *ListConsentsResponse) Reset()

func (*ListConsentsResponse) SetConsents

func (x *ListConsentsResponse) SetConsents(v []*Consent)

func (*ListConsentsResponse) String

func (x *ListConsentsResponse) String() string

type ListConsentsResponse_builder

type ListConsentsResponse_builder struct {
	Consents []*Consent
	// contains filtered or unexported fields
}

func (ListConsentsResponse_builder) Build

type RevokeConsentRequest

type RevokeConsentRequest struct {

	// Unique identifier for the user
	User *v1beta1.User `protobuf:"bytes,1,opt,name=user,proto3" json:"user,omitempty"`
	// Unique identifier for the consent
	ConsentId string `protobuf:"bytes,2,opt,name=consent_id,json=consentId,proto3" json:"consent_id,omitempty"`
	// contains filtered or unexported fields
}

func (*RevokeConsentRequest) ClearUser

func (x *RevokeConsentRequest) ClearUser()

func (*RevokeConsentRequest) GetConsentId

func (x *RevokeConsentRequest) GetConsentId() string

func (*RevokeConsentRequest) GetUser

func (x *RevokeConsentRequest) GetUser() *v1beta1.User

func (*RevokeConsentRequest) HasUser

func (x *RevokeConsentRequest) HasUser() bool

func (*RevokeConsentRequest) ProtoMessage

func (*RevokeConsentRequest) ProtoMessage()

func (*RevokeConsentRequest) ProtoReflect

func (x *RevokeConsentRequest) ProtoReflect() protoreflect.Message

func (*RevokeConsentRequest) Reset

func (x *RevokeConsentRequest) Reset()

func (*RevokeConsentRequest) SetConsentId

func (x *RevokeConsentRequest) SetConsentId(v string)

func (*RevokeConsentRequest) SetUser

func (x *RevokeConsentRequest) SetUser(v *v1beta1.User)

func (*RevokeConsentRequest) String

func (x *RevokeConsentRequest) String() string

type RevokeConsentRequest_builder

type RevokeConsentRequest_builder struct {

	// Unique identifier for the user
	User *v1beta1.User
	// Unique identifier for the consent
	ConsentId string
	// contains filtered or unexported fields
}

func (RevokeConsentRequest_builder) Build

type RevokeConsentResponse

type RevokeConsentResponse struct {
	// contains filtered or unexported fields
}

func (*RevokeConsentResponse) ProtoMessage

func (*RevokeConsentResponse) ProtoMessage()

func (*RevokeConsentResponse) ProtoReflect

func (x *RevokeConsentResponse) ProtoReflect() protoreflect.Message

func (*RevokeConsentResponse) Reset

func (x *RevokeConsentResponse) Reset()

func (*RevokeConsentResponse) String

func (x *RevokeConsentResponse) String() string

type RevokeConsentResponse_builder

type RevokeConsentResponse_builder struct {
	// contains filtered or unexported fields
}

func (RevokeConsentResponse_builder) Build

type TrustedDataNode

type TrustedDataNode struct {
	Id         string                 `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"` // read-only
	ExternalId string                 `protobuf:"bytes,2,opt,name=external_id,json=externalId,proto3" json:"external_id,omitempty"`
	Type       string                 `protobuf:"bytes,3,opt,name=type,proto3" json:"type,omitempty"`
	Tags       []string               `protobuf:"bytes,4,rep,name=tags,proto3" json:"tags,omitempty"`
	CreateTime *timestamppb.Timestamp `protobuf:"bytes,5,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"` // read-only
	UpdateTime *timestamppb.Timestamp `protobuf:"bytes,6,opt,name=update_time,json=updateTime,proto3" json:"update_time,omitempty"` // read-only
	Properties []*v1beta1.Property    `protobuf:"bytes,7,rep,name=properties,proto3" json:"properties,omitempty"`
	IsIdentity bool                   `protobuf:"varint,8,opt,name=is_identity,json=isIdentity,proto3" json:"is_identity,omitempty"`
	Nodes      []*TrustedDataNode     `protobuf:"bytes,9,rep,name=nodes,proto3" json:"nodes,omitempty"`
	// contains filtered or unexported fields
}

TrustedDataNode represents a node and contains nodes with properties what are trusted by the root node.

func (*TrustedDataNode) ClearCreateTime

func (x *TrustedDataNode) ClearCreateTime()

func (*TrustedDataNode) ClearUpdateTime

func (x *TrustedDataNode) ClearUpdateTime()

func (*TrustedDataNode) GetCreateTime

func (x *TrustedDataNode) GetCreateTime() *timestamppb.Timestamp

func (*TrustedDataNode) GetExternalId

func (x *TrustedDataNode) GetExternalId() string

func (*TrustedDataNode) GetId

func (x *TrustedDataNode) GetId() string

func (*TrustedDataNode) GetIsIdentity

func (x *TrustedDataNode) GetIsIdentity() bool

func (*TrustedDataNode) GetNodes

func (x *TrustedDataNode) GetNodes() []*TrustedDataNode

func (*TrustedDataNode) GetProperties

func (x *TrustedDataNode) GetProperties() []*v1beta1.Property

func (*TrustedDataNode) GetTags

func (x *TrustedDataNode) GetTags() []string

func (*TrustedDataNode) GetType

func (x *TrustedDataNode) GetType() string

func (*TrustedDataNode) GetUpdateTime

func (x *TrustedDataNode) GetUpdateTime() *timestamppb.Timestamp

func (*TrustedDataNode) HasCreateTime

func (x *TrustedDataNode) HasCreateTime() bool

func (*TrustedDataNode) HasUpdateTime

func (x *TrustedDataNode) HasUpdateTime() bool

func (*TrustedDataNode) ProtoMessage

func (*TrustedDataNode) ProtoMessage()

func (*TrustedDataNode) ProtoReflect

func (x *TrustedDataNode) ProtoReflect() protoreflect.Message

func (*TrustedDataNode) Reset

func (x *TrustedDataNode) Reset()

func (*TrustedDataNode) SetCreateTime

func (x *TrustedDataNode) SetCreateTime(v *timestamppb.Timestamp)

func (*TrustedDataNode) SetExternalId

func (x *TrustedDataNode) SetExternalId(v string)

func (*TrustedDataNode) SetId

func (x *TrustedDataNode) SetId(v string)

func (*TrustedDataNode) SetIsIdentity

func (x *TrustedDataNode) SetIsIdentity(v bool)

func (*TrustedDataNode) SetNodes

func (x *TrustedDataNode) SetNodes(v []*TrustedDataNode)

func (*TrustedDataNode) SetProperties

func (x *TrustedDataNode) SetProperties(v []*v1beta1.Property)

func (*TrustedDataNode) SetTags

func (x *TrustedDataNode) SetTags(v []string)

func (*TrustedDataNode) SetType

func (x *TrustedDataNode) SetType(v string)

func (*TrustedDataNode) SetUpdateTime

func (x *TrustedDataNode) SetUpdateTime(v *timestamppb.Timestamp)

func (*TrustedDataNode) String

func (x *TrustedDataNode) String() string

type TrustedDataNode_builder

type TrustedDataNode_builder struct {
	Id         string
	ExternalId string
	Type       string
	Tags       []string
	CreateTime *timestamppb.Timestamp
	UpdateTime *timestamppb.Timestamp
	Properties []*v1beta1.Property
	IsIdentity bool
	Nodes      []*TrustedDataNode
	// contains filtered or unexported fields
}

func (TrustedDataNode_builder) Build

Source Files

  • model.pb.go
  • trusted_data_access_api.pb.go

Jump to