Documentation
¶
Index ¶
- Constants
- func NewJapellaDashboardApiServiceHandler(svc JapellaDashboardApiServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
- type JapellaDashboardApiServiceClient
- type JapellaDashboardApiServiceHandler
- type UnimplementedJapellaDashboardApiServiceHandler
- func (UnimplementedJapellaDashboardApiServiceHandler) GetStatus(context.Context, *connect.Request[v1.GetStatusRequest]) (*connect.Response[v1.GetStatusResponse], error)
- func (UnimplementedJapellaDashboardApiServiceHandler) SendMessage(context.Context, *connect.Request[v1.SendMessageRequest]) (*connect.Response[v1.SendMessageResponse], error)
Constants ¶
const ( // JapellaDashboardApiServiceGetStatusProcedure is the fully-qualified name of the // JapellaDashboardApiService's GetStatus RPC. JapellaDashboardApiServiceGetStatusProcedure = "/japella.controlapi.v1.JapellaDashboardApiService/GetStatus" // JapellaDashboardApiServiceSendMessageProcedure is the fully-qualified name of the // JapellaDashboardApiService's SendMessage RPC. JapellaDashboardApiServiceSendMessageProcedure = "/japella.controlapi.v1.JapellaDashboardApiService/SendMessage" )
These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.
Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.
const ( // JapellaDashboardApiServiceName is the fully-qualified name of the JapellaDashboardApiService // service. JapellaDashboardApiServiceName = "japella.controlapi.v1.JapellaDashboardApiService" )
Variables ¶
This section is empty.
Functions ¶
func NewJapellaDashboardApiServiceHandler ¶
func NewJapellaDashboardApiServiceHandler(svc JapellaDashboardApiServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
NewJapellaDashboardApiServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.
By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.
Types ¶
type JapellaDashboardApiServiceClient ¶
type JapellaDashboardApiServiceClient interface {
GetStatus(context.Context, *connect.Request[v1.GetStatusRequest]) (*connect.Response[v1.GetStatusResponse], error)
SendMessage(context.Context, *connect.Request[v1.SendMessageRequest]) (*connect.Response[v1.SendMessageResponse], error)
}
JapellaDashboardApiServiceClient is a client for the japella.controlapi.v1.JapellaDashboardApiService service.
func NewJapellaDashboardApiServiceClient ¶
func NewJapellaDashboardApiServiceClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) JapellaDashboardApiServiceClient
NewJapellaDashboardApiServiceClient constructs a client for the japella.controlapi.v1.JapellaDashboardApiService service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.
The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).
type JapellaDashboardApiServiceHandler ¶
type JapellaDashboardApiServiceHandler interface {
GetStatus(context.Context, *connect.Request[v1.GetStatusRequest]) (*connect.Response[v1.GetStatusResponse], error)
SendMessage(context.Context, *connect.Request[v1.SendMessageRequest]) (*connect.Response[v1.SendMessageResponse], error)
}
JapellaDashboardApiServiceHandler is an implementation of the japella.controlapi.v1.JapellaDashboardApiService service.
type UnimplementedJapellaDashboardApiServiceHandler ¶
type UnimplementedJapellaDashboardApiServiceHandler struct{}
UnimplementedJapellaDashboardApiServiceHandler returns CodeUnimplemented from all methods.
func (UnimplementedJapellaDashboardApiServiceHandler) GetStatus ¶
func (UnimplementedJapellaDashboardApiServiceHandler) GetStatus(context.Context, *connect.Request[v1.GetStatusRequest]) (*connect.Response[v1.GetStatusResponse], error)
func (UnimplementedJapellaDashboardApiServiceHandler) SendMessage ¶
func (UnimplementedJapellaDashboardApiServiceHandler) SendMessage(context.Context, *connect.Request[v1.SendMessageRequest]) (*connect.Response[v1.SendMessageResponse], error)
Source Files
¶
- control.connect.go