Documentation
¶
Index ¶
- Constants
- func NewGameServiceHandler(svc GameServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
- type GameServiceClient
- type GameServiceHandler
- type UnimplementedGameServiceHandler
- func (UnimplementedGameServiceHandler) GameStatusStream(context.Context, *connect.Request[rpc.GameStatusRequest]) (*connect.Response[rpc.GameStatusResponse], error)
- func (UnimplementedGameServiceHandler) PhysicsStream(context.Context, *connect.Request[rpc.PhysicsRequest]) (*connect.Response[rpc.PhysicsResponse], error)
Constants ¶
const ( // GameServiceGameStatusStreamProcedure is the fully-qualified name of the GameService's // GameStatusStream RPC. GameServiceGameStatusStreamProcedure = "/game.GameService/GameStatusStream" // GameServicePhysicsStreamProcedure is the fully-qualified name of the GameService's PhysicsStream // RPC. GameServicePhysicsStreamProcedure = "/game.GameService/PhysicsStream" )
These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.
Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.
const (
// GameServiceName is the fully-qualified name of the GameService service.
GameServiceName = "game.GameService"
)
Variables ¶
This section is empty.
Functions ¶
func NewGameServiceHandler ¶
func NewGameServiceHandler(svc GameServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
NewGameServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.
By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.
Types ¶
type GameServiceClient ¶
type GameServiceClient interface {
GameStatusStream(context.Context, *connect.Request[rpc.GameStatusRequest]) (*connect.Response[rpc.GameStatusResponse], error)
PhysicsStream(context.Context, *connect.Request[rpc.PhysicsRequest]) (*connect.Response[rpc.PhysicsResponse], error)
}
GameServiceClient is a client for the game.GameService service.
func NewGameServiceClient ¶
func NewGameServiceClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) GameServiceClient
NewGameServiceClient constructs a client for the game.GameService service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.
The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).
type GameServiceHandler ¶
type GameServiceHandler interface {
GameStatusStream(context.Context, *connect.Request[rpc.GameStatusRequest]) (*connect.Response[rpc.GameStatusResponse], error)
PhysicsStream(context.Context, *connect.Request[rpc.PhysicsRequest]) (*connect.Response[rpc.PhysicsResponse], error)
}
GameServiceHandler is an implementation of the game.GameService service.
type UnimplementedGameServiceHandler ¶
type UnimplementedGameServiceHandler struct{}
UnimplementedGameServiceHandler returns CodeUnimplemented from all methods.
func (UnimplementedGameServiceHandler) GameStatusStream ¶
func (UnimplementedGameServiceHandler) GameStatusStream(context.Context, *connect.Request[rpc.GameStatusRequest]) (*connect.Response[rpc.GameStatusResponse], error)
func (UnimplementedGameServiceHandler) PhysicsStream ¶
func (UnimplementedGameServiceHandler) PhysicsStream(context.Context, *connect.Request[rpc.PhysicsRequest]) (*connect.Response[rpc.PhysicsResponse], error)
Source Files
¶
- game.connect.go