gamegrpc

package
v1.6.2-20241108200911-... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: BSD-3-Clause Imports: 5 Imported by: 1

Documentation

Index

Constants

const (
	GameService_GameStatusStream_FullMethodName = "/game.GameService/GameStatusStream"
	GameService_PhysicsStream_FullMethodName    = "/game.GameService/PhysicsStream"
)

Variables

var GameService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "game.GameService",
	HandlerType: (*GameServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GameStatusStream",
			Handler:    _GameService_GameStatusStream_Handler,
		},
		{
			MethodName: "PhysicsStream",
			Handler:    _GameService_PhysicsStream_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "game/game.proto",
}

GameService_ServiceDesc is the grpc.ServiceDesc for GameService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterGameServiceServer

func RegisterGameServiceServer(s grpc.ServiceRegistrar, srv GameServiceServer)

Types

type GameServiceClient

type GameServiceClient interface {
	GameStatusStream(ctx context.Context, in *rpc.GameStatusRequest, opts ...grpc.CallOption) (*rpc.GameStatusResponse, error)
	PhysicsStream(ctx context.Context, in *rpc.PhysicsRequest, opts ...grpc.CallOption) (*rpc.PhysicsResponse, error)
}

GameServiceClient is the client API for GameService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewGameServiceClient

func NewGameServiceClient(cc grpc.ClientConnInterface) GameServiceClient

type GameServiceServer

type GameServiceServer interface {
	GameStatusStream(context.Context, *rpc.GameStatusRequest) (*rpc.GameStatusResponse, error)
	PhysicsStream(context.Context, *rpc.PhysicsRequest) (*rpc.PhysicsResponse, error)
}

GameServiceServer is the server API for GameService service. All implementations should embed UnimplementedGameServiceServer for forward compatibility.

type UnimplementedGameServiceServer

type UnimplementedGameServiceServer struct{}

UnimplementedGameServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedGameServiceServer) GameStatusStream

func (UnimplementedGameServiceServer) PhysicsStream

type UnsafeGameServiceServer

type UnsafeGameServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeGameServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to GameServiceServer will result in compilation errors.

Source Files

  • game_grpc.pb.go

Jump to