libraryv1connect

package
v1.19.1-20251202034006... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	// ServiceNewVolumeProcedure is the fully-qualified name of the Service's NewVolume RPC.
	ServiceNewVolumeProcedure = "/krelinga.video.library.v1.Service/NewVolume"
	// ServiceFindVolumesProcedure is the fully-qualified name of the Service's FindVolumes RPC.
	ServiceFindVolumesProcedure = "/krelinga.video.library.v1.Service/FindVolumes"
	// ServiceDiscoverNewDiscsProcedure is the fully-qualified name of the Service's DiscoverNewDiscs
	// RPC.
	ServiceDiscoverNewDiscsProcedure = "/krelinga.video.library.v1.Service/DiscoverNewDiscs"
	// ServiceFindDiscsProcedure is the fully-qualified name of the Service's FindDiscs RPC.
	ServiceFindDiscsProcedure = "/krelinga.video.library.v1.Service/FindDiscs"
)

These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.

Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.

const (
	// ServiceName is the fully-qualified name of the Service service.
	ServiceName = "krelinga.video.library.v1.Service"
)

Variables

This section is empty.

Functions

func NewServiceHandler

func NewServiceHandler(svc ServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)

NewServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.

By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.

Types

type ServiceClient

type ServiceClient interface {
	// Create a new volume.
	NewVolume(context.Context, *connect.Request[v1.NewVolumeRequest]) (*connect.Response[v1.NewVolumeResponse], error)
	// Find existing volumes.
	FindVolumes(context.Context, *connect.Request[v1.FindVolumesRequest]) (*connect.Response[v1.FindVolumesResponse], error)
	// Scan a volume directory to discover new discs.
	DiscoverNewDiscs(context.Context, *connect.Request[v1.DiscoverNewDiscsRequest]) (*connect.Response[v1.DiscoverNewDiscsResponse], error)
	// Find existing discs.
	FindDiscs(context.Context, *connect.Request[v1.FindDiscsRequest]) (*connect.Response[v1.FindDiscsResponse], error)
}

ServiceClient is a client for the krelinga.video.library.v1.Service service.

func NewServiceClient

func NewServiceClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) ServiceClient

NewServiceClient constructs a client for the krelinga.video.library.v1.Service service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.

The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).

type ServiceHandler

type ServiceHandler interface {
	// Create a new volume.
	NewVolume(context.Context, *connect.Request[v1.NewVolumeRequest]) (*connect.Response[v1.NewVolumeResponse], error)
	// Find existing volumes.
	FindVolumes(context.Context, *connect.Request[v1.FindVolumesRequest]) (*connect.Response[v1.FindVolumesResponse], error)
	// Scan a volume directory to discover new discs.
	DiscoverNewDiscs(context.Context, *connect.Request[v1.DiscoverNewDiscsRequest]) (*connect.Response[v1.DiscoverNewDiscsResponse], error)
	// Find existing discs.
	FindDiscs(context.Context, *connect.Request[v1.FindDiscsRequest]) (*connect.Response[v1.FindDiscsResponse], error)
}

ServiceHandler is an implementation of the krelinga.video.library.v1.Service service.

type UnimplementedServiceHandler

type UnimplementedServiceHandler struct{}

UnimplementedServiceHandler returns CodeUnimplemented from all methods.

func (UnimplementedServiceHandler) DiscoverNewDiscs

func (UnimplementedServiceHandler) FindDiscs

func (UnimplementedServiceHandler) FindVolumes

func (UnimplementedServiceHandler) NewVolume

Source Files

  • service.connect.go

Jump to