mkv_util_serverv1connect

package
v1.19.1-20251202034006... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: MIT Imports: 6 Imported by: 1

Documentation

Index

Constants

const (
	// MkvUtilServiceGetFileSizeProcedure is the fully-qualified name of the MkvUtilService's
	// GetFileSize RPC.
	MkvUtilServiceGetFileSizeProcedure = "/krelinga.video.mkv_util_server.v1.MkvUtilService/GetFileSize"
	// MkvUtilServiceRunMkvToolNixCommandProcedure is the fully-qualified name of the MkvUtilService's
	// RunMkvToolNixCommand RPC.
	MkvUtilServiceRunMkvToolNixCommandProcedure = "/krelinga.video.mkv_util_server.v1.MkvUtilService/RunMkvToolNixCommand"
	// MkvUtilServiceConcatProcedure is the fully-qualified name of the MkvUtilService's Concat RPC.
	MkvUtilServiceConcatProcedure = "/krelinga.video.mkv_util_server.v1.MkvUtilService/Concat"
	// MkvUtilServiceGetChaptersProcedure is the fully-qualified name of the MkvUtilService's
	// GetChapters RPC.
	MkvUtilServiceGetChaptersProcedure = "/krelinga.video.mkv_util_server.v1.MkvUtilService/GetChapters"
	// MkvUtilServiceGetInfoProcedure is the fully-qualified name of the MkvUtilService's GetInfo RPC.
	MkvUtilServiceGetInfoProcedure = "/krelinga.video.mkv_util_server.v1.MkvUtilService/GetInfo"
	// MkvUtilServiceSplitProcedure is the fully-qualified name of the MkvUtilService's Split RPC.
	MkvUtilServiceSplitProcedure = "/krelinga.video.mkv_util_server.v1.MkvUtilService/Split"
)

These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.

Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.

const (
	// MkvUtilServiceName is the fully-qualified name of the MkvUtilService service.
	MkvUtilServiceName = "krelinga.video.mkv_util_server.v1.MkvUtilService"
)

Variables

This section is empty.

Functions

func NewMkvUtilServiceHandler

func NewMkvUtilServiceHandler(svc MkvUtilServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)

NewMkvUtilServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.

By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.

Types

type MkvUtilServiceClient

MkvUtilServiceClient is a client for the krelinga.video.mkv_util_server.v1.MkvUtilService service.

func NewMkvUtilServiceClient

func NewMkvUtilServiceClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) MkvUtilServiceClient

NewMkvUtilServiceClient constructs a client for the krelinga.video.mkv_util_server.v1.MkvUtilService service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.

The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).

type MkvUtilServiceHandler

MkvUtilServiceHandler is an implementation of the krelinga.video.mkv_util_server.v1.MkvUtilService service.

type UnimplementedMkvUtilServiceHandler

type UnimplementedMkvUtilServiceHandler struct{}

UnimplementedMkvUtilServiceHandler returns CodeUnimplemented from all methods.

func (UnimplementedMkvUtilServiceHandler) Concat

func (UnimplementedMkvUtilServiceHandler) GetChapters

func (UnimplementedMkvUtilServiceHandler) GetFileSize

func (UnimplementedMkvUtilServiceHandler) GetInfo

func (UnimplementedMkvUtilServiceHandler) RunMkvToolNixCommand

func (UnimplementedMkvUtilServiceHandler) Split

Source Files

  • mkv_util_server.connect.go

Jump to