tccoordv1connect

package
v1.19.1-20251202034006... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: MIT Imports: 6 Imported by: 1

Documentation

Index

Constants

const (
	// TCCoordServiceEnqueueDirProcedure is the fully-qualified name of the TCCoordService's EnqueueDir
	// RPC.
	TCCoordServiceEnqueueDirProcedure = "/krelinga.video.tccoord.v1.TCCoordService/EnqueueDir"
	// TCCoordServiceGetQueueProcedure is the fully-qualified name of the TCCoordService's GetQueue RPC.
	TCCoordServiceGetQueueProcedure = "/krelinga.video.tccoord.v1.TCCoordService/GetQueue"
)

These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.

Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.

const (
	// TCCoordServiceName is the fully-qualified name of the TCCoordService service.
	TCCoordServiceName = "krelinga.video.tccoord.v1.TCCoordService"
)

Variables

This section is empty.

Functions

func NewTCCoordServiceHandler

func NewTCCoordServiceHandler(svc TCCoordServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)

NewTCCoordServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.

By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.

Types

type TCCoordServiceClient

TCCoordServiceClient is a client for the krelinga.video.tccoord.v1.TCCoordService service.

func NewTCCoordServiceClient

func NewTCCoordServiceClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) TCCoordServiceClient

NewTCCoordServiceClient constructs a client for the krelinga.video.tccoord.v1.TCCoordService service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.

The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).

type TCCoordServiceHandler

TCCoordServiceHandler is an implementation of the krelinga.video.tccoord.v1.TCCoordService service.

type UnimplementedTCCoordServiceHandler

type UnimplementedTCCoordServiceHandler struct{}

UnimplementedTCCoordServiceHandler returns CodeUnimplemented from all methods.

func (UnimplementedTCCoordServiceHandler) EnqueueDir

func (UnimplementedTCCoordServiceHandler) GetQueue

Source Files

  • tccoord.connect.go

Jump to