Documentation
¶
Index ¶
- Constants
- func NewTCServiceHandler(svc TCServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
- type TCServiceClient
- type TCServiceHandler
- type UnimplementedTCServiceHandler
- func (UnimplementedTCServiceHandler) CheckAsyncShowTranscode(context.Context, *connect.Request[v1.CheckAsyncShowTranscodeRequest]) (*connect.Response[v1.CheckAsyncShowTranscodeResponse], error)
- func (UnimplementedTCServiceHandler) CheckAsyncSpreadTranscode(context.Context, *connect.Request[v1.CheckAsyncSpreadTranscodeRequest]) (*connect.Response[v1.CheckAsyncSpreadTranscodeResponse], error)
- func (UnimplementedTCServiceHandler) CheckAsyncTranscode(context.Context, *connect.Request[v1.CheckAsyncTranscodeRequest]) (*connect.Response[v1.CheckAsyncTranscodeResponse], error)
- func (UnimplementedTCServiceHandler) ListAsyncTranscodes(context.Context, *connect.Request[v1.ListAsyncTranscodesRequest]) (*connect.Response[v1.ListAsyncTranscodesResponse], error)
- func (UnimplementedTCServiceHandler) StartAsyncShowTranscode(context.Context, *connect.Request[v1.StartAsyncShowTranscodeRequest]) (*connect.Response[v1.StartAsyncShowTranscodeResponse], error)
- func (UnimplementedTCServiceHandler) StartAsyncSpreadTranscode(context.Context, *connect.Request[v1.StartAsyncSpreadTranscodeRequest]) (*connect.Response[v1.StartAsyncSpreadTranscodeResponse], error)
- func (UnimplementedTCServiceHandler) StartAsyncTranscode(context.Context, *connect.Request[v1.StartAsyncTranscodeRequest]) (*connect.Response[v1.StartAsyncTranscodeResponse], error)
Constants ¶
const ( // TCServiceStartAsyncTranscodeProcedure is the fully-qualified name of the TCService's // StartAsyncTranscode RPC. TCServiceStartAsyncTranscodeProcedure = "/krelinga.video.tcserver.v1.TCService/StartAsyncTranscode" // TCServiceCheckAsyncTranscodeProcedure is the fully-qualified name of the TCService's // CheckAsyncTranscode RPC. TCServiceCheckAsyncTranscodeProcedure = "/krelinga.video.tcserver.v1.TCService/CheckAsyncTranscode" // TCServiceStartAsyncShowTranscodeProcedure is the fully-qualified name of the TCService's // StartAsyncShowTranscode RPC. TCServiceStartAsyncShowTranscodeProcedure = "/krelinga.video.tcserver.v1.TCService/StartAsyncShowTranscode" // TCServiceCheckAsyncShowTranscodeProcedure is the fully-qualified name of the TCService's // CheckAsyncShowTranscode RPC. TCServiceCheckAsyncShowTranscodeProcedure = "/krelinga.video.tcserver.v1.TCService/CheckAsyncShowTranscode" // TCServiceStartAsyncSpreadTranscodeProcedure is the fully-qualified name of the TCService's // StartAsyncSpreadTranscode RPC. TCServiceStartAsyncSpreadTranscodeProcedure = "/krelinga.video.tcserver.v1.TCService/StartAsyncSpreadTranscode" // TCServiceCheckAsyncSpreadTranscodeProcedure is the fully-qualified name of the TCService's // CheckAsyncSpreadTranscode RPC. TCServiceCheckAsyncSpreadTranscodeProcedure = "/krelinga.video.tcserver.v1.TCService/CheckAsyncSpreadTranscode" // TCServiceListAsyncTranscodesProcedure is the fully-qualified name of the TCService's // ListAsyncTranscodes RPC. TCServiceListAsyncTranscodesProcedure = "/krelinga.video.tcserver.v1.TCService/ListAsyncTranscodes" )
These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.
Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.
const (
// TCServiceName is the fully-qualified name of the TCService service.
TCServiceName = "krelinga.video.tcserver.v1.TCService"
)
Variables ¶
This section is empty.
Functions ¶
func NewTCServiceHandler ¶
func NewTCServiceHandler(svc TCServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
NewTCServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.
By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.
Types ¶
type TCServiceClient ¶
type TCServiceClient interface {
StartAsyncTranscode(context.Context, *connect.Request[v1.StartAsyncTranscodeRequest]) (*connect.Response[v1.StartAsyncTranscodeResponse], error)
CheckAsyncTranscode(context.Context, *connect.Request[v1.CheckAsyncTranscodeRequest]) (*connect.Response[v1.CheckAsyncTranscodeResponse], error)
StartAsyncShowTranscode(context.Context, *connect.Request[v1.StartAsyncShowTranscodeRequest]) (*connect.Response[v1.StartAsyncShowTranscodeResponse], error)
CheckAsyncShowTranscode(context.Context, *connect.Request[v1.CheckAsyncShowTranscodeRequest]) (*connect.Response[v1.CheckAsyncShowTranscodeResponse], error)
StartAsyncSpreadTranscode(context.Context, *connect.Request[v1.StartAsyncSpreadTranscodeRequest]) (*connect.Response[v1.StartAsyncSpreadTranscodeResponse], error)
CheckAsyncSpreadTranscode(context.Context, *connect.Request[v1.CheckAsyncSpreadTranscodeRequest]) (*connect.Response[v1.CheckAsyncSpreadTranscodeResponse], error)
ListAsyncTranscodes(context.Context, *connect.Request[v1.ListAsyncTranscodesRequest]) (*connect.Response[v1.ListAsyncTranscodesResponse], error)
}
TCServiceClient is a client for the krelinga.video.tcserver.v1.TCService service.
func NewTCServiceClient ¶
func NewTCServiceClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) TCServiceClient
NewTCServiceClient constructs a client for the krelinga.video.tcserver.v1.TCService service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.
The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).
type TCServiceHandler ¶
type TCServiceHandler interface {
StartAsyncTranscode(context.Context, *connect.Request[v1.StartAsyncTranscodeRequest]) (*connect.Response[v1.StartAsyncTranscodeResponse], error)
CheckAsyncTranscode(context.Context, *connect.Request[v1.CheckAsyncTranscodeRequest]) (*connect.Response[v1.CheckAsyncTranscodeResponse], error)
StartAsyncShowTranscode(context.Context, *connect.Request[v1.StartAsyncShowTranscodeRequest]) (*connect.Response[v1.StartAsyncShowTranscodeResponse], error)
CheckAsyncShowTranscode(context.Context, *connect.Request[v1.CheckAsyncShowTranscodeRequest]) (*connect.Response[v1.CheckAsyncShowTranscodeResponse], error)
StartAsyncSpreadTranscode(context.Context, *connect.Request[v1.StartAsyncSpreadTranscodeRequest]) (*connect.Response[v1.StartAsyncSpreadTranscodeResponse], error)
CheckAsyncSpreadTranscode(context.Context, *connect.Request[v1.CheckAsyncSpreadTranscodeRequest]) (*connect.Response[v1.CheckAsyncSpreadTranscodeResponse], error)
ListAsyncTranscodes(context.Context, *connect.Request[v1.ListAsyncTranscodesRequest]) (*connect.Response[v1.ListAsyncTranscodesResponse], error)
}
TCServiceHandler is an implementation of the krelinga.video.tcserver.v1.TCService service.
type UnimplementedTCServiceHandler ¶
type UnimplementedTCServiceHandler struct{}
UnimplementedTCServiceHandler returns CodeUnimplemented from all methods.
func (UnimplementedTCServiceHandler) CheckAsyncShowTranscode ¶
func (UnimplementedTCServiceHandler) CheckAsyncShowTranscode(context.Context, *connect.Request[v1.CheckAsyncShowTranscodeRequest]) (*connect.Response[v1.CheckAsyncShowTranscodeResponse], error)
func (UnimplementedTCServiceHandler) CheckAsyncSpreadTranscode ¶
func (UnimplementedTCServiceHandler) CheckAsyncSpreadTranscode(context.Context, *connect.Request[v1.CheckAsyncSpreadTranscodeRequest]) (*connect.Response[v1.CheckAsyncSpreadTranscodeResponse], error)
func (UnimplementedTCServiceHandler) CheckAsyncTranscode ¶
func (UnimplementedTCServiceHandler) CheckAsyncTranscode(context.Context, *connect.Request[v1.CheckAsyncTranscodeRequest]) (*connect.Response[v1.CheckAsyncTranscodeResponse], error)
func (UnimplementedTCServiceHandler) ListAsyncTranscodes ¶
func (UnimplementedTCServiceHandler) ListAsyncTranscodes(context.Context, *connect.Request[v1.ListAsyncTranscodesRequest]) (*connect.Response[v1.ListAsyncTranscodesResponse], error)
func (UnimplementedTCServiceHandler) StartAsyncShowTranscode ¶
func (UnimplementedTCServiceHandler) StartAsyncShowTranscode(context.Context, *connect.Request[v1.StartAsyncShowTranscodeRequest]) (*connect.Response[v1.StartAsyncShowTranscodeResponse], error)
func (UnimplementedTCServiceHandler) StartAsyncSpreadTranscode ¶
func (UnimplementedTCServiceHandler) StartAsyncSpreadTranscode(context.Context, *connect.Request[v1.StartAsyncSpreadTranscodeRequest]) (*connect.Response[v1.StartAsyncSpreadTranscodeResponse], error)
func (UnimplementedTCServiceHandler) StartAsyncTranscode ¶
func (UnimplementedTCServiceHandler) StartAsyncTranscode(context.Context, *connect.Request[v1.StartAsyncTranscodeRequest]) (*connect.Response[v1.StartAsyncTranscodeResponse], error)
Source Files
¶
- tcserver.connect.go