libraryv1grpc

package
v1.6.0-20251202034006-... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	Service_NewVolume_FullMethodName        = "/krelinga.video.library.v1.Service/NewVolume"
	Service_FindVolumes_FullMethodName      = "/krelinga.video.library.v1.Service/FindVolumes"
	Service_DiscoverNewDiscs_FullMethodName = "/krelinga.video.library.v1.Service/DiscoverNewDiscs"
	Service_FindDiscs_FullMethodName        = "/krelinga.video.library.v1.Service/FindDiscs"
)

Variables

var Service_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "krelinga.video.library.v1.Service",
	HandlerType: (*ServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "NewVolume",
			Handler:    _Service_NewVolume_Handler,
		},
		{
			MethodName: "FindVolumes",
			Handler:    _Service_FindVolumes_Handler,
		},
		{
			MethodName: "DiscoverNewDiscs",
			Handler:    _Service_DiscoverNewDiscs_Handler,
		},
		{
			MethodName: "FindDiscs",
			Handler:    _Service_FindDiscs_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "krelinga/video/library/v1/service.proto",
}

Service_ServiceDesc is the grpc.ServiceDesc for Service service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterServiceServer

func RegisterServiceServer(s grpc.ServiceRegistrar, srv ServiceServer)

Types

type ServiceClient

type ServiceClient interface {
	// Create a new volume.
	NewVolume(ctx context.Context, in *v1.NewVolumeRequest, opts ...grpc.CallOption) (*v1.NewVolumeResponse, error)
	// Find existing volumes.
	FindVolumes(ctx context.Context, in *v1.FindVolumesRequest, opts ...grpc.CallOption) (*v1.FindVolumesResponse, error)
	// Scan a volume directory to discover new discs.
	DiscoverNewDiscs(ctx context.Context, in *v1.DiscoverNewDiscsRequest, opts ...grpc.CallOption) (*v1.DiscoverNewDiscsResponse, error)
	// Find existing discs.
	FindDiscs(ctx context.Context, in *v1.FindDiscsRequest, opts ...grpc.CallOption) (*v1.FindDiscsResponse, error)
}

ServiceClient is the client API for Service service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewServiceClient

func NewServiceClient(cc grpc.ClientConnInterface) ServiceClient

type ServiceServer

type ServiceServer interface {
	// Create a new volume.
	NewVolume(context.Context, *v1.NewVolumeRequest) (*v1.NewVolumeResponse, error)
	// Find existing volumes.
	FindVolumes(context.Context, *v1.FindVolumesRequest) (*v1.FindVolumesResponse, error)
	// Scan a volume directory to discover new discs.
	DiscoverNewDiscs(context.Context, *v1.DiscoverNewDiscsRequest) (*v1.DiscoverNewDiscsResponse, error)
	// Find existing discs.
	FindDiscs(context.Context, *v1.FindDiscsRequest) (*v1.FindDiscsResponse, error)
}

ServiceServer is the server API for Service service. All implementations should embed UnimplementedServiceServer for forward compatibility.

type UnimplementedServiceServer

type UnimplementedServiceServer struct{}

UnimplementedServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedServiceServer) DiscoverNewDiscs

func (UnimplementedServiceServer) FindDiscs

func (UnimplementedServiceServer) FindVolumes

func (UnimplementedServiceServer) NewVolume

type UnsafeServiceServer

type UnsafeServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ServiceServer will result in compilation errors.

Source Files

  • service_grpc.pb.go

Jump to