tccoordv1grpc

package
v1.6.2-20251202034006-... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	TCCoordService_EnqueueDir_FullMethodName = "/krelinga.video.tccoord.v1.TCCoordService/EnqueueDir"
	TCCoordService_GetQueue_FullMethodName   = "/krelinga.video.tccoord.v1.TCCoordService/GetQueue"
)

Variables

var TCCoordService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "krelinga.video.tccoord.v1.TCCoordService",
	HandlerType: (*TCCoordServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "EnqueueDir",
			Handler:    _TCCoordService_EnqueueDir_Handler,
		},
		{
			MethodName: "GetQueue",
			Handler:    _TCCoordService_GetQueue_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "krelinga/video/tccoord/v1/tccoord.proto",
}

TCCoordService_ServiceDesc is the grpc.ServiceDesc for TCCoordService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterTCCoordServiceServer

func RegisterTCCoordServiceServer(s grpc.ServiceRegistrar, srv TCCoordServiceServer)

Types

type TCCoordServiceClient

type TCCoordServiceClient interface {
	EnqueueDir(ctx context.Context, in *v1.EnqueueDirRequest, opts ...grpc.CallOption) (*v1.EnqueueDirResponse, error)
	GetQueue(ctx context.Context, in *v1.GetQueueRequest, opts ...grpc.CallOption) (*v1.GetQueueResponse, error)
}

TCCoordServiceClient is the client API for TCCoordService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewTCCoordServiceClient

func NewTCCoordServiceClient(cc grpc.ClientConnInterface) TCCoordServiceClient

type TCCoordServiceServer

type TCCoordServiceServer interface {
	EnqueueDir(context.Context, *v1.EnqueueDirRequest) (*v1.EnqueueDirResponse, error)
	GetQueue(context.Context, *v1.GetQueueRequest) (*v1.GetQueueResponse, error)
}

TCCoordServiceServer is the server API for TCCoordService service. All implementations should embed UnimplementedTCCoordServiceServer for forward compatibility.

type UnimplementedTCCoordServiceServer

type UnimplementedTCCoordServiceServer struct{}

UnimplementedTCCoordServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedTCCoordServiceServer) EnqueueDir

func (UnimplementedTCCoordServiceServer) GetQueue

type UnsafeTCCoordServiceServer

type UnsafeTCCoordServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeTCCoordServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to TCCoordServiceServer will result in compilation errors.

Source Files

  • tccoord_grpc.pb.go

Jump to