tcserverv1grpc

package
v1.6.1-20251202034006-... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	TCService_StartAsyncTranscode_FullMethodName       = "/krelinga.video.tcserver.v1.TCService/StartAsyncTranscode"
	TCService_CheckAsyncTranscode_FullMethodName       = "/krelinga.video.tcserver.v1.TCService/CheckAsyncTranscode"
	TCService_StartAsyncShowTranscode_FullMethodName   = "/krelinga.video.tcserver.v1.TCService/StartAsyncShowTranscode"
	TCService_CheckAsyncShowTranscode_FullMethodName   = "/krelinga.video.tcserver.v1.TCService/CheckAsyncShowTranscode"
	TCService_StartAsyncSpreadTranscode_FullMethodName = "/krelinga.video.tcserver.v1.TCService/StartAsyncSpreadTranscode"
	TCService_CheckAsyncSpreadTranscode_FullMethodName = "/krelinga.video.tcserver.v1.TCService/CheckAsyncSpreadTranscode"
	TCService_ListAsyncTranscodes_FullMethodName       = "/krelinga.video.tcserver.v1.TCService/ListAsyncTranscodes"
)

Variables

var TCService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "krelinga.video.tcserver.v1.TCService",
	HandlerType: (*TCServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "StartAsyncTranscode",
			Handler:    _TCService_StartAsyncTranscode_Handler,
		},
		{
			MethodName: "CheckAsyncTranscode",
			Handler:    _TCService_CheckAsyncTranscode_Handler,
		},
		{
			MethodName: "StartAsyncShowTranscode",
			Handler:    _TCService_StartAsyncShowTranscode_Handler,
		},
		{
			MethodName: "CheckAsyncShowTranscode",
			Handler:    _TCService_CheckAsyncShowTranscode_Handler,
		},
		{
			MethodName: "StartAsyncSpreadTranscode",
			Handler:    _TCService_StartAsyncSpreadTranscode_Handler,
		},
		{
			MethodName: "CheckAsyncSpreadTranscode",
			Handler:    _TCService_CheckAsyncSpreadTranscode_Handler,
		},
		{
			MethodName: "ListAsyncTranscodes",
			Handler:    _TCService_ListAsyncTranscodes_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "krelinga/video/tcserver/v1/tcserver.proto",
}

TCService_ServiceDesc is the grpc.ServiceDesc for TCService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterTCServiceServer

func RegisterTCServiceServer(s grpc.ServiceRegistrar, srv TCServiceServer)

Types

type TCServiceClient

TCServiceClient is the client API for TCService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewTCServiceClient

func NewTCServiceClient(cc grpc.ClientConnInterface) TCServiceClient

type TCServiceServer

TCServiceServer is the server API for TCService service. All implementations should embed UnimplementedTCServiceServer for forward compatibility.

type UnimplementedTCServiceServer

type UnimplementedTCServiceServer struct{}

UnimplementedTCServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedTCServiceServer) CheckAsyncShowTranscode

func (UnimplementedTCServiceServer) CheckAsyncSpreadTranscode

func (UnimplementedTCServiceServer) CheckAsyncTranscode

func (UnimplementedTCServiceServer) ListAsyncTranscodes

func (UnimplementedTCServiceServer) StartAsyncShowTranscode

func (UnimplementedTCServiceServer) StartAsyncSpreadTranscode

func (UnimplementedTCServiceServer) StartAsyncTranscode

type UnsafeTCServiceServer

type UnsafeTCServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeTCServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to TCServiceServer will result in compilation errors.

Source Files

  • tcserver_grpc.pb.go

Jump to