tcserverv1

package
v1.36.11-2025120203400... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: MIT Imports: 4 Imported by: 5

Documentation

Index

Constants

This section is empty.

Variables

var (
	TranscodeState_name = map[int32]string{
		0: "TRANSCODE_STATE_UNKNOWN",
		4: "TRANSCODE_STATE_NOT_STARTED",
		1: "TRANSCODE_STATE_IN_PROGRESS",
		2: "TRANSCODE_STATE_DONE",
		3: "TRANSCODE_STATE_FAILED",
	}
	TranscodeState_value = map[string]int32{
		"TRANSCODE_STATE_UNKNOWN":     0,
		"TRANSCODE_STATE_NOT_STARTED": 4,
		"TRANSCODE_STATE_IN_PROGRESS": 1,
		"TRANSCODE_STATE_DONE":        2,
		"TRANSCODE_STATE_FAILED":      3,
	}
)

Enum value maps for TranscodeState.

var (
	ListAsyncTranscodesResponse_Op_Type_name = map[int32]string{
		0: "TYPE_UNKNOWN",
		1: "TYPE_SINGLE_FILE",
		2: "TYPE_SHOW",
		3: "TYPE_SPREAD",
	}
	ListAsyncTranscodesResponse_Op_Type_value = map[string]int32{
		"TYPE_UNKNOWN":     0,
		"TYPE_SINGLE_FILE": 1,
		"TYPE_SHOW":        2,
		"TYPE_SPREAD":      3,
	}
)

Enum value maps for ListAsyncTranscodesResponse_Op_Type.

var File_krelinga_video_tcserver_v1_tcserver_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type CheckAsyncShowTranscodeRequest

type CheckAsyncShowTranscodeRequest struct {

	// Must match the name given in StartAsyncTranscodeRequest.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// contains filtered or unexported fields
}

func (*CheckAsyncShowTranscodeRequest) GetName

func (*CheckAsyncShowTranscodeRequest) ProtoMessage

func (*CheckAsyncShowTranscodeRequest) ProtoMessage()

func (*CheckAsyncShowTranscodeRequest) ProtoReflect

func (*CheckAsyncShowTranscodeRequest) Reset

func (x *CheckAsyncShowTranscodeRequest) Reset()

func (*CheckAsyncShowTranscodeRequest) SetName

func (x *CheckAsyncShowTranscodeRequest) SetName(v string)

func (*CheckAsyncShowTranscodeRequest) String

type CheckAsyncShowTranscodeRequest_builder

type CheckAsyncShowTranscodeRequest_builder struct {

	// Must match the name given in StartAsyncTranscodeRequest.
	Name string
	// contains filtered or unexported fields
}

func (CheckAsyncShowTranscodeRequest_builder) Build

type CheckAsyncShowTranscodeResponse

type CheckAsyncShowTranscodeResponse struct {
	File []*CheckAsyncShowTranscodeResponse_File `protobuf:"bytes,1,rep,name=file,proto3" json:"file,omitempty"`
	// State & error of anything not related to individual files.
	State        TranscodeState `protobuf:"varint,2,opt,name=state,proto3,enum=krelinga.video.tcserver.v1.TranscodeState" json:"state,omitempty"`
	ErrorMessage string         `protobuf:"bytes,3,opt,name=error_message,json=errorMessage,proto3" json:"error_message,omitempty"`
	Profile      string         `protobuf:"bytes,4,opt,name=profile,proto3" json:"profile,omitempty"`
	// contains filtered or unexported fields
}

func (*CheckAsyncShowTranscodeResponse) GetErrorMessage

func (x *CheckAsyncShowTranscodeResponse) GetErrorMessage() string

func (*CheckAsyncShowTranscodeResponse) GetFile

func (*CheckAsyncShowTranscodeResponse) GetProfile

func (x *CheckAsyncShowTranscodeResponse) GetProfile() string

func (*CheckAsyncShowTranscodeResponse) GetState

func (*CheckAsyncShowTranscodeResponse) ProtoMessage

func (*CheckAsyncShowTranscodeResponse) ProtoMessage()

func (*CheckAsyncShowTranscodeResponse) ProtoReflect

func (*CheckAsyncShowTranscodeResponse) Reset

func (*CheckAsyncShowTranscodeResponse) SetErrorMessage

func (x *CheckAsyncShowTranscodeResponse) SetErrorMessage(v string)

func (*CheckAsyncShowTranscodeResponse) SetFile

func (*CheckAsyncShowTranscodeResponse) SetProfile

func (x *CheckAsyncShowTranscodeResponse) SetProfile(v string)

func (*CheckAsyncShowTranscodeResponse) SetState

func (*CheckAsyncShowTranscodeResponse) String

type CheckAsyncShowTranscodeResponse_File

type CheckAsyncShowTranscodeResponse_File struct {
	Episode      string         `protobuf:"bytes,1,opt,name=episode,proto3" json:"episode,omitempty"`
	State        TranscodeState `protobuf:"varint,2,opt,name=state,proto3,enum=krelinga.video.tcserver.v1.TranscodeState" json:"state,omitempty"`
	ErrorMessage string         `protobuf:"bytes,3,opt,name=error_message,json=errorMessage,proto3" json:"error_message,omitempty"`
	// Only set if state is TRANSCODE_STATE_IN_PROGRESS
	Progress string `protobuf:"bytes,4,opt,name=progress,proto3" json:"progress,omitempty"`
	// contains filtered or unexported fields
}

func (*CheckAsyncShowTranscodeResponse_File) GetEpisode

func (*CheckAsyncShowTranscodeResponse_File) GetErrorMessage

func (x *CheckAsyncShowTranscodeResponse_File) GetErrorMessage() string

func (*CheckAsyncShowTranscodeResponse_File) GetProgress

func (*CheckAsyncShowTranscodeResponse_File) GetState

func (*CheckAsyncShowTranscodeResponse_File) ProtoMessage

func (*CheckAsyncShowTranscodeResponse_File) ProtoMessage()

func (*CheckAsyncShowTranscodeResponse_File) ProtoReflect

func (*CheckAsyncShowTranscodeResponse_File) Reset

func (*CheckAsyncShowTranscodeResponse_File) SetEpisode

func (*CheckAsyncShowTranscodeResponse_File) SetErrorMessage

func (x *CheckAsyncShowTranscodeResponse_File) SetErrorMessage(v string)

func (*CheckAsyncShowTranscodeResponse_File) SetProgress

func (x *CheckAsyncShowTranscodeResponse_File) SetProgress(v string)

func (*CheckAsyncShowTranscodeResponse_File) SetState

func (*CheckAsyncShowTranscodeResponse_File) String

type CheckAsyncShowTranscodeResponse_File_builder

type CheckAsyncShowTranscodeResponse_File_builder struct {
	Episode      string
	State        TranscodeState
	ErrorMessage string
	// Only set if state is TRANSCODE_STATE_IN_PROGRESS
	Progress string
	// contains filtered or unexported fields
}

func (CheckAsyncShowTranscodeResponse_File_builder) Build

type CheckAsyncShowTranscodeResponse_builder

type CheckAsyncShowTranscodeResponse_builder struct {
	File []*CheckAsyncShowTranscodeResponse_File
	// State & error of anything not related to individual files.
	State        TranscodeState
	ErrorMessage string
	Profile      string
	// contains filtered or unexported fields
}

func (CheckAsyncShowTranscodeResponse_builder) Build

type CheckAsyncSpreadTranscodeRequest

type CheckAsyncSpreadTranscodeRequest struct {

	// Must match the name given in StartAsyncSpreadTranscodeRequest.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// contains filtered or unexported fields
}

func (*CheckAsyncSpreadTranscodeRequest) GetName

func (*CheckAsyncSpreadTranscodeRequest) ProtoMessage

func (*CheckAsyncSpreadTranscodeRequest) ProtoMessage()

func (*CheckAsyncSpreadTranscodeRequest) ProtoReflect

func (*CheckAsyncSpreadTranscodeRequest) Reset

func (*CheckAsyncSpreadTranscodeRequest) SetName

func (*CheckAsyncSpreadTranscodeRequest) String

type CheckAsyncSpreadTranscodeRequest_builder

type CheckAsyncSpreadTranscodeRequest_builder struct {

	// Must match the name given in StartAsyncSpreadTranscodeRequest.
	Name string
	// contains filtered or unexported fields
}

func (CheckAsyncSpreadTranscodeRequest_builder) Build

type CheckAsyncSpreadTranscodeResponse

type CheckAsyncSpreadTranscodeResponse struct {
	Profile      []*CheckAsyncSpreadTranscodeResponse_Profile `protobuf:"bytes,1,rep,name=profile,proto3" json:"profile,omitempty"`
	State        TranscodeState                               `protobuf:"varint,2,opt,name=state,proto3,enum=krelinga.video.tcserver.v1.TranscodeState" json:"state,omitempty"`
	ErrorMessage string                                       `protobuf:"bytes,3,opt,name=error_message,json=errorMessage,proto3" json:"error_message,omitempty"`
	// contains filtered or unexported fields
}

func (*CheckAsyncSpreadTranscodeResponse) GetErrorMessage

func (x *CheckAsyncSpreadTranscodeResponse) GetErrorMessage() string

func (*CheckAsyncSpreadTranscodeResponse) GetProfile

func (*CheckAsyncSpreadTranscodeResponse) GetState

func (*CheckAsyncSpreadTranscodeResponse) ProtoMessage

func (*CheckAsyncSpreadTranscodeResponse) ProtoMessage()

func (*CheckAsyncSpreadTranscodeResponse) ProtoReflect

func (*CheckAsyncSpreadTranscodeResponse) Reset

func (*CheckAsyncSpreadTranscodeResponse) SetErrorMessage

func (x *CheckAsyncSpreadTranscodeResponse) SetErrorMessage(v string)

func (*CheckAsyncSpreadTranscodeResponse) SetProfile

func (*CheckAsyncSpreadTranscodeResponse) SetState

func (*CheckAsyncSpreadTranscodeResponse) String

type CheckAsyncSpreadTranscodeResponse_Profile

type CheckAsyncSpreadTranscodeResponse_Profile struct {
	Profile      string         `protobuf:"bytes,1,opt,name=profile,proto3" json:"profile,omitempty"`
	State        TranscodeState `protobuf:"varint,2,opt,name=state,proto3,enum=krelinga.video.tcserver.v1.TranscodeState" json:"state,omitempty"`
	ErrorMessage string         `protobuf:"bytes,3,opt,name=error_message,json=errorMessage,proto3" json:"error_message,omitempty"`
	// Only set if state is TRANSCODE_STATE_IN_PROGRESS
	Progress string `protobuf:"bytes,4,opt,name=progress,proto3" json:"progress,omitempty"`
	// contains filtered or unexported fields
}

func (*CheckAsyncSpreadTranscodeResponse_Profile) GetErrorMessage

func (*CheckAsyncSpreadTranscodeResponse_Profile) GetProfile

func (*CheckAsyncSpreadTranscodeResponse_Profile) GetProgress

func (*CheckAsyncSpreadTranscodeResponse_Profile) GetState

func (*CheckAsyncSpreadTranscodeResponse_Profile) ProtoMessage

func (*CheckAsyncSpreadTranscodeResponse_Profile) ProtoReflect

func (*CheckAsyncSpreadTranscodeResponse_Profile) Reset

func (*CheckAsyncSpreadTranscodeResponse_Profile) SetErrorMessage

func (x *CheckAsyncSpreadTranscodeResponse_Profile) SetErrorMessage(v string)

func (*CheckAsyncSpreadTranscodeResponse_Profile) SetProfile

func (*CheckAsyncSpreadTranscodeResponse_Profile) SetProgress

func (*CheckAsyncSpreadTranscodeResponse_Profile) SetState

func (*CheckAsyncSpreadTranscodeResponse_Profile) String

type CheckAsyncSpreadTranscodeResponse_Profile_builder

type CheckAsyncSpreadTranscodeResponse_Profile_builder struct {
	Profile      string
	State        TranscodeState
	ErrorMessage string
	// Only set if state is TRANSCODE_STATE_IN_PROGRESS
	Progress string
	// contains filtered or unexported fields
}

func (CheckAsyncSpreadTranscodeResponse_Profile_builder) Build

type CheckAsyncSpreadTranscodeResponse_builder

type CheckAsyncSpreadTranscodeResponse_builder struct {
	Profile      []*CheckAsyncSpreadTranscodeResponse_Profile
	State        TranscodeState
	ErrorMessage string
	// contains filtered or unexported fields
}

func (CheckAsyncSpreadTranscodeResponse_builder) Build

type CheckAsyncTranscodeRequest

type CheckAsyncTranscodeRequest struct {

	// Must match the name given in StartAsyncTranscodeRequest.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// contains filtered or unexported fields
}

func (*CheckAsyncTranscodeRequest) GetName

func (x *CheckAsyncTranscodeRequest) GetName() string

func (*CheckAsyncTranscodeRequest) ProtoMessage

func (*CheckAsyncTranscodeRequest) ProtoMessage()

func (*CheckAsyncTranscodeRequest) ProtoReflect

func (*CheckAsyncTranscodeRequest) Reset

func (x *CheckAsyncTranscodeRequest) Reset()

func (*CheckAsyncTranscodeRequest) SetName

func (x *CheckAsyncTranscodeRequest) SetName(v string)

func (*CheckAsyncTranscodeRequest) String

func (x *CheckAsyncTranscodeRequest) String() string

type CheckAsyncTranscodeRequest_builder

type CheckAsyncTranscodeRequest_builder struct {

	// Must match the name given in StartAsyncTranscodeRequest.
	Name string
	// contains filtered or unexported fields
}

func (CheckAsyncTranscodeRequest_builder) Build

type CheckAsyncTranscodeResponse

type CheckAsyncTranscodeResponse struct {
	State        TranscodeState `protobuf:"varint,1,opt,name=state,proto3,enum=krelinga.video.tcserver.v1.TranscodeState" json:"state,omitempty"`
	ErrorMessage string         `protobuf:"bytes,2,opt,name=error_message,json=errorMessage,proto3" json:"error_message,omitempty"`
	// Only set if state is TRANSCODE_STATE_IN_PROGRESS
	Progress string `protobuf:"bytes,3,opt,name=progress,proto3" json:"progress,omitempty"`
	Profile  string `protobuf:"bytes,4,opt,name=profile,proto3" json:"profile,omitempty"`
	// contains filtered or unexported fields
}

func (*CheckAsyncTranscodeResponse) GetErrorMessage

func (x *CheckAsyncTranscodeResponse) GetErrorMessage() string

func (*CheckAsyncTranscodeResponse) GetProfile

func (x *CheckAsyncTranscodeResponse) GetProfile() string

func (*CheckAsyncTranscodeResponse) GetProgress

func (x *CheckAsyncTranscodeResponse) GetProgress() string

func (*CheckAsyncTranscodeResponse) GetState

func (*CheckAsyncTranscodeResponse) ProtoMessage

func (*CheckAsyncTranscodeResponse) ProtoMessage()

func (*CheckAsyncTranscodeResponse) ProtoReflect

func (*CheckAsyncTranscodeResponse) Reset

func (x *CheckAsyncTranscodeResponse) Reset()

func (*CheckAsyncTranscodeResponse) SetErrorMessage

func (x *CheckAsyncTranscodeResponse) SetErrorMessage(v string)

func (*CheckAsyncTranscodeResponse) SetProfile

func (x *CheckAsyncTranscodeResponse) SetProfile(v string)

func (*CheckAsyncTranscodeResponse) SetProgress

func (x *CheckAsyncTranscodeResponse) SetProgress(v string)

func (*CheckAsyncTranscodeResponse) SetState

func (*CheckAsyncTranscodeResponse) String

func (x *CheckAsyncTranscodeResponse) String() string

type CheckAsyncTranscodeResponse_builder

type CheckAsyncTranscodeResponse_builder struct {
	State        TranscodeState
	ErrorMessage string
	// Only set if state is TRANSCODE_STATE_IN_PROGRESS
	Progress string
	Profile  string
	// contains filtered or unexported fields
}

func (CheckAsyncTranscodeResponse_builder) Build

type ListAsyncTranscodesRequest

type ListAsyncTranscodesRequest struct {
	// contains filtered or unexported fields
}

func (*ListAsyncTranscodesRequest) ProtoMessage

func (*ListAsyncTranscodesRequest) ProtoMessage()

func (*ListAsyncTranscodesRequest) ProtoReflect

func (*ListAsyncTranscodesRequest) Reset

func (x *ListAsyncTranscodesRequest) Reset()

func (*ListAsyncTranscodesRequest) String

func (x *ListAsyncTranscodesRequest) String() string

type ListAsyncTranscodesRequest_builder

type ListAsyncTranscodesRequest_builder struct {
	// contains filtered or unexported fields
}

func (ListAsyncTranscodesRequest_builder) Build

type ListAsyncTranscodesResponse

type ListAsyncTranscodesResponse struct {
	Op []*ListAsyncTranscodesResponse_Op `protobuf:"bytes,1,rep,name=op,proto3" json:"op,omitempty"`
	// contains filtered or unexported fields
}

func (*ListAsyncTranscodesResponse) GetOp

func (*ListAsyncTranscodesResponse) ProtoMessage

func (*ListAsyncTranscodesResponse) ProtoMessage()

func (*ListAsyncTranscodesResponse) ProtoReflect

func (*ListAsyncTranscodesResponse) Reset

func (x *ListAsyncTranscodesResponse) Reset()

func (*ListAsyncTranscodesResponse) SetOp

func (*ListAsyncTranscodesResponse) String

func (x *ListAsyncTranscodesResponse) String() string

type ListAsyncTranscodesResponse_Op

type ListAsyncTranscodesResponse_Op struct {
	Name  string                              `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	Type  ListAsyncTranscodesResponse_Op_Type `` /* 130-byte string literal not displayed */
	State TranscodeState                      `protobuf:"varint,3,opt,name=state,proto3,enum=krelinga.video.tcserver.v1.TranscodeState" json:"state,omitempty"`
	// contains filtered or unexported fields
}

func (*ListAsyncTranscodesResponse_Op) GetName

func (*ListAsyncTranscodesResponse_Op) GetState

func (*ListAsyncTranscodesResponse_Op) GetType

func (*ListAsyncTranscodesResponse_Op) ProtoMessage

func (*ListAsyncTranscodesResponse_Op) ProtoMessage()

func (*ListAsyncTranscodesResponse_Op) ProtoReflect

func (*ListAsyncTranscodesResponse_Op) Reset

func (x *ListAsyncTranscodesResponse_Op) Reset()

func (*ListAsyncTranscodesResponse_Op) SetName

func (x *ListAsyncTranscodesResponse_Op) SetName(v string)

func (*ListAsyncTranscodesResponse_Op) SetState

func (*ListAsyncTranscodesResponse_Op) SetType

func (*ListAsyncTranscodesResponse_Op) String

type ListAsyncTranscodesResponse_Op_Type

type ListAsyncTranscodesResponse_Op_Type int32
const (
	ListAsyncTranscodesResponse_Op_TYPE_UNKNOWN     ListAsyncTranscodesResponse_Op_Type = 0
	ListAsyncTranscodesResponse_Op_TYPE_SINGLE_FILE ListAsyncTranscodesResponse_Op_Type = 1
	ListAsyncTranscodesResponse_Op_TYPE_SHOW        ListAsyncTranscodesResponse_Op_Type = 2
	ListAsyncTranscodesResponse_Op_TYPE_SPREAD      ListAsyncTranscodesResponse_Op_Type = 3
)

func (ListAsyncTranscodesResponse_Op_Type) Descriptor

func (ListAsyncTranscodesResponse_Op_Type) Enum

func (ListAsyncTranscodesResponse_Op_Type) Number

func (ListAsyncTranscodesResponse_Op_Type) String

func (ListAsyncTranscodesResponse_Op_Type) Type

type ListAsyncTranscodesResponse_Op_builder

type ListAsyncTranscodesResponse_Op_builder struct {
	Name  string
	Type  ListAsyncTranscodesResponse_Op_Type
	State TranscodeState
	// contains filtered or unexported fields
}

func (ListAsyncTranscodesResponse_Op_builder) Build

type ListAsyncTranscodesResponse_builder

type ListAsyncTranscodesResponse_builder struct {
	Op []*ListAsyncTranscodesResponse_Op
	// contains filtered or unexported fields
}

func (ListAsyncTranscodesResponse_builder) Build

type StartAsyncShowTranscodeRequest

type StartAsyncShowTranscodeRequest struct {
	Name             string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	InDirPath        string `protobuf:"bytes,2,opt,name=in_dir_path,json=inDirPath,proto3" json:"in_dir_path,omitempty"`
	OutParentDirPath string `protobuf:"bytes,3,opt,name=out_parent_dir_path,json=outParentDirPath,proto3" json:"out_parent_dir_path,omitempty"`
	Profile          string `protobuf:"bytes,4,opt,name=profile,proto3" json:"profile,omitempty"`
	// contains filtered or unexported fields
}

func (*StartAsyncShowTranscodeRequest) GetInDirPath

func (x *StartAsyncShowTranscodeRequest) GetInDirPath() string

func (*StartAsyncShowTranscodeRequest) GetName

func (*StartAsyncShowTranscodeRequest) GetOutParentDirPath

func (x *StartAsyncShowTranscodeRequest) GetOutParentDirPath() string

func (*StartAsyncShowTranscodeRequest) GetProfile

func (x *StartAsyncShowTranscodeRequest) GetProfile() string

func (*StartAsyncShowTranscodeRequest) ProtoMessage

func (*StartAsyncShowTranscodeRequest) ProtoMessage()

func (*StartAsyncShowTranscodeRequest) ProtoReflect

func (*StartAsyncShowTranscodeRequest) Reset

func (x *StartAsyncShowTranscodeRequest) Reset()

func (*StartAsyncShowTranscodeRequest) SetInDirPath

func (x *StartAsyncShowTranscodeRequest) SetInDirPath(v string)

func (*StartAsyncShowTranscodeRequest) SetName

func (x *StartAsyncShowTranscodeRequest) SetName(v string)

func (*StartAsyncShowTranscodeRequest) SetOutParentDirPath

func (x *StartAsyncShowTranscodeRequest) SetOutParentDirPath(v string)

func (*StartAsyncShowTranscodeRequest) SetProfile

func (x *StartAsyncShowTranscodeRequest) SetProfile(v string)

func (*StartAsyncShowTranscodeRequest) String

type StartAsyncShowTranscodeRequest_builder

type StartAsyncShowTranscodeRequest_builder struct {
	Name             string
	InDirPath        string
	OutParentDirPath string
	Profile          string
	// contains filtered or unexported fields
}

func (StartAsyncShowTranscodeRequest_builder) Build

type StartAsyncShowTranscodeResponse

type StartAsyncShowTranscodeResponse struct {
	// contains filtered or unexported fields
}

func (*StartAsyncShowTranscodeResponse) ProtoMessage

func (*StartAsyncShowTranscodeResponse) ProtoMessage()

func (*StartAsyncShowTranscodeResponse) ProtoReflect

func (*StartAsyncShowTranscodeResponse) Reset

func (*StartAsyncShowTranscodeResponse) String

type StartAsyncShowTranscodeResponse_builder

type StartAsyncShowTranscodeResponse_builder struct {
	// contains filtered or unexported fields
}

func (StartAsyncShowTranscodeResponse_builder) Build

type StartAsyncSpreadTranscodeRequest

type StartAsyncSpreadTranscodeRequest struct {
	Name             string                                        `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	InPath           string                                        `protobuf:"bytes,2,opt,name=in_path,json=inPath,proto3" json:"in_path,omitempty"`
	OutParentDirPath string                                        `protobuf:"bytes,3,opt,name=out_parent_dir_path,json=outParentDirPath,proto3" json:"out_parent_dir_path,omitempty"`
	ProfileList      *StartAsyncSpreadTranscodeRequest_ProfileList `protobuf:"bytes,4,opt,name=profile_list,json=profileList,proto3" json:"profile_list,omitempty"`
	// contains filtered or unexported fields
}

func (*StartAsyncSpreadTranscodeRequest) ClearProfileList

func (x *StartAsyncSpreadTranscodeRequest) ClearProfileList()

func (*StartAsyncSpreadTranscodeRequest) GetInPath

func (*StartAsyncSpreadTranscodeRequest) GetName

func (*StartAsyncSpreadTranscodeRequest) GetOutParentDirPath

func (x *StartAsyncSpreadTranscodeRequest) GetOutParentDirPath() string

func (*StartAsyncSpreadTranscodeRequest) GetProfileList

func (*StartAsyncSpreadTranscodeRequest) HasProfileList

func (x *StartAsyncSpreadTranscodeRequest) HasProfileList() bool

func (*StartAsyncSpreadTranscodeRequest) ProtoMessage

func (*StartAsyncSpreadTranscodeRequest) ProtoMessage()

func (*StartAsyncSpreadTranscodeRequest) ProtoReflect

func (*StartAsyncSpreadTranscodeRequest) Reset

func (*StartAsyncSpreadTranscodeRequest) SetInPath

func (x *StartAsyncSpreadTranscodeRequest) SetInPath(v string)

func (*StartAsyncSpreadTranscodeRequest) SetName

func (*StartAsyncSpreadTranscodeRequest) SetOutParentDirPath

func (x *StartAsyncSpreadTranscodeRequest) SetOutParentDirPath(v string)

func (*StartAsyncSpreadTranscodeRequest) SetProfileList

func (*StartAsyncSpreadTranscodeRequest) String

type StartAsyncSpreadTranscodeRequest_ProfileList

type StartAsyncSpreadTranscodeRequest_ProfileList struct {
	Profile []string `protobuf:"bytes,1,rep,name=profile,proto3" json:"profile,omitempty"`
	// contains filtered or unexported fields
}

TODO: expand how these can be specified in the future.

func (*StartAsyncSpreadTranscodeRequest_ProfileList) GetProfile

func (*StartAsyncSpreadTranscodeRequest_ProfileList) ProtoMessage

func (*StartAsyncSpreadTranscodeRequest_ProfileList) ProtoReflect

func (*StartAsyncSpreadTranscodeRequest_ProfileList) Reset

func (*StartAsyncSpreadTranscodeRequest_ProfileList) SetProfile

func (*StartAsyncSpreadTranscodeRequest_ProfileList) String

type StartAsyncSpreadTranscodeRequest_ProfileList_builder

type StartAsyncSpreadTranscodeRequest_ProfileList_builder struct {
	Profile []string
	// contains filtered or unexported fields
}

func (StartAsyncSpreadTranscodeRequest_ProfileList_builder) Build

type StartAsyncSpreadTranscodeRequest_builder

type StartAsyncSpreadTranscodeRequest_builder struct {
	Name             string
	InPath           string
	OutParentDirPath string
	ProfileList      *StartAsyncSpreadTranscodeRequest_ProfileList
	// contains filtered or unexported fields
}

func (StartAsyncSpreadTranscodeRequest_builder) Build

type StartAsyncSpreadTranscodeResponse

type StartAsyncSpreadTranscodeResponse struct {
	// contains filtered or unexported fields
}

func (*StartAsyncSpreadTranscodeResponse) ProtoMessage

func (*StartAsyncSpreadTranscodeResponse) ProtoMessage()

func (*StartAsyncSpreadTranscodeResponse) ProtoReflect

func (*StartAsyncSpreadTranscodeResponse) Reset

func (*StartAsyncSpreadTranscodeResponse) String

type StartAsyncSpreadTranscodeResponse_builder

type StartAsyncSpreadTranscodeResponse_builder struct {
	// contains filtered or unexported fields
}

func (StartAsyncSpreadTranscodeResponse_builder) Build

type StartAsyncTranscodeRequest

type StartAsyncTranscodeRequest struct {

	// Must be unique among all running transcodes on the server.
	Name    string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	InPath  string `protobuf:"bytes,2,opt,name=in_path,json=inPath,proto3" json:"in_path,omitempty"`
	OutPath string `protobuf:"bytes,3,opt,name=out_path,json=outPath,proto3" json:"out_path,omitempty"`
	// If set, the name of the profile to use.
	Profile string `protobuf:"bytes,4,opt,name=profile,proto3" json:"profile,omitempty"`
	// contains filtered or unexported fields
}

func (*StartAsyncTranscodeRequest) GetInPath

func (x *StartAsyncTranscodeRequest) GetInPath() string

func (*StartAsyncTranscodeRequest) GetName

func (x *StartAsyncTranscodeRequest) GetName() string

func (*StartAsyncTranscodeRequest) GetOutPath

func (x *StartAsyncTranscodeRequest) GetOutPath() string

func (*StartAsyncTranscodeRequest) GetProfile

func (x *StartAsyncTranscodeRequest) GetProfile() string

func (*StartAsyncTranscodeRequest) ProtoMessage

func (*StartAsyncTranscodeRequest) ProtoMessage()

func (*StartAsyncTranscodeRequest) ProtoReflect

func (*StartAsyncTranscodeRequest) Reset

func (x *StartAsyncTranscodeRequest) Reset()

func (*StartAsyncTranscodeRequest) SetInPath

func (x *StartAsyncTranscodeRequest) SetInPath(v string)

func (*StartAsyncTranscodeRequest) SetName

func (x *StartAsyncTranscodeRequest) SetName(v string)

func (*StartAsyncTranscodeRequest) SetOutPath

func (x *StartAsyncTranscodeRequest) SetOutPath(v string)

func (*StartAsyncTranscodeRequest) SetProfile

func (x *StartAsyncTranscodeRequest) SetProfile(v string)

func (*StartAsyncTranscodeRequest) String

func (x *StartAsyncTranscodeRequest) String() string

type StartAsyncTranscodeRequest_builder

type StartAsyncTranscodeRequest_builder struct {

	// Must be unique among all running transcodes on the server.
	Name    string
	InPath  string
	OutPath string
	// If set, the name of the profile to use.
	Profile string
	// contains filtered or unexported fields
}

func (StartAsyncTranscodeRequest_builder) Build

type StartAsyncTranscodeResponse

type StartAsyncTranscodeResponse struct {
	// contains filtered or unexported fields
}

func (*StartAsyncTranscodeResponse) ProtoMessage

func (*StartAsyncTranscodeResponse) ProtoMessage()

func (*StartAsyncTranscodeResponse) ProtoReflect

func (*StartAsyncTranscodeResponse) Reset

func (x *StartAsyncTranscodeResponse) Reset()

func (*StartAsyncTranscodeResponse) String

func (x *StartAsyncTranscodeResponse) String() string

type StartAsyncTranscodeResponse_builder

type StartAsyncTranscodeResponse_builder struct {
	// contains filtered or unexported fields
}

func (StartAsyncTranscodeResponse_builder) Build

type TranscodeState

type TranscodeState int32
const (
	TranscodeState_TRANSCODE_STATE_UNKNOWN     TranscodeState = 0
	TranscodeState_TRANSCODE_STATE_NOT_STARTED TranscodeState = 4
	TranscodeState_TRANSCODE_STATE_IN_PROGRESS TranscodeState = 1
	TranscodeState_TRANSCODE_STATE_DONE        TranscodeState = 2
	TranscodeState_TRANSCODE_STATE_FAILED      TranscodeState = 3
)

func (TranscodeState) Descriptor

func (TranscodeState) Enum

func (x TranscodeState) Enum() *TranscodeState

func (TranscodeState) Number

func (TranscodeState) String

func (x TranscodeState) String() string

func (TranscodeState) Type

Source Files

  • tcserver.pb.go

Jump to