Documentation
¶
Index ¶
- Variables
- type SignInGameRequest
- func (x *SignInGameRequest) GetGameToken() string
- func (x *SignInGameRequest) GetGameUserId() string
- func (*SignInGameRequest) ProtoMessage()
- func (x *SignInGameRequest) ProtoReflect() protoreflect.Message
- func (x *SignInGameRequest) Reset()
- func (x *SignInGameRequest) SetGameToken(v string)
- func (x *SignInGameRequest) SetGameUserId(v string)
- func (x *SignInGameRequest) String() string
- type SignInGameRequest_builder
- type SignInGameResponse
- type SignInGameResponse_builder
Constants ¶
This section is empty.
Variables ¶
var File_linq_auth_game_v1_game_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type SignInGameRequest ¶
type SignInGameRequest struct {
// Dedicated special token for linking game services and wallet services.
// It is needed for establishing the initial handshake between services and
// before user obtained their's own access token.
GameToken string `protobuf:"bytes,1,opt,name=game_token,json=gameToken,proto3" json:"game_token,omitempty"`
// Internal game user identifier used for linking it with profile on wallet side.
// Prefered to use value that can not be changed in the future.
//
// Good example: incremental ID, UUID value, eny kind of unique value
// Bad example: username, email or any kind of information which users can update by themself.
GameUserId string `protobuf:"bytes,2,opt,name=game_user_id,json=gameUserId,proto3" json:"game_user_id,omitempty"`
// contains filtered or unexported fields
}
Request data for registering in the services as a game user
func (*SignInGameRequest) GetGameToken ¶
func (x *SignInGameRequest) GetGameToken() string
func (*SignInGameRequest) GetGameUserId ¶
func (x *SignInGameRequest) GetGameUserId() string
func (*SignInGameRequest) ProtoMessage ¶
func (*SignInGameRequest) ProtoMessage()
func (*SignInGameRequest) ProtoReflect ¶
func (x *SignInGameRequest) ProtoReflect() protoreflect.Message
func (*SignInGameRequest) Reset ¶
func (x *SignInGameRequest) Reset()
func (*SignInGameRequest) SetGameToken ¶
func (x *SignInGameRequest) SetGameToken(v string)
func (*SignInGameRequest) SetGameUserId ¶
func (x *SignInGameRequest) SetGameUserId(v string)
func (*SignInGameRequest) String ¶
func (x *SignInGameRequest) String() string
type SignInGameRequest_builder ¶
type SignInGameRequest_builder struct {
// Dedicated special token for linking game services and wallet services.
// It is needed for establishing the initial handshake between services and
// before user obtained their's own access token.
GameToken string
// Internal game user identifier used for linking it with profile on wallet side.
// Prefered to use value that can not be changed in the future.
//
// Good example: incremental ID, UUID value, eny kind of unique value
// Bad example: username, email or any kind of information which users can update by themself.
GameUserId string
// contains filtered or unexported fields
}
func (SignInGameRequest_builder) Build ¶
func (b0 SignInGameRequest_builder) Build() *SignInGameRequest
type SignInGameResponse ¶
type SignInGameResponse struct {
// Access token for getting access to protected API endpoints, which requires user authorisation.
AccessToken string `protobuf:"bytes,1,opt,name=access_token,json=accessToken,proto3" json:"access_token,omitempty"`
// contains filtered or unexported fields
}
Response with generated access token for a given user.
func (*SignInGameResponse) GetAccessToken ¶
func (x *SignInGameResponse) GetAccessToken() string
func (*SignInGameResponse) ProtoMessage ¶
func (*SignInGameResponse) ProtoMessage()
func (*SignInGameResponse) ProtoReflect ¶
func (x *SignInGameResponse) ProtoReflect() protoreflect.Message
func (*SignInGameResponse) Reset ¶
func (x *SignInGameResponse) Reset()
func (*SignInGameResponse) SetAccessToken ¶
func (x *SignInGameResponse) SetAccessToken(v string)
func (*SignInGameResponse) String ¶
func (x *SignInGameResponse) String() string
type SignInGameResponse_builder ¶
type SignInGameResponse_builder struct {
// Access token for getting access to protected API endpoints, which requires user authorisation.
AccessToken string
// contains filtered or unexported fields
}
func (SignInGameResponse_builder) Build ¶
func (b0 SignInGameResponse_builder) Build() *SignInGameResponse
Source Files
¶
- game.pb.go
Click to show internal directories.
Click to hide internal directories.