restrictionsv1

package
v1.36.11-2025102014493... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: MIT Imports: 4 Imported by: 1

Documentation

Index

Constants

This section is empty.

Variables

var File_linq_geo_restrictions_v1_restrictions_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type AccessAppRequest deprecated

type AccessAppRequest struct {

	// Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.
	App *string `protobuf:"bytes,1,opt,name=app,proto3,oneof" json:"app,omitempty"`
	// contains filtered or unexported fields
}

Access request payload, optionally receives app code To check access for a specific application

Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.

func (*AccessAppRequest) ClearApp deprecated

func (x *AccessAppRequest) ClearApp()

Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.

func (*AccessAppRequest) GetApp deprecated

func (x *AccessAppRequest) GetApp() string

Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.

func (*AccessAppRequest) HasApp deprecated

func (x *AccessAppRequest) HasApp() bool

Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.

func (*AccessAppRequest) ProtoMessage

func (*AccessAppRequest) ProtoMessage()

func (*AccessAppRequest) ProtoReflect

func (x *AccessAppRequest) ProtoReflect() protoreflect.Message

func (*AccessAppRequest) Reset

func (x *AccessAppRequest) Reset()

func (*AccessAppRequest) SetApp deprecated

func (x *AccessAppRequest) SetApp(v string)

Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.

func (*AccessAppRequest) String

func (x *AccessAppRequest) String() string

type AccessAppRequest_builder deprecated

type AccessAppRequest_builder struct {

	// Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.
	App *string
	// contains filtered or unexported fields
}

Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.

func (AccessAppRequest_builder) Build

type AccessStatus deprecated

type AccessStatus struct {

	// Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.
	Allowed bool `protobuf:"varint,1,opt,name=allowed,proto3" json:"allowed,omitempty"`
	// Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.
	Location *UserLocationData `protobuf:"bytes,2,opt,name=location,proto3" json:"location,omitempty"`
	// contains filtered or unexported fields
}

Access details message with included user location data

Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.

func (*AccessStatus) ClearLocation deprecated

func (x *AccessStatus) ClearLocation()

Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.

func (*AccessStatus) GetAllowed deprecated

func (x *AccessStatus) GetAllowed() bool

Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.

func (*AccessStatus) GetLocation deprecated

func (x *AccessStatus) GetLocation() *UserLocationData

Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.

func (*AccessStatus) HasLocation deprecated

func (x *AccessStatus) HasLocation() bool

Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.

func (*AccessStatus) ProtoMessage

func (*AccessStatus) ProtoMessage()

func (*AccessStatus) ProtoReflect

func (x *AccessStatus) ProtoReflect() protoreflect.Message

func (*AccessStatus) Reset

func (x *AccessStatus) Reset()

func (*AccessStatus) SetAllowed deprecated

func (x *AccessStatus) SetAllowed(v bool)

Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.

func (*AccessStatus) SetLocation deprecated

func (x *AccessStatus) SetLocation(v *UserLocationData)

Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.

func (*AccessStatus) String

func (x *AccessStatus) String() string

type AccessStatus_builder deprecated

type AccessStatus_builder struct {

	// Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.
	Allowed bool
	// Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.
	Location *UserLocationData
	// contains filtered or unexported fields
}

Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.

func (AccessStatus_builder) Build

func (b0 AccessStatus_builder) Build() *AccessStatus

type Areas deprecated

type Areas struct {

	// Country two-letter code
	//
	// Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.
	Country string `protobuf:"bytes,1,opt,name=country,proto3" json:"country,omitempty"`
	// List of two-letter codes of regions
	//
	// Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.
	Regions []string `protobuf:"bytes,2,rep,name=regions,proto3" json:"regions,omitempty"`
	// contains filtered or unexported fields
}

List of areas attached to the country

Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.

func (*Areas) GetCountry deprecated

func (x *Areas) GetCountry() string

Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.

func (*Areas) GetRegions deprecated

func (x *Areas) GetRegions() []string

Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.

func (*Areas) ProtoMessage

func (*Areas) ProtoMessage()

func (*Areas) ProtoReflect

func (x *Areas) ProtoReflect() protoreflect.Message

func (*Areas) Reset

func (x *Areas) Reset()

func (*Areas) SetCountry deprecated

func (x *Areas) SetCountry(v string)

Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.

func (*Areas) SetRegions deprecated

func (x *Areas) SetRegions(v []string)

Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.

func (*Areas) String

func (x *Areas) String() string

type Areas_builder deprecated

type Areas_builder struct {

	// Country two-letter code
	//
	// Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.
	Country string
	// List of two-letter codes of regions
	//
	// Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.
	Regions []string
	// contains filtered or unexported fields
}

Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.

func (Areas_builder) Build

func (b0 Areas_builder) Build() *Areas

type AvoidedRegionsResponse deprecated

type AvoidedRegionsResponse struct {

	// List of avoided countries
	//
	// Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.
	Countries []string `protobuf:"bytes,1,rep,name=countries,proto3" json:"countries,omitempty"`
	// List of avoided areas mapped by country
	//
	// Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.
	Areas []*Areas `protobuf:"bytes,2,rep,name=areas,proto3" json:"areas,omitempty"`
	// contains filtered or unexported fields
}

Reponse with avoided areas configuration

Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.

func (*AvoidedRegionsResponse) GetAreas deprecated

func (x *AvoidedRegionsResponse) GetAreas() []*Areas

Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.

func (*AvoidedRegionsResponse) GetCountries deprecated

func (x *AvoidedRegionsResponse) GetCountries() []string

Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.

func (*AvoidedRegionsResponse) ProtoMessage

func (*AvoidedRegionsResponse) ProtoMessage()

func (*AvoidedRegionsResponse) ProtoReflect

func (x *AvoidedRegionsResponse) ProtoReflect() protoreflect.Message

func (*AvoidedRegionsResponse) Reset

func (x *AvoidedRegionsResponse) Reset()

func (*AvoidedRegionsResponse) SetAreas deprecated

func (x *AvoidedRegionsResponse) SetAreas(v []*Areas)

Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.

func (*AvoidedRegionsResponse) SetCountries deprecated

func (x *AvoidedRegionsResponse) SetCountries(v []string)

Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.

func (*AvoidedRegionsResponse) String

func (x *AvoidedRegionsResponse) String() string

type AvoidedRegionsResponse_builder deprecated

type AvoidedRegionsResponse_builder struct {

	// List of avoided countries
	//
	// Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.
	Countries []string
	// List of avoided areas mapped by country
	//
	// Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.
	Areas []*Areas
	// contains filtered or unexported fields
}

Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.

func (AvoidedRegionsResponse_builder) Build

type RegionsConfigRequest deprecated

type RegionsConfigRequest struct {

	// Game token used for authorization requests
	// Same as for AuthGameService::SignInGame
	//
	// Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.
	Token string `protobuf:"bytes,1,opt,name=token,proto3" json:"token,omitempty"`
	// contains filtered or unexported fields
}

Request for asking current avoided regions settings

Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.

func (*RegionsConfigRequest) GetToken deprecated

func (x *RegionsConfigRequest) GetToken() string

Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.

func (*RegionsConfigRequest) ProtoMessage

func (*RegionsConfigRequest) ProtoMessage()

func (*RegionsConfigRequest) ProtoReflect

func (x *RegionsConfigRequest) ProtoReflect() protoreflect.Message

func (*RegionsConfigRequest) Reset

func (x *RegionsConfigRequest) Reset()

func (*RegionsConfigRequest) SetToken deprecated

func (x *RegionsConfigRequest) SetToken(v string)

Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.

func (*RegionsConfigRequest) String

func (x *RegionsConfigRequest) String() string

type RegionsConfigRequest_builder deprecated

type RegionsConfigRequest_builder struct {

	// Game token used for authorization requests
	// Same as for AuthGameService::SignInGame
	//
	// Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.
	Token string
	// contains filtered or unexported fields
}

Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.

func (RegionsConfigRequest_builder) Build

type UserLocationData deprecated

type UserLocationData struct {

	// Country code, two letter by ISO
	//
	// Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.
	Country string `protobuf:"bytes,1,opt,name=country,proto3" json:"country,omitempty"`
	// Country region code
	//
	// Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.
	Region string `protobuf:"bytes,2,opt,name=region,proto3" json:"region,omitempty"`
	// Name of place or location, like a town or city
	//
	// Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.
	City string `protobuf:"bytes,3,opt,name=city,proto3" json:"city,omitempty"`
	// contains filtered or unexported fields
}

Determined user location

Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.

func (*UserLocationData) GetCity deprecated

func (x *UserLocationData) GetCity() string

Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.

func (*UserLocationData) GetCountry deprecated

func (x *UserLocationData) GetCountry() string

Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.

func (*UserLocationData) GetRegion deprecated

func (x *UserLocationData) GetRegion() string

Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.

func (*UserLocationData) ProtoMessage

func (*UserLocationData) ProtoMessage()

func (*UserLocationData) ProtoReflect

func (x *UserLocationData) ProtoReflect() protoreflect.Message

func (*UserLocationData) Reset

func (x *UserLocationData) Reset()

func (*UserLocationData) SetCity deprecated

func (x *UserLocationData) SetCity(v string)

Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.

func (*UserLocationData) SetCountry deprecated

func (x *UserLocationData) SetCountry(v string)

Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.

func (*UserLocationData) SetRegion deprecated

func (x *UserLocationData) SetRegion(v string)

Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.

func (*UserLocationData) String

func (x *UserLocationData) String() string

type UserLocationData_builder deprecated

type UserLocationData_builder struct {

	// Country code, two letter by ISO
	//
	// Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.
	Country string
	// Country region code
	//
	// Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.
	Region string
	// Name of place or location, like a town or city
	//
	// Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.
	City string
	// contains filtered or unexported fields
}

Deprecated: The entire proto file linq/geo/restrictions/v1/restrictions.proto is marked as deprecated.

func (UserLocationData_builder) Build

Source Files

  • restrictions.pb.go

Jump to