Documentation
¶
Index ¶
- Variables
- type AccountBalance
- func (x *AccountBalance) ClearBalance()
- func (x *AccountBalance) GetBalance() *Balance
- func (x *AccountBalance) GetCurrency() string
- func (x *AccountBalance) GetNumber() string
- func (x *AccountBalance) HasBalance() bool
- func (*AccountBalance) ProtoMessage()
- func (x *AccountBalance) ProtoReflect() protoreflect.Message
- func (x *AccountBalance) Reset()
- func (x *AccountBalance) SetBalance(v *Balance)
- func (x *AccountBalance) SetCurrency(v string)
- func (x *AccountBalance) SetNumber(v string)
- func (x *AccountBalance) String() string
- type AccountBalance_builder
- type AccountsResponse
- type AccountsResponse_builder
- type AppliedRewardOrder
- func (x *AppliedRewardOrder) GetAmount() uint32
- func (x *AppliedRewardOrder) GetId() string
- func (x *AppliedRewardOrder) GetReference() string
- func (x *AppliedRewardOrder) GetStatus() string
- func (*AppliedRewardOrder) ProtoMessage()
- func (x *AppliedRewardOrder) ProtoReflect() protoreflect.Message
- func (x *AppliedRewardOrder) Reset()
- func (x *AppliedRewardOrder) SetAmount(v uint32)
- func (x *AppliedRewardOrder) SetId(v string)
- func (x *AppliedRewardOrder) SetReference(v string)
- func (x *AppliedRewardOrder) SetStatus(v string)
- func (x *AppliedRewardOrder) String() string
- type AppliedRewardOrder_builder
- type Balance
- func (x *Balance) GetAvailable() uint32
- func (x *Balance) GetCurrent() uint32
- func (*Balance) ProtoMessage()
- func (x *Balance) ProtoReflect() protoreflect.Message
- func (x *Balance) Reset()
- func (x *Balance) SetAvailable(v uint32)
- func (x *Balance) SetCurrent(v uint32)
- func (x *Balance) String() string
- type Balance_builder
- type CustomRewardRequest
- func (x *CustomRewardRequest) ClearReference()
- func (x *CustomRewardRequest) GetAmount() int32
- func (x *CustomRewardRequest) GetReason() string
- func (x *CustomRewardRequest) GetReference() string
- func (x *CustomRewardRequest) HasReference() bool
- func (*CustomRewardRequest) ProtoMessage()
- func (x *CustomRewardRequest) ProtoReflect() protoreflect.Message
- func (x *CustomRewardRequest) Reset()
- func (x *CustomRewardRequest) SetAmount(v int32)
- func (x *CustomRewardRequest) SetReason(v string)
- func (x *CustomRewardRequest) SetReference(v string)
- func (x *CustomRewardRequest) String() string
- type CustomRewardRequest_builder
Constants ¶
This section is empty.
Variables ¶
var File_linq_money_accounts_v2_accounts_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type AccountBalance ¶
type AccountBalance struct {
// Number of the internal account
Number string `protobuf:"bytes,1,opt,name=number,proto3" json:"number,omitempty"`
// Internal currency 3-letters code
// LNQ for wallet balance, for example
Currency string `protobuf:"bytes,2,opt,name=currency,proto3" json:"currency,omitempty"`
// Actual balance of the user in coins
Balance *Balance `protobuf:"bytes,3,opt,name=balance,proto3" json:"balance,omitempty"`
// contains filtered or unexported fields
}
Returns detailed information about user balance on the requested account
func (*AccountBalance) ClearBalance ¶
func (x *AccountBalance) ClearBalance()
func (*AccountBalance) GetBalance ¶
func (x *AccountBalance) GetBalance() *Balance
func (*AccountBalance) GetCurrency ¶
func (x *AccountBalance) GetCurrency() string
func (*AccountBalance) GetNumber ¶
func (x *AccountBalance) GetNumber() string
func (*AccountBalance) HasBalance ¶
func (x *AccountBalance) HasBalance() bool
func (*AccountBalance) ProtoMessage ¶
func (*AccountBalance) ProtoMessage()
func (*AccountBalance) ProtoReflect ¶
func (x *AccountBalance) ProtoReflect() protoreflect.Message
func (*AccountBalance) Reset ¶
func (x *AccountBalance) Reset()
func (*AccountBalance) SetBalance ¶
func (x *AccountBalance) SetBalance(v *Balance)
func (*AccountBalance) SetCurrency ¶
func (x *AccountBalance) SetCurrency(v string)
func (*AccountBalance) SetNumber ¶
func (x *AccountBalance) SetNumber(v string)
func (*AccountBalance) String ¶
func (x *AccountBalance) String() string
type AccountBalance_builder ¶
type AccountBalance_builder struct {
// Number of the internal account
Number string
// Internal currency 3-letters code
// LNQ for wallet balance, for example
Currency string
// Actual balance of the user in coins
Balance *Balance
// contains filtered or unexported fields
}
func (AccountBalance_builder) Build ¶
func (b0 AccountBalance_builder) Build() *AccountBalance
type AccountsResponse ¶
type AccountsResponse struct {
// Returns list of accounts, limited by user access
// For the game request only LNQ and this game accounts will be returned
Accounts []*AccountBalance `protobuf:"bytes,1,rep,name=accounts,proto3" json:"accounts,omitempty"`
// contains filtered or unexported fields
}
List of active accounts for the current user
func (*AccountsResponse) GetAccounts ¶
func (x *AccountsResponse) GetAccounts() []*AccountBalance
func (*AccountsResponse) ProtoMessage ¶
func (*AccountsResponse) ProtoMessage()
func (*AccountsResponse) ProtoReflect ¶
func (x *AccountsResponse) ProtoReflect() protoreflect.Message
func (*AccountsResponse) Reset ¶
func (x *AccountsResponse) Reset()
func (*AccountsResponse) SetAccounts ¶
func (x *AccountsResponse) SetAccounts(v []*AccountBalance)
func (*AccountsResponse) String ¶
func (x *AccountsResponse) String() string
type AccountsResponse_builder ¶
type AccountsResponse_builder struct {
// Returns list of accounts, limited by user access
// For the game request only LNQ and this game accounts will be returned
Accounts []*AccountBalance
// contains filtered or unexported fields
}
func (AccountsResponse_builder) Build ¶
func (b0 AccountsResponse_builder) Build() *AccountsResponse
type AppliedRewardOrder ¶
type AppliedRewardOrder struct {
// Order identifier, uuid string
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
// Amount of the order for bet or win
Amount uint32 `protobuf:"varint,2,opt,name=amount,proto3" json:"amount,omitempty"`
// Order status after transaction has beed applied
Status string `protobuf:"bytes,3,opt,name=status,proto3" json:"status,omitempty"`
// Reference data that was placed into the order during the creation
Reference string `protobuf:"bytes,4,opt,name=reference,proto3" json:"reference,omitempty"`
// contains filtered or unexported fields
}
Returns order details and account state
func (*AppliedRewardOrder) GetAmount ¶
func (x *AppliedRewardOrder) GetAmount() uint32
func (*AppliedRewardOrder) GetId ¶
func (x *AppliedRewardOrder) GetId() string
func (*AppliedRewardOrder) GetReference ¶
func (x *AppliedRewardOrder) GetReference() string
func (*AppliedRewardOrder) GetStatus ¶
func (x *AppliedRewardOrder) GetStatus() string
func (*AppliedRewardOrder) ProtoMessage ¶
func (*AppliedRewardOrder) ProtoMessage()
func (*AppliedRewardOrder) ProtoReflect ¶
func (x *AppliedRewardOrder) ProtoReflect() protoreflect.Message
func (*AppliedRewardOrder) Reset ¶
func (x *AppliedRewardOrder) Reset()
func (*AppliedRewardOrder) SetAmount ¶
func (x *AppliedRewardOrder) SetAmount(v uint32)
func (*AppliedRewardOrder) SetId ¶
func (x *AppliedRewardOrder) SetId(v string)
func (*AppliedRewardOrder) SetReference ¶
func (x *AppliedRewardOrder) SetReference(v string)
func (*AppliedRewardOrder) SetStatus ¶
func (x *AppliedRewardOrder) SetStatus(v string)
func (*AppliedRewardOrder) String ¶
func (x *AppliedRewardOrder) String() string
type AppliedRewardOrder_builder ¶
type AppliedRewardOrder_builder struct {
// Order identifier, uuid string
Id string
// Amount of the order for bet or win
Amount uint32
// Order status after transaction has beed applied
Status string
// Reference data that was placed into the order during the creation
Reference string
// contains filtered or unexported fields
}
func (AppliedRewardOrder_builder) Build ¶
func (b0 AppliedRewardOrder_builder) Build() *AppliedRewardOrder
type Balance ¶
type Balance struct {
// Current balance of the account in coins
Current uint32 `protobuf:"varint,1,opt,name=current,proto3" json:"current,omitempty"`
// Available to spend balance of the user in coins
Available uint32 `protobuf:"varint,2,opt,name=available,proto3" json:"available,omitempty"`
// contains filtered or unexported fields
}
Object containing current and available balances Values presented in currency coins, which means that values should be devided by 100
func (*Balance) ProtoReflect ¶
func (x *Balance) ProtoReflect() protoreflect.Message
type Balance_builder ¶
type Balance_builder struct {
// Current balance of the account in coins
Current uint32
// Available to spend balance of the user in coins
Available uint32
// contains filtered or unexported fields
}
func (Balance_builder) Build ¶
func (b0 Balance_builder) Build() *Balance
type CustomRewardRequest ¶
type CustomRewardRequest struct {
// Amount of money for reward in coins
Amount int32 `protobuf:"varint,1,opt,name=amount,proto3" json:"amount,omitempty"`
// Reason for the reward, has to be explained
Reason string `protobuf:"bytes,2,opt,name=reason,proto3" json:"reason,omitempty"`
// Reference to the transaction, if any
Reference *string `protobuf:"bytes,3,opt,name=reference,proto3,oneof" json:"reference,omitempty"`
// contains filtered or unexported fields
}
Request to apply custom reward to the user account
func (*CustomRewardRequest) ClearReference ¶
func (x *CustomRewardRequest) ClearReference()
func (*CustomRewardRequest) GetAmount ¶
func (x *CustomRewardRequest) GetAmount() int32
func (*CustomRewardRequest) GetReason ¶
func (x *CustomRewardRequest) GetReason() string
func (*CustomRewardRequest) GetReference ¶
func (x *CustomRewardRequest) GetReference() string
func (*CustomRewardRequest) HasReference ¶
func (x *CustomRewardRequest) HasReference() bool
func (*CustomRewardRequest) ProtoMessage ¶
func (*CustomRewardRequest) ProtoMessage()
func (*CustomRewardRequest) ProtoReflect ¶
func (x *CustomRewardRequest) ProtoReflect() protoreflect.Message
func (*CustomRewardRequest) Reset ¶
func (x *CustomRewardRequest) Reset()
func (*CustomRewardRequest) SetAmount ¶
func (x *CustomRewardRequest) SetAmount(v int32)
func (*CustomRewardRequest) SetReason ¶
func (x *CustomRewardRequest) SetReason(v string)
func (*CustomRewardRequest) SetReference ¶
func (x *CustomRewardRequest) SetReference(v string)
func (*CustomRewardRequest) String ¶
func (x *CustomRewardRequest) String() string
type CustomRewardRequest_builder ¶
type CustomRewardRequest_builder struct {
// Amount of money for reward in coins
Amount int32
// Reason for the reward, has to be explained
Reason string
// Reference to the transaction, if any
Reference *string
// contains filtered or unexported fields
}
func (CustomRewardRequest_builder) Build ¶
func (b0 CustomRewardRequest_builder) Build() *CustomRewardRequest
Source Files
¶
- accounts.pb.go
Click to show internal directories.
Click to hide internal directories.