sessionsv1

package
v1.36.11-2025102014451... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var File_linq_play_sessions_v1_sessions_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type CompleteSessionRequest

type CompleteSessionRequest struct {

	// Session identifier created on init
	Session string `protobuf:"bytes,1,opt,name=session,proto3" json:"session,omitempty"`
	// Final leaderboard table for the tournament
	Positions []*Position `protobuf:"bytes,2,rep,name=positions,proto3" json:"positions,omitempty"`
	// Timestamp when the session was completed
	CompletedAt *timestamppb.Timestamp `protobuf:"bytes,3,opt,name=completed_at,json=completedAt,proto3,oneof" json:"completed_at,omitempty"`
	// contains filtered or unexported fields
}

Params for stopping play session

func (*CompleteSessionRequest) ClearCompletedAt

func (x *CompleteSessionRequest) ClearCompletedAt()

func (*CompleteSessionRequest) GetCompletedAt

func (x *CompleteSessionRequest) GetCompletedAt() *timestamppb.Timestamp

func (*CompleteSessionRequest) GetPositions

func (x *CompleteSessionRequest) GetPositions() []*Position

func (*CompleteSessionRequest) GetSession

func (x *CompleteSessionRequest) GetSession() string

func (*CompleteSessionRequest) HasCompletedAt

func (x *CompleteSessionRequest) HasCompletedAt() bool

func (*CompleteSessionRequest) ProtoMessage

func (*CompleteSessionRequest) ProtoMessage()

func (*CompleteSessionRequest) ProtoReflect

func (x *CompleteSessionRequest) ProtoReflect() protoreflect.Message

func (*CompleteSessionRequest) Reset

func (x *CompleteSessionRequest) Reset()

func (*CompleteSessionRequest) SetCompletedAt

func (x *CompleteSessionRequest) SetCompletedAt(v *timestamppb.Timestamp)

func (*CompleteSessionRequest) SetPositions

func (x *CompleteSessionRequest) SetPositions(v []*Position)

func (*CompleteSessionRequest) SetSession

func (x *CompleteSessionRequest) SetSession(v string)

func (*CompleteSessionRequest) String

func (x *CompleteSessionRequest) String() string

type CompleteSessionRequest_builder

type CompleteSessionRequest_builder struct {

	// Session identifier created on init
	Session string
	// Final leaderboard table for the tournament
	Positions []*Position
	// Timestamp when the session was completed
	CompletedAt *timestamppb.Timestamp
	// contains filtered or unexported fields
}

func (CompleteSessionRequest_builder) Build

type Conditions

type Conditions struct {

	// Total prize pool for the tournament
	Prize int32 `protobuf:"varint,1,opt,name=prize,proto3" json:"prize,omitempty"`
	// Entry fee for the tournament
	Entry int32 `protobuf:"varint,2,opt,name=entry,proto3" json:"entry,omitempty"`
	// contains filtered or unexported fields
}

Information about the prize pool and entry fee

func (*Conditions) GetEntry

func (x *Conditions) GetEntry() int32

func (*Conditions) GetPrize

func (x *Conditions) GetPrize() int32

func (*Conditions) ProtoMessage

func (*Conditions) ProtoMessage()

func (*Conditions) ProtoReflect

func (x *Conditions) ProtoReflect() protoreflect.Message

func (*Conditions) Reset

func (x *Conditions) Reset()

func (*Conditions) SetEntry

func (x *Conditions) SetEntry(v int32)

func (*Conditions) SetPrize

func (x *Conditions) SetPrize(v int32)

func (*Conditions) String

func (x *Conditions) String() string

type Conditions_builder

type Conditions_builder struct {

	// Total prize pool for the tournament
	Prize int32
	// Entry fee for the tournament
	Entry int32
	// contains filtered or unexported fields
}

func (Conditions_builder) Build

func (b0 Conditions_builder) Build() *Conditions

type DissolveSessionRequest

type DissolveSessionRequest struct {

	// Session identifier created on init
	Session string `protobuf:"bytes,1,opt,name=session,proto3" json:"session,omitempty"`
	// Reason why session was dropped, in free form
	Reason string `protobuf:"bytes,2,opt,name=reason,proto3" json:"reason,omitempty"`
	// Timestamp when the session was completed
	CompletedAt *timestamppb.Timestamp `protobuf:"bytes,5,opt,name=completed_at,json=completedAt,proto3,oneof" json:"completed_at,omitempty"`
	// contains filtered or unexported fields
}

Params for terminating play session

func (*DissolveSessionRequest) ClearCompletedAt

func (x *DissolveSessionRequest) ClearCompletedAt()

func (*DissolveSessionRequest) GetCompletedAt

func (x *DissolveSessionRequest) GetCompletedAt() *timestamppb.Timestamp

func (*DissolveSessionRequest) GetReason

func (x *DissolveSessionRequest) GetReason() string

func (*DissolveSessionRequest) GetSession

func (x *DissolveSessionRequest) GetSession() string

func (*DissolveSessionRequest) HasCompletedAt

func (x *DissolveSessionRequest) HasCompletedAt() bool

func (*DissolveSessionRequest) ProtoMessage

func (*DissolveSessionRequest) ProtoMessage()

func (*DissolveSessionRequest) ProtoReflect

func (x *DissolveSessionRequest) ProtoReflect() protoreflect.Message

func (*DissolveSessionRequest) Reset

func (x *DissolveSessionRequest) Reset()

func (*DissolveSessionRequest) SetCompletedAt

func (x *DissolveSessionRequest) SetCompletedAt(v *timestamppb.Timestamp)

func (*DissolveSessionRequest) SetReason

func (x *DissolveSessionRequest) SetReason(v string)

func (*DissolveSessionRequest) SetSession

func (x *DissolveSessionRequest) SetSession(v string)

func (*DissolveSessionRequest) String

func (x *DissolveSessionRequest) String() string

type DissolveSessionRequest_builder

type DissolveSessionRequest_builder struct {

	// Session identifier created on init
	Session string
	// Reason why session was dropped, in free form
	Reason string
	// Timestamp when the session was completed
	CompletedAt *timestamppb.Timestamp
	// contains filtered or unexported fields
}

func (DissolveSessionRequest_builder) Build

type InitiateSessionRequest

type InitiateSessionRequest struct {

	// Number of seats, like number of players in tournament
	Seats int32 `protobuf:"varint,1,opt,name=seats,proto3" json:"seats,omitempty"`
	// Detailed information about the prize pool and entry fee
	// Key is a currency code in 3-letter format by ISO 4217
	// Value is a prize pool and entry fee in cents
	Rates map[string]*Conditions `` /* 137-byte string literal not displayed */
	// Title or human readable name of the game, tournament, etc
	Title *string `protobuf:"bytes,3,opt,name=title,proto3,oneof" json:"title,omitempty"`
	// Timestamp when the session was initiated
	InitiatedAt *timestamppb.Timestamp `protobuf:"bytes,4,opt,name=initiated_at,json=initiatedAt,proto3,oneof" json:"initiated_at,omitempty"`
	// contains filtered or unexported fields
}

Params for creating a new play session

func (*InitiateSessionRequest) ClearInitiatedAt

func (x *InitiateSessionRequest) ClearInitiatedAt()

func (*InitiateSessionRequest) ClearTitle

func (x *InitiateSessionRequest) ClearTitle()

func (*InitiateSessionRequest) GetInitiatedAt

func (x *InitiateSessionRequest) GetInitiatedAt() *timestamppb.Timestamp

func (*InitiateSessionRequest) GetRates

func (x *InitiateSessionRequest) GetRates() map[string]*Conditions

func (*InitiateSessionRequest) GetSeats

func (x *InitiateSessionRequest) GetSeats() int32

func (*InitiateSessionRequest) GetTitle

func (x *InitiateSessionRequest) GetTitle() string

func (*InitiateSessionRequest) HasInitiatedAt

func (x *InitiateSessionRequest) HasInitiatedAt() bool

func (*InitiateSessionRequest) HasTitle

func (x *InitiateSessionRequest) HasTitle() bool

func (*InitiateSessionRequest) ProtoMessage

func (*InitiateSessionRequest) ProtoMessage()

func (*InitiateSessionRequest) ProtoReflect

func (x *InitiateSessionRequest) ProtoReflect() protoreflect.Message

func (*InitiateSessionRequest) Reset

func (x *InitiateSessionRequest) Reset()

func (*InitiateSessionRequest) SetInitiatedAt

func (x *InitiateSessionRequest) SetInitiatedAt(v *timestamppb.Timestamp)

func (*InitiateSessionRequest) SetRates

func (x *InitiateSessionRequest) SetRates(v map[string]*Conditions)

func (*InitiateSessionRequest) SetSeats

func (x *InitiateSessionRequest) SetSeats(v int32)

func (*InitiateSessionRequest) SetTitle

func (x *InitiateSessionRequest) SetTitle(v string)

func (*InitiateSessionRequest) String

func (x *InitiateSessionRequest) String() string

type InitiateSessionRequest_builder

type InitiateSessionRequest_builder struct {

	// Number of seats, like number of players in tournament
	Seats int32
	// Detailed information about the prize pool and entry fee
	// Key is a currency code in 3-letter format by ISO 4217
	// Value is a prize pool and entry fee in cents
	Rates map[string]*Conditions
	// Title or human readable name of the game, tournament, etc
	Title *string
	// Timestamp when the session was initiated
	InitiatedAt *timestamppb.Timestamp
	// contains filtered or unexported fields
}

func (InitiateSessionRequest_builder) Build

type Position

type Position struct {

	// Remote player ID returned on Join request
	Player string `protobuf:"bytes,1,opt,name=player,proto3" json:"player,omitempty"`
	// Place taken by the player
	Place int32 `protobuf:"varint,2,opt,name=place,proto3" json:"place,omitempty"`
	// Prize that has to be paid to the player
	Prize int32 `protobuf:"varint,3,opt,name=prize,proto3" json:"prize,omitempty"`
	// Bonus that has to be paid to the player
	Bonus int32 `protobuf:"varint,4,opt,name=bonus,proto3" json:"bonus,omitempty"`
	// Score earned by the player
	Score *int32 `protobuf:"varint,5,opt,name=score,proto3,oneof" json:"score,omitempty"`
	// Duration spend by the player, in seconds
	Duration *int32 `protobuf:"varint,6,opt,name=duration,proto3,oneof" json:"duration,omitempty"`
	// Reference data that was placed into the order during the creation
	// Will be applied only when spread is true
	Reference *string `protobuf:"bytes,7,opt,name=reference,proto3,oneof" json:"reference,omitempty"`
	// Additional gaming data for further analysis
	Telemetry *string `protobuf:"bytes,8,opt,name=telemetry,proto3,oneof" json:"telemetry,omitempty"`
	// Timestamp when the player exited the game
	ExitedAt *timestamppb.Timestamp `protobuf:"bytes,9,opt,name=exited_at,json=exitedAt,proto3,oneof" json:"exited_at,omitempty"`
	// contains filtered or unexported fields
}

Agregated player info after game finished

func (*Position) ClearDuration

func (x *Position) ClearDuration()

func (*Position) ClearExitedAt

func (x *Position) ClearExitedAt()

func (*Position) ClearReference

func (x *Position) ClearReference()

func (*Position) ClearScore

func (x *Position) ClearScore()

func (*Position) ClearTelemetry

func (x *Position) ClearTelemetry()

func (*Position) GetBonus

func (x *Position) GetBonus() int32

func (*Position) GetDuration

func (x *Position) GetDuration() int32

func (*Position) GetExitedAt

func (x *Position) GetExitedAt() *timestamppb.Timestamp

func (*Position) GetPlace

func (x *Position) GetPlace() int32

func (*Position) GetPlayer

func (x *Position) GetPlayer() string

func (*Position) GetPrize

func (x *Position) GetPrize() int32

func (*Position) GetReference

func (x *Position) GetReference() string

func (*Position) GetScore

func (x *Position) GetScore() int32

func (*Position) GetTelemetry

func (x *Position) GetTelemetry() string

func (*Position) HasDuration

func (x *Position) HasDuration() bool

func (*Position) HasExitedAt

func (x *Position) HasExitedAt() bool

func (*Position) HasReference

func (x *Position) HasReference() bool

func (*Position) HasScore

func (x *Position) HasScore() bool

func (*Position) HasTelemetry

func (x *Position) HasTelemetry() bool

func (*Position) ProtoMessage

func (*Position) ProtoMessage()

func (*Position) ProtoReflect

func (x *Position) ProtoReflect() protoreflect.Message

func (*Position) Reset

func (x *Position) Reset()

func (*Position) SetBonus

func (x *Position) SetBonus(v int32)

func (*Position) SetDuration

func (x *Position) SetDuration(v int32)

func (*Position) SetExitedAt

func (x *Position) SetExitedAt(v *timestamppb.Timestamp)

func (*Position) SetPlace

func (x *Position) SetPlace(v int32)

func (*Position) SetPlayer

func (x *Position) SetPlayer(v string)

func (*Position) SetPrize

func (x *Position) SetPrize(v int32)

func (*Position) SetReference

func (x *Position) SetReference(v string)

func (*Position) SetScore

func (x *Position) SetScore(v int32)

func (*Position) SetTelemetry

func (x *Position) SetTelemetry(v string)

func (*Position) String

func (x *Position) String() string

type Position_builder

type Position_builder struct {

	// Remote player ID returned on Join request
	Player string
	// Place taken by the player
	Place int32
	// Prize that has to be paid to the player
	Prize int32
	// Bonus that has to be paid to the player
	Bonus int32
	// Score earned by the player
	Score *int32
	// Duration spend by the player, in seconds
	Duration *int32
	// Reference data that was placed into the order during the creation
	// Will be applied only when spread is true
	Reference *string
	// Additional gaming data for further analysis
	Telemetry *string
	// Timestamp when the player exited the game
	ExitedAt *timestamppb.Timestamp
	// contains filtered or unexported fields
}

func (Position_builder) Build

func (b0 Position_builder) Build() *Position

type UnifiedSessionResponse

type UnifiedSessionResponse struct {

	// Session identifier created on initiate stage
	Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	// Current status of the sessions on the wallet side
	Status string `protobuf:"bytes,2,opt,name=status,proto3" json:"status,omitempty"`
	// List of players that joined the session
	// It will return player with orders in case
	// when spread is true and session is completed
	Players []*v1.UnifiedPlayerResponse `protobuf:"bytes,3,rep,name=players,proto3" json:"players,omitempty"`
	// contains filtered or unexported fields
}

Response definition for InitSession

func (*UnifiedSessionResponse) GetId

func (x *UnifiedSessionResponse) GetId() string

func (*UnifiedSessionResponse) GetPlayers

func (x *UnifiedSessionResponse) GetPlayers() []*v1.UnifiedPlayerResponse

func (*UnifiedSessionResponse) GetStatus

func (x *UnifiedSessionResponse) GetStatus() string

func (*UnifiedSessionResponse) ProtoMessage

func (*UnifiedSessionResponse) ProtoMessage()

func (*UnifiedSessionResponse) ProtoReflect

func (x *UnifiedSessionResponse) ProtoReflect() protoreflect.Message

func (*UnifiedSessionResponse) Reset

func (x *UnifiedSessionResponse) Reset()

func (*UnifiedSessionResponse) SetId

func (x *UnifiedSessionResponse) SetId(v string)

func (*UnifiedSessionResponse) SetPlayers

func (x *UnifiedSessionResponse) SetPlayers(v []*v1.UnifiedPlayerResponse)

func (*UnifiedSessionResponse) SetStatus

func (x *UnifiedSessionResponse) SetStatus(v string)

func (*UnifiedSessionResponse) String

func (x *UnifiedSessionResponse) String() string

type UnifiedSessionResponse_builder

type UnifiedSessionResponse_builder struct {

	// Session identifier created on initiate stage
	Id string
	// Current status of the sessions on the wallet side
	Status string
	// List of players that joined the session
	// It will return player with orders in case
	// when spread is true and session is completed
	Players []*v1.UnifiedPlayerResponse
	// contains filtered or unexported fields
}

func (UnifiedSessionResponse_builder) Build

Source Files

  • sessions.pb.go

Jump to