shared

package
v1.36.11-2025102014493... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var File_shared_billing_address_proto protoreflect.FileDescriptor
var File_shared_user_location_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type BillingAddress

type BillingAddress struct {

	// two-letter ISO 3166 country code
	Country string `protobuf:"bytes,1,opt,name=country,proto3" json:"country,omitempty"`
	// two-letter state for US, BR
	Region string `protobuf:"bytes,2,opt,name=region,proto3" json:"region,omitempty"`
	// city
	City string `protobuf:"bytes,3,opt,name=city,proto3" json:"city,omitempty"`
	// street with apt etc
	Street string `protobuf:"bytes,4,opt,name=street,proto3" json:"street,omitempty"`
	// zip or postal code
	Zip string `protobuf:"bytes,5,opt,name=zip,proto3" json:"zip,omitempty"`
	// contains filtered or unexported fields
}

Billing address fields

func (*BillingAddress) GetCity

func (x *BillingAddress) GetCity() string

func (*BillingAddress) GetCountry

func (x *BillingAddress) GetCountry() string

func (*BillingAddress) GetRegion

func (x *BillingAddress) GetRegion() string

func (*BillingAddress) GetStreet

func (x *BillingAddress) GetStreet() string

func (*BillingAddress) GetZip

func (x *BillingAddress) GetZip() string

func (*BillingAddress) ProtoMessage

func (*BillingAddress) ProtoMessage()

func (*BillingAddress) ProtoReflect

func (x *BillingAddress) ProtoReflect() protoreflect.Message

func (*BillingAddress) Reset

func (x *BillingAddress) Reset()

func (*BillingAddress) SetCity

func (x *BillingAddress) SetCity(v string)

func (*BillingAddress) SetCountry

func (x *BillingAddress) SetCountry(v string)

func (*BillingAddress) SetRegion

func (x *BillingAddress) SetRegion(v string)

func (*BillingAddress) SetStreet

func (x *BillingAddress) SetStreet(v string)

func (*BillingAddress) SetZip

func (x *BillingAddress) SetZip(v string)

func (*BillingAddress) String

func (x *BillingAddress) String() string

type BillingAddress_builder

type BillingAddress_builder struct {

	// two-letter ISO 3166 country code
	Country string
	// two-letter state for US, BR
	Region string
	// city
	City string
	// street with apt etc
	Street string
	// zip or postal code
	Zip string
	// contains filtered or unexported fields
}

func (BillingAddress_builder) Build

type UserLocationData

type UserLocationData struct {

	// Country code, two letter by ISO
	Country string `protobuf:"bytes,1,opt,name=country,proto3" json:"country,omitempty"`
	// Country region code
	Region string `protobuf:"bytes,2,opt,name=region,proto3" json:"region,omitempty"`
	// Name of place or location, like a town or city
	City string `protobuf:"bytes,3,opt,name=city,proto3" json:"city,omitempty"`
	// contains filtered or unexported fields
}

Determined user location

func (*UserLocationData) GetCity

func (x *UserLocationData) GetCity() string

func (*UserLocationData) GetCountry

func (x *UserLocationData) GetCountry() string

func (*UserLocationData) GetRegion

func (x *UserLocationData) GetRegion() string

func (*UserLocationData) ProtoMessage

func (*UserLocationData) ProtoMessage()

func (*UserLocationData) ProtoReflect

func (x *UserLocationData) ProtoReflect() protoreflect.Message

func (*UserLocationData) Reset

func (x *UserLocationData) Reset()

func (*UserLocationData) SetCity

func (x *UserLocationData) SetCity(v string)

func (*UserLocationData) SetCountry

func (x *UserLocationData) SetCountry(v string)

func (*UserLocationData) SetRegion

func (x *UserLocationData) SetRegion(v string)

func (*UserLocationData) String

func (x *UserLocationData) String() string

type UserLocationData_builder

type UserLocationData_builder struct {

	// Country code, two letter by ISO
	Country string
	// Country region code
	Region string
	// Name of place or location, like a town or city
	City string
	// contains filtered or unexported fields
}

func (UserLocationData_builder) Build

Source Files

  • billing_address.pb.go
  • user_location.pb.go

Jump to