streamingv1connect

package
v1.20.0-20240928120844... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: GPL-3.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	// StreamingServiceCreateStreamProcedure is the fully-qualified name of the StreamingService's
	// CreateStream RPC.
	StreamingServiceCreateStreamProcedure = "/plume.api.streaming.v1.StreamingService/CreateStream"
	// StreamingServiceCloseStreamProcedure is the fully-qualified name of the StreamingService's
	// CloseStream RPC.
	StreamingServiceCloseStreamProcedure = "/plume.api.streaming.v1.StreamingService/CloseStream"
	// StreamingServiceSendStreamPacketProcedure is the fully-qualified name of the StreamingService's
	// SendStreamPacket RPC.
	StreamingServiceSendStreamPacketProcedure = "/plume.api.streaming.v1.StreamingService/SendStreamPacket"
)

These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.

Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.

const (
	// StreamingServiceName is the fully-qualified name of the StreamingService service.
	StreamingServiceName = "plume.api.streaming.v1.StreamingService"
)

Variables

This section is empty.

Functions

func NewStreamingServiceHandler

func NewStreamingServiceHandler(svc StreamingServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)

NewStreamingServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.

By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.

Types

type StreamingServiceClient

StreamingServiceClient is a client for the plume.api.streaming.v1.StreamingService service.

func NewStreamingServiceClient

func NewStreamingServiceClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) StreamingServiceClient

NewStreamingServiceClient constructs a client for the plume.api.streaming.v1.StreamingService service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.

The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).

type StreamingServiceHandler

StreamingServiceHandler is an implementation of the plume.api.streaming.v1.StreamingService service.

type UnimplementedStreamingServiceHandler

type UnimplementedStreamingServiceHandler struct{}

UnimplementedStreamingServiceHandler returns CodeUnimplemented from all methods.

func (UnimplementedStreamingServiceHandler) CloseStream

func (UnimplementedStreamingServiceHandler) CreateStream

func (UnimplementedStreamingServiceHandler) SendStreamPacket

Source Files

  • streaming.connect.go

Jump to