authv1grpc

package
v1.6.0-20240928120844-... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: GPL-3.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	AuthenticationService_Register_FullMethodName = "/plume.api.auth.v1.AuthenticationService/Register"
	AuthenticationService_Login_FullMethodName    = "/plume.api.auth.v1.AuthenticationService/Login"
)

Variables

var AuthenticationService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "plume.api.auth.v1.AuthenticationService",
	HandlerType: (*AuthenticationServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "Register",
			Handler:    _AuthenticationService_Register_Handler,
		},
		{
			MethodName: "Login",
			Handler:    _AuthenticationService_Login_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "plume/api/auth/v1/auth.proto",
}

AuthenticationService_ServiceDesc is the grpc.ServiceDesc for AuthenticationService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterAuthenticationServiceServer

func RegisterAuthenticationServiceServer(s grpc.ServiceRegistrar, srv AuthenticationServiceServer)

Types

type AuthenticationServiceClient

type AuthenticationServiceClient interface {
	Register(ctx context.Context, in *v1.RegisterRequest, opts ...grpc.CallOption) (*v1.RegisterResponse, error)
	Login(ctx context.Context, in *v1.LoginRequest, opts ...grpc.CallOption) (*v1.LoginResponse, error)
}

AuthenticationServiceClient is the client API for AuthenticationService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewAuthenticationServiceClient

func NewAuthenticationServiceClient(cc grpc.ClientConnInterface) AuthenticationServiceClient

type AuthenticationServiceServer

type AuthenticationServiceServer interface {
	Register(context.Context, *v1.RegisterRequest) (*v1.RegisterResponse, error)
	Login(context.Context, *v1.LoginRequest) (*v1.LoginResponse, error)
}

AuthenticationServiceServer is the server API for AuthenticationService service. All implementations should embed UnimplementedAuthenticationServiceServer for forward compatibility.

type UnimplementedAuthenticationServiceServer

type UnimplementedAuthenticationServiceServer struct{}

UnimplementedAuthenticationServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedAuthenticationServiceServer) Login

func (UnimplementedAuthenticationServiceServer) Register

type UnsafeAuthenticationServiceServer

type UnsafeAuthenticationServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeAuthenticationServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to AuthenticationServiceServer will result in compilation errors.

Source Files

  • auth_grpc.pb.go

Jump to