streamingv1grpc

package
v1.6.1-20240928120844-... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: GPL-3.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	StreamingService_CreateStream_FullMethodName     = "/plume.api.streaming.v1.StreamingService/CreateStream"
	StreamingService_CloseStream_FullMethodName      = "/plume.api.streaming.v1.StreamingService/CloseStream"
	StreamingService_SendStreamPacket_FullMethodName = "/plume.api.streaming.v1.StreamingService/SendStreamPacket"
)

Variables

var StreamingService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "plume.api.streaming.v1.StreamingService",
	HandlerType: (*StreamingServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "CreateStream",
			Handler:    _StreamingService_CreateStream_Handler,
		},
		{
			MethodName: "CloseStream",
			Handler:    _StreamingService_CloseStream_Handler,
		},
	},
	Streams: []grpc.StreamDesc{
		{
			StreamName:    "SendStreamPacket",
			Handler:       _StreamingService_SendStreamPacket_Handler,
			ClientStreams: true,
		},
	},
	Metadata: "plume/api/streaming/v1/streaming.proto",
}

StreamingService_ServiceDesc is the grpc.ServiceDesc for StreamingService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterStreamingServiceServer

func RegisterStreamingServiceServer(s grpc.ServiceRegistrar, srv StreamingServiceServer)

Types

type StreamingServiceClient

type StreamingServiceClient interface {
	CreateStream(ctx context.Context, in *v1.CreateStreamRequest, opts ...grpc.CallOption) (*v1.CreateStreamResponse, error)
	CloseStream(ctx context.Context, in *v1.CloseStreamRequest, opts ...grpc.CallOption) (*v1.CloseStreamResponse, error)
	SendStreamPacket(ctx context.Context, opts ...grpc.CallOption) (grpc.ClientStreamingClient[v1.SendStreamPacketRequest, v1.SendStreamPacketResponse], error)
}

StreamingServiceClient is the client API for StreamingService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewStreamingServiceClient

func NewStreamingServiceClient(cc grpc.ClientConnInterface) StreamingServiceClient

type StreamingServiceServer

StreamingServiceServer is the server API for StreamingService service. All implementations should embed UnimplementedStreamingServiceServer for forward compatibility.

type StreamingService_SendStreamPacketClient

type StreamingService_SendStreamPacketClient = grpc.ClientStreamingClient[v1.SendStreamPacketRequest, v1.SendStreamPacketResponse]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type StreamingService_SendStreamPacketServer

type StreamingService_SendStreamPacketServer = grpc.ClientStreamingServer[v1.SendStreamPacketRequest, v1.SendStreamPacketResponse]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type UnimplementedStreamingServiceServer

type UnimplementedStreamingServiceServer struct{}

UnimplementedStreamingServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedStreamingServiceServer) CloseStream

func (UnimplementedStreamingServiceServer) CreateStream

func (UnimplementedStreamingServiceServer) SendStreamPacket

type UnsafeStreamingServiceServer

type UnsafeStreamingServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeStreamingServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to StreamingServiceServer will result in compilation errors.

Source Files

  • streaming_grpc.pb.go

Jump to