authv1connect

package
v1.19.1-20240902232541... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: GPL-3.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	// AuthServiceRegisterProcedure is the fully-qualified name of the AuthService's Register RPC.
	AuthServiceRegisterProcedure = "/listenup.auth.v1.AuthService/Register"
	// AuthServiceLoginProcedure is the fully-qualified name of the AuthService's Login RPC.
	AuthServiceLoginProcedure = "/listenup.auth.v1.AuthService/Login"
	// AuthServiceRefreshTokenProcedure is the fully-qualified name of the AuthService's RefreshToken
	// RPC.
	AuthServiceRefreshTokenProcedure = "/listenup.auth.v1.AuthService/RefreshToken"
)

These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.

Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.

const (
	// AuthServiceName is the fully-qualified name of the AuthService service.
	AuthServiceName = "listenup.auth.v1.AuthService"
)

Variables

This section is empty.

Functions

func NewAuthServiceHandler

func NewAuthServiceHandler(svc AuthServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)

NewAuthServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.

By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.

Types

type AuthServiceClient

type AuthServiceClient interface {
	// Registers a user and creates a [User] object behind the scenes
	Register(context.Context, *connect.Request[v1.RegisterRequest]) (*connect.Response[v1.RegisterResponse], error)
	// Logs the user in
	Login(context.Context, *connect.Request[v1.LoginRequest]) (*connect.Response[v1.LoginResponse], error)
	// Refreshes a users access token
	RefreshToken(context.Context, *connect.Request[v1.RefreshTokenRequest]) (*connect.Response[v1.RefreshTokenResponse], error)
}

AuthServiceClient is a client for the listenup.auth.v1.AuthService service.

func NewAuthServiceClient

func NewAuthServiceClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) AuthServiceClient

NewAuthServiceClient constructs a client for the listenup.auth.v1.AuthService service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.

The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).

type AuthServiceHandler

type AuthServiceHandler interface {
	// Registers a user and creates a [User] object behind the scenes
	Register(context.Context, *connect.Request[v1.RegisterRequest]) (*connect.Response[v1.RegisterResponse], error)
	// Logs the user in
	Login(context.Context, *connect.Request[v1.LoginRequest]) (*connect.Response[v1.LoginResponse], error)
	// Refreshes a users access token
	RefreshToken(context.Context, *connect.Request[v1.RefreshTokenRequest]) (*connect.Response[v1.RefreshTokenResponse], error)
}

AuthServiceHandler is an implementation of the listenup.auth.v1.AuthService service.

type UnimplementedAuthServiceHandler

type UnimplementedAuthServiceHandler struct{}

UnimplementedAuthServiceHandler returns CodeUnimplemented from all methods.

func (UnimplementedAuthServiceHandler) Login

func (UnimplementedAuthServiceHandler) RefreshToken

func (UnimplementedAuthServiceHandler) Register

Source Files

  • auth.connect.go

Jump to