folderv1connect

package
v1.19.1-20240902232541... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: GPL-3.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	// FolderServiceGetFolderProcedure is the fully-qualified name of the FolderService's GetFolder RPC.
	FolderServiceGetFolderProcedure = "/listenup.folder.v1.FolderService/GetFolder"
)

These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.

Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.

const (
	// FolderServiceName is the fully-qualified name of the FolderService service.
	FolderServiceName = "listenup.folder.v1.FolderService"
)

Variables

This section is empty.

Functions

func NewFolderServiceHandler

func NewFolderServiceHandler(svc FolderServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)

NewFolderServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.

By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.

Types

type FolderServiceClient

type FolderServiceClient interface {
	// Gets a folder on the host machines hard drive
	GetFolder(context.Context, *connect.Request[v1.GetFolderRequest]) (*connect.Response[v1.GetFolderResponse], error)
}

FolderServiceClient is a client for the listenup.folder.v1.FolderService service.

func NewFolderServiceClient

func NewFolderServiceClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) FolderServiceClient

NewFolderServiceClient constructs a client for the listenup.folder.v1.FolderService service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.

The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).

type FolderServiceHandler

type FolderServiceHandler interface {
	// Gets a folder on the host machines hard drive
	GetFolder(context.Context, *connect.Request[v1.GetFolderRequest]) (*connect.Response[v1.GetFolderResponse], error)
}

FolderServiceHandler is an implementation of the listenup.folder.v1.FolderService service.

type UnimplementedFolderServiceHandler

type UnimplementedFolderServiceHandler struct{}

UnimplementedFolderServiceHandler returns CodeUnimplemented from all methods.

func (UnimplementedFolderServiceHandler) GetFolder

Source Files

  • folder.connect.go

Jump to