permissionv1connect

package
v1.19.1-20240902232541... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: GPL-3.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

const (
	// PermissionServiceName is the fully-qualified name of the PermissionService service.
	PermissionServiceName = "listenup.permission.v1.PermissionService"
)

Variables

This section is empty.

Functions

func NewPermissionServiceHandler

func NewPermissionServiceHandler(svc PermissionServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)

NewPermissionServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.

By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.

Types

type PermissionServiceClient

type PermissionServiceClient interface {
}

PermissionServiceClient is a client for the listenup.permission.v1.PermissionService service.

func NewPermissionServiceClient

func NewPermissionServiceClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) PermissionServiceClient

NewPermissionServiceClient constructs a client for the listenup.permission.v1.PermissionService service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.

The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).

type PermissionServiceHandler

type PermissionServiceHandler interface {
}

PermissionServiceHandler is an implementation of the listenup.permission.v1.PermissionService service.

type UnimplementedPermissionServiceHandler

type UnimplementedPermissionServiceHandler struct{}

UnimplementedPermissionServiceHandler returns CodeUnimplemented from all methods.

Source Files

  • permission.connect.go

Jump to