Documentation
¶
Index ¶
Constants ¶
const ( // ServerServicePingProcedure is the fully-qualified name of the ServerService's Ping RPC. ServerServicePingProcedure = "/listenup.server.v1.ServerService/Ping" // ServerServiceGetServerProcedure is the fully-qualified name of the ServerService's GetServer RPC. ServerServiceGetServerProcedure = "/listenup.server.v1.ServerService/GetServer" )
These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.
Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.
const (
// ServerServiceName is the fully-qualified name of the ServerService service.
ServerServiceName = "listenup.server.v1.ServerService"
)
Variables ¶
This section is empty.
Functions ¶
func NewServerServiceHandler ¶
func NewServerServiceHandler(svc ServerServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
NewServerServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.
By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.
Types ¶
type ServerServiceClient ¶
type ServerServiceClient interface {
// Ping method to check server responsiveness
Ping(context.Context, *connect.Request[v1.PingRequest]) (*connect.Response[v1.PingResponse], error)
// Gets a copy of the server and it's configuration details
GetServer(context.Context, *connect.Request[v1.GetServerRequest]) (*connect.Response[v1.GetServerResponse], error)
}
ServerServiceClient is a client for the listenup.server.v1.ServerService service.
func NewServerServiceClient ¶
func NewServerServiceClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) ServerServiceClient
NewServerServiceClient constructs a client for the listenup.server.v1.ServerService service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.
The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).
type ServerServiceHandler ¶
type ServerServiceHandler interface {
// Ping method to check server responsiveness
Ping(context.Context, *connect.Request[v1.PingRequest]) (*connect.Response[v1.PingResponse], error)
// Gets a copy of the server and it's configuration details
GetServer(context.Context, *connect.Request[v1.GetServerRequest]) (*connect.Response[v1.GetServerResponse], error)
}
ServerServiceHandler is an implementation of the listenup.server.v1.ServerService service.
type UnimplementedServerServiceHandler ¶
type UnimplementedServerServiceHandler struct{}
UnimplementedServerServiceHandler returns CodeUnimplemented from all methods.
func (UnimplementedServerServiceHandler) GetServer ¶
func (UnimplementedServerServiceHandler) GetServer(context.Context, *connect.Request[v1.GetServerRequest]) (*connect.Response[v1.GetServerResponse], error)
func (UnimplementedServerServiceHandler) Ping ¶
func (UnimplementedServerServiceHandler) Ping(context.Context, *connect.Request[v1.PingRequest]) (*connect.Response[v1.PingResponse], error)
Source Files
¶
- server.connect.go