permissionv1grpc

package
v1.6.1-20240902232541-... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: GPL-3.0 Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var PermissionService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "listenup.permission.v1.PermissionService",
	HandlerType: (*PermissionServiceServer)(nil),
	Methods:     []grpc.MethodDesc{},
	Streams:     []grpc.StreamDesc{},
	Metadata:    "listenup/permission/v1/permission.proto",
}

PermissionService_ServiceDesc is the grpc.ServiceDesc for PermissionService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterPermissionServiceServer

func RegisterPermissionServiceServer(s grpc.ServiceRegistrar, srv PermissionServiceServer)

Types

type PermissionServiceClient

type PermissionServiceClient interface {
}

PermissionServiceClient is the client API for PermissionService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

Service for managing permissions

func NewPermissionServiceClient

func NewPermissionServiceClient(cc grpc.ClientConnInterface) PermissionServiceClient

type PermissionServiceServer

type PermissionServiceServer interface {
}

PermissionServiceServer is the server API for PermissionService service. All implementations should embed UnimplementedPermissionServiceServer for forward compatibility.

Service for managing permissions

type UnimplementedPermissionServiceServer

type UnimplementedPermissionServiceServer struct{}

UnimplementedPermissionServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

type UnsafePermissionServiceServer

type UnsafePermissionServiceServer interface {
	// contains filtered or unexported methods
}

UnsafePermissionServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to PermissionServiceServer will result in compilation errors.

Source Files

  • permission_grpc.pb.go

Jump to