serverv1grpc

package
v1.6.2-20240902232541-... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: GPL-3.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	ServerService_Ping_FullMethodName      = "/listenup.server.v1.ServerService/Ping"
	ServerService_GetServer_FullMethodName = "/listenup.server.v1.ServerService/GetServer"
)

Variables

var ServerService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "listenup.server.v1.ServerService",
	HandlerType: (*ServerServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "Ping",
			Handler:    _ServerService_Ping_Handler,
		},
		{
			MethodName: "GetServer",
			Handler:    _ServerService_GetServer_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "listenup/server/v1/server.proto",
}

ServerService_ServiceDesc is the grpc.ServiceDesc for ServerService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterServerServiceServer

func RegisterServerServiceServer(s grpc.ServiceRegistrar, srv ServerServiceServer)

Types

type ServerServiceClient

type ServerServiceClient interface {
	// Ping method to check server responsiveness
	Ping(ctx context.Context, in *v1.PingRequest, opts ...grpc.CallOption) (*v1.PingResponse, error)
	// Gets a copy of the server and it's configuration details
	GetServer(ctx context.Context, in *v1.GetServerRequest, opts ...grpc.CallOption) (*v1.GetServerResponse, error)
}

ServerServiceClient is the client API for ServerService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

Service definition for server operations

func NewServerServiceClient

func NewServerServiceClient(cc grpc.ClientConnInterface) ServerServiceClient

type ServerServiceServer

type ServerServiceServer interface {
	// Ping method to check server responsiveness
	Ping(context.Context, *v1.PingRequest) (*v1.PingResponse, error)
	// Gets a copy of the server and it's configuration details
	GetServer(context.Context, *v1.GetServerRequest) (*v1.GetServerResponse, error)
}

ServerServiceServer is the server API for ServerService service. All implementations should embed UnimplementedServerServiceServer for forward compatibility.

Service definition for server operations

type UnimplementedServerServiceServer

type UnimplementedServerServiceServer struct{}

UnimplementedServerServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedServerServiceServer) GetServer

func (UnimplementedServerServiceServer) Ping

type UnsafeServerServiceServer

type UnsafeServerServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeServerServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ServerServiceServer will result in compilation errors.

Source Files

  • server_grpc.pb.go

Jump to