serverv1

package
v1.36.11-2024090223254... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: GPL-3.0 Imports: 4 Imported by: 2

Documentation

Index

Constants

This section is empty.

Variables

var File_listenup_server_v1_server_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type GetServerRequest

type GetServerRequest struct {
	// contains filtered or unexported fields
}

Empty request to get a copy of the servers information

func (*GetServerRequest) ProtoMessage

func (*GetServerRequest) ProtoMessage()

func (*GetServerRequest) ProtoReflect

func (x *GetServerRequest) ProtoReflect() protoreflect.Message

func (*GetServerRequest) Reset

func (x *GetServerRequest) Reset()

func (*GetServerRequest) String

func (x *GetServerRequest) String() string

type GetServerRequest_builder

type GetServerRequest_builder struct {
	// contains filtered or unexported fields
}

func (GetServerRequest_builder) Build

type GetServerResponse

type GetServerResponse struct {
	Server *Server `protobuf:"bytes,1,opt,name=server,proto3" json:"server,omitempty"`
	// contains filtered or unexported fields
}

Returns a copy of the server with configuration info

func (*GetServerResponse) ClearServer

func (x *GetServerResponse) ClearServer()

func (*GetServerResponse) GetServer

func (x *GetServerResponse) GetServer() *Server

func (*GetServerResponse) HasServer

func (x *GetServerResponse) HasServer() bool

func (*GetServerResponse) ProtoMessage

func (*GetServerResponse) ProtoMessage()

func (*GetServerResponse) ProtoReflect

func (x *GetServerResponse) ProtoReflect() protoreflect.Message

func (*GetServerResponse) Reset

func (x *GetServerResponse) Reset()

func (*GetServerResponse) SetServer

func (x *GetServerResponse) SetServer(v *Server)

func (*GetServerResponse) String

func (x *GetServerResponse) String() string

type GetServerResponse_builder

type GetServerResponse_builder struct {
	Server *Server
	// contains filtered or unexported fields
}

func (GetServerResponse_builder) Build

type PingRequest

type PingRequest struct {
	// contains filtered or unexported fields
}

Request message for the Ping method

func (*PingRequest) ProtoMessage

func (*PingRequest) ProtoMessage()

func (*PingRequest) ProtoReflect

func (x *PingRequest) ProtoReflect() protoreflect.Message

func (*PingRequest) Reset

func (x *PingRequest) Reset()

func (*PingRequest) String

func (x *PingRequest) String() string

type PingRequest_builder

type PingRequest_builder struct {
	// contains filtered or unexported fields
}

func (PingRequest_builder) Build

func (b0 PingRequest_builder) Build() *PingRequest

type PingResponse

type PingResponse struct {
	Message   string `protobuf:"bytes,1,opt,name=message,proto3" json:"message,omitempty"`
	Timestamp int64  `protobuf:"varint,2,opt,name=timestamp,proto3" json:"timestamp,omitempty"`
	// contains filtered or unexported fields
}

Response message for the Ping method

func (*PingResponse) GetMessage

func (x *PingResponse) GetMessage() string

func (*PingResponse) GetTimestamp

func (x *PingResponse) GetTimestamp() int64

func (*PingResponse) ProtoMessage

func (*PingResponse) ProtoMessage()

func (*PingResponse) ProtoReflect

func (x *PingResponse) ProtoReflect() protoreflect.Message

func (*PingResponse) Reset

func (x *PingResponse) Reset()

func (*PingResponse) SetMessage

func (x *PingResponse) SetMessage(v string)

func (*PingResponse) SetTimestamp

func (x *PingResponse) SetTimestamp(v int64)

func (*PingResponse) String

func (x *PingResponse) String() string

type PingResponse_builder

type PingResponse_builder struct {
	Message   string
	Timestamp int64
	// contains filtered or unexported fields
}

func (PingResponse_builder) Build

func (b0 PingResponse_builder) Build() *PingResponse

type Server

type Server struct {

	// Whether the server has a root user or not.
	IsSetUp bool `protobuf:"varint,1,opt,name=is_set_up,json=isSetUp,proto3" json:"is_set_up,omitempty"`
	// The config for the server
	Config *ServerConfig `protobuf:"bytes,2,opt,name=config,proto3" json:"config,omitempty"`
	// contains filtered or unexported fields
}

Defines a ListenUp Server

func (*Server) ClearConfig

func (x *Server) ClearConfig()

func (*Server) GetConfig

func (x *Server) GetConfig() *ServerConfig

func (*Server) GetIsSetUp

func (x *Server) GetIsSetUp() bool

func (*Server) HasConfig

func (x *Server) HasConfig() bool

func (*Server) ProtoMessage

func (*Server) ProtoMessage()

func (*Server) ProtoReflect

func (x *Server) ProtoReflect() protoreflect.Message

func (*Server) Reset

func (x *Server) Reset()

func (*Server) SetConfig

func (x *Server) SetConfig(v *ServerConfig)

func (*Server) SetIsSetUp

func (x *Server) SetIsSetUp(v bool)

func (*Server) String

func (x *Server) String() string

type ServerConfig

type ServerConfig struct {
	ServerName string `protobuf:"bytes,1,opt,name=server_name,json=serverName,proto3" json:"server_name,omitempty"`
	// contains filtered or unexported fields
}

Holds any and all server configuration information

func (*ServerConfig) GetServerName

func (x *ServerConfig) GetServerName() string

func (*ServerConfig) ProtoMessage

func (*ServerConfig) ProtoMessage()

func (*ServerConfig) ProtoReflect

func (x *ServerConfig) ProtoReflect() protoreflect.Message

func (*ServerConfig) Reset

func (x *ServerConfig) Reset()

func (*ServerConfig) SetServerName

func (x *ServerConfig) SetServerName(v string)

func (*ServerConfig) String

func (x *ServerConfig) String() string

type ServerConfig_builder

type ServerConfig_builder struct {
	ServerName string
	// contains filtered or unexported fields
}

func (ServerConfig_builder) Build

func (b0 ServerConfig_builder) Build() *ServerConfig

type Server_builder

type Server_builder struct {

	// Whether the server has a root user or not.
	IsSetUp bool
	// The config for the server
	Config *ServerConfig
	// contains filtered or unexported fields
}

func (Server_builder) Build

func (b0 Server_builder) Build() *Server

Source Files

  • server.pb.go

Jump to