pdfservv1

package
v1.36.10-2025043004490... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: BSD-3-Clause Imports: 5 Imported by: 1

Documentation

Index

Constants

This section is empty.

Variables

var File_pdfserv_v1_pdfserv_proto protoreflect.FileDescriptor
var File_pdfserv_v1_service_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type GenerateRequest

type GenerateRequest struct {

	// The base64 string of the html to render as PDF.
	HtmlBase64 string `protobuf:"bytes,1,opt,name=html_base64,json=htmlBase64,proto3" json:"html_base64,omitempty"`
	// contains filtered or unexported fields
}

Generate a PDF by passing base64 bytes of an html document.

func (*GenerateRequest) GetHtmlBase64

func (x *GenerateRequest) GetHtmlBase64() string

func (*GenerateRequest) ProtoMessage

func (*GenerateRequest) ProtoMessage()

func (*GenerateRequest) ProtoReflect

func (x *GenerateRequest) ProtoReflect() protoreflect.Message

func (*GenerateRequest) Reset

func (x *GenerateRequest) Reset()

func (*GenerateRequest) SetHtmlBase64

func (x *GenerateRequest) SetHtmlBase64(v string)

func (*GenerateRequest) String

func (x *GenerateRequest) String() string

type GenerateRequest_builder

type GenerateRequest_builder struct {

	// The base64 string of the html to render as PDF.
	HtmlBase64 string
	// contains filtered or unexported fields
}

func (GenerateRequest_builder) Build

type GenerateResponse

type GenerateResponse struct {

	// An exception if an error occurred during processing request.
	Exception *v1.Exception `protobuf:"bytes,1,opt,name=exception,proto3" json:"exception,omitempty"`
	// Base64 encoded PDF generated from the request.
	PdfBase64 string `protobuf:"bytes,2,opt,name=pdf_base64,json=pdfBase64,proto3" json:"pdf_base64,omitempty"`
	// contains filtered or unexported fields
}

Response to PDF generation.

func (*GenerateResponse) ClearException

func (x *GenerateResponse) ClearException()

func (*GenerateResponse) GetException

func (x *GenerateResponse) GetException() *v1.Exception

func (*GenerateResponse) GetPdfBase64

func (x *GenerateResponse) GetPdfBase64() string

func (*GenerateResponse) HasException

func (x *GenerateResponse) HasException() bool

func (*GenerateResponse) ProtoMessage

func (*GenerateResponse) ProtoMessage()

func (*GenerateResponse) ProtoReflect

func (x *GenerateResponse) ProtoReflect() protoreflect.Message

func (*GenerateResponse) Reset

func (x *GenerateResponse) Reset()

func (*GenerateResponse) SetException

func (x *GenerateResponse) SetException(v *v1.Exception)

func (*GenerateResponse) SetPdfBase64

func (x *GenerateResponse) SetPdfBase64(v string)

func (*GenerateResponse) String

func (x *GenerateResponse) String() string

type GenerateResponse_builder

type GenerateResponse_builder struct {

	// An exception if an error occurred during processing request.
	Exception *v1.Exception
	// Base64 encoded PDF generated from the request.
	PdfBase64 string
	// contains filtered or unexported fields
}

func (GenerateResponse_builder) Build

Source Files

  • pdfserv.pb.go
  • service.pb.go

Jump to