Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterNodeReadServiceServer(s grpc.ServiceRegistrar, srv NodeReadServiceServer)
- type NodeReadServiceClient
- type NodeReadServiceServer
- type UnimplementedNodeReadServiceServer
- func (UnimplementedNodeReadServiceServer) GetAccount(context.Context, *v1.GetAccountRequest) (*v1.GetAccountResponse, error)
- func (UnimplementedNodeReadServiceServer) GetFullMempool(context.Context, *v1.GetFullMempoolRequest) (*v1.GetFullMempoolResponse, error)
- func (UnimplementedNodeReadServiceServer) GetFullState(context.Context, *v1.FullStateSnapshotRequest) (*v1.FullStateSnapshotResponse, error)
- func (UnimplementedNodeReadServiceServer) GetNodeType(context.Context, *v1.GetNodeTypeRequest) (*v1.GetNodeTypeResponse, error)
- func (UnimplementedNodeReadServiceServer) GetTransaction(context.Context, *v1.GetTransactionRequest) (*v1.GetTransactionResponse, error)
- func (UnimplementedNodeReadServiceServer) ListTransactions(context.Context, *v1.ListTransactionsRequest) (*v1.ListTransactionsResponse, error)
- type UnsafeNodeReadServiceServer
Constants ¶
const ( NodeReadService_GetFullState_FullMethodName = "/node_read_service.v1.NodeReadService/GetFullState" NodeReadService_GetFullMempool_FullMethodName = "/node_read_service.v1.NodeReadService/GetFullMempool" NodeReadService_GetNodeType_FullMethodName = "/node_read_service.v1.NodeReadService/GetNodeType" NodeReadService_GetTransaction_FullMethodName = "/node_read_service.v1.NodeReadService/GetTransaction" NodeReadService_ListTransactions_FullMethodName = "/node_read_service.v1.NodeReadService/ListTransactions" NodeReadService_GetAccount_FullMethodName = "/node_read_service.v1.NodeReadService/GetAccount" )
Variables ¶
var NodeReadService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "node_read_service.v1.NodeReadService", HandlerType: (*NodeReadServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "GetFullState", Handler: _NodeReadService_GetFullState_Handler, }, { MethodName: "GetFullMempool", Handler: _NodeReadService_GetFullMempool_Handler, }, { MethodName: "GetNodeType", Handler: _NodeReadService_GetNodeType_Handler, }, { MethodName: "GetTransaction", Handler: _NodeReadService_GetTransaction_Handler, }, { MethodName: "ListTransactions", Handler: _NodeReadService_ListTransactions_Handler, }, { MethodName: "GetAccount", Handler: _NodeReadService_GetAccount_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "infra/proto/node_read_service/v1/node_read_service.proto", }
NodeReadService_ServiceDesc is the grpc.ServiceDesc for NodeReadService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterNodeReadServiceServer ¶
func RegisterNodeReadServiceServer(s grpc.ServiceRegistrar, srv NodeReadServiceServer)
Types ¶
type NodeReadServiceClient ¶
type NodeReadServiceClient interface {
GetFullState(ctx context.Context, in *v1.FullStateSnapshotRequest, opts ...grpc.CallOption) (*v1.FullStateSnapshotResponse, error)
GetFullMempool(ctx context.Context, in *v1.GetFullMempoolRequest, opts ...grpc.CallOption) (*v1.GetFullMempoolResponse, error)
GetNodeType(ctx context.Context, in *v1.GetNodeTypeRequest, opts ...grpc.CallOption) (*v1.GetNodeTypeResponse, error)
GetTransaction(ctx context.Context, in *v1.GetTransactionRequest, opts ...grpc.CallOption) (*v1.GetTransactionResponse, error)
ListTransactions(ctx context.Context, in *v1.ListTransactionsRequest, opts ...grpc.CallOption) (*v1.ListTransactionsResponse, error)
GetAccount(ctx context.Context, in *v1.GetAccountRequest, opts ...grpc.CallOption) (*v1.GetAccountResponse, error)
}
NodeReadServiceClient is the client API for NodeReadService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewNodeReadServiceClient ¶
func NewNodeReadServiceClient(cc grpc.ClientConnInterface) NodeReadServiceClient
type NodeReadServiceServer ¶
type NodeReadServiceServer interface {
GetFullState(context.Context, *v1.FullStateSnapshotRequest) (*v1.FullStateSnapshotResponse, error)
GetFullMempool(context.Context, *v1.GetFullMempoolRequest) (*v1.GetFullMempoolResponse, error)
GetNodeType(context.Context, *v1.GetNodeTypeRequest) (*v1.GetNodeTypeResponse, error)
GetTransaction(context.Context, *v1.GetTransactionRequest) (*v1.GetTransactionResponse, error)
ListTransactions(context.Context, *v1.ListTransactionsRequest) (*v1.ListTransactionsResponse, error)
GetAccount(context.Context, *v1.GetAccountRequest) (*v1.GetAccountResponse, error)
}
NodeReadServiceServer is the server API for NodeReadService service. All implementations should embed UnimplementedNodeReadServiceServer for forward compatibility.
type UnimplementedNodeReadServiceServer ¶
type UnimplementedNodeReadServiceServer struct{}
UnimplementedNodeReadServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedNodeReadServiceServer) GetAccount ¶
func (UnimplementedNodeReadServiceServer) GetAccount(context.Context, *v1.GetAccountRequest) (*v1.GetAccountResponse, error)
func (UnimplementedNodeReadServiceServer) GetFullMempool ¶
func (UnimplementedNodeReadServiceServer) GetFullMempool(context.Context, *v1.GetFullMempoolRequest) (*v1.GetFullMempoolResponse, error)
func (UnimplementedNodeReadServiceServer) GetFullState ¶
func (UnimplementedNodeReadServiceServer) GetFullState(context.Context, *v1.FullStateSnapshotRequest) (*v1.FullStateSnapshotResponse, error)
func (UnimplementedNodeReadServiceServer) GetNodeType ¶
func (UnimplementedNodeReadServiceServer) GetNodeType(context.Context, *v1.GetNodeTypeRequest) (*v1.GetNodeTypeResponse, error)
func (UnimplementedNodeReadServiceServer) GetTransaction ¶
func (UnimplementedNodeReadServiceServer) GetTransaction(context.Context, *v1.GetTransactionRequest) (*v1.GetTransactionResponse, error)
func (UnimplementedNodeReadServiceServer) ListTransactions ¶
func (UnimplementedNodeReadServiceServer) ListTransactions(context.Context, *v1.ListTransactionsRequest) (*v1.ListTransactionsResponse, error)
type UnsafeNodeReadServiceServer ¶
type UnsafeNodeReadServiceServer interface {
// contains filtered or unexported methods
}
UnsafeNodeReadServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to NodeReadServiceServer will result in compilation errors.
Source Files
¶
- node_read_service_grpc.pb.go