tenantv1connect

package
v1.19.1-20251019125030... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: MIT Imports: 6 Imported by: 2

Documentation

Index

Constants

const (
	// TenantServiceCreateTenantProcedure is the fully-qualified name of the TenantService's
	// CreateTenant RPC.
	TenantServiceCreateTenantProcedure = "/iracelog.tenant.v1.TenantService/CreateTenant"
	// TenantServiceDeleteTenantProcedure is the fully-qualified name of the TenantService's
	// DeleteTenant RPC.
	TenantServiceDeleteTenantProcedure = "/iracelog.tenant.v1.TenantService/DeleteTenant"
	// TenantServiceUpdateTenantProcedure is the fully-qualified name of the TenantService's
	// UpdateTenant RPC.
	TenantServiceUpdateTenantProcedure = "/iracelog.tenant.v1.TenantService/UpdateTenant"
	// TenantServiceGetTenantProcedure is the fully-qualified name of the TenantService's GetTenant RPC.
	TenantServiceGetTenantProcedure = "/iracelog.tenant.v1.TenantService/GetTenant"
	// TenantServiceGetTenantsProcedure is the fully-qualified name of the TenantService's GetTenants
	// RPC.
	TenantServiceGetTenantsProcedure = "/iracelog.tenant.v1.TenantService/GetTenants"
	// TenantServiceReloadTenantsProcedure is the fully-qualified name of the TenantService's
	// ReloadTenants RPC.
	TenantServiceReloadTenantsProcedure = "/iracelog.tenant.v1.TenantService/ReloadTenants"
)

These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.

Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.

const (
	// TenantServiceName is the fully-qualified name of the TenantService service.
	TenantServiceName = "iracelog.tenant.v1.TenantService"
)

Variables

This section is empty.

Functions

func NewTenantServiceHandler

func NewTenantServiceHandler(svc TenantServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)

NewTenantServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.

By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.

Types

type TenantServiceClient

TenantServiceClient is a client for the iracelog.tenant.v1.TenantService service.

func NewTenantServiceClient

func NewTenantServiceClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) TenantServiceClient

NewTenantServiceClient constructs a client for the iracelog.tenant.v1.TenantService service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.

The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).

type TenantServiceHandler

TenantServiceHandler is an implementation of the iracelog.tenant.v1.TenantService service.

type UnimplementedTenantServiceHandler

type UnimplementedTenantServiceHandler struct{}

UnimplementedTenantServiceHandler returns CodeUnimplemented from all methods.

func (UnimplementedTenantServiceHandler) CreateTenant

func (UnimplementedTenantServiceHandler) DeleteTenant

func (UnimplementedTenantServiceHandler) GetTenant

func (UnimplementedTenantServiceHandler) GetTenants

func (UnimplementedTenantServiceHandler) ReloadTenants

func (UnimplementedTenantServiceHandler) UpdateTenant

Source Files

  • tenant_service.connect.go

Jump to