Documentation
¶
Index ¶
- Variables
- type Analysis
- func (x *Analysis) GetCarComputeStates() []*CarComputeState
- func (x *Analysis) GetCarLaps() []*CarLaps
- func (x *Analysis) GetCarOccupancies() []*CarOccupancy
- func (x *Analysis) GetCarPits() []*CarPit
- func (x *Analysis) GetCarStints() []*CarStint
- func (x *Analysis) GetRaceGraph() []*RaceGraph
- func (x *Analysis) GetRaceOrder() []string
- func (*Analysis) ProtoMessage()
- func (x *Analysis) ProtoReflect() protoreflect.Message
- func (x *Analysis) Reset()
- func (x *Analysis) SetCarComputeStates(v []*CarComputeState)
- func (x *Analysis) SetCarLaps(v []*CarLaps)
- func (x *Analysis) SetCarOccupancies(v []*CarOccupancy)
- func (x *Analysis) SetCarPits(v []*CarPit)
- func (x *Analysis) SetCarStints(v []*CarStint)
- func (x *Analysis) SetRaceGraph(v []*RaceGraph)
- func (x *Analysis) SetRaceOrder(v []string)
- func (x *Analysis) String() string
- type AnalysisComponent
- type AnalysisPersistMode
- type Analysis_builder
- type CarComputeState
- func (x *CarComputeState) GetCarNum() string
- func (x *CarComputeState) GetCarState() v1.CarState
- func (x *CarComputeState) GetOutEncountered() float32
- func (*CarComputeState) ProtoMessage()
- func (x *CarComputeState) ProtoReflect() protoreflect.Message
- func (x *CarComputeState) Reset()
- func (x *CarComputeState) SetCarNum(v string)
- func (x *CarComputeState) SetCarState(v v1.CarState)
- func (x *CarComputeState) SetOutEncountered(v float32)
- func (x *CarComputeState) String() string
- type CarComputeState_builder
- type CarLaps
- type CarLaps_builder
- type CarOccupancy
- func (x *CarOccupancy) GetCarClass() string
- func (x *CarOccupancy) GetCarNum() string
- func (x *CarOccupancy) GetCurrentDriverName() string
- func (x *CarOccupancy) GetDrivers() []*Driver
- func (x *CarOccupancy) GetName() string
- func (*CarOccupancy) ProtoMessage()
- func (x *CarOccupancy) ProtoReflect() protoreflect.Message
- func (x *CarOccupancy) Reset()
- func (x *CarOccupancy) SetCarClass(v string)
- func (x *CarOccupancy) SetCarNum(v string)
- func (x *CarOccupancy) SetCurrentDriverName(v string)
- func (x *CarOccupancy) SetDrivers(v []*Driver)
- func (x *CarOccupancy) SetName(v string)
- func (x *CarOccupancy) String() string
- type CarOccupancy_builder
- type CarPit
- func (x *CarPit) ClearCurrent()
- func (x *CarPit) GetCarNum() string
- func (x *CarPit) GetCurrent() *PitInfo
- func (x *CarPit) GetHistory() []*PitInfo
- func (x *CarPit) HasCurrent() bool
- func (*CarPit) ProtoMessage()
- func (x *CarPit) ProtoReflect() protoreflect.Message
- func (x *CarPit) Reset()
- func (x *CarPit) SetCarNum(v string)
- func (x *CarPit) SetCurrent(v *PitInfo)
- func (x *CarPit) SetHistory(v []*PitInfo)
- func (x *CarPit) String() string
- type CarPit_builder
- type CarStint
- func (x *CarStint) ClearCurrent()
- func (x *CarStint) GetCarNum() string
- func (x *CarStint) GetCurrent() *StintInfo
- func (x *CarStint) GetHistory() []*StintInfo
- func (x *CarStint) HasCurrent() bool
- func (*CarStint) ProtoMessage()
- func (x *CarStint) ProtoReflect() protoreflect.Message
- func (x *CarStint) Reset()
- func (x *CarStint) SetCarNum(v string)
- func (x *CarStint) SetCurrent(v *StintInfo)
- func (x *CarStint) SetHistory(v []*StintInfo)
- func (x *CarStint) String() string
- type CarStint_builder
- type ComputeAnalysisRequest
- func (x *ComputeAnalysisRequest) ClearEventSelector()
- func (x *ComputeAnalysisRequest) GetComponent() AnalysisComponent
- func (x *ComputeAnalysisRequest) GetEventSelector() *v1.EventSelector
- func (x *ComputeAnalysisRequest) GetPersistMode() AnalysisPersistMode
- func (x *ComputeAnalysisRequest) HasEventSelector() bool
- func (*ComputeAnalysisRequest) ProtoMessage()
- func (x *ComputeAnalysisRequest) ProtoReflect() protoreflect.Message
- func (x *ComputeAnalysisRequest) Reset()
- func (x *ComputeAnalysisRequest) SetComponent(v AnalysisComponent)
- func (x *ComputeAnalysisRequest) SetEventSelector(v *v1.EventSelector)
- func (x *ComputeAnalysisRequest) SetPersistMode(v AnalysisPersistMode)
- func (x *ComputeAnalysisRequest) String() string
- type ComputeAnalysisRequest_builder
- type ComputeAnalysisResponse
- func (x *ComputeAnalysisResponse) ClearAnalysis()
- func (x *ComputeAnalysisResponse) GetAnalysis() *Analysis
- func (x *ComputeAnalysisResponse) HasAnalysis() bool
- func (*ComputeAnalysisResponse) ProtoMessage()
- func (x *ComputeAnalysisResponse) ProtoReflect() protoreflect.Message
- func (x *ComputeAnalysisResponse) Reset()
- func (x *ComputeAnalysisResponse) SetAnalysis(v *Analysis)
- func (x *ComputeAnalysisResponse) String() string
- type ComputeAnalysisResponse_builder
- type Driver
- type Driver_builder
- type GapInfo
- func (x *GapInfo) GetCarNum() string
- func (x *GapInfo) GetGap() float32
- func (x *GapInfo) GetLapNo() int32
- func (x *GapInfo) GetPic() int32
- func (x *GapInfo) GetPos() int32
- func (*GapInfo) ProtoMessage()
- func (x *GapInfo) ProtoReflect() protoreflect.Message
- func (x *GapInfo) Reset()
- func (x *GapInfo) SetCarNum(v string)
- func (x *GapInfo) SetGap(v float32)
- func (x *GapInfo) SetLapNo(v int32)
- func (x *GapInfo) SetPic(v int32)
- func (x *GapInfo) SetPos(v int32)
- func (x *GapInfo) String() string
- type GapInfo_builder
- type GetAnalysisRequest
- func (x *GetAnalysisRequest) ClearEventSelector()
- func (x *GetAnalysisRequest) GetEventSelector() *v1.EventSelector
- func (x *GetAnalysisRequest) HasEventSelector() bool
- func (*GetAnalysisRequest) ProtoMessage()
- func (x *GetAnalysisRequest) ProtoReflect() protoreflect.Message
- func (x *GetAnalysisRequest) Reset()
- func (x *GetAnalysisRequest) SetEventSelector(v *v1.EventSelector)
- func (x *GetAnalysisRequest) String() string
- type GetAnalysisRequest_builder
- type GetAnalysisResponse
- func (x *GetAnalysisResponse) ClearAnalysis()
- func (x *GetAnalysisResponse) GetAnalysis() *Analysis
- func (x *GetAnalysisResponse) GetSnapshots() []*SnapshotData
- func (x *GetAnalysisResponse) HasAnalysis() bool
- func (*GetAnalysisResponse) ProtoMessage()
- func (x *GetAnalysisResponse) ProtoReflect() protoreflect.Message
- func (x *GetAnalysisResponse) Reset()
- func (x *GetAnalysisResponse) SetAnalysis(v *Analysis)
- func (x *GetAnalysisResponse) SetSnapshots(v []*SnapshotData)
- func (x *GetAnalysisResponse) String() string
- type GetAnalysisResponse_builder
- type Lap
- func (x *Lap) ClearLapInfo()
- func (x *Lap) GetLapInfo() *LapInfo
- func (x *Lap) GetLapNo() int32
- func (x *Lap) GetLapTime() float32
- func (x *Lap) HasLapInfo() bool
- func (*Lap) ProtoMessage()
- func (x *Lap) ProtoReflect() protoreflect.Message
- func (x *Lap) Reset()
- func (x *Lap) SetLapInfo(v *LapInfo)
- func (x *Lap) SetLapNo(v int32)
- func (x *Lap) SetLapTime(v float32)
- func (x *Lap) String() string
- type LapInfo
- type LapInfo_builder
- type Lap_builder
- type PitInfo
- func (x *PitInfo) GetCarNum() string
- func (x *PitInfo) GetEnterTime() float32
- func (x *PitInfo) GetExitTime() float32
- func (x *PitInfo) GetIsCurrentPitstop() bool
- func (x *PitInfo) GetLaneTime() float32
- func (x *PitInfo) GetLapEnter() int32
- func (x *PitInfo) GetLapExit() int32
- func (*PitInfo) ProtoMessage()
- func (x *PitInfo) ProtoReflect() protoreflect.Message
- func (x *PitInfo) Reset()
- func (x *PitInfo) SetCarNum(v string)
- func (x *PitInfo) SetEnterTime(v float32)
- func (x *PitInfo) SetExitTime(v float32)
- func (x *PitInfo) SetIsCurrentPitstop(v bool)
- func (x *PitInfo) SetLaneTime(v float32)
- func (x *PitInfo) SetLapEnter(v int32)
- func (x *PitInfo) SetLapExit(v int32)
- func (x *PitInfo) String() string
- type PitInfo_builder
- type RaceGraph
- func (x *RaceGraph) GetCarClass() string
- func (x *RaceGraph) GetGaps() []*GapInfo
- func (x *RaceGraph) GetLapNo() int32
- func (*RaceGraph) ProtoMessage()
- func (x *RaceGraph) ProtoReflect() protoreflect.Message
- func (x *RaceGraph) Reset()
- func (x *RaceGraph) SetCarClass(v string)
- func (x *RaceGraph) SetGaps(v []*GapInfo)
- func (x *RaceGraph) SetLapNo(v int32)
- func (x *RaceGraph) String() string
- type RaceGraph_builder
- type SeatTime
- func (x *SeatTime) GetEnterCarTime() float32
- func (x *SeatTime) GetLeaveCarTime() float32
- func (*SeatTime) ProtoMessage()
- func (x *SeatTime) ProtoReflect() protoreflect.Message
- func (x *SeatTime) Reset()
- func (x *SeatTime) SetEnterCarTime(v float32)
- func (x *SeatTime) SetLeaveCarTime(v float32)
- func (x *SeatTime) String() string
- type SeatTime_builder
- type SnapshotData
- func (x *SnapshotData) ClearRecordStamp()
- func (x *SnapshotData) GetAirTemp() float32
- func (x *SnapshotData) GetCarClassLaptimes() map[string]float32
- func (x *SnapshotData) GetPrecipitation() float32
- func (x *SnapshotData) GetRecordStamp() *timestamppb.Timestamp
- func (x *SnapshotData) GetSessionTime() float32
- func (x *SnapshotData) GetTimeOfDay() uint32
- func (x *SnapshotData) GetTrackTemp() float32
- func (x *SnapshotData) GetTrackWetness() v1.TrackWetness
- func (x *SnapshotData) HasRecordStamp() bool
- func (*SnapshotData) ProtoMessage()
- func (x *SnapshotData) ProtoReflect() protoreflect.Message
- func (x *SnapshotData) Reset()
- func (x *SnapshotData) SetAirTemp(v float32)
- func (x *SnapshotData) SetCarClassLaptimes(v map[string]float32)
- func (x *SnapshotData) SetPrecipitation(v float32)
- func (x *SnapshotData) SetRecordStamp(v *timestamppb.Timestamp)
- func (x *SnapshotData) SetSessionTime(v float32)
- func (x *SnapshotData) SetTimeOfDay(v uint32)
- func (x *SnapshotData) SetTrackTemp(v float32)
- func (x *SnapshotData) SetTrackWetness(v v1.TrackWetness)
- func (x *SnapshotData) String() string
- type SnapshotData_builder
- type StintInfo
- func (x *StintInfo) GetCarNum() string
- func (x *StintInfo) GetEnterTime() float32
- func (x *StintInfo) GetExitTime() float32
- func (x *StintInfo) GetIsCurrentStint() bool
- func (x *StintInfo) GetLapEnter() int32
- func (x *StintInfo) GetLapExit() int32
- func (x *StintInfo) GetNumLaps() int32
- func (x *StintInfo) GetStintTime() float32
- func (*StintInfo) ProtoMessage()
- func (x *StintInfo) ProtoReflect() protoreflect.Message
- func (x *StintInfo) Reset()
- func (x *StintInfo) SetCarNum(v string)
- func (x *StintInfo) SetEnterTime(v float32)
- func (x *StintInfo) SetExitTime(v float32)
- func (x *StintInfo) SetIsCurrentStint(v bool)
- func (x *StintInfo) SetLapEnter(v int32)
- func (x *StintInfo) SetLapExit(v int32)
- func (x *StintInfo) SetNumLaps(v int32)
- func (x *StintInfo) SetStintTime(v float32)
- func (x *StintInfo) String() string
- type StintInfo_builder
Constants ¶
This section is empty.
Variables ¶
var ( AnalysisComponent_name = map[int32]string{ 0: "ANALYSIS_COMPONENT_UNSPECIFIED", 1: "ANALYSIS_COMPONENT_ALL", 2: "ANALYSIS_COMPONENT_RACEGRAPH", } AnalysisComponent_value = map[string]int32{ "ANALYSIS_COMPONENT_UNSPECIFIED": 0, "ANALYSIS_COMPONENT_ALL": 1, "ANALYSIS_COMPONENT_RACEGRAPH": 2, } )
Enum value maps for AnalysisComponent.
var ( AnalysisPersistMode_name = map[int32]string{ 0: "ANALYSIS_PERSIST_MODE_UNSPECIFIED", 1: "ANALYSIS_PERSIST_MODE_ON", 2: "ANALYSIS_PERSIST_MODE_OFF", } AnalysisPersistMode_value = map[string]int32{ "ANALYSIS_PERSIST_MODE_UNSPECIFIED": 0, "ANALYSIS_PERSIST_MODE_ON": 1, "ANALYSIS_PERSIST_MODE_OFF": 2, } )
Enum value maps for AnalysisPersistMode.
var File_iracelog_analysis_v1_analysis_proto protoreflect.FileDescriptor
var File_iracelog_analysis_v1_analysis_service_proto protoreflect.FileDescriptor
var File_iracelog_analysis_v1_car_compute_state_proto protoreflect.FileDescriptor
var File_iracelog_analysis_v1_car_laps_proto protoreflect.FileDescriptor
var File_iracelog_analysis_v1_car_occupancy_proto protoreflect.FileDescriptor
var File_iracelog_analysis_v1_car_pit_proto protoreflect.FileDescriptor
var File_iracelog_analysis_v1_car_stint_proto protoreflect.FileDescriptor
var File_iracelog_analysis_v1_racegraph_proto protoreflect.FileDescriptor
var File_iracelog_analysis_v1_snapshot_data_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Analysis ¶
type Analysis struct {
CarOccupancies []*CarOccupancy `protobuf:"bytes,1,rep,name=car_occupancies,json=carOccupancies,proto3" json:"car_occupancies,omitempty"`
CarLaps []*CarLaps `protobuf:"bytes,2,rep,name=car_laps,json=carLaps,proto3" json:"car_laps,omitempty"`
CarPits []*CarPit `protobuf:"bytes,3,rep,name=car_pits,json=carPits,proto3" json:"car_pits,omitempty"`
CarStints []*CarStint `protobuf:"bytes,4,rep,name=car_stints,json=carStints,proto3" json:"car_stints,omitempty"`
CarComputeStates []*CarComputeState `protobuf:"bytes,5,rep,name=car_compute_states,json=carComputeStates,proto3" json:"car_compute_states,omitempty"`
RaceGraph []*RaceGraph `protobuf:"bytes,6,rep,name=race_graph,json=raceGraph,proto3" json:"race_graph,omitempty"`
RaceOrder []string `protobuf:"bytes,7,rep,name=race_order,json=raceOrder,proto3" json:"race_order,omitempty"`
// contains filtered or unexported fields
}
func (*Analysis) GetCarComputeStates ¶
func (x *Analysis) GetCarComputeStates() []*CarComputeState
func (*Analysis) GetCarOccupancies ¶
func (x *Analysis) GetCarOccupancies() []*CarOccupancy
func (*Analysis) ProtoReflect ¶
func (x *Analysis) ProtoReflect() protoreflect.Message
func (*Analysis) SetCarComputeStates ¶
func (x *Analysis) SetCarComputeStates(v []*CarComputeState)
func (*Analysis) SetCarOccupancies ¶
func (x *Analysis) SetCarOccupancies(v []*CarOccupancy)
type AnalysisComponent ¶
type AnalysisComponent int32
const ( AnalysisComponent_ANALYSIS_COMPONENT_UNSPECIFIED AnalysisComponent = 0 AnalysisComponent_ANALYSIS_COMPONENT_ALL AnalysisComponent = 1 AnalysisComponent_ANALYSIS_COMPONENT_RACEGRAPH AnalysisComponent = 2 )
func (AnalysisComponent) Descriptor ¶
func (AnalysisComponent) Descriptor() protoreflect.EnumDescriptor
func (AnalysisComponent) Enum ¶
func (x AnalysisComponent) Enum() *AnalysisComponent
func (AnalysisComponent) Number ¶
func (x AnalysisComponent) Number() protoreflect.EnumNumber
func (AnalysisComponent) String ¶
func (x AnalysisComponent) String() string
func (AnalysisComponent) Type ¶
func (AnalysisComponent) Type() protoreflect.EnumType
type AnalysisPersistMode ¶
type AnalysisPersistMode int32
const ( AnalysisPersistMode_ANALYSIS_PERSIST_MODE_UNSPECIFIED AnalysisPersistMode = 0 AnalysisPersistMode_ANALYSIS_PERSIST_MODE_ON AnalysisPersistMode = 1 AnalysisPersistMode_ANALYSIS_PERSIST_MODE_OFF AnalysisPersistMode = 2 )
func (AnalysisPersistMode) Descriptor ¶
func (AnalysisPersistMode) Descriptor() protoreflect.EnumDescriptor
func (AnalysisPersistMode) Enum ¶
func (x AnalysisPersistMode) Enum() *AnalysisPersistMode
func (AnalysisPersistMode) Number ¶
func (x AnalysisPersistMode) Number() protoreflect.EnumNumber
func (AnalysisPersistMode) String ¶
func (x AnalysisPersistMode) String() string
func (AnalysisPersistMode) Type ¶
func (AnalysisPersistMode) Type() protoreflect.EnumType
type Analysis_builder ¶
type Analysis_builder struct {
CarOccupancies []*CarOccupancy
CarLaps []*CarLaps
CarPits []*CarPit
CarStints []*CarStint
CarComputeStates []*CarComputeState
RaceGraph []*RaceGraph
RaceOrder []string
// contains filtered or unexported fields
}
func (Analysis_builder) Build ¶
func (b0 Analysis_builder) Build() *Analysis
type CarComputeState ¶
type CarComputeState struct {
CarNum string `protobuf:"bytes,1,opt,name=car_num,json=carNum,proto3" json:"car_num,omitempty"`
CarState v1.CarState `protobuf:"varint,2,opt,name=car_state,json=carState,proto3,enum=iracelog.racestate.v1.CarState" json:"car_state,omitempty"`
OutEncountered float32 `protobuf:"fixed32,3,opt,name=out_encountered,json=outEncountered,proto3" json:"out_encountered,omitempty"`
// contains filtered or unexported fields
}
func (*CarComputeState) GetCarNum ¶
func (x *CarComputeState) GetCarNum() string
func (*CarComputeState) GetCarState ¶
func (x *CarComputeState) GetCarState() v1.CarState
func (*CarComputeState) GetOutEncountered ¶
func (x *CarComputeState) GetOutEncountered() float32
func (*CarComputeState) ProtoMessage ¶
func (*CarComputeState) ProtoMessage()
func (*CarComputeState) ProtoReflect ¶
func (x *CarComputeState) ProtoReflect() protoreflect.Message
func (*CarComputeState) Reset ¶
func (x *CarComputeState) Reset()
func (*CarComputeState) SetCarNum ¶
func (x *CarComputeState) SetCarNum(v string)
func (*CarComputeState) SetCarState ¶
func (x *CarComputeState) SetCarState(v v1.CarState)
func (*CarComputeState) SetOutEncountered ¶
func (x *CarComputeState) SetOutEncountered(v float32)
func (*CarComputeState) String ¶
func (x *CarComputeState) String() string
type CarComputeState_builder ¶
type CarComputeState_builder struct {
CarNum string
CarState v1.CarState
OutEncountered float32
// contains filtered or unexported fields
}
func (CarComputeState_builder) Build ¶
func (b0 CarComputeState_builder) Build() *CarComputeState
type CarLaps ¶
type CarLaps struct {
CarNum string `protobuf:"bytes,1,opt,name=car_num,json=carNum,proto3" json:"car_num,omitempty"`
Laps []*Lap `protobuf:"bytes,2,rep,name=laps,proto3" json:"laps,omitempty"`
// contains filtered or unexported fields
}
CarLaps
func (*CarLaps) ProtoReflect ¶
func (x *CarLaps) ProtoReflect() protoreflect.Message
type CarLaps_builder ¶
func (CarLaps_builder) Build ¶
func (b0 CarLaps_builder) Build() *CarLaps
type CarOccupancy ¶
type CarOccupancy struct {
// in team races this is the team name, otherwise the driver name
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
CarNum string `protobuf:"bytes,2,opt,name=car_num,json=carNum,proto3" json:"car_num,omitempty"`
CarClass string `protobuf:"bytes,3,opt,name=car_class,json=carClass,proto3" json:"car_class,omitempty"`
CurrentDriverName string `protobuf:"bytes,4,opt,name=current_driver_name,json=currentDriverName,proto3" json:"current_driver_name,omitempty"`
Drivers []*Driver `protobuf:"bytes,5,rep,name=drivers,proto3" json:"drivers,omitempty"`
// contains filtered or unexported fields
}
CarOccupancy contains information which drivers used a specific car
func (*CarOccupancy) GetCarClass ¶
func (x *CarOccupancy) GetCarClass() string
func (*CarOccupancy) GetCarNum ¶
func (x *CarOccupancy) GetCarNum() string
func (*CarOccupancy) GetCurrentDriverName ¶
func (x *CarOccupancy) GetCurrentDriverName() string
func (*CarOccupancy) GetDrivers ¶
func (x *CarOccupancy) GetDrivers() []*Driver
func (*CarOccupancy) GetName ¶
func (x *CarOccupancy) GetName() string
func (*CarOccupancy) ProtoMessage ¶
func (*CarOccupancy) ProtoMessage()
func (*CarOccupancy) ProtoReflect ¶
func (x *CarOccupancy) ProtoReflect() protoreflect.Message
func (*CarOccupancy) Reset ¶
func (x *CarOccupancy) Reset()
func (*CarOccupancy) SetCarClass ¶
func (x *CarOccupancy) SetCarClass(v string)
func (*CarOccupancy) SetCarNum ¶
func (x *CarOccupancy) SetCarNum(v string)
func (*CarOccupancy) SetCurrentDriverName ¶
func (x *CarOccupancy) SetCurrentDriverName(v string)
func (*CarOccupancy) SetDrivers ¶
func (x *CarOccupancy) SetDrivers(v []*Driver)
func (*CarOccupancy) SetName ¶
func (x *CarOccupancy) SetName(v string)
func (*CarOccupancy) String ¶
func (x *CarOccupancy) String() string
type CarOccupancy_builder ¶
type CarOccupancy_builder struct {
// in team races this is the team name, otherwise the driver name
Name string
CarNum string
CarClass string
CurrentDriverName string
Drivers []*Driver
// contains filtered or unexported fields
}
func (CarOccupancy_builder) Build ¶
func (b0 CarOccupancy_builder) Build() *CarOccupancy
type CarPit ¶
type CarPit struct {
CarNum string `protobuf:"bytes,1,opt,name=car_num,json=carNum,proto3" json:"car_num,omitempty"`
Current *PitInfo `protobuf:"bytes,2,opt,name=current,proto3" json:"current,omitempty"`
History []*PitInfo `protobuf:"bytes,3,rep,name=history,proto3" json:"history,omitempty"`
// contains filtered or unexported fields
}
CarPit
func (*CarPit) ProtoReflect ¶
func (x *CarPit) ProtoReflect() protoreflect.Message
type CarPit_builder ¶
type CarPit_builder struct {
CarNum string
Current *PitInfo
History []*PitInfo
// contains filtered or unexported fields
}
func (CarPit_builder) Build ¶
func (b0 CarPit_builder) Build() *CarPit
type CarStint ¶
type CarStint struct {
CarNum string `protobuf:"bytes,1,opt,name=car_num,json=carNum,proto3" json:"car_num,omitempty"`
Current *StintInfo `protobuf:"bytes,2,opt,name=current,proto3" json:"current,omitempty"`
History []*StintInfo `protobuf:"bytes,3,rep,name=history,proto3" json:"history,omitempty"`
// contains filtered or unexported fields
}
CarStint
func (*CarStint) ProtoReflect ¶
func (x *CarStint) ProtoReflect() protoreflect.Message
type CarStint_builder ¶
type CarStint_builder struct {
CarNum string
Current *StintInfo
History []*StintInfo
// contains filtered or unexported fields
}
func (CarStint_builder) Build ¶
func (b0 CarStint_builder) Build() *CarStint
type ComputeAnalysisRequest ¶
type ComputeAnalysisRequest struct {
EventSelector *v1.EventSelector `protobuf:"bytes,1,opt,name=event_selector,json=eventSelector,proto3" json:"event_selector,omitempty"`
Component AnalysisComponent `protobuf:"varint,2,opt,name=component,proto3,enum=iracelog.analysis.v1.AnalysisComponent" json:"component,omitempty"`
PersistMode AnalysisPersistMode `` /* 141-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*ComputeAnalysisRequest) ClearEventSelector ¶
func (x *ComputeAnalysisRequest) ClearEventSelector()
func (*ComputeAnalysisRequest) GetComponent ¶
func (x *ComputeAnalysisRequest) GetComponent() AnalysisComponent
func (*ComputeAnalysisRequest) GetEventSelector ¶
func (x *ComputeAnalysisRequest) GetEventSelector() *v1.EventSelector
func (*ComputeAnalysisRequest) GetPersistMode ¶
func (x *ComputeAnalysisRequest) GetPersistMode() AnalysisPersistMode
func (*ComputeAnalysisRequest) HasEventSelector ¶
func (x *ComputeAnalysisRequest) HasEventSelector() bool
func (*ComputeAnalysisRequest) ProtoMessage ¶
func (*ComputeAnalysisRequest) ProtoMessage()
func (*ComputeAnalysisRequest) ProtoReflect ¶
func (x *ComputeAnalysisRequest) ProtoReflect() protoreflect.Message
func (*ComputeAnalysisRequest) Reset ¶
func (x *ComputeAnalysisRequest) Reset()
func (*ComputeAnalysisRequest) SetComponent ¶
func (x *ComputeAnalysisRequest) SetComponent(v AnalysisComponent)
func (*ComputeAnalysisRequest) SetEventSelector ¶
func (x *ComputeAnalysisRequest) SetEventSelector(v *v1.EventSelector)
func (*ComputeAnalysisRequest) SetPersistMode ¶
func (x *ComputeAnalysisRequest) SetPersistMode(v AnalysisPersistMode)
func (*ComputeAnalysisRequest) String ¶
func (x *ComputeAnalysisRequest) String() string
type ComputeAnalysisRequest_builder ¶
type ComputeAnalysisRequest_builder struct {
EventSelector *v1.EventSelector
Component AnalysisComponent
PersistMode AnalysisPersistMode
// contains filtered or unexported fields
}
func (ComputeAnalysisRequest_builder) Build ¶
func (b0 ComputeAnalysisRequest_builder) Build() *ComputeAnalysisRequest
type ComputeAnalysisResponse ¶
type ComputeAnalysisResponse struct {
Analysis *Analysis `protobuf:"bytes,1,opt,name=analysis,proto3" json:"analysis,omitempty"`
// contains filtered or unexported fields
}
func (*ComputeAnalysisResponse) ClearAnalysis ¶
func (x *ComputeAnalysisResponse) ClearAnalysis()
func (*ComputeAnalysisResponse) GetAnalysis ¶
func (x *ComputeAnalysisResponse) GetAnalysis() *Analysis
func (*ComputeAnalysisResponse) HasAnalysis ¶
func (x *ComputeAnalysisResponse) HasAnalysis() bool
func (*ComputeAnalysisResponse) ProtoMessage ¶
func (*ComputeAnalysisResponse) ProtoMessage()
func (*ComputeAnalysisResponse) ProtoReflect ¶
func (x *ComputeAnalysisResponse) ProtoReflect() protoreflect.Message
func (*ComputeAnalysisResponse) Reset ¶
func (x *ComputeAnalysisResponse) Reset()
func (*ComputeAnalysisResponse) SetAnalysis ¶
func (x *ComputeAnalysisResponse) SetAnalysis(v *Analysis)
func (*ComputeAnalysisResponse) String ¶
func (x *ComputeAnalysisResponse) String() string
type ComputeAnalysisResponse_builder ¶
type ComputeAnalysisResponse_builder struct {
Analysis *Analysis
// contains filtered or unexported fields
}
func (ComputeAnalysisResponse_builder) Build ¶
func (b0 ComputeAnalysisResponse_builder) Build() *ComputeAnalysisResponse
type Driver ¶
type Driver struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
SeatTimes []*SeatTime `protobuf:"bytes,2,rep,name=seat_times,json=seatTimes,proto3" json:"seat_times,omitempty"`
// contains filtered or unexported fields
}
func (*Driver) ProtoReflect ¶
func (x *Driver) ProtoReflect() protoreflect.Message
type Driver_builder ¶
type Driver_builder struct {
Name string
SeatTimes []*SeatTime
// contains filtered or unexported fields
}
func (Driver_builder) Build ¶
func (b0 Driver_builder) Build() *Driver
type GapInfo ¶
type GapInfo struct {
CarNum string `protobuf:"bytes,1,opt,name=car_num,json=carNum,proto3" json:"car_num,omitempty"`
LapNo int32 `protobuf:"varint,2,opt,name=lap_no,json=lapNo,proto3" json:"lap_no,omitempty"`
Pos int32 `protobuf:"varint,3,opt,name=pos,proto3" json:"pos,omitempty"`
Pic int32 `protobuf:"varint,4,opt,name=pic,proto3" json:"pic,omitempty"`
Gap float32 `protobuf:"fixed32,5,opt,name=gap,proto3" json:"gap,omitempty"`
// contains filtered or unexported fields
}
func (*GapInfo) ProtoReflect ¶
func (x *GapInfo) ProtoReflect() protoreflect.Message
type GapInfo_builder ¶
type GapInfo_builder struct {
CarNum string
LapNo int32
Pos int32
Pic int32
Gap float32
// contains filtered or unexported fields
}
func (GapInfo_builder) Build ¶
func (b0 GapInfo_builder) Build() *GapInfo
type GetAnalysisRequest ¶
type GetAnalysisRequest struct {
EventSelector *v1.EventSelector `protobuf:"bytes,1,opt,name=event_selector,json=eventSelector,proto3" json:"event_selector,omitempty"`
// contains filtered or unexported fields
}
func (*GetAnalysisRequest) ClearEventSelector ¶
func (x *GetAnalysisRequest) ClearEventSelector()
func (*GetAnalysisRequest) GetEventSelector ¶
func (x *GetAnalysisRequest) GetEventSelector() *v1.EventSelector
func (*GetAnalysisRequest) HasEventSelector ¶
func (x *GetAnalysisRequest) HasEventSelector() bool
func (*GetAnalysisRequest) ProtoMessage ¶
func (*GetAnalysisRequest) ProtoMessage()
func (*GetAnalysisRequest) ProtoReflect ¶
func (x *GetAnalysisRequest) ProtoReflect() protoreflect.Message
func (*GetAnalysisRequest) Reset ¶
func (x *GetAnalysisRequest) Reset()
func (*GetAnalysisRequest) SetEventSelector ¶
func (x *GetAnalysisRequest) SetEventSelector(v *v1.EventSelector)
func (*GetAnalysisRequest) String ¶
func (x *GetAnalysisRequest) String() string
type GetAnalysisRequest_builder ¶
type GetAnalysisRequest_builder struct {
EventSelector *v1.EventSelector
// contains filtered or unexported fields
}
func (GetAnalysisRequest_builder) Build ¶
func (b0 GetAnalysisRequest_builder) Build() *GetAnalysisRequest
type GetAnalysisResponse ¶
type GetAnalysisResponse struct {
Analysis *Analysis `protobuf:"bytes,1,opt,name=analysis,proto3" json:"analysis,omitempty"`
Snapshots []*SnapshotData `protobuf:"bytes,2,rep,name=snapshots,proto3" json:"snapshots,omitempty"`
// contains filtered or unexported fields
}
func (*GetAnalysisResponse) ClearAnalysis ¶
func (x *GetAnalysisResponse) ClearAnalysis()
func (*GetAnalysisResponse) GetAnalysis ¶
func (x *GetAnalysisResponse) GetAnalysis() *Analysis
func (*GetAnalysisResponse) GetSnapshots ¶
func (x *GetAnalysisResponse) GetSnapshots() []*SnapshotData
func (*GetAnalysisResponse) HasAnalysis ¶
func (x *GetAnalysisResponse) HasAnalysis() bool
func (*GetAnalysisResponse) ProtoMessage ¶
func (*GetAnalysisResponse) ProtoMessage()
func (*GetAnalysisResponse) ProtoReflect ¶
func (x *GetAnalysisResponse) ProtoReflect() protoreflect.Message
func (*GetAnalysisResponse) Reset ¶
func (x *GetAnalysisResponse) Reset()
func (*GetAnalysisResponse) SetAnalysis ¶
func (x *GetAnalysisResponse) SetAnalysis(v *Analysis)
func (*GetAnalysisResponse) SetSnapshots ¶
func (x *GetAnalysisResponse) SetSnapshots(v []*SnapshotData)
func (*GetAnalysisResponse) String ¶
func (x *GetAnalysisResponse) String() string
type GetAnalysisResponse_builder ¶
type GetAnalysisResponse_builder struct {
Analysis *Analysis
Snapshots []*SnapshotData
// contains filtered or unexported fields
}
func (GetAnalysisResponse_builder) Build ¶
func (b0 GetAnalysisResponse_builder) Build() *GetAnalysisResponse
type Lap ¶
type Lap struct {
LapNo int32 `protobuf:"varint,1,opt,name=lap_no,json=lapNo,proto3" json:"lap_no,omitempty"`
LapTime float32 `protobuf:"fixed32,2,opt,name=lap_time,json=lapTime,proto3" json:"lap_time,omitempty"`
LapInfo *LapInfo `protobuf:"bytes,3,opt,name=lap_info,json=lapInfo,proto3" json:"lap_info,omitempty"`
// contains filtered or unexported fields
}
Lap
func (*Lap) ProtoReflect ¶
func (x *Lap) ProtoReflect() protoreflect.Message
type LapInfo ¶
type LapInfo struct {
Mode v1.LapMode `protobuf:"varint,1,opt,name=mode,proto3,enum=iracelog.common.v1.LapMode" json:"mode,omitempty"`
Time float32 `protobuf:"fixed32,2,opt,name=time,proto3" json:"time,omitempty"`
// contains filtered or unexported fields
}
LapInfo
func (*LapInfo) ProtoReflect ¶
func (x *LapInfo) ProtoReflect() protoreflect.Message
type LapInfo_builder ¶
type LapInfo_builder struct {
Mode v1.LapMode
Time float32
// contains filtered or unexported fields
}
func (LapInfo_builder) Build ¶
func (b0 LapInfo_builder) Build() *LapInfo
type Lap_builder ¶
type Lap_builder struct {
LapNo int32
LapTime float32
LapInfo *LapInfo
// contains filtered or unexported fields
}
func (Lap_builder) Build ¶
func (b0 Lap_builder) Build() *Lap
type PitInfo ¶
type PitInfo struct {
CarNum string `protobuf:"bytes,1,opt,name=car_num,json=carNum,proto3" json:"car_num,omitempty"`
EnterTime float32 `protobuf:"fixed32,2,opt,name=enter_time,json=enterTime,proto3" json:"enter_time,omitempty"`
ExitTime float32 `protobuf:"fixed32,3,opt,name=exit_time,json=exitTime,proto3" json:"exit_time,omitempty"`
LapEnter int32 `protobuf:"varint,4,opt,name=lap_enter,json=lapEnter,proto3" json:"lap_enter,omitempty"`
LapExit int32 `protobuf:"varint,5,opt,name=lap_exit,json=lapExit,proto3" json:"lap_exit,omitempty"`
LaneTime float32 `protobuf:"fixed32,6,opt,name=lane_time,json=laneTime,proto3" json:"lane_time,omitempty"`
IsCurrentPitstop bool `protobuf:"varint,7,opt,name=is_current_pitstop,json=isCurrentPitstop,proto3" json:"is_current_pitstop,omitempty"`
// contains filtered or unexported fields
}
func (*PitInfo) ProtoReflect ¶
func (x *PitInfo) ProtoReflect() protoreflect.Message
type PitInfo_builder ¶
type PitInfo_builder struct {
CarNum string
EnterTime float32
ExitTime float32
LapEnter int32
LapExit int32
LaneTime float32
IsCurrentPitstop bool
// contains filtered or unexported fields
}
func (PitInfo_builder) Build ¶
func (b0 PitInfo_builder) Build() *PitInfo
type RaceGraph ¶
type RaceGraph struct {
LapNo int32 `protobuf:"varint,1,opt,name=lap_no,json=lapNo,proto3" json:"lap_no,omitempty"`
CarClass string `protobuf:"bytes,2,opt,name=car_class,json=carClass,proto3" json:"car_class,omitempty"`
Gaps []*GapInfo `protobuf:"bytes,3,rep,name=gaps,proto3" json:"gaps,omitempty"`
// contains filtered or unexported fields
}
func (*RaceGraph) ProtoReflect ¶
func (x *RaceGraph) ProtoReflect() protoreflect.Message
type RaceGraph_builder ¶
type RaceGraph_builder struct {
LapNo int32
CarClass string
Gaps []*GapInfo
// contains filtered or unexported fields
}
func (RaceGraph_builder) Build ¶
func (b0 RaceGraph_builder) Build() *RaceGraph
type SeatTime ¶
type SeatTime struct {
EnterCarTime float32 `protobuf:"fixed32,1,opt,name=enter_car_time,json=enterCarTime,proto3" json:"enter_car_time,omitempty"`
LeaveCarTime float32 `protobuf:"fixed32,2,opt,name=leave_car_time,json=leaveCarTime,proto3" json:"leave_car_time,omitempty"`
// contains filtered or unexported fields
}
func (*SeatTime) ProtoReflect ¶
func (x *SeatTime) ProtoReflect() protoreflect.Message
type SeatTime_builder ¶
type SeatTime_builder struct {
EnterCarTime float32
LeaveCarTime float32
// contains filtered or unexported fields
}
func (SeatTime_builder) Build ¶
func (b0 SeatTime_builder) Build() *SeatTime
type SnapshotData ¶
type SnapshotData struct {
// this is the real time of the corresponding speedmap message on which these data are based
RecordStamp *timestamppb.Timestamp `protobuf:"bytes,1,opt,name=record_stamp,json=recordStamp,proto3" json:"record_stamp,omitempty"`
SessionTime float32 `protobuf:"fixed32,2,opt,name=session_time,json=sessionTime,proto3" json:"session_time,omitempty"`
TimeOfDay uint32 `protobuf:"varint,3,opt,name=time_of_day,json=timeOfDay,proto3" json:"time_of_day,omitempty"`
AirTemp float32 `protobuf:"fixed32,4,opt,name=air_temp,json=airTemp,proto3" json:"air_temp,omitempty"`
TrackTemp float32 `protobuf:"fixed32,5,opt,name=track_temp,json=trackTemp,proto3" json:"track_temp,omitempty"`
TrackWetness v1.TrackWetness `` /* 135-byte string literal not displayed */
Precipitation float32 `protobuf:"fixed32,7,opt,name=precipitation,proto3" json:"precipitation,omitempty"`
// avg laptime by car class
CarClassLaptimes map[string]float32 `` /* 187-byte string literal not displayed */
// contains filtered or unexported fields
}
contains snapshot data over a race. This is used to show the certain data history over the complete event duration we use this for data that is not directly related to laps a use case is to collect these attributes for every 2min in a 12h race
func (*SnapshotData) ClearRecordStamp ¶
func (x *SnapshotData) ClearRecordStamp()
func (*SnapshotData) GetAirTemp ¶
func (x *SnapshotData) GetAirTemp() float32
func (*SnapshotData) GetCarClassLaptimes ¶
func (x *SnapshotData) GetCarClassLaptimes() map[string]float32
func (*SnapshotData) GetPrecipitation ¶
func (x *SnapshotData) GetPrecipitation() float32
func (*SnapshotData) GetRecordStamp ¶
func (x *SnapshotData) GetRecordStamp() *timestamppb.Timestamp
func (*SnapshotData) GetSessionTime ¶
func (x *SnapshotData) GetSessionTime() float32
func (*SnapshotData) GetTimeOfDay ¶
func (x *SnapshotData) GetTimeOfDay() uint32
func (*SnapshotData) GetTrackTemp ¶
func (x *SnapshotData) GetTrackTemp() float32
func (*SnapshotData) GetTrackWetness ¶
func (x *SnapshotData) GetTrackWetness() v1.TrackWetness
func (*SnapshotData) HasRecordStamp ¶
func (x *SnapshotData) HasRecordStamp() bool
func (*SnapshotData) ProtoMessage ¶
func (*SnapshotData) ProtoMessage()
func (*SnapshotData) ProtoReflect ¶
func (x *SnapshotData) ProtoReflect() protoreflect.Message
func (*SnapshotData) Reset ¶
func (x *SnapshotData) Reset()
func (*SnapshotData) SetAirTemp ¶
func (x *SnapshotData) SetAirTemp(v float32)
func (*SnapshotData) SetCarClassLaptimes ¶
func (x *SnapshotData) SetCarClassLaptimes(v map[string]float32)
func (*SnapshotData) SetPrecipitation ¶
func (x *SnapshotData) SetPrecipitation(v float32)
func (*SnapshotData) SetRecordStamp ¶
func (x *SnapshotData) SetRecordStamp(v *timestamppb.Timestamp)
func (*SnapshotData) SetSessionTime ¶
func (x *SnapshotData) SetSessionTime(v float32)
func (*SnapshotData) SetTimeOfDay ¶
func (x *SnapshotData) SetTimeOfDay(v uint32)
func (*SnapshotData) SetTrackTemp ¶
func (x *SnapshotData) SetTrackTemp(v float32)
func (*SnapshotData) SetTrackWetness ¶
func (x *SnapshotData) SetTrackWetness(v v1.TrackWetness)
func (*SnapshotData) String ¶
func (x *SnapshotData) String() string
type SnapshotData_builder ¶
type SnapshotData_builder struct {
// this is the real time of the corresponding speedmap message on which these data are based
RecordStamp *timestamppb.Timestamp
SessionTime float32
TimeOfDay uint32
AirTemp float32
TrackTemp float32
TrackWetness v1.TrackWetness
Precipitation float32
// avg laptime by car class
CarClassLaptimes map[string]float32
// contains filtered or unexported fields
}
func (SnapshotData_builder) Build ¶
func (b0 SnapshotData_builder) Build() *SnapshotData
type StintInfo ¶
type StintInfo struct {
CarNum string `protobuf:"bytes,1,opt,name=car_num,json=carNum,proto3" json:"car_num,omitempty"`
EnterTime float32 `protobuf:"fixed32,2,opt,name=enter_time,json=enterTime,proto3" json:"enter_time,omitempty"`
ExitTime float32 `protobuf:"fixed32,3,opt,name=exit_time,json=exitTime,proto3" json:"exit_time,omitempty"`
LapEnter int32 `protobuf:"varint,4,opt,name=lap_enter,json=lapEnter,proto3" json:"lap_enter,omitempty"`
LapExit int32 `protobuf:"varint,5,opt,name=lap_exit,json=lapExit,proto3" json:"lap_exit,omitempty"`
StintTime float32 `protobuf:"fixed32,6,opt,name=stint_time,json=stintTime,proto3" json:"stint_time,omitempty"`
NumLaps int32 `protobuf:"varint,7,opt,name=num_laps,json=numLaps,proto3" json:"num_laps,omitempty"`
IsCurrentStint bool `protobuf:"varint,8,opt,name=is_current_stint,json=isCurrentStint,proto3" json:"is_current_stint,omitempty"`
// contains filtered or unexported fields
}
func (*StintInfo) ProtoReflect ¶
func (x *StintInfo) ProtoReflect() protoreflect.Message
type StintInfo_builder ¶
type StintInfo_builder struct {
CarNum string
EnterTime float32
ExitTime float32
LapEnter int32
LapExit int32
StintTime float32
NumLaps int32
IsCurrentStint bool
// contains filtered or unexported fields
}
func (StintInfo_builder) Build ¶
func (b0 StintInfo_builder) Build() *StintInfo
Source Files
¶
- analysis.pb.go
- analysis_service.pb.go
- car_compute_state.pb.go
- car_laps.pb.go
- car_occupancy.pb.go
- car_pit.pb.go
- car_stint.pb.go
- racegraph.pb.go
- snapshot_data.pb.go
Click to show internal directories.
Click to hide internal directories.