analysisv1grpc

package
v1.6.0-20240523183733-... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	AnalysisService_GetAnalysis_FullMethodName = "/testrepo.analysis.v1.AnalysisService/GetAnalysis"
)

Variables

var AnalysisService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "testrepo.analysis.v1.AnalysisService",
	HandlerType: (*AnalysisServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetAnalysis",
			Handler:    _AnalysisService_GetAnalysis_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "testrepo/analysis/v1/analysis_service.proto",
}

AnalysisService_ServiceDesc is the grpc.ServiceDesc for AnalysisService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterAnalysisServiceServer

func RegisterAnalysisServiceServer(s grpc.ServiceRegistrar, srv AnalysisServiceServer)

Types

type AnalysisServiceClient

type AnalysisServiceClient interface {
	GetAnalysis(ctx context.Context, in *v1.GetAnalysisRequest, opts ...grpc.CallOption) (*v1.GetAnalysisResponse, error)
}

AnalysisServiceClient is the client API for AnalysisService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewAnalysisServiceClient

func NewAnalysisServiceClient(cc grpc.ClientConnInterface) AnalysisServiceClient

type AnalysisServiceServer

type AnalysisServiceServer interface {
	GetAnalysis(context.Context, *v1.GetAnalysisRequest) (*v1.GetAnalysisResponse, error)
}

AnalysisServiceServer is the server API for AnalysisService service. All implementations should embed UnimplementedAnalysisServiceServer for forward compatibility.

type UnimplementedAnalysisServiceServer

type UnimplementedAnalysisServiceServer struct{}

UnimplementedAnalysisServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedAnalysisServiceServer) GetAnalysis

type UnsafeAnalysisServiceServer

type UnsafeAnalysisServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeAnalysisServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to AnalysisServiceServer will result in compilation errors.

Source Files

  • analysis_service_grpc.pb.go

Jump to