eventv1grpc

package
v1.6.1-20240523183733-... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: MIT Imports: 5 Imported by: 1

Documentation

Index

Constants

const (
	EventService_GetEvents_FullMethodName       = "/testrepo.event.v1.EventService/GetEvents"
	EventService_GetEvent_FullMethodName        = "/testrepo.event.v1.EventService/GetEvent"
	EventService_DeleteEvent_FullMethodName     = "/testrepo.event.v1.EventService/DeleteEvent"
	EventService_GetLatestEvents_FullMethodName = "/testrepo.event.v1.EventService/GetLatestEvents"
)

Variables

var EventService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "testrepo.event.v1.EventService",
	HandlerType: (*EventServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetEvent",
			Handler:    _EventService_GetEvent_Handler,
		},
		{
			MethodName: "DeleteEvent",
			Handler:    _EventService_DeleteEvent_Handler,
		},
		{
			MethodName: "GetLatestEvents",
			Handler:    _EventService_GetLatestEvents_Handler,
		},
	},
	Streams: []grpc.StreamDesc{
		{
			StreamName:    "GetEvents",
			Handler:       _EventService_GetEvents_Handler,
			ServerStreams: true,
		},
	},
	Metadata: "testrepo/event/v1/event_service.proto",
}

EventService_ServiceDesc is the grpc.ServiceDesc for EventService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterEventServiceServer

func RegisterEventServiceServer(s grpc.ServiceRegistrar, srv EventServiceServer)

Types

type EventServiceClient

type EventServiceClient interface {
	GetEvents(ctx context.Context, in *v1.GetEventsRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[v1.GetEventsResponse], error)
	// returns the event along with all data required for the frontend
	GetEvent(ctx context.Context, in *v1.GetEventRequest, opts ...grpc.CallOption) (*v1.GetEventResponse, error)
	DeleteEvent(ctx context.Context, in *v1.DeleteEventRequest, opts ...grpc.CallOption) (*v1.DeleteEventResponse, error)
	GetLatestEvents(ctx context.Context, in *v1.GetLatestEventsRequest, opts ...grpc.CallOption) (*v1.GetLatestEventsResponse, error)
}

EventServiceClient is the client API for EventService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewEventServiceClient

func NewEventServiceClient(cc grpc.ClientConnInterface) EventServiceClient

type EventServiceServer

type EventServiceServer interface {
	GetEvents(*v1.GetEventsRequest, grpc.ServerStreamingServer[v1.GetEventsResponse]) error
	// returns the event along with all data required for the frontend
	GetEvent(context.Context, *v1.GetEventRequest) (*v1.GetEventResponse, error)
	DeleteEvent(context.Context, *v1.DeleteEventRequest) (*v1.DeleteEventResponse, error)
	GetLatestEvents(context.Context, *v1.GetLatestEventsRequest) (*v1.GetLatestEventsResponse, error)
}

EventServiceServer is the server API for EventService service. All implementations should embed UnimplementedEventServiceServer for forward compatibility.

type EventService_GetEventsClient

type EventService_GetEventsClient = grpc.ServerStreamingClient[v1.GetEventsResponse]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type EventService_GetEventsServer

type EventService_GetEventsServer = grpc.ServerStreamingServer[v1.GetEventsResponse]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type UnimplementedEventServiceServer

type UnimplementedEventServiceServer struct{}

UnimplementedEventServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedEventServiceServer) DeleteEvent

func (UnimplementedEventServiceServer) GetEvent

func (UnimplementedEventServiceServer) GetEvents

func (UnimplementedEventServiceServer) GetLatestEvents

type UnsafeEventServiceServer

type UnsafeEventServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeEventServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to EventServiceServer will result in compilation errors.

Source Files

  • event_service_grpc.pb.go

Jump to