syncv1gateway

package
v2.28.0-20260309153440... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 14 Imported by: 0

Documentation

Overview

Package syncv1gateway is a reverse proxy.

It translates gRPC into RESTful JSON APIs.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func RegisterSantaSyncHandler

func RegisterSantaSyncHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error

RegisterSantaSyncHandler registers the http handlers for service SantaSync to "mux". The handlers forward requests to the grpc endpoint over "conn".

func RegisterSantaSyncHandlerClient

func RegisterSantaSyncHandlerClient(ctx context.Context, mux *runtime.ServeMux, client syncv1grpc.SantaSyncClient) error

RegisterSantaSyncHandlerClient registers the http handlers for service SantaSync to "mux". The handlers forward requests to the grpc endpoint over the given implementation of "syncv1grpc.SantaSyncClient". Note: the gRPC framework executes interceptors within the gRPC handler. If the passed in "syncv1grpc.SantaSyncClient" doesn't go through the normal gRPC flow (creating a gRPC client etc.) then it will be up to the passed in "syncv1grpc.SantaSyncClient" to call the correct interceptors. This client ignores the HTTP middlewares.

func RegisterSantaSyncHandlerFromEndpoint

func RegisterSantaSyncHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, opts []grpc.DialOption) (err error)

RegisterSantaSyncHandlerFromEndpoint is same as RegisterSantaSyncHandler but automatically dials to "endpoint" and closes the connection when "ctx" gets done.

func RegisterSantaSyncHandlerServer

func RegisterSantaSyncHandlerServer(ctx context.Context, mux *runtime.ServeMux, server syncv1grpc.SantaSyncServer) error

RegisterSantaSyncHandlerServer registers the http handlers for service SantaSync to "mux". UnaryRPC :call SantaSyncServer directly. StreamingRPC :currently unsupported pending https://github.com/grpc/grpc-go/issues/906. Note that using this registration option will cause many gRPC library features to stop working. Consider using RegisterSantaSyncHandlerFromEndpoint instead. GRPC interceptors will not work for this type of registration. To use interceptors, you must use the "runtime.WithMiddlewares" option in the "runtime.NewServeMux" call.

Types

This section is empty.

Source Files

  • v1.pb.gw.go

Jump to