Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterServiceServer(s grpc.ServiceRegistrar, srv ServiceServer)
- type ServiceClient
- type ServiceServer
- type UnimplementedServiceServer
- func (UnimplementedServiceServer) Create(context.Context, *credential.CreateRequest) (*credential.CreateResponse, error)
- func (UnimplementedServiceServer) Delete(context.Context, *credential.DeleteRequest) (*credential.DeleteResponse, error)
- func (UnimplementedServiceServer) List(context.Context, *credential.ListRequest) (*credential.ListResponse, error)
- func (UnimplementedServiceServer) Ping(context.Context, *credential.PingRequest) (*credential.PingResponse, error)
- type UnsafeServiceServer
Constants ¶
const ( Service_Ping_FullMethodName = "/nuntio.management.api.credential.Service/Ping" Service_Create_FullMethodName = "/nuntio.management.api.credential.Service/Create" Service_List_FullMethodName = "/nuntio.management.api.credential.Service/List" Service_Delete_FullMethodName = "/nuntio.management.api.credential.Service/Delete" )
Variables ¶
var Service_ServiceDesc = grpc.ServiceDesc{ ServiceName: "nuntio.management.api.credential.Service", HandlerType: (*ServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "Ping", Handler: _Service_Ping_Handler, }, { MethodName: "Create", Handler: _Service_Create_Handler, }, { MethodName: "List", Handler: _Service_List_Handler, }, { MethodName: "Delete", Handler: _Service_Delete_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "nuntio/management/api/credential/service.proto", }
Service_ServiceDesc is the grpc.ServiceDesc for Service service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterServiceServer ¶
func RegisterServiceServer(s grpc.ServiceRegistrar, srv ServiceServer)
Types ¶
type ServiceClient ¶
type ServiceClient interface {
// Ping a server to check if it is live.
Ping(ctx context.Context, in *credential.PingRequest, opts ...grpc.CallOption) (*credential.PingResponse, error)
// Create a new certificate. The returned client_id and client_secret can be
// used as login credentials. Note that the client_secret can only be read out
// once, at creation.
Create(ctx context.Context, in *credential.CreateRequest, opts ...grpc.CallOption) (*credential.CreateResponse, error)
// List all credentials for the current project.
List(ctx context.Context, in *credential.ListRequest, opts ...grpc.CallOption) (*credential.ListResponse, error)
// Delete a credential. It can take up to the TTL of access tokens for
// existing sessions using this credential, to expire.
Delete(ctx context.Context, in *credential.DeleteRequest, opts ...grpc.CallOption) (*credential.DeleteResponse, error)
}
ServiceClient is the client API for Service service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
The service to manage your project credentials
func NewServiceClient ¶
func NewServiceClient(cc grpc.ClientConnInterface) ServiceClient
type ServiceServer ¶
type ServiceServer interface {
// Ping a server to check if it is live.
Ping(context.Context, *credential.PingRequest) (*credential.PingResponse, error)
// Create a new certificate. The returned client_id and client_secret can be
// used as login credentials. Note that the client_secret can only be read out
// once, at creation.
Create(context.Context, *credential.CreateRequest) (*credential.CreateResponse, error)
// List all credentials for the current project.
List(context.Context, *credential.ListRequest) (*credential.ListResponse, error)
// Delete a credential. It can take up to the TTL of access tokens for
// existing sessions using this credential, to expire.
Delete(context.Context, *credential.DeleteRequest) (*credential.DeleteResponse, error)
}
ServiceServer is the server API for Service service. All implementations should embed UnimplementedServiceServer for forward compatibility.
The service to manage your project credentials
type UnimplementedServiceServer ¶
type UnimplementedServiceServer struct{}
UnimplementedServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedServiceServer) Create ¶
func (UnimplementedServiceServer) Create(context.Context, *credential.CreateRequest) (*credential.CreateResponse, error)
func (UnimplementedServiceServer) Delete ¶
func (UnimplementedServiceServer) Delete(context.Context, *credential.DeleteRequest) (*credential.DeleteResponse, error)
func (UnimplementedServiceServer) List ¶
func (UnimplementedServiceServer) List(context.Context, *credential.ListRequest) (*credential.ListResponse, error)
func (UnimplementedServiceServer) Ping ¶
func (UnimplementedServiceServer) Ping(context.Context, *credential.PingRequest) (*credential.PingResponse, error)
type UnsafeServiceServer ¶
type UnsafeServiceServer interface {
// contains filtered or unexported methods
}
UnsafeServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ServiceServer will result in compilation errors.
Source Files
¶
- service_grpc.pb.go