Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterServiceServer(s grpc.ServiceRegistrar, srv ServiceServer)
- type ServiceClient
- type ServiceServer
- type Service_LogsClient
- type Service_LogsServer
- type UnimplementedServiceServer
- func (UnimplementedServiceServer) Create(context.Context, *deployment.CreateRequest) (*deployment.CreateResponse, error)
- func (UnimplementedServiceServer) Delete(context.Context, *deployment.DeleteRequest) (*deployment.DeleteResponse, error)
- func (UnimplementedServiceServer) Logs(*deployment.LogsRequest, grpc.ServerStreamingServer[deployment.LogsResponse]) error
- func (UnimplementedServiceServer) Ping(context.Context, *deployment.PingRequest) (*deployment.PingResponse, error)
- type UnsafeServiceServer
Constants ¶
const ( Service_Ping_FullMethodName = "/nuntio.management.api.deployment.Service/Ping" Service_Create_FullMethodName = "/nuntio.management.api.deployment.Service/Create" Service_Delete_FullMethodName = "/nuntio.management.api.deployment.Service/Delete" Service_Logs_FullMethodName = "/nuntio.management.api.deployment.Service/Logs" )
Variables ¶
var Service_ServiceDesc = grpc.ServiceDesc{ ServiceName: "nuntio.management.api.deployment.Service", HandlerType: (*ServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "Ping", Handler: _Service_Ping_Handler, }, { MethodName: "Create", Handler: _Service_Create_Handler, }, { MethodName: "Delete", Handler: _Service_Delete_Handler, }, }, Streams: []grpc.StreamDesc{ { StreamName: "Logs", Handler: _Service_Logs_Handler, ServerStreams: true, }, }, Metadata: "nuntio/management/api/deployment/service.proto", }
Service_ServiceDesc is the grpc.ServiceDesc for Service service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterServiceServer ¶
func RegisterServiceServer(s grpc.ServiceRegistrar, srv ServiceServer)
Types ¶
type ServiceClient ¶
type ServiceClient interface {
// Ping a service to check if it is live.
Ping(ctx context.Context, in *deployment.PingRequest, opts ...grpc.CallOption) (*deployment.PingResponse, error)
// Create a new deployment.
Create(ctx context.Context, in *deployment.CreateRequest, opts ...grpc.CallOption) (*deployment.CreateResponse, error)
// Delete a deployment.
Delete(ctx context.Context, in *deployment.DeleteRequest, opts ...grpc.CallOption) (*deployment.DeleteResponse, error)
// Logs returns (and streams) the log output of a deployment.
Logs(ctx context.Context, in *deployment.LogsRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[deployment.LogsResponse], error)
}
ServiceClient is the client API for Service service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
The service to manage deployments.
func NewServiceClient ¶
func NewServiceClient(cc grpc.ClientConnInterface) ServiceClient
type ServiceServer ¶
type ServiceServer interface {
// Ping a service to check if it is live.
Ping(context.Context, *deployment.PingRequest) (*deployment.PingResponse, error)
// Create a new deployment.
Create(context.Context, *deployment.CreateRequest) (*deployment.CreateResponse, error)
// Delete a deployment.
Delete(context.Context, *deployment.DeleteRequest) (*deployment.DeleteResponse, error)
// Logs returns (and streams) the log output of a deployment.
Logs(*deployment.LogsRequest, grpc.ServerStreamingServer[deployment.LogsResponse]) error
}
ServiceServer is the server API for Service service. All implementations should embed UnimplementedServiceServer for forward compatibility.
The service to manage deployments.
type Service_LogsClient ¶
type Service_LogsClient = grpc.ServerStreamingClient[deployment.LogsResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type Service_LogsServer ¶
type Service_LogsServer = grpc.ServerStreamingServer[deployment.LogsResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type UnimplementedServiceServer ¶
type UnimplementedServiceServer struct{}
UnimplementedServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedServiceServer) Create ¶
func (UnimplementedServiceServer) Create(context.Context, *deployment.CreateRequest) (*deployment.CreateResponse, error)
func (UnimplementedServiceServer) Delete ¶
func (UnimplementedServiceServer) Delete(context.Context, *deployment.DeleteRequest) (*deployment.DeleteResponse, error)
func (UnimplementedServiceServer) Logs ¶
func (UnimplementedServiceServer) Ping ¶
func (UnimplementedServiceServer) Ping(context.Context, *deployment.PingRequest) (*deployment.PingResponse, error)
type UnsafeServiceServer ¶
type UnsafeServiceServer interface {
// contains filtered or unexported methods
}
UnsafeServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ServiceServer will result in compilation errors.
Source Files
¶
- service_grpc.pb.go