storagegrpc

package
v1.6.0-20230531113704-... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	Service_Ping_FullMethodName           = "/nuntio.sdk.api.storage.Service/Ping"
	Service_CreateBucket_FullMethodName   = "/nuntio.sdk.api.storage.Service/CreateBucket"
	Service_GetBucket_FullMethodName      = "/nuntio.sdk.api.storage.Service/GetBucket"
	Service_ListBuckets_FullMethodName    = "/nuntio.sdk.api.storage.Service/ListBuckets"
	Service_DeleteBucket_FullMethodName   = "/nuntio.sdk.api.storage.Service/DeleteBucket"
	Service_GetObject_FullMethodName      = "/nuntio.sdk.api.storage.Service/GetObject"
	Service_ListObjects_FullMethodName    = "/nuntio.sdk.api.storage.Service/ListObjects"
	Service_DeleteObject_FullMethodName   = "/nuntio.sdk.api.storage.Service/DeleteObject"
	Service_CopyObject_FullMethodName     = "/nuntio.sdk.api.storage.Service/CopyObject"
	Service_UploadObject_FullMethodName   = "/nuntio.sdk.api.storage.Service/UploadObject"
	Service_DownloadObject_FullMethodName = "/nuntio.sdk.api.storage.Service/DownloadObject"
)

Variables

var Service_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "nuntio.sdk.api.storage.Service",
	HandlerType: (*ServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "Ping",
			Handler:    _Service_Ping_Handler,
		},
		{
			MethodName: "CreateBucket",
			Handler:    _Service_CreateBucket_Handler,
		},
		{
			MethodName: "GetBucket",
			Handler:    _Service_GetBucket_Handler,
		},
		{
			MethodName: "ListBuckets",
			Handler:    _Service_ListBuckets_Handler,
		},
		{
			MethodName: "DeleteBucket",
			Handler:    _Service_DeleteBucket_Handler,
		},
		{
			MethodName: "GetObject",
			Handler:    _Service_GetObject_Handler,
		},
		{
			MethodName: "ListObjects",
			Handler:    _Service_ListObjects_Handler,
		},
		{
			MethodName: "DeleteObject",
			Handler:    _Service_DeleteObject_Handler,
		},
		{
			MethodName: "CopyObject",
			Handler:    _Service_CopyObject_Handler,
		},
	},
	Streams: []grpc.StreamDesc{
		{
			StreamName:    "UploadObject",
			Handler:       _Service_UploadObject_Handler,
			ClientStreams: true,
		},
		{
			StreamName:    "DownloadObject",
			Handler:       _Service_DownloadObject_Handler,
			ServerStreams: true,
		},
	},
	Metadata: "nuntio/sdk/api/storage/service.proto",
}

Service_ServiceDesc is the grpc.ServiceDesc for Service service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterServiceServer

func RegisterServiceServer(s grpc.ServiceRegistrar, srv ServiceServer)

Types

type ServiceClient

ServiceClient is the client API for Service service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewServiceClient

func NewServiceClient(cc grpc.ClientConnInterface) ServiceClient

type Service_DownloadObjectClient

type Service_DownloadObjectClient = grpc.ServerStreamingClient[storage.DownloadObjectResponse]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type Service_DownloadObjectServer

type Service_DownloadObjectServer = grpc.ServerStreamingServer[storage.DownloadObjectResponse]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type Service_UploadObjectClient

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type Service_UploadObjectServer

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type UnimplementedServiceServer

type UnimplementedServiceServer struct{}

UnimplementedServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedServiceServer) CopyObject

func (UnimplementedServiceServer) CreateBucket

func (UnimplementedServiceServer) DeleteBucket

func (UnimplementedServiceServer) DeleteObject

func (UnimplementedServiceServer) DownloadObject

func (UnimplementedServiceServer) GetBucket

func (UnimplementedServiceServer) GetObject

func (UnimplementedServiceServer) ListBuckets

func (UnimplementedServiceServer) ListObjects

func (UnimplementedServiceServer) Ping

func (UnimplementedServiceServer) UploadObject

type UnsafeServiceServer

type UnsafeServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ServiceServer will result in compilation errors.

Source Files

  • service_grpc.pb.go

Jump to