Documentation
¶
Index ¶
- Variables
- type CreateRequest
- func (x *CreateRequest) ClearDeployment()
- func (x *CreateRequest) GetDeployment() *deployment.Deployment
- func (x *CreateRequest) GetName() string
- func (x *CreateRequest) HasDeployment() bool
- func (*CreateRequest) ProtoMessage()
- func (x *CreateRequest) ProtoReflect() protoreflect.Message
- func (x *CreateRequest) Reset()
- func (x *CreateRequest) SetDeployment(v *deployment.Deployment)
- func (x *CreateRequest) SetName(v string)
- func (x *CreateRequest) String() string
- type CreateRequest_builder
- type CreateResponse
- type CreateResponse_builder
- type DeleteRequest
- type DeleteRequest_builder
- type DeleteResponse
- type DeleteResponse_builder
- type LogsRequest
- func (x *LogsRequest) GetFollow() bool
- func (x *LogsRequest) GetName() string
- func (*LogsRequest) ProtoMessage()
- func (x *LogsRequest) ProtoReflect() protoreflect.Message
- func (x *LogsRequest) Reset()
- func (x *LogsRequest) SetFollow(v bool)
- func (x *LogsRequest) SetName(v string)
- func (x *LogsRequest) String() string
- type LogsRequest_builder
- type LogsResponse
- func (x *LogsResponse) GetKind() LogsResponse_Kind
- func (x *LogsResponse) GetMessage() []byte
- func (*LogsResponse) ProtoMessage()
- func (x *LogsResponse) ProtoReflect() protoreflect.Message
- func (x *LogsResponse) Reset()
- func (x *LogsResponse) SetKind(v LogsResponse_Kind)
- func (x *LogsResponse) SetMessage(v []byte)
- func (x *LogsResponse) String() string
- type LogsResponse_Kind
- type LogsResponse_builder
- type PingRequest
- type PingRequest_builder
- type PingResponse
- type PingResponse_builder
Constants ¶
This section is empty.
Variables ¶
var ( LogsResponse_Kind_name = map[int32]string{ 0: "KIND_UNSPECIFIED", 1: "KIND_STDOUT", 2: "KIND_STDERR", } LogsResponse_Kind_value = map[string]int32{ "KIND_UNSPECIFIED": 0, "KIND_STDOUT": 1, "KIND_STDERR": 2, } )
Enum value maps for LogsResponse_Kind.
var File_nuntio_management_api_deployment_service_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type CreateRequest ¶
type CreateRequest struct {
// The deployment to create.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
Deployment *deployment.Deployment `protobuf:"bytes,2,opt,name=deployment,proto3" json:"deployment,omitempty"`
// contains filtered or unexported fields
}
The request of a deployment.Create RPC.
func (*CreateRequest) ClearDeployment ¶
func (x *CreateRequest) ClearDeployment()
func (*CreateRequest) GetDeployment ¶
func (x *CreateRequest) GetDeployment() *deployment.Deployment
func (*CreateRequest) GetName ¶
func (x *CreateRequest) GetName() string
func (*CreateRequest) HasDeployment ¶
func (x *CreateRequest) HasDeployment() bool
func (*CreateRequest) ProtoMessage ¶
func (*CreateRequest) ProtoMessage()
func (*CreateRequest) ProtoReflect ¶
func (x *CreateRequest) ProtoReflect() protoreflect.Message
func (*CreateRequest) Reset ¶
func (x *CreateRequest) Reset()
func (*CreateRequest) SetDeployment ¶
func (x *CreateRequest) SetDeployment(v *deployment.Deployment)
func (*CreateRequest) SetName ¶
func (x *CreateRequest) SetName(v string)
func (*CreateRequest) String ¶
func (x *CreateRequest) String() string
type CreateRequest_builder ¶
type CreateRequest_builder struct {
// The deployment to create.
Name string
Deployment *deployment.Deployment
// contains filtered or unexported fields
}
func (CreateRequest_builder) Build ¶
func (b0 CreateRequest_builder) Build() *CreateRequest
type CreateResponse ¶
type CreateResponse struct {
// contains filtered or unexported fields
}
The response of a deployment.Create RPC
func (*CreateResponse) ProtoMessage ¶
func (*CreateResponse) ProtoMessage()
func (*CreateResponse) ProtoReflect ¶
func (x *CreateResponse) ProtoReflect() protoreflect.Message
func (*CreateResponse) Reset ¶
func (x *CreateResponse) Reset()
func (*CreateResponse) String ¶
func (x *CreateResponse) String() string
type CreateResponse_builder ¶
type CreateResponse_builder struct {
// contains filtered or unexported fields
}
func (CreateResponse_builder) Build ¶
func (b0 CreateResponse_builder) Build() *CreateResponse
type DeleteRequest ¶
type DeleteRequest struct {
// The deployment to delete.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
The request of a deployment.Delete RPC.
func (*DeleteRequest) GetName ¶
func (x *DeleteRequest) GetName() string
func (*DeleteRequest) ProtoMessage ¶
func (*DeleteRequest) ProtoMessage()
func (*DeleteRequest) ProtoReflect ¶
func (x *DeleteRequest) ProtoReflect() protoreflect.Message
func (*DeleteRequest) Reset ¶
func (x *DeleteRequest) Reset()
func (*DeleteRequest) SetName ¶
func (x *DeleteRequest) SetName(v string)
func (*DeleteRequest) String ¶
func (x *DeleteRequest) String() string
type DeleteRequest_builder ¶
type DeleteRequest_builder struct {
// The deployment to delete.
Name string
// contains filtered or unexported fields
}
func (DeleteRequest_builder) Build ¶
func (b0 DeleteRequest_builder) Build() *DeleteRequest
type DeleteResponse ¶
type DeleteResponse struct {
// contains filtered or unexported fields
}
The response of a deployment.Delete RPC
func (*DeleteResponse) ProtoMessage ¶
func (*DeleteResponse) ProtoMessage()
func (*DeleteResponse) ProtoReflect ¶
func (x *DeleteResponse) ProtoReflect() protoreflect.Message
func (*DeleteResponse) Reset ¶
func (x *DeleteResponse) Reset()
func (*DeleteResponse) String ¶
func (x *DeleteResponse) String() string
type DeleteResponse_builder ¶
type DeleteResponse_builder struct {
// contains filtered or unexported fields
}
func (DeleteResponse_builder) Build ¶
func (b0 DeleteResponse_builder) Build() *DeleteResponse
type LogsRequest ¶
type LogsRequest struct {
// The deployment to read logs from.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// If true, the request will stay open and stream new log messages.
Follow bool `protobuf:"varint,2,opt,name=follow,proto3" json:"follow,omitempty"`
// contains filtered or unexported fields
}
The request of a deployment.Logs RPC.
func (*LogsRequest) GetFollow ¶
func (x *LogsRequest) GetFollow() bool
func (*LogsRequest) GetName ¶
func (x *LogsRequest) GetName() string
func (*LogsRequest) ProtoMessage ¶
func (*LogsRequest) ProtoMessage()
func (*LogsRequest) ProtoReflect ¶
func (x *LogsRequest) ProtoReflect() protoreflect.Message
func (*LogsRequest) Reset ¶
func (x *LogsRequest) Reset()
func (*LogsRequest) SetFollow ¶
func (x *LogsRequest) SetFollow(v bool)
func (*LogsRequest) SetName ¶
func (x *LogsRequest) SetName(v string)
func (*LogsRequest) String ¶
func (x *LogsRequest) String() string
type LogsRequest_builder ¶
type LogsRequest_builder struct {
// The deployment to read logs from.
Name string
// If true, the request will stay open and stream new log messages.
Follow bool
// contains filtered or unexported fields
}
func (LogsRequest_builder) Build ¶
func (b0 LogsRequest_builder) Build() *LogsRequest
type LogsResponse ¶
type LogsResponse struct {
Message []byte `protobuf:"bytes,1,opt,name=message,proto3" json:"message,omitempty"`
Kind LogsResponse_Kind `protobuf:"varint,2,opt,name=kind,proto3,enum=nuntio.management.api.deployment.LogsResponse_Kind" json:"kind,omitempty"`
// contains filtered or unexported fields
}
The response of a deployment.Logs RPC
func (*LogsResponse) GetKind ¶
func (x *LogsResponse) GetKind() LogsResponse_Kind
func (*LogsResponse) GetMessage ¶
func (x *LogsResponse) GetMessage() []byte
func (*LogsResponse) ProtoMessage ¶
func (*LogsResponse) ProtoMessage()
func (*LogsResponse) ProtoReflect ¶
func (x *LogsResponse) ProtoReflect() protoreflect.Message
func (*LogsResponse) Reset ¶
func (x *LogsResponse) Reset()
func (*LogsResponse) SetKind ¶
func (x *LogsResponse) SetKind(v LogsResponse_Kind)
func (*LogsResponse) SetMessage ¶
func (x *LogsResponse) SetMessage(v []byte)
func (*LogsResponse) String ¶
func (x *LogsResponse) String() string
type LogsResponse_Kind ¶
type LogsResponse_Kind int32
const ( LogsResponse_KIND_UNSPECIFIED LogsResponse_Kind = 0 LogsResponse_KIND_STDOUT LogsResponse_Kind = 1 LogsResponse_KIND_STDERR LogsResponse_Kind = 2 )
func (LogsResponse_Kind) Descriptor ¶
func (LogsResponse_Kind) Descriptor() protoreflect.EnumDescriptor
func (LogsResponse_Kind) Enum ¶
func (x LogsResponse_Kind) Enum() *LogsResponse_Kind
func (LogsResponse_Kind) Number ¶
func (x LogsResponse_Kind) Number() protoreflect.EnumNumber
func (LogsResponse_Kind) String ¶
func (x LogsResponse_Kind) String() string
func (LogsResponse_Kind) Type ¶
func (LogsResponse_Kind) Type() protoreflect.EnumType
type LogsResponse_builder ¶
type LogsResponse_builder struct {
Message []byte
Kind LogsResponse_Kind
// contains filtered or unexported fields
}
func (LogsResponse_builder) Build ¶
func (b0 LogsResponse_builder) Build() *LogsResponse
type PingRequest ¶
type PingRequest struct {
// contains filtered or unexported fields
}
The request of a deployment.Ping RPC.
func (*PingRequest) ProtoMessage ¶
func (*PingRequest) ProtoMessage()
func (*PingRequest) ProtoReflect ¶
func (x *PingRequest) ProtoReflect() protoreflect.Message
func (*PingRequest) Reset ¶
func (x *PingRequest) Reset()
func (*PingRequest) String ¶
func (x *PingRequest) String() string
type PingRequest_builder ¶
type PingRequest_builder struct {
// contains filtered or unexported fields
}
func (PingRequest_builder) Build ¶
func (b0 PingRequest_builder) Build() *PingRequest
type PingResponse ¶
type PingResponse struct {
// contains filtered or unexported fields
}
The response of a deployment.Ping RPC.
func (*PingResponse) ProtoMessage ¶
func (*PingResponse) ProtoMessage()
func (*PingResponse) ProtoReflect ¶
func (x *PingResponse) ProtoReflect() protoreflect.Message
func (*PingResponse) Reset ¶
func (x *PingResponse) Reset()
func (*PingResponse) String ¶
func (x *PingResponse) String() string
type PingResponse_builder ¶
type PingResponse_builder struct {
// contains filtered or unexported fields
}
func (PingResponse_builder) Build ¶
func (b0 PingResponse_builder) Build() *PingResponse
Source Files
¶
- service.pb.go
Click to show internal directories.
Click to hide internal directories.