Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterTraceServiceServer(s grpc.ServiceRegistrar, srv TraceServiceServer)
- type TraceServiceClient
- type TraceServiceServer
- type TraceService_ConfigClient
- type TraceService_ConfigServer
- type TraceService_ExportClient
- type TraceService_ExportServer
- type UnimplementedTraceServiceServer
- type UnsafeTraceServiceServer
Constants ¶
const ( TraceService_Config_FullMethodName = "/opencensus.proto.agent.trace.v1.TraceService/Config" TraceService_Export_FullMethodName = "/opencensus.proto.agent.trace.v1.TraceService/Export" )
Variables ¶
var TraceService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "opencensus.proto.agent.trace.v1.TraceService", HandlerType: (*TraceServiceServer)(nil), Methods: []grpc.MethodDesc{}, Streams: []grpc.StreamDesc{ { StreamName: "Config", Handler: _TraceService_Config_Handler, ServerStreams: true, ClientStreams: true, }, { StreamName: "Export", Handler: _TraceService_Export_Handler, ServerStreams: true, ClientStreams: true, }, }, Metadata: "opencensus/proto/agent/trace/v1/trace_service.proto", }
TraceService_ServiceDesc is the grpc.ServiceDesc for TraceService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterTraceServiceServer ¶
func RegisterTraceServiceServer(s grpc.ServiceRegistrar, srv TraceServiceServer)
Types ¶
type TraceServiceClient ¶
type TraceServiceClient interface {
// After initialization, this RPC must be kept alive for the entire life of
// the application. The agent pushes configs down to applications via a
// stream.
Config(ctx context.Context, opts ...grpc.CallOption) (grpc.BidiStreamingClient[v1.CurrentLibraryConfig, v1.UpdatedLibraryConfig], error)
// For performance reasons, it is recommended to keep this RPC
// alive for the entire life of the application.
Export(ctx context.Context, opts ...grpc.CallOption) (grpc.BidiStreamingClient[v1.ExportTraceServiceRequest, v1.ExportTraceServiceResponse], error)
}
TraceServiceClient is the client API for TraceService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
Service that can be used to push spans and configs between one Application instrumented with OpenCensus and an agent, or between an agent and a central collector or config service (in this case spans and configs are sent/received to/from multiple Applications).
func NewTraceServiceClient ¶
func NewTraceServiceClient(cc grpc.ClientConnInterface) TraceServiceClient
type TraceServiceServer ¶
type TraceServiceServer interface {
// After initialization, this RPC must be kept alive for the entire life of
// the application. The agent pushes configs down to applications via a
// stream.
Config(grpc.BidiStreamingServer[v1.CurrentLibraryConfig, v1.UpdatedLibraryConfig]) error
// For performance reasons, it is recommended to keep this RPC
// alive for the entire life of the application.
Export(grpc.BidiStreamingServer[v1.ExportTraceServiceRequest, v1.ExportTraceServiceResponse]) error
}
TraceServiceServer is the server API for TraceService service. All implementations should embed UnimplementedTraceServiceServer for forward compatibility.
Service that can be used to push spans and configs between one Application instrumented with OpenCensus and an agent, or between an agent and a central collector or config service (in this case spans and configs are sent/received to/from multiple Applications).
type TraceService_ConfigClient ¶
type TraceService_ConfigClient = grpc.BidiStreamingClient[v1.CurrentLibraryConfig, v1.UpdatedLibraryConfig]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type TraceService_ConfigServer ¶
type TraceService_ConfigServer = grpc.BidiStreamingServer[v1.CurrentLibraryConfig, v1.UpdatedLibraryConfig]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type TraceService_ExportClient ¶
type TraceService_ExportClient = grpc.BidiStreamingClient[v1.ExportTraceServiceRequest, v1.ExportTraceServiceResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type TraceService_ExportServer ¶
type TraceService_ExportServer = grpc.BidiStreamingServer[v1.ExportTraceServiceRequest, v1.ExportTraceServiceResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type UnimplementedTraceServiceServer ¶
type UnimplementedTraceServiceServer struct{}
UnimplementedTraceServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedTraceServiceServer) Config ¶
func (UnimplementedTraceServiceServer) Export ¶
type UnsafeTraceServiceServer ¶
type UnsafeTraceServiceServer interface {
// contains filtered or unexported methods
}
UnsafeTraceServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to TraceServiceServer will result in compilation errors.
Source Files
¶
- trace_service_grpc.pb.go