commonv1

package
v1.36.11-2024061717285... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	LibraryInfo_Language_name = map[int32]string{
		0:  "LANGUAGE_UNSPECIFIED",
		1:  "CPP",
		2:  "C_SHARP",
		3:  "ERLANG",
		4:  "GO_LANG",
		5:  "JAVA",
		6:  "NODE_JS",
		7:  "PHP",
		8:  "PYTHON",
		9:  "RUBY",
		10: "WEB_JS",
	}
	LibraryInfo_Language_value = map[string]int32{
		"LANGUAGE_UNSPECIFIED": 0,
		"CPP":                  1,
		"C_SHARP":              2,
		"ERLANG":               3,
		"GO_LANG":              4,
		"JAVA":                 5,
		"NODE_JS":              6,
		"PHP":                  7,
		"PYTHON":               8,
		"RUBY":                 9,
		"WEB_JS":               10,
	}
)

Enum value maps for LibraryInfo_Language.

var File_opencensus_proto_agent_common_v1_common_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type LibraryInfo

type LibraryInfo struct {

	// Language of OpenCensus Library.
	Language LibraryInfo_Language `` /* 129-byte string literal not displayed */
	// Version of Agent exporter of Library.
	ExporterVersion string `protobuf:"bytes,2,opt,name=exporter_version,json=exporterVersion,proto3" json:"exporter_version,omitempty"`
	// Version of OpenCensus Library.
	CoreLibraryVersion string `protobuf:"bytes,3,opt,name=core_library_version,json=coreLibraryVersion,proto3" json:"core_library_version,omitempty"`
	// contains filtered or unexported fields
}

Information on OpenCensus Library.

func (*LibraryInfo) GetCoreLibraryVersion

func (x *LibraryInfo) GetCoreLibraryVersion() string

func (*LibraryInfo) GetExporterVersion

func (x *LibraryInfo) GetExporterVersion() string

func (*LibraryInfo) GetLanguage

func (x *LibraryInfo) GetLanguage() LibraryInfo_Language

func (*LibraryInfo) ProtoMessage

func (*LibraryInfo) ProtoMessage()

func (*LibraryInfo) ProtoReflect

func (x *LibraryInfo) ProtoReflect() protoreflect.Message

func (*LibraryInfo) Reset

func (x *LibraryInfo) Reset()

func (*LibraryInfo) SetCoreLibraryVersion

func (x *LibraryInfo) SetCoreLibraryVersion(v string)

func (*LibraryInfo) SetExporterVersion

func (x *LibraryInfo) SetExporterVersion(v string)

func (*LibraryInfo) SetLanguage

func (x *LibraryInfo) SetLanguage(v LibraryInfo_Language)

func (*LibraryInfo) String

func (x *LibraryInfo) String() string

type LibraryInfo_Language

type LibraryInfo_Language int32
const (
	LibraryInfo_LANGUAGE_UNSPECIFIED LibraryInfo_Language = 0
	LibraryInfo_CPP                  LibraryInfo_Language = 1
	LibraryInfo_C_SHARP              LibraryInfo_Language = 2
	LibraryInfo_ERLANG               LibraryInfo_Language = 3
	LibraryInfo_GO_LANG              LibraryInfo_Language = 4
	LibraryInfo_JAVA                 LibraryInfo_Language = 5
	LibraryInfo_NODE_JS              LibraryInfo_Language = 6
	LibraryInfo_PHP                  LibraryInfo_Language = 7
	LibraryInfo_PYTHON               LibraryInfo_Language = 8
	LibraryInfo_RUBY                 LibraryInfo_Language = 9
	LibraryInfo_WEB_JS               LibraryInfo_Language = 10
)

func (LibraryInfo_Language) Descriptor

func (LibraryInfo_Language) Enum

func (LibraryInfo_Language) Number

func (LibraryInfo_Language) String

func (x LibraryInfo_Language) String() string

func (LibraryInfo_Language) Type

type LibraryInfo_builder

type LibraryInfo_builder struct {

	// Language of OpenCensus Library.
	Language LibraryInfo_Language
	// Version of Agent exporter of Library.
	ExporterVersion string
	// Version of OpenCensus Library.
	CoreLibraryVersion string
	// contains filtered or unexported fields
}

func (LibraryInfo_builder) Build

func (b0 LibraryInfo_builder) Build() *LibraryInfo

type Node

type Node struct {

	// Identifier that uniquely identifies a process within a VM/container.
	Identifier *ProcessIdentifier `protobuf:"bytes,1,opt,name=identifier,proto3" json:"identifier,omitempty"`
	// Information on the OpenCensus Library that initiates the stream.
	LibraryInfo *LibraryInfo `protobuf:"bytes,2,opt,name=library_info,json=libraryInfo,proto3" json:"library_info,omitempty"`
	// Additional information on service.
	ServiceInfo *ServiceInfo `protobuf:"bytes,3,opt,name=service_info,json=serviceInfo,proto3" json:"service_info,omitempty"`
	// Additional attributes.
	Attributes map[string]string `` /* 147-byte string literal not displayed */
	// contains filtered or unexported fields
}

Identifier metadata of the Node that produces the span or tracing data. Note, this is not the metadata about the Node or service that is described by associated spans. In the future we plan to extend the identifier proto definition to support additional information (e.g cloud id, etc.)

func (*Node) ClearIdentifier

func (x *Node) ClearIdentifier()

func (*Node) ClearLibraryInfo

func (x *Node) ClearLibraryInfo()

func (*Node) ClearServiceInfo

func (x *Node) ClearServiceInfo()

func (*Node) GetAttributes

func (x *Node) GetAttributes() map[string]string

func (*Node) GetIdentifier

func (x *Node) GetIdentifier() *ProcessIdentifier

func (*Node) GetLibraryInfo

func (x *Node) GetLibraryInfo() *LibraryInfo

func (*Node) GetServiceInfo

func (x *Node) GetServiceInfo() *ServiceInfo

func (*Node) HasIdentifier

func (x *Node) HasIdentifier() bool

func (*Node) HasLibraryInfo

func (x *Node) HasLibraryInfo() bool

func (*Node) HasServiceInfo

func (x *Node) HasServiceInfo() bool

func (*Node) ProtoMessage

func (*Node) ProtoMessage()

func (*Node) ProtoReflect

func (x *Node) ProtoReflect() protoreflect.Message

func (*Node) Reset

func (x *Node) Reset()

func (*Node) SetAttributes

func (x *Node) SetAttributes(v map[string]string)

func (*Node) SetIdentifier

func (x *Node) SetIdentifier(v *ProcessIdentifier)

func (*Node) SetLibraryInfo

func (x *Node) SetLibraryInfo(v *LibraryInfo)

func (*Node) SetServiceInfo

func (x *Node) SetServiceInfo(v *ServiceInfo)

func (*Node) String

func (x *Node) String() string

type Node_builder

type Node_builder struct {

	// Identifier that uniquely identifies a process within a VM/container.
	Identifier *ProcessIdentifier
	// Information on the OpenCensus Library that initiates the stream.
	LibraryInfo *LibraryInfo
	// Additional information on service.
	ServiceInfo *ServiceInfo
	// Additional attributes.
	Attributes map[string]string
	// contains filtered or unexported fields
}

func (Node_builder) Build

func (b0 Node_builder) Build() *Node

type ProcessIdentifier

type ProcessIdentifier struct {

	// The host name. Usually refers to the machine/container name.
	// For example: os.Hostname() in Go, socket.gethostname() in Python.
	HostName string `protobuf:"bytes,1,opt,name=host_name,json=hostName,proto3" json:"host_name,omitempty"`
	// Process id.
	Pid uint32 `protobuf:"varint,2,opt,name=pid,proto3" json:"pid,omitempty"`
	// Start time of this ProcessIdentifier. Represented in epoch time.
	StartTimestamp *timestamppb.Timestamp `protobuf:"bytes,3,opt,name=start_timestamp,json=startTimestamp,proto3" json:"start_timestamp,omitempty"`
	// contains filtered or unexported fields
}

Identifier that uniquely identifies a process within a VM/container.

func (*ProcessIdentifier) ClearStartTimestamp

func (x *ProcessIdentifier) ClearStartTimestamp()

func (*ProcessIdentifier) GetHostName

func (x *ProcessIdentifier) GetHostName() string

func (*ProcessIdentifier) GetPid

func (x *ProcessIdentifier) GetPid() uint32

func (*ProcessIdentifier) GetStartTimestamp

func (x *ProcessIdentifier) GetStartTimestamp() *timestamppb.Timestamp

func (*ProcessIdentifier) HasStartTimestamp

func (x *ProcessIdentifier) HasStartTimestamp() bool

func (*ProcessIdentifier) ProtoMessage

func (*ProcessIdentifier) ProtoMessage()

func (*ProcessIdentifier) ProtoReflect

func (x *ProcessIdentifier) ProtoReflect() protoreflect.Message

func (*ProcessIdentifier) Reset

func (x *ProcessIdentifier) Reset()

func (*ProcessIdentifier) SetHostName

func (x *ProcessIdentifier) SetHostName(v string)

func (*ProcessIdentifier) SetPid

func (x *ProcessIdentifier) SetPid(v uint32)

func (*ProcessIdentifier) SetStartTimestamp

func (x *ProcessIdentifier) SetStartTimestamp(v *timestamppb.Timestamp)

func (*ProcessIdentifier) String

func (x *ProcessIdentifier) String() string

type ProcessIdentifier_builder

type ProcessIdentifier_builder struct {

	// The host name. Usually refers to the machine/container name.
	// For example: os.Hostname() in Go, socket.gethostname() in Python.
	HostName string
	// Process id.
	Pid uint32
	// Start time of this ProcessIdentifier. Represented in epoch time.
	StartTimestamp *timestamppb.Timestamp
	// contains filtered or unexported fields
}

func (ProcessIdentifier_builder) Build

type ServiceInfo

type ServiceInfo struct {

	// Name of the service.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// contains filtered or unexported fields
}

Additional service information.

func (*ServiceInfo) GetName

func (x *ServiceInfo) GetName() string

func (*ServiceInfo) ProtoMessage

func (*ServiceInfo) ProtoMessage()

func (*ServiceInfo) ProtoReflect

func (x *ServiceInfo) ProtoReflect() protoreflect.Message

func (*ServiceInfo) Reset

func (x *ServiceInfo) Reset()

func (*ServiceInfo) SetName

func (x *ServiceInfo) SetName(v string)

func (*ServiceInfo) String

func (x *ServiceInfo) String() string

type ServiceInfo_builder

type ServiceInfo_builder struct {

	// Name of the service.
	Name string
	// contains filtered or unexported fields
}

func (ServiceInfo_builder) Build

func (b0 ServiceInfo_builder) Build() *ServiceInfo

Source Files

  • common.pb.go

Jump to