Documentation
¶
Index ¶
- Variables
- type ExportMetricsServiceRequest
- func (x *ExportMetricsServiceRequest) ClearNode()
- func (x *ExportMetricsServiceRequest) ClearResource()
- func (x *ExportMetricsServiceRequest) GetMetrics() []*v11.Metric
- func (x *ExportMetricsServiceRequest) GetNode() *v1.Node
- func (x *ExportMetricsServiceRequest) GetResource() *v12.Resource
- func (x *ExportMetricsServiceRequest) HasNode() bool
- func (x *ExportMetricsServiceRequest) HasResource() bool
- func (*ExportMetricsServiceRequest) ProtoMessage()
- func (x *ExportMetricsServiceRequest) ProtoReflect() protoreflect.Message
- func (x *ExportMetricsServiceRequest) Reset()
- func (x *ExportMetricsServiceRequest) SetMetrics(v []*v11.Metric)
- func (x *ExportMetricsServiceRequest) SetNode(v *v1.Node)
- func (x *ExportMetricsServiceRequest) SetResource(v *v12.Resource)
- func (x *ExportMetricsServiceRequest) String() string
- type ExportMetricsServiceRequest_builder
- type ExportMetricsServiceResponse
- type ExportMetricsServiceResponse_builder
Constants ¶
This section is empty.
Variables ¶
var File_opencensus_proto_agent_metrics_v1_metrics_service_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type ExportMetricsServiceRequest ¶
type ExportMetricsServiceRequest struct {
// This is required only in the first message on the stream or if the
// previous sent ExportMetricsServiceRequest message has a different Node (e.g.
// when the same RPC is used to send Metrics from multiple Applications).
Node *v1.Node `protobuf:"bytes,1,opt,name=node,proto3" json:"node,omitempty"`
// A list of metrics that belong to the last received Node.
Metrics []*v11.Metric `protobuf:"bytes,2,rep,name=metrics,proto3" json:"metrics,omitempty"`
// The resource for the metrics in this message that do not have an explicit
// resource set.
// If unset, the most recently set resource in the RPC stream applies. It is
// valid to never be set within a stream, e.g. when no resource info is known
// at all or when all sent metrics have an explicit resource set.
Resource *v12.Resource `protobuf:"bytes,3,opt,name=resource,proto3" json:"resource,omitempty"`
// contains filtered or unexported fields
}
func (*ExportMetricsServiceRequest) ClearNode ¶
func (x *ExportMetricsServiceRequest) ClearNode()
func (*ExportMetricsServiceRequest) ClearResource ¶
func (x *ExportMetricsServiceRequest) ClearResource()
func (*ExportMetricsServiceRequest) GetMetrics ¶
func (x *ExportMetricsServiceRequest) GetMetrics() []*v11.Metric
func (*ExportMetricsServiceRequest) GetNode ¶
func (x *ExportMetricsServiceRequest) GetNode() *v1.Node
func (*ExportMetricsServiceRequest) GetResource ¶
func (x *ExportMetricsServiceRequest) GetResource() *v12.Resource
func (*ExportMetricsServiceRequest) HasNode ¶
func (x *ExportMetricsServiceRequest) HasNode() bool
func (*ExportMetricsServiceRequest) HasResource ¶
func (x *ExportMetricsServiceRequest) HasResource() bool
func (*ExportMetricsServiceRequest) ProtoMessage ¶
func (*ExportMetricsServiceRequest) ProtoMessage()
func (*ExportMetricsServiceRequest) ProtoReflect ¶
func (x *ExportMetricsServiceRequest) ProtoReflect() protoreflect.Message
func (*ExportMetricsServiceRequest) Reset ¶
func (x *ExportMetricsServiceRequest) Reset()
func (*ExportMetricsServiceRequest) SetMetrics ¶
func (x *ExportMetricsServiceRequest) SetMetrics(v []*v11.Metric)
func (*ExportMetricsServiceRequest) SetNode ¶
func (x *ExportMetricsServiceRequest) SetNode(v *v1.Node)
func (*ExportMetricsServiceRequest) SetResource ¶
func (x *ExportMetricsServiceRequest) SetResource(v *v12.Resource)
func (*ExportMetricsServiceRequest) String ¶
func (x *ExportMetricsServiceRequest) String() string
type ExportMetricsServiceRequest_builder ¶
type ExportMetricsServiceRequest_builder struct {
// This is required only in the first message on the stream or if the
// previous sent ExportMetricsServiceRequest message has a different Node (e.g.
// when the same RPC is used to send Metrics from multiple Applications).
Node *v1.Node
// A list of metrics that belong to the last received Node.
Metrics []*v11.Metric
// The resource for the metrics in this message that do not have an explicit
// resource set.
// If unset, the most recently set resource in the RPC stream applies. It is
// valid to never be set within a stream, e.g. when no resource info is known
// at all or when all sent metrics have an explicit resource set.
Resource *v12.Resource
// contains filtered or unexported fields
}
func (ExportMetricsServiceRequest_builder) Build ¶
func (b0 ExportMetricsServiceRequest_builder) Build() *ExportMetricsServiceRequest
type ExportMetricsServiceResponse ¶
type ExportMetricsServiceResponse struct {
// contains filtered or unexported fields
}
func (*ExportMetricsServiceResponse) ProtoMessage ¶
func (*ExportMetricsServiceResponse) ProtoMessage()
func (*ExportMetricsServiceResponse) ProtoReflect ¶
func (x *ExportMetricsServiceResponse) ProtoReflect() protoreflect.Message
func (*ExportMetricsServiceResponse) Reset ¶
func (x *ExportMetricsServiceResponse) Reset()
func (*ExportMetricsServiceResponse) String ¶
func (x *ExportMetricsServiceResponse) String() string
type ExportMetricsServiceResponse_builder ¶
type ExportMetricsServiceResponse_builder struct {
// contains filtered or unexported fields
}
func (ExportMetricsServiceResponse_builder) Build ¶
func (b0 ExportMetricsServiceResponse_builder) Build() *ExportMetricsServiceResponse
Source Files
¶
- metrics_service.pb.go
Click to show internal directories.
Click to hide internal directories.