Documentation
¶
Index ¶
- Constants
- Variables
- type DistributionValue
- func (x *DistributionValue) ClearBucketOptions()
- func (x *DistributionValue) GetBucketOptions() *DistributionValue_BucketOptions
- func (x *DistributionValue) GetBuckets() []*DistributionValue_Bucket
- func (x *DistributionValue) GetCount() int64
- func (x *DistributionValue) GetSum() float64
- func (x *DistributionValue) GetSumOfSquaredDeviation() float64
- func (x *DistributionValue) HasBucketOptions() bool
- func (*DistributionValue) ProtoMessage()
- func (x *DistributionValue) ProtoReflect() protoreflect.Message
- func (x *DistributionValue) Reset()
- func (x *DistributionValue) SetBucketOptions(v *DistributionValue_BucketOptions)
- func (x *DistributionValue) SetBuckets(v []*DistributionValue_Bucket)
- func (x *DistributionValue) SetCount(v int64)
- func (x *DistributionValue) SetSum(v float64)
- func (x *DistributionValue) SetSumOfSquaredDeviation(v float64)
- func (x *DistributionValue) String() string
- type DistributionValue_Bucket
- func (x *DistributionValue_Bucket) ClearExemplar()
- func (x *DistributionValue_Bucket) GetCount() int64
- func (x *DistributionValue_Bucket) GetExemplar() *DistributionValue_Exemplar
- func (x *DistributionValue_Bucket) HasExemplar() bool
- func (*DistributionValue_Bucket) ProtoMessage()
- func (x *DistributionValue_Bucket) ProtoReflect() protoreflect.Message
- func (x *DistributionValue_Bucket) Reset()
- func (x *DistributionValue_Bucket) SetCount(v int64)
- func (x *DistributionValue_Bucket) SetExemplar(v *DistributionValue_Exemplar)
- func (x *DistributionValue_Bucket) String() string
- type DistributionValue_BucketOptions
- func (x *DistributionValue_BucketOptions) ClearExplicit()
- func (x *DistributionValue_BucketOptions) ClearType()
- func (x *DistributionValue_BucketOptions) GetExplicit() *DistributionValue_BucketOptions_Explicit
- func (x *DistributionValue_BucketOptions) GetType() isDistributionValue_BucketOptions_Type
- func (x *DistributionValue_BucketOptions) HasExplicit() bool
- func (x *DistributionValue_BucketOptions) HasType() bool
- func (*DistributionValue_BucketOptions) ProtoMessage()
- func (x *DistributionValue_BucketOptions) ProtoReflect() protoreflect.Message
- func (x *DistributionValue_BucketOptions) Reset()
- func (x *DistributionValue_BucketOptions) SetExplicit(v *DistributionValue_BucketOptions_Explicit)
- func (x *DistributionValue_BucketOptions) String() string
- func (x *DistributionValue_BucketOptions) WhichType() case_DistributionValue_BucketOptions_Type
- type DistributionValue_BucketOptions_Explicit
- func (x *DistributionValue_BucketOptions_Explicit) GetBounds() []float64
- func (*DistributionValue_BucketOptions_Explicit) ProtoMessage()
- func (x *DistributionValue_BucketOptions_Explicit) ProtoReflect() protoreflect.Message
- func (x *DistributionValue_BucketOptions_Explicit) Reset()
- func (x *DistributionValue_BucketOptions_Explicit) SetBounds(v []float64)
- func (x *DistributionValue_BucketOptions_Explicit) String() string
- type DistributionValue_BucketOptions_Explicit_
- type DistributionValue_BucketOptions_Explicit_builder
- type DistributionValue_BucketOptions_builder
- type DistributionValue_Bucket_builder
- type DistributionValue_Exemplar
- func (x *DistributionValue_Exemplar) ClearTimestamp()
- func (x *DistributionValue_Exemplar) GetAttachments() map[string]string
- func (x *DistributionValue_Exemplar) GetTimestamp() *timestamppb.Timestamp
- func (x *DistributionValue_Exemplar) GetValue() float64
- func (x *DistributionValue_Exemplar) HasTimestamp() bool
- func (*DistributionValue_Exemplar) ProtoMessage()
- func (x *DistributionValue_Exemplar) ProtoReflect() protoreflect.Message
- func (x *DistributionValue_Exemplar) Reset()
- func (x *DistributionValue_Exemplar) SetAttachments(v map[string]string)
- func (x *DistributionValue_Exemplar) SetTimestamp(v *timestamppb.Timestamp)
- func (x *DistributionValue_Exemplar) SetValue(v float64)
- func (x *DistributionValue_Exemplar) String() string
- type DistributionValue_Exemplar_builder
- type DistributionValue_builder
- type LabelKey
- func (x *LabelKey) GetDescription() string
- func (x *LabelKey) GetKey() string
- func (*LabelKey) ProtoMessage()
- func (x *LabelKey) ProtoReflect() protoreflect.Message
- func (x *LabelKey) Reset()
- func (x *LabelKey) SetDescription(v string)
- func (x *LabelKey) SetKey(v string)
- func (x *LabelKey) String() string
- type LabelKey_builder
- type LabelValue
- func (x *LabelValue) GetHasValue() bool
- func (x *LabelValue) GetValue() string
- func (*LabelValue) ProtoMessage()
- func (x *LabelValue) ProtoReflect() protoreflect.Message
- func (x *LabelValue) Reset()
- func (x *LabelValue) SetHasValue(v bool)
- func (x *LabelValue) SetValue(v string)
- func (x *LabelValue) String() string
- type LabelValue_builder
- type Metric
- func (x *Metric) ClearMetricDescriptor()
- func (x *Metric) ClearResource()
- func (x *Metric) GetMetricDescriptor() *MetricDescriptor
- func (x *Metric) GetResource() *v1.Resource
- func (x *Metric) GetTimeseries() []*TimeSeries
- func (x *Metric) HasMetricDescriptor() bool
- func (x *Metric) HasResource() bool
- func (*Metric) ProtoMessage()
- func (x *Metric) ProtoReflect() protoreflect.Message
- func (x *Metric) Reset()
- func (x *Metric) SetMetricDescriptor(v *MetricDescriptor)
- func (x *Metric) SetResource(v *v1.Resource)
- func (x *Metric) SetTimeseries(v []*TimeSeries)
- func (x *Metric) String() string
- type MetricDescriptor
- func (x *MetricDescriptor) GetDescription() string
- func (x *MetricDescriptor) GetLabelKeys() []*LabelKey
- func (x *MetricDescriptor) GetName() string
- func (x *MetricDescriptor) GetType() MetricDescriptor_Type
- func (x *MetricDescriptor) GetUnit() string
- func (*MetricDescriptor) ProtoMessage()
- func (x *MetricDescriptor) ProtoReflect() protoreflect.Message
- func (x *MetricDescriptor) Reset()
- func (x *MetricDescriptor) SetDescription(v string)
- func (x *MetricDescriptor) SetLabelKeys(v []*LabelKey)
- func (x *MetricDescriptor) SetName(v string)
- func (x *MetricDescriptor) SetType(v MetricDescriptor_Type)
- func (x *MetricDescriptor) SetUnit(v string)
- func (x *MetricDescriptor) String() string
- type MetricDescriptor_Type
- type MetricDescriptor_builder
- type Metric_builder
- type Point
- func (x *Point) ClearDistributionValue()
- func (x *Point) ClearDoubleValue()
- func (x *Point) ClearInt64Value()
- func (x *Point) ClearSummaryValue()
- func (x *Point) ClearTimestamp()
- func (x *Point) ClearValue()
- func (x *Point) GetDistributionValue() *DistributionValue
- func (x *Point) GetDoubleValue() float64
- func (x *Point) GetInt64Value() int64
- func (x *Point) GetSummaryValue() *SummaryValue
- func (x *Point) GetTimestamp() *timestamppb.Timestamp
- func (x *Point) GetValue() isPoint_Value
- func (x *Point) HasDistributionValue() bool
- func (x *Point) HasDoubleValue() bool
- func (x *Point) HasInt64Value() bool
- func (x *Point) HasSummaryValue() bool
- func (x *Point) HasTimestamp() bool
- func (x *Point) HasValue() bool
- func (*Point) ProtoMessage()
- func (x *Point) ProtoReflect() protoreflect.Message
- func (x *Point) Reset()
- func (x *Point) SetDistributionValue(v *DistributionValue)
- func (x *Point) SetDoubleValue(v float64)
- func (x *Point) SetInt64Value(v int64)
- func (x *Point) SetSummaryValue(v *SummaryValue)
- func (x *Point) SetTimestamp(v *timestamppb.Timestamp)
- func (x *Point) String() string
- func (x *Point) WhichValue() case_Point_Value
- type Point_DistributionValue
- type Point_DoubleValue
- type Point_Int64Value
- type Point_SummaryValue
- type Point_builder
- type SummaryValue
- func (x *SummaryValue) ClearCount()
- func (x *SummaryValue) ClearSnapshot()
- func (x *SummaryValue) ClearSum()
- func (x *SummaryValue) GetCount() *wrapperspb.Int64Value
- func (x *SummaryValue) GetSnapshot() *SummaryValue_Snapshot
- func (x *SummaryValue) GetSum() *wrapperspb.DoubleValue
- func (x *SummaryValue) HasCount() bool
- func (x *SummaryValue) HasSnapshot() bool
- func (x *SummaryValue) HasSum() bool
- func (*SummaryValue) ProtoMessage()
- func (x *SummaryValue) ProtoReflect() protoreflect.Message
- func (x *SummaryValue) Reset()
- func (x *SummaryValue) SetCount(v *wrapperspb.Int64Value)
- func (x *SummaryValue) SetSnapshot(v *SummaryValue_Snapshot)
- func (x *SummaryValue) SetSum(v *wrapperspb.DoubleValue)
- func (x *SummaryValue) String() string
- type SummaryValue_Snapshot
- func (x *SummaryValue_Snapshot) ClearCount()
- func (x *SummaryValue_Snapshot) ClearSum()
- func (x *SummaryValue_Snapshot) GetCount() *wrapperspb.Int64Value
- func (x *SummaryValue_Snapshot) GetPercentileValues() []*SummaryValue_Snapshot_ValueAtPercentile
- func (x *SummaryValue_Snapshot) GetSum() *wrapperspb.DoubleValue
- func (x *SummaryValue_Snapshot) HasCount() bool
- func (x *SummaryValue_Snapshot) HasSum() bool
- func (*SummaryValue_Snapshot) ProtoMessage()
- func (x *SummaryValue_Snapshot) ProtoReflect() protoreflect.Message
- func (x *SummaryValue_Snapshot) Reset()
- func (x *SummaryValue_Snapshot) SetCount(v *wrapperspb.Int64Value)
- func (x *SummaryValue_Snapshot) SetPercentileValues(v []*SummaryValue_Snapshot_ValueAtPercentile)
- func (x *SummaryValue_Snapshot) SetSum(v *wrapperspb.DoubleValue)
- func (x *SummaryValue_Snapshot) String() string
- type SummaryValue_Snapshot_ValueAtPercentile
- func (x *SummaryValue_Snapshot_ValueAtPercentile) GetPercentile() float64
- func (x *SummaryValue_Snapshot_ValueAtPercentile) GetValue() float64
- func (*SummaryValue_Snapshot_ValueAtPercentile) ProtoMessage()
- func (x *SummaryValue_Snapshot_ValueAtPercentile) ProtoReflect() protoreflect.Message
- func (x *SummaryValue_Snapshot_ValueAtPercentile) Reset()
- func (x *SummaryValue_Snapshot_ValueAtPercentile) SetPercentile(v float64)
- func (x *SummaryValue_Snapshot_ValueAtPercentile) SetValue(v float64)
- func (x *SummaryValue_Snapshot_ValueAtPercentile) String() string
- type SummaryValue_Snapshot_ValueAtPercentile_builder
- type SummaryValue_Snapshot_builder
- type SummaryValue_builder
- type TimeSeries
- func (x *TimeSeries) ClearStartTimestamp()
- func (x *TimeSeries) GetLabelValues() []*LabelValue
- func (x *TimeSeries) GetPoints() []*Point
- func (x *TimeSeries) GetStartTimestamp() *timestamppb.Timestamp
- func (x *TimeSeries) HasStartTimestamp() bool
- func (*TimeSeries) ProtoMessage()
- func (x *TimeSeries) ProtoReflect() protoreflect.Message
- func (x *TimeSeries) Reset()
- func (x *TimeSeries) SetLabelValues(v []*LabelValue)
- func (x *TimeSeries) SetPoints(v []*Point)
- func (x *TimeSeries) SetStartTimestamp(v *timestamppb.Timestamp)
- func (x *TimeSeries) String() string
- type TimeSeries_builder
Constants ¶
const DistributionValue_BucketOptions_Explicit_case case_DistributionValue_BucketOptions_Type = 1
const DistributionValue_BucketOptions_Type_not_set_case case_DistributionValue_BucketOptions_Type = 0
const Point_DistributionValue_case case_Point_Value = 4
const Point_DoubleValue_case case_Point_Value = 3
const Point_Int64Value_case case_Point_Value = 2
const Point_SummaryValue_case case_Point_Value = 5
const Point_Value_not_set_case case_Point_Value = 0
Variables ¶
var ( MetricDescriptor_Type_name = map[int32]string{ 0: "UNSPECIFIED", 1: "GAUGE_INT64", 2: "GAUGE_DOUBLE", 3: "GAUGE_DISTRIBUTION", 4: "CUMULATIVE_INT64", 5: "CUMULATIVE_DOUBLE", 6: "CUMULATIVE_DISTRIBUTION", 7: "SUMMARY", } MetricDescriptor_Type_value = map[string]int32{ "UNSPECIFIED": 0, "GAUGE_INT64": 1, "GAUGE_DOUBLE": 2, "GAUGE_DISTRIBUTION": 3, "CUMULATIVE_INT64": 4, "CUMULATIVE_DOUBLE": 5, "CUMULATIVE_DISTRIBUTION": 6, "SUMMARY": 7, } )
Enum value maps for MetricDescriptor_Type.
var File_opencensus_proto_metrics_v1_metrics_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type DistributionValue ¶
type DistributionValue struct {
// The number of values in the population. Must be non-negative. This value
// must equal the sum of the values in bucket_counts if a histogram is
// provided.
Count int64 `protobuf:"varint,1,opt,name=count,proto3" json:"count,omitempty"`
// The sum of the values in the population. If count is zero then this field
// must be zero.
Sum float64 `protobuf:"fixed64,2,opt,name=sum,proto3" json:"sum,omitempty"`
// The sum of squared deviations from the mean of the values in the
// population. For values x_i this is:
//
// Sum[i=1..n]((x_i - mean)^2)
//
// Knuth, "The Art of Computer Programming", Vol. 2, page 323, 3rd edition
// describes Welford's method for accumulating this sum in one pass.
//
// If count is zero then this field must be zero.
SumOfSquaredDeviation float64 `` /* 130-byte string literal not displayed */
// Don't change bucket boundaries within a TimeSeries if your backend doesn't
// support this.
// TODO(issue #152): consider not required to send bucket options for
// optimization.
BucketOptions *DistributionValue_BucketOptions `protobuf:"bytes,4,opt,name=bucket_options,json=bucketOptions,proto3" json:"bucket_options,omitempty"`
// If the distribution does not have a histogram, then omit this field.
// If there is a histogram, then the sum of the values in the Bucket counts
// must equal the value in the count field of the distribution.
Buckets []*DistributionValue_Bucket `protobuf:"bytes,5,rep,name=buckets,proto3" json:"buckets,omitempty"`
// contains filtered or unexported fields
}
Distribution contains summary statistics for a population of values. It optionally contains a histogram representing the distribution of those values across a set of buckets.
func (*DistributionValue) ClearBucketOptions ¶
func (x *DistributionValue) ClearBucketOptions()
func (*DistributionValue) GetBucketOptions ¶
func (x *DistributionValue) GetBucketOptions() *DistributionValue_BucketOptions
func (*DistributionValue) GetBuckets ¶
func (x *DistributionValue) GetBuckets() []*DistributionValue_Bucket
func (*DistributionValue) GetCount ¶
func (x *DistributionValue) GetCount() int64
func (*DistributionValue) GetSum ¶
func (x *DistributionValue) GetSum() float64
func (*DistributionValue) GetSumOfSquaredDeviation ¶
func (x *DistributionValue) GetSumOfSquaredDeviation() float64
func (*DistributionValue) HasBucketOptions ¶
func (x *DistributionValue) HasBucketOptions() bool
func (*DistributionValue) ProtoMessage ¶
func (*DistributionValue) ProtoMessage()
func (*DistributionValue) ProtoReflect ¶
func (x *DistributionValue) ProtoReflect() protoreflect.Message
func (*DistributionValue) Reset ¶
func (x *DistributionValue) Reset()
func (*DistributionValue) SetBucketOptions ¶
func (x *DistributionValue) SetBucketOptions(v *DistributionValue_BucketOptions)
func (*DistributionValue) SetBuckets ¶
func (x *DistributionValue) SetBuckets(v []*DistributionValue_Bucket)
func (*DistributionValue) SetCount ¶
func (x *DistributionValue) SetCount(v int64)
func (*DistributionValue) SetSum ¶
func (x *DistributionValue) SetSum(v float64)
func (*DistributionValue) SetSumOfSquaredDeviation ¶
func (x *DistributionValue) SetSumOfSquaredDeviation(v float64)
func (*DistributionValue) String ¶
func (x *DistributionValue) String() string
type DistributionValue_Bucket ¶
type DistributionValue_Bucket struct {
// The number of values in each bucket of the histogram, as described in
// bucket_bounds.
Count int64 `protobuf:"varint,1,opt,name=count,proto3" json:"count,omitempty"`
// If the distribution does not have a histogram, then omit this field.
Exemplar *DistributionValue_Exemplar `protobuf:"bytes,2,opt,name=exemplar,proto3" json:"exemplar,omitempty"`
// contains filtered or unexported fields
}
func (*DistributionValue_Bucket) ClearExemplar ¶
func (x *DistributionValue_Bucket) ClearExemplar()
func (*DistributionValue_Bucket) GetCount ¶
func (x *DistributionValue_Bucket) GetCount() int64
func (*DistributionValue_Bucket) GetExemplar ¶
func (x *DistributionValue_Bucket) GetExemplar() *DistributionValue_Exemplar
func (*DistributionValue_Bucket) HasExemplar ¶
func (x *DistributionValue_Bucket) HasExemplar() bool
func (*DistributionValue_Bucket) ProtoMessage ¶
func (*DistributionValue_Bucket) ProtoMessage()
func (*DistributionValue_Bucket) ProtoReflect ¶
func (x *DistributionValue_Bucket) ProtoReflect() protoreflect.Message
func (*DistributionValue_Bucket) Reset ¶
func (x *DistributionValue_Bucket) Reset()
func (*DistributionValue_Bucket) SetCount ¶
func (x *DistributionValue_Bucket) SetCount(v int64)
func (*DistributionValue_Bucket) SetExemplar ¶
func (x *DistributionValue_Bucket) SetExemplar(v *DistributionValue_Exemplar)
func (*DistributionValue_Bucket) String ¶
func (x *DistributionValue_Bucket) String() string
type DistributionValue_BucketOptions ¶
type DistributionValue_BucketOptions struct {
// Types that are valid to be assigned to Type:
//
// *DistributionValue_BucketOptions_Explicit_
Type isDistributionValue_BucketOptions_Type `protobuf_oneof:"type"`
// contains filtered or unexported fields
}
A Distribution may optionally contain a histogram of the values in the population. The bucket boundaries for that histogram are described by BucketOptions.
If bucket_options has no type, then there is no histogram associated with the Distribution.
func (*DistributionValue_BucketOptions) ClearExplicit ¶
func (x *DistributionValue_BucketOptions) ClearExplicit()
func (*DistributionValue_BucketOptions) ClearType ¶
func (x *DistributionValue_BucketOptions) ClearType()
func (*DistributionValue_BucketOptions) GetExplicit ¶
func (x *DistributionValue_BucketOptions) GetExplicit() *DistributionValue_BucketOptions_Explicit
func (*DistributionValue_BucketOptions) GetType ¶
func (x *DistributionValue_BucketOptions) GetType() isDistributionValue_BucketOptions_Type
func (*DistributionValue_BucketOptions) HasExplicit ¶
func (x *DistributionValue_BucketOptions) HasExplicit() bool
func (*DistributionValue_BucketOptions) HasType ¶
func (x *DistributionValue_BucketOptions) HasType() bool
func (*DistributionValue_BucketOptions) ProtoMessage ¶
func (*DistributionValue_BucketOptions) ProtoMessage()
func (*DistributionValue_BucketOptions) ProtoReflect ¶
func (x *DistributionValue_BucketOptions) ProtoReflect() protoreflect.Message
func (*DistributionValue_BucketOptions) Reset ¶
func (x *DistributionValue_BucketOptions) Reset()
func (*DistributionValue_BucketOptions) SetExplicit ¶
func (x *DistributionValue_BucketOptions) SetExplicit(v *DistributionValue_BucketOptions_Explicit)
func (*DistributionValue_BucketOptions) String ¶
func (x *DistributionValue_BucketOptions) String() string
func (*DistributionValue_BucketOptions) WhichType ¶
func (x *DistributionValue_BucketOptions) WhichType() case_DistributionValue_BucketOptions_Type
type DistributionValue_BucketOptions_Explicit ¶
type DistributionValue_BucketOptions_Explicit struct {
// The values must be strictly increasing and > 0.
Bounds []float64 `protobuf:"fixed64,1,rep,packed,name=bounds,proto3" json:"bounds,omitempty"`
// contains filtered or unexported fields
}
Specifies a set of buckets with arbitrary upper-bounds. This defines size(bounds) + 1 (= N) buckets. The boundaries for bucket index i are:
[0, bucket_bounds[i]) for i == 0 [bucket_bounds[i-1], bucket_bounds[i]) for 0 < i < N-1 [bucket_bounds[i], +infinity) for i == N-1
func (*DistributionValue_BucketOptions_Explicit) GetBounds ¶
func (x *DistributionValue_BucketOptions_Explicit) GetBounds() []float64
func (*DistributionValue_BucketOptions_Explicit) ProtoMessage ¶
func (*DistributionValue_BucketOptions_Explicit) ProtoMessage()
func (*DistributionValue_BucketOptions_Explicit) ProtoReflect ¶
func (x *DistributionValue_BucketOptions_Explicit) ProtoReflect() protoreflect.Message
func (*DistributionValue_BucketOptions_Explicit) Reset ¶
func (x *DistributionValue_BucketOptions_Explicit) Reset()
func (*DistributionValue_BucketOptions_Explicit) SetBounds ¶
func (x *DistributionValue_BucketOptions_Explicit) SetBounds(v []float64)
func (*DistributionValue_BucketOptions_Explicit) String ¶
func (x *DistributionValue_BucketOptions_Explicit) String() string
type DistributionValue_BucketOptions_Explicit_ ¶
type DistributionValue_BucketOptions_Explicit_ struct {
// Bucket with explicit bounds.
Explicit *DistributionValue_BucketOptions_Explicit `protobuf:"bytes,1,opt,name=explicit,proto3,oneof"`
}
type DistributionValue_BucketOptions_Explicit_builder ¶
type DistributionValue_BucketOptions_Explicit_builder struct {
// The values must be strictly increasing and > 0.
Bounds []float64
// contains filtered or unexported fields
}
func (DistributionValue_BucketOptions_Explicit_builder) Build ¶
type DistributionValue_BucketOptions_builder ¶
type DistributionValue_BucketOptions_builder struct {
// Fields of oneof Type:
// Bucket with explicit bounds.
Explicit *DistributionValue_BucketOptions_Explicit
// contains filtered or unexported fields
}
func (DistributionValue_BucketOptions_builder) Build ¶
func (b0 DistributionValue_BucketOptions_builder) Build() *DistributionValue_BucketOptions
type DistributionValue_Bucket_builder ¶
type DistributionValue_Bucket_builder struct {
// The number of values in each bucket of the histogram, as described in
// bucket_bounds.
Count int64
// If the distribution does not have a histogram, then omit this field.
Exemplar *DistributionValue_Exemplar
// contains filtered or unexported fields
}
func (DistributionValue_Bucket_builder) Build ¶
func (b0 DistributionValue_Bucket_builder) Build() *DistributionValue_Bucket
type DistributionValue_Exemplar ¶
type DistributionValue_Exemplar struct {
// Value of the exemplar point. It determines which bucket the exemplar
// belongs to.
Value float64 `protobuf:"fixed64,1,opt,name=value,proto3" json:"value,omitempty"`
// The observation (sampling) time of the above value.
Timestamp *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=timestamp,proto3" json:"timestamp,omitempty"`
// Contextual information about the example value.
Attachments map[string]string `` /* 149-byte string literal not displayed */
// contains filtered or unexported fields
}
Exemplars are example points that may be used to annotate aggregated Distribution values. They are metadata that gives information about a particular value added to a Distribution bucket.
func (*DistributionValue_Exemplar) ClearTimestamp ¶
func (x *DistributionValue_Exemplar) ClearTimestamp()
func (*DistributionValue_Exemplar) GetAttachments ¶
func (x *DistributionValue_Exemplar) GetAttachments() map[string]string
func (*DistributionValue_Exemplar) GetTimestamp ¶
func (x *DistributionValue_Exemplar) GetTimestamp() *timestamppb.Timestamp
func (*DistributionValue_Exemplar) GetValue ¶
func (x *DistributionValue_Exemplar) GetValue() float64
func (*DistributionValue_Exemplar) HasTimestamp ¶
func (x *DistributionValue_Exemplar) HasTimestamp() bool
func (*DistributionValue_Exemplar) ProtoMessage ¶
func (*DistributionValue_Exemplar) ProtoMessage()
func (*DistributionValue_Exemplar) ProtoReflect ¶
func (x *DistributionValue_Exemplar) ProtoReflect() protoreflect.Message
func (*DistributionValue_Exemplar) Reset ¶
func (x *DistributionValue_Exemplar) Reset()
func (*DistributionValue_Exemplar) SetAttachments ¶
func (x *DistributionValue_Exemplar) SetAttachments(v map[string]string)
func (*DistributionValue_Exemplar) SetTimestamp ¶
func (x *DistributionValue_Exemplar) SetTimestamp(v *timestamppb.Timestamp)
func (*DistributionValue_Exemplar) SetValue ¶
func (x *DistributionValue_Exemplar) SetValue(v float64)
func (*DistributionValue_Exemplar) String ¶
func (x *DistributionValue_Exemplar) String() string
type DistributionValue_Exemplar_builder ¶
type DistributionValue_Exemplar_builder struct {
// Value of the exemplar point. It determines which bucket the exemplar
// belongs to.
Value float64
// The observation (sampling) time of the above value.
Timestamp *timestamppb.Timestamp
// Contextual information about the example value.
Attachments map[string]string
// contains filtered or unexported fields
}
func (DistributionValue_Exemplar_builder) Build ¶
func (b0 DistributionValue_Exemplar_builder) Build() *DistributionValue_Exemplar
type DistributionValue_builder ¶
type DistributionValue_builder struct {
// The number of values in the population. Must be non-negative. This value
// must equal the sum of the values in bucket_counts if a histogram is
// provided.
Count int64
// The sum of the values in the population. If count is zero then this field
// must be zero.
Sum float64
// The sum of squared deviations from the mean of the values in the
// population. For values x_i this is:
//
// Sum[i=1..n]((x_i - mean)^2)
//
// Knuth, "The Art of Computer Programming", Vol. 2, page 323, 3rd edition
// describes Welford's method for accumulating this sum in one pass.
//
// If count is zero then this field must be zero.
SumOfSquaredDeviation float64
// Don't change bucket boundaries within a TimeSeries if your backend doesn't
// support this.
// TODO(issue #152): consider not required to send bucket options for
// optimization.
BucketOptions *DistributionValue_BucketOptions
// If the distribution does not have a histogram, then omit this field.
// If there is a histogram, then the sum of the values in the Bucket counts
// must equal the value in the count field of the distribution.
Buckets []*DistributionValue_Bucket
// contains filtered or unexported fields
}
func (DistributionValue_builder) Build ¶
func (b0 DistributionValue_builder) Build() *DistributionValue
type LabelKey ¶
type LabelKey struct {
// The key for the label.
Key string `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
// A human-readable description of what this label key represents.
Description string `protobuf:"bytes,2,opt,name=description,proto3" json:"description,omitempty"`
// contains filtered or unexported fields
}
Defines a label key associated with a metric descriptor.
func (*LabelKey) ProtoReflect ¶
func (x *LabelKey) ProtoReflect() protoreflect.Message
type LabelKey_builder ¶
type LabelKey_builder struct {
// The key for the label.
Key string
// A human-readable description of what this label key represents.
Description string
// contains filtered or unexported fields
}
func (LabelKey_builder) Build ¶
func (b0 LabelKey_builder) Build() *LabelKey
type LabelValue ¶
type LabelValue struct {
// The value for the label.
Value string `protobuf:"bytes,1,opt,name=value,proto3" json:"value,omitempty"`
// If false the value field is ignored and considered not set.
// This is used to differentiate a missing label from an empty string.
HasValue bool `protobuf:"varint,2,opt,name=has_value,json=hasValue,proto3" json:"has_value,omitempty"`
// contains filtered or unexported fields
}
func (*LabelValue) GetHasValue ¶
func (x *LabelValue) GetHasValue() bool
func (*LabelValue) GetValue ¶
func (x *LabelValue) GetValue() string
func (*LabelValue) ProtoMessage ¶
func (*LabelValue) ProtoMessage()
func (*LabelValue) ProtoReflect ¶
func (x *LabelValue) ProtoReflect() protoreflect.Message
func (*LabelValue) Reset ¶
func (x *LabelValue) Reset()
func (*LabelValue) SetHasValue ¶
func (x *LabelValue) SetHasValue(v bool)
func (*LabelValue) SetValue ¶
func (x *LabelValue) SetValue(v string)
func (*LabelValue) String ¶
func (x *LabelValue) String() string
type LabelValue_builder ¶
type LabelValue_builder struct {
// The value for the label.
Value string
// If false the value field is ignored and considered not set.
// This is used to differentiate a missing label from an empty string.
HasValue bool
// contains filtered or unexported fields
}
func (LabelValue_builder) Build ¶
func (b0 LabelValue_builder) Build() *LabelValue
type Metric ¶
type Metric struct {
// The descriptor of the Metric.
// TODO(issue #152): consider only sending the name of descriptor for
// optimization.
MetricDescriptor *MetricDescriptor `protobuf:"bytes,1,opt,name=metric_descriptor,json=metricDescriptor,proto3" json:"metric_descriptor,omitempty"`
// One or more timeseries for a single metric, where each timeseries has
// one or more points.
Timeseries []*TimeSeries `protobuf:"bytes,2,rep,name=timeseries,proto3" json:"timeseries,omitempty"`
// The resource for the metric. If unset, it may be set to a default value
// provided for a sequence of messages in an RPC stream.
Resource *v1.Resource `protobuf:"bytes,3,opt,name=resource,proto3" json:"resource,omitempty"`
// contains filtered or unexported fields
}
Defines a Metric which has one or more timeseries.
func (*Metric) GetMetricDescriptor ¶
func (x *Metric) GetMetricDescriptor() *MetricDescriptor
func (*Metric) GetTimeseries ¶
func (x *Metric) GetTimeseries() []*TimeSeries
func (*Metric) ProtoReflect ¶
func (x *Metric) ProtoReflect() protoreflect.Message
func (*Metric) SetMetricDescriptor ¶
func (x *Metric) SetMetricDescriptor(v *MetricDescriptor)
func (*Metric) SetTimeseries ¶
func (x *Metric) SetTimeseries(v []*TimeSeries)
type MetricDescriptor ¶
type MetricDescriptor struct {
// The metric type, including its DNS name prefix. It must be unique.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// A detailed description of the metric, which can be used in documentation.
Description string `protobuf:"bytes,2,opt,name=description,proto3" json:"description,omitempty"`
// The unit in which the metric value is reported. Follows the format
// described by http://unitsofmeasure.org/ucum.html.
Unit string `protobuf:"bytes,3,opt,name=unit,proto3" json:"unit,omitempty"`
Type MetricDescriptor_Type `protobuf:"varint,4,opt,name=type,proto3,enum=opencensus.proto.metrics.v1.MetricDescriptor_Type" json:"type,omitempty"`
// The label keys associated with the metric descriptor.
LabelKeys []*LabelKey `protobuf:"bytes,5,rep,name=label_keys,json=labelKeys,proto3" json:"label_keys,omitempty"`
// contains filtered or unexported fields
}
Defines a metric type and its schema.
func (*MetricDescriptor) GetDescription ¶
func (x *MetricDescriptor) GetDescription() string
func (*MetricDescriptor) GetLabelKeys ¶
func (x *MetricDescriptor) GetLabelKeys() []*LabelKey
func (*MetricDescriptor) GetName ¶
func (x *MetricDescriptor) GetName() string
func (*MetricDescriptor) GetType ¶
func (x *MetricDescriptor) GetType() MetricDescriptor_Type
func (*MetricDescriptor) GetUnit ¶
func (x *MetricDescriptor) GetUnit() string
func (*MetricDescriptor) ProtoMessage ¶
func (*MetricDescriptor) ProtoMessage()
func (*MetricDescriptor) ProtoReflect ¶
func (x *MetricDescriptor) ProtoReflect() protoreflect.Message
func (*MetricDescriptor) Reset ¶
func (x *MetricDescriptor) Reset()
func (*MetricDescriptor) SetDescription ¶
func (x *MetricDescriptor) SetDescription(v string)
func (*MetricDescriptor) SetLabelKeys ¶
func (x *MetricDescriptor) SetLabelKeys(v []*LabelKey)
func (*MetricDescriptor) SetName ¶
func (x *MetricDescriptor) SetName(v string)
func (*MetricDescriptor) SetType ¶
func (x *MetricDescriptor) SetType(v MetricDescriptor_Type)
func (*MetricDescriptor) SetUnit ¶
func (x *MetricDescriptor) SetUnit(v string)
func (*MetricDescriptor) String ¶
func (x *MetricDescriptor) String() string
type MetricDescriptor_Type ¶
type MetricDescriptor_Type int32
The kind of metric. It describes how the data is reported.
A gauge is an instantaneous measurement of a value.
A cumulative measurement is a value accumulated over a time interval. In a time series, cumulative measurements should have the same start time, increasing values and increasing end times, until an event resets the cumulative value to zero and sets a new start time for the following points.
const ( // Do not use this default value. MetricDescriptor_UNSPECIFIED MetricDescriptor_Type = 0 // Integer gauge. The value can go both up and down. MetricDescriptor_GAUGE_INT64 MetricDescriptor_Type = 1 // Floating point gauge. The value can go both up and down. MetricDescriptor_GAUGE_DOUBLE MetricDescriptor_Type = 2 // Distribution gauge measurement. The count and sum can go both up and // down. Recorded values are always >= 0. // Used in scenarios like a snapshot of time the current items in a queue // have spent there. MetricDescriptor_GAUGE_DISTRIBUTION MetricDescriptor_Type = 3 // Integer cumulative measurement. The value cannot decrease, if resets // then the start_time should also be reset. MetricDescriptor_CUMULATIVE_INT64 MetricDescriptor_Type = 4 // Floating point cumulative measurement. The value cannot decrease, if // resets then the start_time should also be reset. Recorded values are // always >= 0. MetricDescriptor_CUMULATIVE_DOUBLE MetricDescriptor_Type = 5 // Distribution cumulative measurement. The count and sum cannot decrease, // if resets then the start_time should also be reset. MetricDescriptor_CUMULATIVE_DISTRIBUTION MetricDescriptor_Type = 6 // Some frameworks implemented Histograms as a summary of observations // (usually things like request durations and response sizes). While it // also provides a total count of observations and a sum of all observed // values, it calculates configurable percentiles over a sliding time // window. This is not recommended, since it cannot be aggregated. MetricDescriptor_SUMMARY MetricDescriptor_Type = 7 )
func (MetricDescriptor_Type) Descriptor ¶
func (MetricDescriptor_Type) Descriptor() protoreflect.EnumDescriptor
func (MetricDescriptor_Type) Enum ¶
func (x MetricDescriptor_Type) Enum() *MetricDescriptor_Type
func (MetricDescriptor_Type) Number ¶
func (x MetricDescriptor_Type) Number() protoreflect.EnumNumber
func (MetricDescriptor_Type) String ¶
func (x MetricDescriptor_Type) String() string
func (MetricDescriptor_Type) Type ¶
func (MetricDescriptor_Type) Type() protoreflect.EnumType
type MetricDescriptor_builder ¶
type MetricDescriptor_builder struct {
// The metric type, including its DNS name prefix. It must be unique.
Name string
// A detailed description of the metric, which can be used in documentation.
Description string
// The unit in which the metric value is reported. Follows the format
// described by http://unitsofmeasure.org/ucum.html.
Unit string
Type MetricDescriptor_Type
// The label keys associated with the metric descriptor.
LabelKeys []*LabelKey
// contains filtered or unexported fields
}
func (MetricDescriptor_builder) Build ¶
func (b0 MetricDescriptor_builder) Build() *MetricDescriptor
type Metric_builder ¶
type Metric_builder struct {
// The descriptor of the Metric.
// TODO(issue #152): consider only sending the name of descriptor for
// optimization.
MetricDescriptor *MetricDescriptor
// One or more timeseries for a single metric, where each timeseries has
// one or more points.
Timeseries []*TimeSeries
// The resource for the metric. If unset, it may be set to a default value
// provided for a sequence of messages in an RPC stream.
Resource *v1.Resource
// contains filtered or unexported fields
}
func (Metric_builder) Build ¶
func (b0 Metric_builder) Build() *Metric
type Point ¶
type Point struct {
// The moment when this point was recorded. Inclusive.
// If not specified, the timestamp will be decided by the backend.
Timestamp *timestamppb.Timestamp `protobuf:"bytes,1,opt,name=timestamp,proto3" json:"timestamp,omitempty"`
// The actual point value.
//
// Types that are valid to be assigned to Value:
//
// *Point_Int64Value
// *Point_DoubleValue
// *Point_DistributionValue
// *Point_SummaryValue
Value isPoint_Value `protobuf_oneof:"value"`
// contains filtered or unexported fields
}
A timestamped measurement.
func (*Point) GetDistributionValue ¶
func (x *Point) GetDistributionValue() *DistributionValue
func (*Point) GetSummaryValue ¶
func (x *Point) GetSummaryValue() *SummaryValue
func (*Point) GetTimestamp ¶
func (x *Point) GetTimestamp() *timestamppb.Timestamp
func (*Point) ProtoReflect ¶
func (x *Point) ProtoReflect() protoreflect.Message
func (*Point) SetDistributionValue ¶
func (x *Point) SetDistributionValue(v *DistributionValue)
func (*Point) SetSummaryValue ¶
func (x *Point) SetSummaryValue(v *SummaryValue)
func (*Point) SetTimestamp ¶
func (x *Point) SetTimestamp(v *timestamppb.Timestamp)
type Point_DistributionValue ¶
type Point_DistributionValue struct {
// A distribution value.
DistributionValue *DistributionValue `protobuf:"bytes,4,opt,name=distribution_value,json=distributionValue,proto3,oneof"`
}
type Point_DoubleValue ¶
type Point_DoubleValue struct {
// A 64-bit double-precision floating-point number.
DoubleValue float64 `protobuf:"fixed64,3,opt,name=double_value,json=doubleValue,proto3,oneof"`
}
type Point_Int64Value ¶
type Point_Int64Value struct {
// A 64-bit integer.
Int64Value int64 `protobuf:"varint,2,opt,name=int64_value,json=int64Value,proto3,oneof"`
}
type Point_SummaryValue ¶
type Point_SummaryValue struct {
// A summary value. This is not recommended, since it cannot be aggregated.
SummaryValue *SummaryValue `protobuf:"bytes,5,opt,name=summary_value,json=summaryValue,proto3,oneof"`
}
type Point_builder ¶
type Point_builder struct {
// The moment when this point was recorded. Inclusive.
// If not specified, the timestamp will be decided by the backend.
Timestamp *timestamppb.Timestamp
// Fields of oneof Value:
// A 64-bit integer.
Int64Value *int64
// A 64-bit double-precision floating-point number.
DoubleValue *float64
// A distribution value.
DistributionValue *DistributionValue
// A summary value. This is not recommended, since it cannot be aggregated.
SummaryValue *SummaryValue
// contains filtered or unexported fields
}
func (Point_builder) Build ¶
func (b0 Point_builder) Build() *Point
type SummaryValue ¶
type SummaryValue struct {
// The total number of recorded values since start_time. Optional since
// some systems don't expose this.
Count *wrapperspb.Int64Value `protobuf:"bytes,1,opt,name=count,proto3" json:"count,omitempty"`
// The total sum of recorded values since start_time. Optional since some
// systems don't expose this. If count is zero then this field must be zero.
// This field must be unset if the sum is not available.
Sum *wrapperspb.DoubleValue `protobuf:"bytes,2,opt,name=sum,proto3" json:"sum,omitempty"`
// Values calculated over an arbitrary time window.
Snapshot *SummaryValue_Snapshot `protobuf:"bytes,3,opt,name=snapshot,proto3" json:"snapshot,omitempty"`
// contains filtered or unexported fields
}
The start_timestamp only applies to the count and sum in the SummaryValue.
func (*SummaryValue) ClearCount ¶
func (x *SummaryValue) ClearCount()
func (*SummaryValue) ClearSnapshot ¶
func (x *SummaryValue) ClearSnapshot()
func (*SummaryValue) ClearSum ¶
func (x *SummaryValue) ClearSum()
func (*SummaryValue) GetCount ¶
func (x *SummaryValue) GetCount() *wrapperspb.Int64Value
func (*SummaryValue) GetSnapshot ¶
func (x *SummaryValue) GetSnapshot() *SummaryValue_Snapshot
func (*SummaryValue) GetSum ¶
func (x *SummaryValue) GetSum() *wrapperspb.DoubleValue
func (*SummaryValue) HasCount ¶
func (x *SummaryValue) HasCount() bool
func (*SummaryValue) HasSnapshot ¶
func (x *SummaryValue) HasSnapshot() bool
func (*SummaryValue) HasSum ¶
func (x *SummaryValue) HasSum() bool
func (*SummaryValue) ProtoMessage ¶
func (*SummaryValue) ProtoMessage()
func (*SummaryValue) ProtoReflect ¶
func (x *SummaryValue) ProtoReflect() protoreflect.Message
func (*SummaryValue) Reset ¶
func (x *SummaryValue) Reset()
func (*SummaryValue) SetCount ¶
func (x *SummaryValue) SetCount(v *wrapperspb.Int64Value)
func (*SummaryValue) SetSnapshot ¶
func (x *SummaryValue) SetSnapshot(v *SummaryValue_Snapshot)
func (*SummaryValue) SetSum ¶
func (x *SummaryValue) SetSum(v *wrapperspb.DoubleValue)
func (*SummaryValue) String ¶
func (x *SummaryValue) String() string
type SummaryValue_Snapshot ¶
type SummaryValue_Snapshot struct {
// The number of values in the snapshot. Optional since some systems don't
// expose this.
Count *wrapperspb.Int64Value `protobuf:"bytes,1,opt,name=count,proto3" json:"count,omitempty"`
// The sum of values in the snapshot. Optional since some systems don't
// expose this. If count is zero then this field must be zero or not set
// (if not supported).
Sum *wrapperspb.DoubleValue `protobuf:"bytes,2,opt,name=sum,proto3" json:"sum,omitempty"`
// A list of values at different percentiles of the distribution calculated
// from the current snapshot. The percentiles must be strictly increasing.
PercentileValues []*SummaryValue_Snapshot_ValueAtPercentile `protobuf:"bytes,3,rep,name=percentile_values,json=percentileValues,proto3" json:"percentile_values,omitempty"`
// contains filtered or unexported fields
}
The values in this message can be reset at arbitrary unknown times, with the requirement that all of them are reset at the same time.
func (*SummaryValue_Snapshot) ClearCount ¶
func (x *SummaryValue_Snapshot) ClearCount()
func (*SummaryValue_Snapshot) ClearSum ¶
func (x *SummaryValue_Snapshot) ClearSum()
func (*SummaryValue_Snapshot) GetCount ¶
func (x *SummaryValue_Snapshot) GetCount() *wrapperspb.Int64Value
func (*SummaryValue_Snapshot) GetPercentileValues ¶
func (x *SummaryValue_Snapshot) GetPercentileValues() []*SummaryValue_Snapshot_ValueAtPercentile
func (*SummaryValue_Snapshot) GetSum ¶
func (x *SummaryValue_Snapshot) GetSum() *wrapperspb.DoubleValue
func (*SummaryValue_Snapshot) HasCount ¶
func (x *SummaryValue_Snapshot) HasCount() bool
func (*SummaryValue_Snapshot) HasSum ¶
func (x *SummaryValue_Snapshot) HasSum() bool
func (*SummaryValue_Snapshot) ProtoMessage ¶
func (*SummaryValue_Snapshot) ProtoMessage()
func (*SummaryValue_Snapshot) ProtoReflect ¶
func (x *SummaryValue_Snapshot) ProtoReflect() protoreflect.Message
func (*SummaryValue_Snapshot) Reset ¶
func (x *SummaryValue_Snapshot) Reset()
func (*SummaryValue_Snapshot) SetCount ¶
func (x *SummaryValue_Snapshot) SetCount(v *wrapperspb.Int64Value)
func (*SummaryValue_Snapshot) SetPercentileValues ¶
func (x *SummaryValue_Snapshot) SetPercentileValues(v []*SummaryValue_Snapshot_ValueAtPercentile)
func (*SummaryValue_Snapshot) SetSum ¶
func (x *SummaryValue_Snapshot) SetSum(v *wrapperspb.DoubleValue)
func (*SummaryValue_Snapshot) String ¶
func (x *SummaryValue_Snapshot) String() string
type SummaryValue_Snapshot_ValueAtPercentile ¶
type SummaryValue_Snapshot_ValueAtPercentile struct {
// The percentile of a distribution. Must be in the interval
// (0.0, 100.0].
Percentile float64 `protobuf:"fixed64,1,opt,name=percentile,proto3" json:"percentile,omitempty"`
// The value at the given percentile of a distribution.
Value float64 `protobuf:"fixed64,2,opt,name=value,proto3" json:"value,omitempty"`
// contains filtered or unexported fields
}
Represents the value at a given percentile of a distribution.
func (*SummaryValue_Snapshot_ValueAtPercentile) GetPercentile ¶
func (x *SummaryValue_Snapshot_ValueAtPercentile) GetPercentile() float64
func (*SummaryValue_Snapshot_ValueAtPercentile) GetValue ¶
func (x *SummaryValue_Snapshot_ValueAtPercentile) GetValue() float64
func (*SummaryValue_Snapshot_ValueAtPercentile) ProtoMessage ¶
func (*SummaryValue_Snapshot_ValueAtPercentile) ProtoMessage()
func (*SummaryValue_Snapshot_ValueAtPercentile) ProtoReflect ¶
func (x *SummaryValue_Snapshot_ValueAtPercentile) ProtoReflect() protoreflect.Message
func (*SummaryValue_Snapshot_ValueAtPercentile) Reset ¶
func (x *SummaryValue_Snapshot_ValueAtPercentile) Reset()
func (*SummaryValue_Snapshot_ValueAtPercentile) SetPercentile ¶
func (x *SummaryValue_Snapshot_ValueAtPercentile) SetPercentile(v float64)
func (*SummaryValue_Snapshot_ValueAtPercentile) SetValue ¶
func (x *SummaryValue_Snapshot_ValueAtPercentile) SetValue(v float64)
func (*SummaryValue_Snapshot_ValueAtPercentile) String ¶
func (x *SummaryValue_Snapshot_ValueAtPercentile) String() string
type SummaryValue_Snapshot_ValueAtPercentile_builder ¶
type SummaryValue_Snapshot_ValueAtPercentile_builder struct {
// The percentile of a distribution. Must be in the interval
// (0.0, 100.0].
Percentile float64
// The value at the given percentile of a distribution.
Value float64
// contains filtered or unexported fields
}
func (SummaryValue_Snapshot_ValueAtPercentile_builder) Build ¶
type SummaryValue_Snapshot_builder ¶
type SummaryValue_Snapshot_builder struct {
// The number of values in the snapshot. Optional since some systems don't
// expose this.
Count *wrapperspb.Int64Value
// The sum of values in the snapshot. Optional since some systems don't
// expose this. If count is zero then this field must be zero or not set
// (if not supported).
Sum *wrapperspb.DoubleValue
// A list of values at different percentiles of the distribution calculated
// from the current snapshot. The percentiles must be strictly increasing.
PercentileValues []*SummaryValue_Snapshot_ValueAtPercentile
// contains filtered or unexported fields
}
func (SummaryValue_Snapshot_builder) Build ¶
func (b0 SummaryValue_Snapshot_builder) Build() *SummaryValue_Snapshot
type SummaryValue_builder ¶
type SummaryValue_builder struct {
// The total number of recorded values since start_time. Optional since
// some systems don't expose this.
Count *wrapperspb.Int64Value
// The total sum of recorded values since start_time. Optional since some
// systems don't expose this. If count is zero then this field must be zero.
// This field must be unset if the sum is not available.
Sum *wrapperspb.DoubleValue
// Values calculated over an arbitrary time window.
Snapshot *SummaryValue_Snapshot
// contains filtered or unexported fields
}
func (SummaryValue_builder) Build ¶
func (b0 SummaryValue_builder) Build() *SummaryValue
type TimeSeries ¶
type TimeSeries struct {
// Must be present for cumulative metrics. The time when the cumulative value
// was reset to zero. Exclusive. The cumulative value is over the time interval
// (start_timestamp, timestamp]. If not specified, the backend can use the
// previous recorded value.
StartTimestamp *timestamppb.Timestamp `protobuf:"bytes,1,opt,name=start_timestamp,json=startTimestamp,proto3" json:"start_timestamp,omitempty"`
// The set of label values that uniquely identify this timeseries. Applies to
// all points. The order of label values must match that of label keys in the
// metric descriptor.
LabelValues []*LabelValue `protobuf:"bytes,2,rep,name=label_values,json=labelValues,proto3" json:"label_values,omitempty"`
// The data points of this timeseries. Point.value type MUST match the
// MetricDescriptor.type.
Points []*Point `protobuf:"bytes,3,rep,name=points,proto3" json:"points,omitempty"`
// contains filtered or unexported fields
}
A collection of data points that describes the time-varying values of a metric.
func (*TimeSeries) ClearStartTimestamp ¶
func (x *TimeSeries) ClearStartTimestamp()
func (*TimeSeries) GetLabelValues ¶
func (x *TimeSeries) GetLabelValues() []*LabelValue
func (*TimeSeries) GetPoints ¶
func (x *TimeSeries) GetPoints() []*Point
func (*TimeSeries) GetStartTimestamp ¶
func (x *TimeSeries) GetStartTimestamp() *timestamppb.Timestamp
func (*TimeSeries) HasStartTimestamp ¶
func (x *TimeSeries) HasStartTimestamp() bool
func (*TimeSeries) ProtoMessage ¶
func (*TimeSeries) ProtoMessage()
func (*TimeSeries) ProtoReflect ¶
func (x *TimeSeries) ProtoReflect() protoreflect.Message
func (*TimeSeries) Reset ¶
func (x *TimeSeries) Reset()
func (*TimeSeries) SetLabelValues ¶
func (x *TimeSeries) SetLabelValues(v []*LabelValue)
func (*TimeSeries) SetPoints ¶
func (x *TimeSeries) SetPoints(v []*Point)
func (*TimeSeries) SetStartTimestamp ¶
func (x *TimeSeries) SetStartTimestamp(v *timestamppb.Timestamp)
func (*TimeSeries) String ¶
func (x *TimeSeries) String() string
type TimeSeries_builder ¶
type TimeSeries_builder struct {
// Must be present for cumulative metrics. The time when the cumulative value
// was reset to zero. Exclusive. The cumulative value is over the time interval
// (start_timestamp, timestamp]. If not specified, the backend can use the
// previous recorded value.
StartTimestamp *timestamppb.Timestamp
// The set of label values that uniquely identify this timeseries. Applies to
// all points. The order of label values must match that of label keys in the
// metric descriptor.
LabelValues []*LabelValue
// The data points of this timeseries. Point.value type MUST match the
// MetricDescriptor.type.
Points []*Point
// contains filtered or unexported fields
}
func (TimeSeries_builder) Build ¶
func (b0 TimeSeries_builder) Build() *TimeSeries
Source Files
¶
- metrics.pb.go