statsv1

package
v1.36.11-2024061717285... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

const Measurement_DoubleValue_case case_Measurement_Value = 3
const Measurement_IntValue_case case_Measurement_Value = 4
const Measurement_Value_not_set_case case_Measurement_Value = 0
const View_Aggregation_not_set_case case_View_Aggregation = 0
const View_CountAggregation_case case_View_Aggregation = 5
const View_DistributionAggregation_case case_View_Aggregation = 8
const View_LastValueAggregation_case case_View_Aggregation = 7
const View_SumAggregation_case case_View_Aggregation = 6

Variables

var (
	Measure_Type_name = map[int32]string{
		0: "TYPE_UNSPECIFIED",
		1: "INT64",
		2: "DOUBLE",
	}
	Measure_Type_value = map[string]int32{
		"TYPE_UNSPECIFIED": 0,
		"INT64":            1,
		"DOUBLE":           2,
	}
)

Enum value maps for Measure_Type.

var File_opencensus_proto_stats_v1_stats_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type CountAggregation

type CountAggregation struct {
	// contains filtered or unexported fields
}

func (*CountAggregation) ProtoMessage

func (*CountAggregation) ProtoMessage()

func (*CountAggregation) ProtoReflect

func (x *CountAggregation) ProtoReflect() protoreflect.Message

func (*CountAggregation) Reset

func (x *CountAggregation) Reset()

func (*CountAggregation) String

func (x *CountAggregation) String() string

type CountAggregation_builder

type CountAggregation_builder struct {
	// contains filtered or unexported fields
}

func (CountAggregation_builder) Build

type DistributionAggregation

type DistributionAggregation struct {

	// A Distribution may optionally contain a histogram of the values in the
	// population. The bucket boundaries for that histogram are described by
	// `bucket_bounds`. This defines `size(bucket_bounds) + 1` (= N)
	// buckets. The boundaries for bucket index i are:
	//
	// (-infinity, bucket_bounds[i]) for i == 0
	// [bucket_bounds[i-1], bucket_bounds[i]) for 0 < i < N-2
	// [bucket_bounds[i-1], +infinity) for i == N-1
	//
	// i.e. an underflow bucket (number 0), zero or more finite buckets (1
	// through N - 2, and an overflow bucket (N - 1), with inclusive lower
	// bounds and exclusive upper bounds.
	//
	// If `bucket_bounds` has no elements (zero size), then there is no
	// histogram associated with the Distribution. If `bucket_bounds` has only
	// one element, there are no finite buckets, and that single element is the
	// common boundary of the overflow and underflow buckets. The values must
	// be monotonically increasing.
	BucketBounds []float64 `protobuf:"fixed64,1,rep,packed,name=bucket_bounds,json=bucketBounds,proto3" json:"bucket_bounds,omitempty"`
	// contains filtered or unexported fields
}

func (*DistributionAggregation) GetBucketBounds

func (x *DistributionAggregation) GetBucketBounds() []float64

func (*DistributionAggregation) ProtoMessage

func (*DistributionAggregation) ProtoMessage()

func (*DistributionAggregation) ProtoReflect

func (x *DistributionAggregation) ProtoReflect() protoreflect.Message

func (*DistributionAggregation) Reset

func (x *DistributionAggregation) Reset()

func (*DistributionAggregation) SetBucketBounds

func (x *DistributionAggregation) SetBucketBounds(v []float64)

func (*DistributionAggregation) String

func (x *DistributionAggregation) String() string

type DistributionAggregation_builder

type DistributionAggregation_builder struct {

	// A Distribution may optionally contain a histogram of the values in the
	// population. The bucket boundaries for that histogram are described by
	// `bucket_bounds`. This defines `size(bucket_bounds) + 1` (= N)
	// buckets. The boundaries for bucket index i are:
	//
	// (-infinity, bucket_bounds[i]) for i == 0
	// [bucket_bounds[i-1], bucket_bounds[i]) for 0 < i < N-2
	// [bucket_bounds[i-1], +infinity) for i == N-1
	//
	// i.e. an underflow bucket (number 0), zero or more finite buckets (1
	// through N - 2, and an overflow bucket (N - 1), with inclusive lower
	// bounds and exclusive upper bounds.
	//
	// If `bucket_bounds` has no elements (zero size), then there is no
	// histogram associated with the Distribution. If `bucket_bounds` has only
	// one element, there are no finite buckets, and that single element is the
	// common boundary of the overflow and underflow buckets. The values must
	// be monotonically increasing.
	BucketBounds []float64
	// contains filtered or unexported fields
}

func (DistributionAggregation_builder) Build

type LastValueAggregation

type LastValueAggregation struct {
	// contains filtered or unexported fields
}

func (*LastValueAggregation) ProtoMessage

func (*LastValueAggregation) ProtoMessage()

func (*LastValueAggregation) ProtoReflect

func (x *LastValueAggregation) ProtoReflect() protoreflect.Message

func (*LastValueAggregation) Reset

func (x *LastValueAggregation) Reset()

func (*LastValueAggregation) String

func (x *LastValueAggregation) String() string

type LastValueAggregation_builder

type LastValueAggregation_builder struct {
	// contains filtered or unexported fields
}

func (LastValueAggregation_builder) Build

type Measure

type Measure struct {

	// A string by which the measure will be referred to, e.g. "rpc_server_latency". Names MUST be
	// unique within the library.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Describes the measure, e.g. "RPC latency in seconds".
	Description string `protobuf:"bytes,2,opt,name=description,proto3" json:"description,omitempty"`
	// Describes the unit used for the Measure. Follows the format described by
	// http://unitsofmeasure.org/ucum.html.
	Unit string `protobuf:"bytes,3,opt,name=unit,proto3" json:"unit,omitempty"`
	// The type used for this Measure.
	Type Measure_Type `protobuf:"varint,4,opt,name=type,proto3,enum=opencensus.proto.stats.v1.Measure_Type" json:"type,omitempty"`
	// contains filtered or unexported fields
}

Measure .

func (*Measure) GetDescription

func (x *Measure) GetDescription() string

func (*Measure) GetName

func (x *Measure) GetName() string

func (*Measure) GetType

func (x *Measure) GetType() Measure_Type

func (*Measure) GetUnit

func (x *Measure) GetUnit() string

func (*Measure) ProtoMessage

func (*Measure) ProtoMessage()

func (*Measure) ProtoReflect

func (x *Measure) ProtoReflect() protoreflect.Message

func (*Measure) Reset

func (x *Measure) Reset()

func (*Measure) SetDescription

func (x *Measure) SetDescription(v string)

func (*Measure) SetName

func (x *Measure) SetName(v string)

func (*Measure) SetType

func (x *Measure) SetType(v Measure_Type)

func (*Measure) SetUnit

func (x *Measure) SetUnit(v string)

func (*Measure) String

func (x *Measure) String() string

type Measure_Type

type Measure_Type int32
const (
	// Unknown type.
	Measure_TYPE_UNSPECIFIED Measure_Type = 0
	// Indicates an int64 Measure.
	Measure_INT64 Measure_Type = 1
	// Indicates a double Measure.
	Measure_DOUBLE Measure_Type = 2
)

func (Measure_Type) Descriptor

func (Measure_Type) Enum

func (x Measure_Type) Enum() *Measure_Type

func (Measure_Type) Number

func (Measure_Type) String

func (x Measure_Type) String() string

func (Measure_Type) Type

type Measure_builder

type Measure_builder struct {

	// A string by which the measure will be referred to, e.g. "rpc_server_latency". Names MUST be
	// unique within the library.
	Name string
	// Describes the measure, e.g. "RPC latency in seconds".
	Description string
	// Describes the unit used for the Measure. Follows the format described by
	// http://unitsofmeasure.org/ucum.html.
	Unit string
	// The type used for this Measure.
	Type Measure_Type
	// contains filtered or unexported fields
}

func (Measure_builder) Build

func (b0 Measure_builder) Build() *Measure

type Measurement

type Measurement struct {
	Tags []*Tag `protobuf:"bytes,1,rep,name=tags,proto3" json:"tags,omitempty"`
	// The name of the measure to which the value is applied.
	MeasureName string `protobuf:"bytes,2,opt,name=measure_name,json=measureName,proto3" json:"measure_name,omitempty"`
	// The recorded value, MUST have the appropriate type to match the Measure.
	//
	// Types that are valid to be assigned to Value:
	//
	//	*Measurement_DoubleValue
	//	*Measurement_IntValue
	Value isMeasurement_Value `protobuf_oneof:"value"`
	// The time when this measurement was recorded. If the implementation uses a async buffer to
	// record measurements this may be the time when the measurement was read from the buffer.
	Time *timestamppb.Timestamp `protobuf:"bytes,5,opt,name=time,proto3" json:"time,omitempty"`
	// contains filtered or unexported fields
}

Describes a data point to be collected for a Measure.

func (*Measurement) ClearDoubleValue

func (x *Measurement) ClearDoubleValue()

func (*Measurement) ClearIntValue

func (x *Measurement) ClearIntValue()

func (*Measurement) ClearTime

func (x *Measurement) ClearTime()

func (*Measurement) ClearValue

func (x *Measurement) ClearValue()

func (*Measurement) GetDoubleValue

func (x *Measurement) GetDoubleValue() float64

func (*Measurement) GetIntValue

func (x *Measurement) GetIntValue() int64

func (*Measurement) GetMeasureName

func (x *Measurement) GetMeasureName() string

func (*Measurement) GetTags

func (x *Measurement) GetTags() []*Tag

func (*Measurement) GetTime

func (x *Measurement) GetTime() *timestamppb.Timestamp

func (*Measurement) GetValue

func (x *Measurement) GetValue() isMeasurement_Value

func (*Measurement) HasDoubleValue

func (x *Measurement) HasDoubleValue() bool

func (*Measurement) HasIntValue

func (x *Measurement) HasIntValue() bool

func (*Measurement) HasTime

func (x *Measurement) HasTime() bool

func (*Measurement) HasValue

func (x *Measurement) HasValue() bool

func (*Measurement) ProtoMessage

func (*Measurement) ProtoMessage()

func (*Measurement) ProtoReflect

func (x *Measurement) ProtoReflect() protoreflect.Message

func (*Measurement) Reset

func (x *Measurement) Reset()

func (*Measurement) SetDoubleValue

func (x *Measurement) SetDoubleValue(v float64)

func (*Measurement) SetIntValue

func (x *Measurement) SetIntValue(v int64)

func (*Measurement) SetMeasureName

func (x *Measurement) SetMeasureName(v string)

func (*Measurement) SetTags

func (x *Measurement) SetTags(v []*Tag)

func (*Measurement) SetTime

func (x *Measurement) SetTime(v *timestamppb.Timestamp)

func (*Measurement) String

func (x *Measurement) String() string

func (*Measurement) WhichValue

func (x *Measurement) WhichValue() case_Measurement_Value

type Measurement_DoubleValue

type Measurement_DoubleValue struct {
	DoubleValue float64 `protobuf:"fixed64,3,opt,name=double_value,json=doubleValue,proto3,oneof"`
}

type Measurement_IntValue

type Measurement_IntValue struct {
	IntValue int64 `protobuf:"varint,4,opt,name=int_value,json=intValue,proto3,oneof"`
}

type Measurement_builder

type Measurement_builder struct {
	Tags []*Tag
	// The name of the measure to which the value is applied.
	MeasureName string

	// Fields of oneof Value:
	DoubleValue *float64
	IntValue    *int64
	// -- end of Value
	// The time when this measurement was recorded. If the implementation uses a async buffer to
	// record measurements this may be the time when the measurement was read from the buffer.
	Time *timestamppb.Timestamp
	// contains filtered or unexported fields
}

func (Measurement_builder) Build

func (b0 Measurement_builder) Build() *Measurement

type SumAggregation

type SumAggregation struct {
	// contains filtered or unexported fields
}

func (*SumAggregation) ProtoMessage

func (*SumAggregation) ProtoMessage()

func (*SumAggregation) ProtoReflect

func (x *SumAggregation) ProtoReflect() protoreflect.Message

func (*SumAggregation) Reset

func (x *SumAggregation) Reset()

func (*SumAggregation) String

func (x *SumAggregation) String() string

type SumAggregation_builder

type SumAggregation_builder struct {
	// contains filtered or unexported fields
}

func (SumAggregation_builder) Build

type Tag

type Tag struct {
	Key   string `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
	Value string `protobuf:"bytes,2,opt,name=value,proto3" json:"value,omitempty"`
	// contains filtered or unexported fields
}

TODO(bdrutu): Consider if this should be moved to a "tags" directory to match the API structure.

func (*Tag) GetKey

func (x *Tag) GetKey() string

func (*Tag) GetValue

func (x *Tag) GetValue() string

func (*Tag) ProtoMessage

func (*Tag) ProtoMessage()

func (*Tag) ProtoReflect

func (x *Tag) ProtoReflect() protoreflect.Message

func (*Tag) Reset

func (x *Tag) Reset()

func (*Tag) SetKey

func (x *Tag) SetKey(v string)

func (*Tag) SetValue

func (x *Tag) SetValue(v string)

func (*Tag) String

func (x *Tag) String() string

type Tag_builder

type Tag_builder struct {
	Key   string
	Value string
	// contains filtered or unexported fields
}

func (Tag_builder) Build

func (b0 Tag_builder) Build() *Tag

type View

type View struct {

	// A string by which the View will be referred to, e.g. "rpc_latency". Names MUST be unique
	// within the library.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Describes the view, e.g. "RPC latency distribution"
	Description string `protobuf:"bytes,2,opt,name=description,proto3" json:"description,omitempty"`
	// The Measure to which this view is applied.
	Measure *Measure `protobuf:"bytes,3,opt,name=measure,proto3" json:"measure,omitempty"`
	// An array of tag keys. These values associated with tags of this name form the basis by which
	// individual stats will be aggregated (one aggregation per unique tag value). If none are
	// provided, then all data is recorded in a single aggregation.
	Columns []string `protobuf:"bytes,4,rep,name=columns,proto3" json:"columns,omitempty"`
	// The description of the aggregation used for this view which describes how data collected are
	// aggregated.
	//
	// Types that are valid to be assigned to Aggregation:
	//
	//	*View_CountAggregation
	//	*View_SumAggregation
	//	*View_LastValueAggregation
	//	*View_DistributionAggregation
	Aggregation isView_Aggregation `protobuf_oneof:"aggregation"`
	// contains filtered or unexported fields
}

func (*View) ClearAggregation

func (x *View) ClearAggregation()

func (*View) ClearCountAggregation

func (x *View) ClearCountAggregation()

func (*View) ClearDistributionAggregation

func (x *View) ClearDistributionAggregation()

func (*View) ClearLastValueAggregation

func (x *View) ClearLastValueAggregation()

func (*View) ClearMeasure

func (x *View) ClearMeasure()

func (*View) ClearSumAggregation

func (x *View) ClearSumAggregation()

func (*View) GetAggregation

func (x *View) GetAggregation() isView_Aggregation

func (*View) GetColumns

func (x *View) GetColumns() []string

func (*View) GetCountAggregation

func (x *View) GetCountAggregation() *CountAggregation

func (*View) GetDescription

func (x *View) GetDescription() string

func (*View) GetDistributionAggregation

func (x *View) GetDistributionAggregation() *DistributionAggregation

func (*View) GetLastValueAggregation

func (x *View) GetLastValueAggregation() *LastValueAggregation

func (*View) GetMeasure

func (x *View) GetMeasure() *Measure

func (*View) GetName

func (x *View) GetName() string

func (*View) GetSumAggregation

func (x *View) GetSumAggregation() *SumAggregation

func (*View) HasAggregation

func (x *View) HasAggregation() bool

func (*View) HasCountAggregation

func (x *View) HasCountAggregation() bool

func (*View) HasDistributionAggregation

func (x *View) HasDistributionAggregation() bool

func (*View) HasLastValueAggregation

func (x *View) HasLastValueAggregation() bool

func (*View) HasMeasure

func (x *View) HasMeasure() bool

func (*View) HasSumAggregation

func (x *View) HasSumAggregation() bool

func (*View) ProtoMessage

func (*View) ProtoMessage()

func (*View) ProtoReflect

func (x *View) ProtoReflect() protoreflect.Message

func (*View) Reset

func (x *View) Reset()

func (*View) SetColumns

func (x *View) SetColumns(v []string)

func (*View) SetCountAggregation

func (x *View) SetCountAggregation(v *CountAggregation)

func (*View) SetDescription

func (x *View) SetDescription(v string)

func (*View) SetDistributionAggregation

func (x *View) SetDistributionAggregation(v *DistributionAggregation)

func (*View) SetLastValueAggregation

func (x *View) SetLastValueAggregation(v *LastValueAggregation)

func (*View) SetMeasure

func (x *View) SetMeasure(v *Measure)

func (*View) SetName

func (x *View) SetName(v string)

func (*View) SetSumAggregation

func (x *View) SetSumAggregation(v *SumAggregation)

func (*View) String

func (x *View) String() string

func (*View) WhichAggregation

func (x *View) WhichAggregation() case_View_Aggregation

type View_CountAggregation

type View_CountAggregation struct {
	// Counts the number of measurements recorded.
	CountAggregation *CountAggregation `protobuf:"bytes,5,opt,name=count_aggregation,json=countAggregation,proto3,oneof"`
}

type View_DistributionAggregation

type View_DistributionAggregation struct {
	// Indicates that the desired Aggregation is a histogram distribution. A distribution
	// Aggregation may contain a histogram of the values in the population. User should define the
	// bucket boundaries for that histogram (see DistributionAggregation).
	DistributionAggregation *DistributionAggregation `protobuf:"bytes,8,opt,name=distribution_aggregation,json=distributionAggregation,proto3,oneof"`
}

type View_LastValueAggregation

type View_LastValueAggregation struct {
	// Indicates that data collected and aggregated with this Aggregation will represent the last
	// recorded value. This is useful to support Gauges.
	LastValueAggregation *LastValueAggregation `protobuf:"bytes,7,opt,name=last_value_aggregation,json=lastValueAggregation,proto3,oneof"`
}

type View_SumAggregation

type View_SumAggregation struct {
	// Indicates that data collected and aggregated with this Aggregation will be summed up.
	SumAggregation *SumAggregation `protobuf:"bytes,6,opt,name=sum_aggregation,json=sumAggregation,proto3,oneof"`
}

type View_builder

type View_builder struct {

	// A string by which the View will be referred to, e.g. "rpc_latency". Names MUST be unique
	// within the library.
	Name string
	// Describes the view, e.g. "RPC latency distribution"
	Description string
	// The Measure to which this view is applied.
	Measure *Measure
	// An array of tag keys. These values associated with tags of this name form the basis by which
	// individual stats will be aggregated (one aggregation per unique tag value). If none are
	// provided, then all data is recorded in a single aggregation.
	Columns []string

	// Fields of oneof Aggregation:
	// Counts the number of measurements recorded.
	CountAggregation *CountAggregation
	// Indicates that data collected and aggregated with this Aggregation will be summed up.
	SumAggregation *SumAggregation
	// Indicates that data collected and aggregated with this Aggregation will represent the last
	// recorded value. This is useful to support Gauges.
	LastValueAggregation *LastValueAggregation
	// Indicates that the desired Aggregation is a histogram distribution. A distribution
	// Aggregation may contain a histogram of the values in the population. User should define the
	// bucket boundaries for that histogram (see DistributionAggregation).
	DistributionAggregation *DistributionAggregation
	// contains filtered or unexported fields
}

func (View_builder) Build

func (b0 View_builder) Build() *View

Source Files

  • stats.pb.go

Jump to