logsv1grpc

package
v1.6.1-20251103204844-... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	LogsService_Export_FullMethodName = "/opentelemetry.proto.collector.logs.v1.LogsService/Export"
)

Variables

var LogsService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "opentelemetry.proto.collector.logs.v1.LogsService",
	HandlerType: (*LogsServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "Export",
			Handler:    _LogsService_Export_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "opentelemetry/proto/collector/logs/v1/logs_service.proto",
}

LogsService_ServiceDesc is the grpc.ServiceDesc for LogsService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterLogsServiceServer

func RegisterLogsServiceServer(s grpc.ServiceRegistrar, srv LogsServiceServer)

Types

type LogsServiceClient

type LogsServiceClient interface {
	Export(ctx context.Context, in *v1.ExportLogsServiceRequest, opts ...grpc.CallOption) (*v1.ExportLogsServiceResponse, error)
}

LogsServiceClient is the client API for LogsService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

Service that can be used to push logs between one Application instrumented with OpenTelemetry and an collector, or between an collector and a central collector (in this case logs are sent/received to/from multiple Applications).

func NewLogsServiceClient

func NewLogsServiceClient(cc grpc.ClientConnInterface) LogsServiceClient

type LogsServiceServer

type LogsServiceServer interface {
	Export(context.Context, *v1.ExportLogsServiceRequest) (*v1.ExportLogsServiceResponse, error)
}

LogsServiceServer is the server API for LogsService service. All implementations should embed UnimplementedLogsServiceServer for forward compatibility.

Service that can be used to push logs between one Application instrumented with OpenTelemetry and an collector, or between an collector and a central collector (in this case logs are sent/received to/from multiple Applications).

type UnimplementedLogsServiceServer

type UnimplementedLogsServiceServer struct{}

UnimplementedLogsServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedLogsServiceServer) Export

type UnsafeLogsServiceServer

type UnsafeLogsServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeLogsServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to LogsServiceServer will result in compilation errors.

Source Files

  • logs_service_grpc.pb.go

Jump to