v1developmentgrpc

package
v1.6.2-20260310202139-... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	ProfilesService_Export_FullMethodName = "/opentelemetry.proto.collector.profiles.v1development.ProfilesService/Export"
)

Variables

var ProfilesService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "opentelemetry.proto.collector.profiles.v1development.ProfilesService",
	HandlerType: (*ProfilesServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "Export",
			Handler:    _ProfilesService_Export_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "opentelemetry/proto/collector/profiles/v1development/profiles_service.proto",
}

ProfilesService_ServiceDesc is the grpc.ServiceDesc for ProfilesService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterProfilesServiceServer

func RegisterProfilesServiceServer(s grpc.ServiceRegistrar, srv ProfilesServiceServer)

Types

type ProfilesServiceClient

type ProfilesServiceClient interface {
	Export(ctx context.Context, in *v1development.ExportProfilesServiceRequest, opts ...grpc.CallOption) (*v1development.ExportProfilesServiceResponse, error)
}

ProfilesServiceClient is the client API for ProfilesService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

Service that can be used to push profiles between one Application instrumented with OpenTelemetry and a collector, or between a collector and a central collector.

func NewProfilesServiceClient

func NewProfilesServiceClient(cc grpc.ClientConnInterface) ProfilesServiceClient

type ProfilesServiceServer

ProfilesServiceServer is the server API for ProfilesService service. All implementations should embed UnimplementedProfilesServiceServer for forward compatibility.

Service that can be used to push profiles between one Application instrumented with OpenTelemetry and a collector, or between a collector and a central collector.

type UnimplementedProfilesServiceServer

type UnimplementedProfilesServiceServer struct{}

UnimplementedProfilesServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

type UnsafeProfilesServiceServer

type UnsafeProfilesServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeProfilesServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ProfilesServiceServer will result in compilation errors.

Source Files

  • profiles_service_grpc.pb.go

Jump to