tracev1grpc

package
v1.6.0-20251103204844-... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	TraceService_Export_FullMethodName = "/opentelemetry.proto.collector.trace.v1.TraceService/Export"
)

Variables

var TraceService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "opentelemetry.proto.collector.trace.v1.TraceService",
	HandlerType: (*TraceServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "Export",
			Handler:    _TraceService_Export_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "opentelemetry/proto/collector/trace/v1/trace_service.proto",
}

TraceService_ServiceDesc is the grpc.ServiceDesc for TraceService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterTraceServiceServer

func RegisterTraceServiceServer(s grpc.ServiceRegistrar, srv TraceServiceServer)

Types

type TraceServiceClient

type TraceServiceClient interface {
	Export(ctx context.Context, in *v1.ExportTraceServiceRequest, opts ...grpc.CallOption) (*v1.ExportTraceServiceResponse, error)
}

TraceServiceClient is the client API for TraceService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

Service that can be used to push spans between one Application instrumented with OpenTelemetry and a collector, or between a collector and a central collector (in this case spans are sent/received to/from multiple Applications).

func NewTraceServiceClient

func NewTraceServiceClient(cc grpc.ClientConnInterface) TraceServiceClient

type TraceServiceServer

type TraceServiceServer interface {
	Export(context.Context, *v1.ExportTraceServiceRequest) (*v1.ExportTraceServiceResponse, error)
}

TraceServiceServer is the server API for TraceService service. All implementations should embed UnimplementedTraceServiceServer for forward compatibility.

Service that can be used to push spans between one Application instrumented with OpenTelemetry and a collector, or between a collector and a central collector (in this case spans are sent/received to/from multiple Applications).

type UnimplementedTraceServiceServer

type UnimplementedTraceServiceServer struct{}

UnimplementedTraceServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedTraceServiceServer) Export

type UnsafeTraceServiceServer

type UnsafeTraceServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeTraceServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to TraceServiceServer will result in compilation errors.

Source Files

  • trace_service_grpc.pb.go

Jump to