Documentation
¶
Index ¶
- Variables
- type ExportLogsPartialSuccess
- func (x *ExportLogsPartialSuccess) GetErrorMessage() string
- func (x *ExportLogsPartialSuccess) GetRejectedLogRecords() int64
- func (*ExportLogsPartialSuccess) ProtoMessage()
- func (x *ExportLogsPartialSuccess) ProtoReflect() protoreflect.Message
- func (x *ExportLogsPartialSuccess) Reset()
- func (x *ExportLogsPartialSuccess) SetErrorMessage(v string)
- func (x *ExportLogsPartialSuccess) SetRejectedLogRecords(v int64)
- func (x *ExportLogsPartialSuccess) String() string
- type ExportLogsPartialSuccess_builder
- type ExportLogsServiceRequest
- func (x *ExportLogsServiceRequest) GetResourceLogs() []*v1.ResourceLogs
- func (*ExportLogsServiceRequest) ProtoMessage()
- func (x *ExportLogsServiceRequest) ProtoReflect() protoreflect.Message
- func (x *ExportLogsServiceRequest) Reset()
- func (x *ExportLogsServiceRequest) SetResourceLogs(v []*v1.ResourceLogs)
- func (x *ExportLogsServiceRequest) String() string
- type ExportLogsServiceRequest_builder
- type ExportLogsServiceResponse
- func (x *ExportLogsServiceResponse) ClearPartialSuccess()
- func (x *ExportLogsServiceResponse) GetPartialSuccess() *ExportLogsPartialSuccess
- func (x *ExportLogsServiceResponse) HasPartialSuccess() bool
- func (*ExportLogsServiceResponse) ProtoMessage()
- func (x *ExportLogsServiceResponse) ProtoReflect() protoreflect.Message
- func (x *ExportLogsServiceResponse) Reset()
- func (x *ExportLogsServiceResponse) SetPartialSuccess(v *ExportLogsPartialSuccess)
- func (x *ExportLogsServiceResponse) String() string
- type ExportLogsServiceResponse_builder
Constants ¶
This section is empty.
Variables ¶
var File_opentelemetry_proto_collector_logs_v1_logs_service_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type ExportLogsPartialSuccess ¶
type ExportLogsPartialSuccess struct {
// The number of rejected log records.
//
// A `rejected_<signal>` field holding a `0` value indicates that the
// request was fully accepted.
RejectedLogRecords int64 `protobuf:"varint,1,opt,name=rejected_log_records,json=rejectedLogRecords,proto3" json:"rejected_log_records,omitempty"`
// A developer-facing human-readable message in English. It should be used
// either to explain why the server rejected parts of the data during a partial
// success or to convey warnings/suggestions during a full success. The message
// should offer guidance on how users can address such issues.
//
// error_message is an optional field. An error_message with an empty value
// is equivalent to it not being set.
ErrorMessage string `protobuf:"bytes,2,opt,name=error_message,json=errorMessage,proto3" json:"error_message,omitempty"`
// contains filtered or unexported fields
}
func (*ExportLogsPartialSuccess) GetErrorMessage ¶
func (x *ExportLogsPartialSuccess) GetErrorMessage() string
func (*ExportLogsPartialSuccess) GetRejectedLogRecords ¶
func (x *ExportLogsPartialSuccess) GetRejectedLogRecords() int64
func (*ExportLogsPartialSuccess) ProtoMessage ¶
func (*ExportLogsPartialSuccess) ProtoMessage()
func (*ExportLogsPartialSuccess) ProtoReflect ¶
func (x *ExportLogsPartialSuccess) ProtoReflect() protoreflect.Message
func (*ExportLogsPartialSuccess) Reset ¶
func (x *ExportLogsPartialSuccess) Reset()
func (*ExportLogsPartialSuccess) SetErrorMessage ¶
func (x *ExportLogsPartialSuccess) SetErrorMessage(v string)
func (*ExportLogsPartialSuccess) SetRejectedLogRecords ¶
func (x *ExportLogsPartialSuccess) SetRejectedLogRecords(v int64)
func (*ExportLogsPartialSuccess) String ¶
func (x *ExportLogsPartialSuccess) String() string
type ExportLogsPartialSuccess_builder ¶
type ExportLogsPartialSuccess_builder struct {
// The number of rejected log records.
//
// A `rejected_<signal>` field holding a `0` value indicates that the
// request was fully accepted.
RejectedLogRecords int64
// A developer-facing human-readable message in English. It should be used
// either to explain why the server rejected parts of the data during a partial
// success or to convey warnings/suggestions during a full success. The message
// should offer guidance on how users can address such issues.
//
// error_message is an optional field. An error_message with an empty value
// is equivalent to it not being set.
ErrorMessage string
// contains filtered or unexported fields
}
func (ExportLogsPartialSuccess_builder) Build ¶
func (b0 ExportLogsPartialSuccess_builder) Build() *ExportLogsPartialSuccess
type ExportLogsServiceRequest ¶
type ExportLogsServiceRequest struct {
// An array of ResourceLogs.
// For data coming from a single resource this array will typically contain one
// element. Intermediary nodes (such as OpenTelemetry Collector) that receive
// data from multiple origins typically batch the data before forwarding further and
// in that case this array will contain multiple elements.
ResourceLogs []*v1.ResourceLogs `protobuf:"bytes,1,rep,name=resource_logs,json=resourceLogs,proto3" json:"resource_logs,omitempty"`
// contains filtered or unexported fields
}
func (*ExportLogsServiceRequest) GetResourceLogs ¶
func (x *ExportLogsServiceRequest) GetResourceLogs() []*v1.ResourceLogs
func (*ExportLogsServiceRequest) ProtoMessage ¶
func (*ExportLogsServiceRequest) ProtoMessage()
func (*ExportLogsServiceRequest) ProtoReflect ¶
func (x *ExportLogsServiceRequest) ProtoReflect() protoreflect.Message
func (*ExportLogsServiceRequest) Reset ¶
func (x *ExportLogsServiceRequest) Reset()
func (*ExportLogsServiceRequest) SetResourceLogs ¶
func (x *ExportLogsServiceRequest) SetResourceLogs(v []*v1.ResourceLogs)
func (*ExportLogsServiceRequest) String ¶
func (x *ExportLogsServiceRequest) String() string
type ExportLogsServiceRequest_builder ¶
type ExportLogsServiceRequest_builder struct {
// An array of ResourceLogs.
// For data coming from a single resource this array will typically contain one
// element. Intermediary nodes (such as OpenTelemetry Collector) that receive
// data from multiple origins typically batch the data before forwarding further and
// in that case this array will contain multiple elements.
ResourceLogs []*v1.ResourceLogs
// contains filtered or unexported fields
}
func (ExportLogsServiceRequest_builder) Build ¶
func (b0 ExportLogsServiceRequest_builder) Build() *ExportLogsServiceRequest
type ExportLogsServiceResponse ¶
type ExportLogsServiceResponse struct {
// The details of a partially successful export request.
//
// If the request is only partially accepted
// (i.e. when the server accepts only parts of the data and rejects the rest)
// the server MUST initialize the `partial_success` field and MUST
// set the `rejected_<signal>` with the number of items it rejected.
//
// Servers MAY also make use of the `partial_success` field to convey
// warnings/suggestions to senders even when the request was fully accepted.
// In such cases, the `rejected_<signal>` MUST have a value of `0` and
// the `error_message` MUST be non-empty.
//
// A `partial_success` message with an empty value (rejected_<signal> = 0 and
// `error_message` = "") is equivalent to it not being set/present. Senders
// SHOULD interpret it the same way as in the full success case.
PartialSuccess *ExportLogsPartialSuccess `protobuf:"bytes,1,opt,name=partial_success,json=partialSuccess,proto3" json:"partial_success,omitempty"`
// contains filtered or unexported fields
}
func (*ExportLogsServiceResponse) ClearPartialSuccess ¶
func (x *ExportLogsServiceResponse) ClearPartialSuccess()
func (*ExportLogsServiceResponse) GetPartialSuccess ¶
func (x *ExportLogsServiceResponse) GetPartialSuccess() *ExportLogsPartialSuccess
func (*ExportLogsServiceResponse) HasPartialSuccess ¶
func (x *ExportLogsServiceResponse) HasPartialSuccess() bool
func (*ExportLogsServiceResponse) ProtoMessage ¶
func (*ExportLogsServiceResponse) ProtoMessage()
func (*ExportLogsServiceResponse) ProtoReflect ¶
func (x *ExportLogsServiceResponse) ProtoReflect() protoreflect.Message
func (*ExportLogsServiceResponse) Reset ¶
func (x *ExportLogsServiceResponse) Reset()
func (*ExportLogsServiceResponse) SetPartialSuccess ¶
func (x *ExportLogsServiceResponse) SetPartialSuccess(v *ExportLogsPartialSuccess)
func (*ExportLogsServiceResponse) String ¶
func (x *ExportLogsServiceResponse) String() string
type ExportLogsServiceResponse_builder ¶
type ExportLogsServiceResponse_builder struct {
// The details of a partially successful export request.
//
// If the request is only partially accepted
// (i.e. when the server accepts only parts of the data and rejects the rest)
// the server MUST initialize the `partial_success` field and MUST
// set the `rejected_<signal>` with the number of items it rejected.
//
// Servers MAY also make use of the `partial_success` field to convey
// warnings/suggestions to senders even when the request was fully accepted.
// In such cases, the `rejected_<signal>` MUST have a value of `0` and
// the `error_message` MUST be non-empty.
//
// A `partial_success` message with an empty value (rejected_<signal> = 0 and
// `error_message` = "") is equivalent to it not being set/present. Senders
// SHOULD interpret it the same way as in the full success case.
PartialSuccess *ExportLogsPartialSuccess
// contains filtered or unexported fields
}
func (ExportLogsServiceResponse_builder) Build ¶
func (b0 ExportLogsServiceResponse_builder) Build() *ExportLogsServiceResponse
Source Files
¶
- logs_service.pb.go
Click to show internal directories.
Click to hide internal directories.