Documentation
¶
Index ¶
- Variables
- type ExportProfilesPartialSuccess
- func (x *ExportProfilesPartialSuccess) GetErrorMessage() string
- func (x *ExportProfilesPartialSuccess) GetRejectedProfiles() int64
- func (*ExportProfilesPartialSuccess) ProtoMessage()
- func (x *ExportProfilesPartialSuccess) ProtoReflect() protoreflect.Message
- func (x *ExportProfilesPartialSuccess) Reset()
- func (x *ExportProfilesPartialSuccess) SetErrorMessage(v string)
- func (x *ExportProfilesPartialSuccess) SetRejectedProfiles(v int64)
- func (x *ExportProfilesPartialSuccess) String() string
- type ExportProfilesPartialSuccess_builder
- type ExportProfilesServiceRequest
- func (x *ExportProfilesServiceRequest) ClearDictionary()
- func (x *ExportProfilesServiceRequest) GetDictionary() *v1development.ProfilesDictionary
- func (x *ExportProfilesServiceRequest) GetResourceProfiles() []*v1development.ResourceProfiles
- func (x *ExportProfilesServiceRequest) HasDictionary() bool
- func (*ExportProfilesServiceRequest) ProtoMessage()
- func (x *ExportProfilesServiceRequest) ProtoReflect() protoreflect.Message
- func (x *ExportProfilesServiceRequest) Reset()
- func (x *ExportProfilesServiceRequest) SetDictionary(v *v1development.ProfilesDictionary)
- func (x *ExportProfilesServiceRequest) SetResourceProfiles(v []*v1development.ResourceProfiles)
- func (x *ExportProfilesServiceRequest) String() string
- type ExportProfilesServiceRequest_builder
- type ExportProfilesServiceResponse
- func (x *ExportProfilesServiceResponse) ClearPartialSuccess()
- func (x *ExportProfilesServiceResponse) GetPartialSuccess() *ExportProfilesPartialSuccess
- func (x *ExportProfilesServiceResponse) HasPartialSuccess() bool
- func (*ExportProfilesServiceResponse) ProtoMessage()
- func (x *ExportProfilesServiceResponse) ProtoReflect() protoreflect.Message
- func (x *ExportProfilesServiceResponse) Reset()
- func (x *ExportProfilesServiceResponse) SetPartialSuccess(v *ExportProfilesPartialSuccess)
- func (x *ExportProfilesServiceResponse) String() string
- type ExportProfilesServiceResponse_builder
Constants ¶
This section is empty.
Variables ¶
var File_opentelemetry_proto_collector_profiles_v1development_profiles_service_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type ExportProfilesPartialSuccess ¶
type ExportProfilesPartialSuccess struct {
// The number of rejected profiles.
//
// A `rejected_<signal>` field holding a `0` value indicates that the
// request was fully accepted.
RejectedProfiles int64 `protobuf:"varint,1,opt,name=rejected_profiles,json=rejectedProfiles,proto3" json:"rejected_profiles,omitempty"`
// A developer-facing human-readable message in English. It should be used
// either to explain why the server rejected parts of the data during a partial
// success or to convey warnings/suggestions during a full success. The message
// should offer guidance on how users can address such issues.
//
// error_message is an optional field. An error_message with an empty value
// is equivalent to it not being set.
ErrorMessage string `protobuf:"bytes,2,opt,name=error_message,json=errorMessage,proto3" json:"error_message,omitempty"`
// contains filtered or unexported fields
}
func (*ExportProfilesPartialSuccess) GetErrorMessage ¶
func (x *ExportProfilesPartialSuccess) GetErrorMessage() string
func (*ExportProfilesPartialSuccess) GetRejectedProfiles ¶
func (x *ExportProfilesPartialSuccess) GetRejectedProfiles() int64
func (*ExportProfilesPartialSuccess) ProtoMessage ¶
func (*ExportProfilesPartialSuccess) ProtoMessage()
func (*ExportProfilesPartialSuccess) ProtoReflect ¶
func (x *ExportProfilesPartialSuccess) ProtoReflect() protoreflect.Message
func (*ExportProfilesPartialSuccess) Reset ¶
func (x *ExportProfilesPartialSuccess) Reset()
func (*ExportProfilesPartialSuccess) SetErrorMessage ¶
func (x *ExportProfilesPartialSuccess) SetErrorMessage(v string)
func (*ExportProfilesPartialSuccess) SetRejectedProfiles ¶
func (x *ExportProfilesPartialSuccess) SetRejectedProfiles(v int64)
func (*ExportProfilesPartialSuccess) String ¶
func (x *ExportProfilesPartialSuccess) String() string
type ExportProfilesPartialSuccess_builder ¶
type ExportProfilesPartialSuccess_builder struct {
// The number of rejected profiles.
//
// A `rejected_<signal>` field holding a `0` value indicates that the
// request was fully accepted.
RejectedProfiles int64
// A developer-facing human-readable message in English. It should be used
// either to explain why the server rejected parts of the data during a partial
// success or to convey warnings/suggestions during a full success. The message
// should offer guidance on how users can address such issues.
//
// error_message is an optional field. An error_message with an empty value
// is equivalent to it not being set.
ErrorMessage string
// contains filtered or unexported fields
}
func (ExportProfilesPartialSuccess_builder) Build ¶
func (b0 ExportProfilesPartialSuccess_builder) Build() *ExportProfilesPartialSuccess
type ExportProfilesServiceRequest ¶
type ExportProfilesServiceRequest struct {
// An array of ResourceProfiles.
// For data coming from a single resource this array will typically contain one
// element. Intermediary nodes (such as OpenTelemetry Collector) that receive
// data from multiple origins typically batch the data before forwarding further and
// in that case this array will contain multiple elements.
ResourceProfiles []*v1development.ResourceProfiles `protobuf:"bytes,1,rep,name=resource_profiles,json=resourceProfiles,proto3" json:"resource_profiles,omitempty"`
// The reference table containing all data shared by profiles across the message being sent.
Dictionary *v1development.ProfilesDictionary `protobuf:"bytes,2,opt,name=dictionary,proto3" json:"dictionary,omitempty"`
// contains filtered or unexported fields
}
func (*ExportProfilesServiceRequest) ClearDictionary ¶
func (x *ExportProfilesServiceRequest) ClearDictionary()
func (*ExportProfilesServiceRequest) GetDictionary ¶
func (x *ExportProfilesServiceRequest) GetDictionary() *v1development.ProfilesDictionary
func (*ExportProfilesServiceRequest) GetResourceProfiles ¶
func (x *ExportProfilesServiceRequest) GetResourceProfiles() []*v1development.ResourceProfiles
func (*ExportProfilesServiceRequest) HasDictionary ¶
func (x *ExportProfilesServiceRequest) HasDictionary() bool
func (*ExportProfilesServiceRequest) ProtoMessage ¶
func (*ExportProfilesServiceRequest) ProtoMessage()
func (*ExportProfilesServiceRequest) ProtoReflect ¶
func (x *ExportProfilesServiceRequest) ProtoReflect() protoreflect.Message
func (*ExportProfilesServiceRequest) Reset ¶
func (x *ExportProfilesServiceRequest) Reset()
func (*ExportProfilesServiceRequest) SetDictionary ¶
func (x *ExportProfilesServiceRequest) SetDictionary(v *v1development.ProfilesDictionary)
func (*ExportProfilesServiceRequest) SetResourceProfiles ¶
func (x *ExportProfilesServiceRequest) SetResourceProfiles(v []*v1development.ResourceProfiles)
func (*ExportProfilesServiceRequest) String ¶
func (x *ExportProfilesServiceRequest) String() string
type ExportProfilesServiceRequest_builder ¶
type ExportProfilesServiceRequest_builder struct {
// An array of ResourceProfiles.
// For data coming from a single resource this array will typically contain one
// element. Intermediary nodes (such as OpenTelemetry Collector) that receive
// data from multiple origins typically batch the data before forwarding further and
// in that case this array will contain multiple elements.
ResourceProfiles []*v1development.ResourceProfiles
// The reference table containing all data shared by profiles across the message being sent.
Dictionary *v1development.ProfilesDictionary
// contains filtered or unexported fields
}
func (ExportProfilesServiceRequest_builder) Build ¶
func (b0 ExportProfilesServiceRequest_builder) Build() *ExportProfilesServiceRequest
type ExportProfilesServiceResponse ¶
type ExportProfilesServiceResponse struct {
// The details of a partially successful export request.
//
// If the request is only partially accepted
// (i.e. when the server accepts only parts of the data and rejects the rest)
// the server MUST initialize the `partial_success` field and MUST
// set the `rejected_<signal>` with the number of items it rejected.
//
// Servers MAY also make use of the `partial_success` field to convey
// warnings/suggestions to senders even when the request was fully accepted.
// In such cases, the `rejected_<signal>` MUST have a value of `0` and
// the `error_message` MUST be non-empty.
//
// A `partial_success` message with an empty value (rejected_<signal> = 0 and
// `error_message` = "") is equivalent to it not being set/present. Senders
// SHOULD interpret it the same way as in the full success case.
PartialSuccess *ExportProfilesPartialSuccess `protobuf:"bytes,1,opt,name=partial_success,json=partialSuccess,proto3" json:"partial_success,omitempty"`
// contains filtered or unexported fields
}
func (*ExportProfilesServiceResponse) ClearPartialSuccess ¶
func (x *ExportProfilesServiceResponse) ClearPartialSuccess()
func (*ExportProfilesServiceResponse) GetPartialSuccess ¶
func (x *ExportProfilesServiceResponse) GetPartialSuccess() *ExportProfilesPartialSuccess
func (*ExportProfilesServiceResponse) HasPartialSuccess ¶
func (x *ExportProfilesServiceResponse) HasPartialSuccess() bool
func (*ExportProfilesServiceResponse) ProtoMessage ¶
func (*ExportProfilesServiceResponse) ProtoMessage()
func (*ExportProfilesServiceResponse) ProtoReflect ¶
func (x *ExportProfilesServiceResponse) ProtoReflect() protoreflect.Message
func (*ExportProfilesServiceResponse) Reset ¶
func (x *ExportProfilesServiceResponse) Reset()
func (*ExportProfilesServiceResponse) SetPartialSuccess ¶
func (x *ExportProfilesServiceResponse) SetPartialSuccess(v *ExportProfilesPartialSuccess)
func (*ExportProfilesServiceResponse) String ¶
func (x *ExportProfilesServiceResponse) String() string
type ExportProfilesServiceResponse_builder ¶
type ExportProfilesServiceResponse_builder struct {
// The details of a partially successful export request.
//
// If the request is only partially accepted
// (i.e. when the server accepts only parts of the data and rejects the rest)
// the server MUST initialize the `partial_success` field and MUST
// set the `rejected_<signal>` with the number of items it rejected.
//
// Servers MAY also make use of the `partial_success` field to convey
// warnings/suggestions to senders even when the request was fully accepted.
// In such cases, the `rejected_<signal>` MUST have a value of `0` and
// the `error_message` MUST be non-empty.
//
// A `partial_success` message with an empty value (rejected_<signal> = 0 and
// `error_message` = "") is equivalent to it not being set/present. Senders
// SHOULD interpret it the same way as in the full success case.
PartialSuccess *ExportProfilesPartialSuccess
// contains filtered or unexported fields
}
func (ExportProfilesServiceResponse_builder) Build ¶
func (b0 ExportProfilesServiceResponse_builder) Build() *ExportProfilesServiceResponse
Source Files
¶
- profiles_service.pb.go
Click to show internal directories.
Click to hide internal directories.