Documentation
¶
Index ¶
- Variables
- type ExportTracePartialSuccess
- func (x *ExportTracePartialSuccess) GetErrorMessage() string
- func (x *ExportTracePartialSuccess) GetRejectedSpans() int64
- func (*ExportTracePartialSuccess) ProtoMessage()
- func (x *ExportTracePartialSuccess) ProtoReflect() protoreflect.Message
- func (x *ExportTracePartialSuccess) Reset()
- func (x *ExportTracePartialSuccess) SetErrorMessage(v string)
- func (x *ExportTracePartialSuccess) SetRejectedSpans(v int64)
- func (x *ExportTracePartialSuccess) String() string
- type ExportTracePartialSuccess_builder
- type ExportTraceServiceRequest
- func (x *ExportTraceServiceRequest) GetResourceSpans() []*v1.ResourceSpans
- func (*ExportTraceServiceRequest) ProtoMessage()
- func (x *ExportTraceServiceRequest) ProtoReflect() protoreflect.Message
- func (x *ExportTraceServiceRequest) Reset()
- func (x *ExportTraceServiceRequest) SetResourceSpans(v []*v1.ResourceSpans)
- func (x *ExportTraceServiceRequest) String() string
- type ExportTraceServiceRequest_builder
- type ExportTraceServiceResponse
- func (x *ExportTraceServiceResponse) ClearPartialSuccess()
- func (x *ExportTraceServiceResponse) GetPartialSuccess() *ExportTracePartialSuccess
- func (x *ExportTraceServiceResponse) HasPartialSuccess() bool
- func (*ExportTraceServiceResponse) ProtoMessage()
- func (x *ExportTraceServiceResponse) ProtoReflect() protoreflect.Message
- func (x *ExportTraceServiceResponse) Reset()
- func (x *ExportTraceServiceResponse) SetPartialSuccess(v *ExportTracePartialSuccess)
- func (x *ExportTraceServiceResponse) String() string
- type ExportTraceServiceResponse_builder
Constants ¶
This section is empty.
Variables ¶
var File_opentelemetry_proto_collector_trace_v1_trace_service_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type ExportTracePartialSuccess ¶
type ExportTracePartialSuccess struct {
// The number of rejected spans.
//
// A `rejected_<signal>` field holding a `0` value indicates that the
// request was fully accepted.
RejectedSpans int64 `protobuf:"varint,1,opt,name=rejected_spans,json=rejectedSpans,proto3" json:"rejected_spans,omitempty"`
// A developer-facing human-readable message in English. It should be used
// either to explain why the server rejected parts of the data during a partial
// success or to convey warnings/suggestions during a full success. The message
// should offer guidance on how users can address such issues.
//
// error_message is an optional field. An error_message with an empty value
// is equivalent to it not being set.
ErrorMessage string `protobuf:"bytes,2,opt,name=error_message,json=errorMessage,proto3" json:"error_message,omitempty"`
// contains filtered or unexported fields
}
func (*ExportTracePartialSuccess) GetErrorMessage ¶
func (x *ExportTracePartialSuccess) GetErrorMessage() string
func (*ExportTracePartialSuccess) GetRejectedSpans ¶
func (x *ExportTracePartialSuccess) GetRejectedSpans() int64
func (*ExportTracePartialSuccess) ProtoMessage ¶
func (*ExportTracePartialSuccess) ProtoMessage()
func (*ExportTracePartialSuccess) ProtoReflect ¶
func (x *ExportTracePartialSuccess) ProtoReflect() protoreflect.Message
func (*ExportTracePartialSuccess) Reset ¶
func (x *ExportTracePartialSuccess) Reset()
func (*ExportTracePartialSuccess) SetErrorMessage ¶
func (x *ExportTracePartialSuccess) SetErrorMessage(v string)
func (*ExportTracePartialSuccess) SetRejectedSpans ¶
func (x *ExportTracePartialSuccess) SetRejectedSpans(v int64)
func (*ExportTracePartialSuccess) String ¶
func (x *ExportTracePartialSuccess) String() string
type ExportTracePartialSuccess_builder ¶
type ExportTracePartialSuccess_builder struct {
// The number of rejected spans.
//
// A `rejected_<signal>` field holding a `0` value indicates that the
// request was fully accepted.
RejectedSpans int64
// A developer-facing human-readable message in English. It should be used
// either to explain why the server rejected parts of the data during a partial
// success or to convey warnings/suggestions during a full success. The message
// should offer guidance on how users can address such issues.
//
// error_message is an optional field. An error_message with an empty value
// is equivalent to it not being set.
ErrorMessage string
// contains filtered or unexported fields
}
func (ExportTracePartialSuccess_builder) Build ¶
func (b0 ExportTracePartialSuccess_builder) Build() *ExportTracePartialSuccess
type ExportTraceServiceRequest ¶
type ExportTraceServiceRequest struct {
// An array of ResourceSpans.
// For data coming from a single resource this array will typically contain one
// element. Intermediary nodes (such as OpenTelemetry Collector) that receive
// data from multiple origins typically batch the data before forwarding further and
// in that case this array will contain multiple elements.
ResourceSpans []*v1.ResourceSpans `protobuf:"bytes,1,rep,name=resource_spans,json=resourceSpans,proto3" json:"resource_spans,omitempty"`
// contains filtered or unexported fields
}
func (*ExportTraceServiceRequest) GetResourceSpans ¶
func (x *ExportTraceServiceRequest) GetResourceSpans() []*v1.ResourceSpans
func (*ExportTraceServiceRequest) ProtoMessage ¶
func (*ExportTraceServiceRequest) ProtoMessage()
func (*ExportTraceServiceRequest) ProtoReflect ¶
func (x *ExportTraceServiceRequest) ProtoReflect() protoreflect.Message
func (*ExportTraceServiceRequest) Reset ¶
func (x *ExportTraceServiceRequest) Reset()
func (*ExportTraceServiceRequest) SetResourceSpans ¶
func (x *ExportTraceServiceRequest) SetResourceSpans(v []*v1.ResourceSpans)
func (*ExportTraceServiceRequest) String ¶
func (x *ExportTraceServiceRequest) String() string
type ExportTraceServiceRequest_builder ¶
type ExportTraceServiceRequest_builder struct {
// An array of ResourceSpans.
// For data coming from a single resource this array will typically contain one
// element. Intermediary nodes (such as OpenTelemetry Collector) that receive
// data from multiple origins typically batch the data before forwarding further and
// in that case this array will contain multiple elements.
ResourceSpans []*v1.ResourceSpans
// contains filtered or unexported fields
}
func (ExportTraceServiceRequest_builder) Build ¶
func (b0 ExportTraceServiceRequest_builder) Build() *ExportTraceServiceRequest
type ExportTraceServiceResponse ¶
type ExportTraceServiceResponse struct {
// The details of a partially successful export request.
//
// If the request is only partially accepted
// (i.e. when the server accepts only parts of the data and rejects the rest)
// the server MUST initialize the `partial_success` field and MUST
// set the `rejected_<signal>` with the number of items it rejected.
//
// Servers MAY also make use of the `partial_success` field to convey
// warnings/suggestions to senders even when the request was fully accepted.
// In such cases, the `rejected_<signal>` MUST have a value of `0` and
// the `error_message` MUST be non-empty.
//
// A `partial_success` message with an empty value (rejected_<signal> = 0 and
// `error_message` = "") is equivalent to it not being set/present. Senders
// SHOULD interpret it the same way as in the full success case.
PartialSuccess *ExportTracePartialSuccess `protobuf:"bytes,1,opt,name=partial_success,json=partialSuccess,proto3" json:"partial_success,omitempty"`
// contains filtered or unexported fields
}
func (*ExportTraceServiceResponse) ClearPartialSuccess ¶
func (x *ExportTraceServiceResponse) ClearPartialSuccess()
func (*ExportTraceServiceResponse) GetPartialSuccess ¶
func (x *ExportTraceServiceResponse) GetPartialSuccess() *ExportTracePartialSuccess
func (*ExportTraceServiceResponse) HasPartialSuccess ¶
func (x *ExportTraceServiceResponse) HasPartialSuccess() bool
func (*ExportTraceServiceResponse) ProtoMessage ¶
func (*ExportTraceServiceResponse) ProtoMessage()
func (*ExportTraceServiceResponse) ProtoReflect ¶
func (x *ExportTraceServiceResponse) ProtoReflect() protoreflect.Message
func (*ExportTraceServiceResponse) Reset ¶
func (x *ExportTraceServiceResponse) Reset()
func (*ExportTraceServiceResponse) SetPartialSuccess ¶
func (x *ExportTraceServiceResponse) SetPartialSuccess(v *ExportTracePartialSuccess)
func (*ExportTraceServiceResponse) String ¶
func (x *ExportTraceServiceResponse) String() string
type ExportTraceServiceResponse_builder ¶
type ExportTraceServiceResponse_builder struct {
// The details of a partially successful export request.
//
// If the request is only partially accepted
// (i.e. when the server accepts only parts of the data and rejects the rest)
// the server MUST initialize the `partial_success` field and MUST
// set the `rejected_<signal>` with the number of items it rejected.
//
// Servers MAY also make use of the `partial_success` field to convey
// warnings/suggestions to senders even when the request was fully accepted.
// In such cases, the `rejected_<signal>` MUST have a value of `0` and
// the `error_message` MUST be non-empty.
//
// A `partial_success` message with an empty value (rejected_<signal> = 0 and
// `error_message` = "") is equivalent to it not being set/present. Senders
// SHOULD interpret it the same way as in the full success case.
PartialSuccess *ExportTracePartialSuccess
// contains filtered or unexported fields
}
func (ExportTraceServiceResponse_builder) Build ¶
func (b0 ExportTraceServiceResponse_builder) Build() *ExportTraceServiceResponse
Source Files
¶
- trace_service.pb.go
Click to show internal directories.
Click to hide internal directories.