resourcev1

package
v1.36.11-2025110320484... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 5 Imported by: 3

Documentation

Index

Constants

This section is empty.

Variables

var File_opentelemetry_proto_resource_v1_resource_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type Resource

type Resource struct {

	// Set of attributes that describe the resource.
	// Attribute keys MUST be unique (it is not allowed to have more than one
	// attribute with the same key).
	// The behavior of software that receives duplicated keys can be unpredictable.
	Attributes []*v1.KeyValue `protobuf:"bytes,1,rep,name=attributes,proto3" json:"attributes,omitempty"`
	// The number of dropped attributes. If the value is 0, then
	// no attributes were dropped.
	DroppedAttributesCount uint32 `` /* 130-byte string literal not displayed */
	// Set of entities that participate in this Resource.
	//
	// Note: keys in the references MUST exist in attributes of this message.
	//
	// Status: [Development]
	EntityRefs []*v1.EntityRef `protobuf:"bytes,3,rep,name=entity_refs,json=entityRefs,proto3" json:"entity_refs,omitempty"`
	// contains filtered or unexported fields
}

Resource information.

func (*Resource) GetAttributes

func (x *Resource) GetAttributes() []*v1.KeyValue

func (*Resource) GetDroppedAttributesCount

func (x *Resource) GetDroppedAttributesCount() uint32

func (*Resource) GetEntityRefs

func (x *Resource) GetEntityRefs() []*v1.EntityRef

func (*Resource) ProtoMessage

func (*Resource) ProtoMessage()

func (*Resource) ProtoReflect

func (x *Resource) ProtoReflect() protoreflect.Message

func (*Resource) Reset

func (x *Resource) Reset()

func (*Resource) SetAttributes

func (x *Resource) SetAttributes(v []*v1.KeyValue)

func (*Resource) SetDroppedAttributesCount

func (x *Resource) SetDroppedAttributesCount(v uint32)

func (*Resource) SetEntityRefs

func (x *Resource) SetEntityRefs(v []*v1.EntityRef)

func (*Resource) String

func (x *Resource) String() string

type Resource_builder

type Resource_builder struct {

	// Set of attributes that describe the resource.
	// Attribute keys MUST be unique (it is not allowed to have more than one
	// attribute with the same key).
	// The behavior of software that receives duplicated keys can be unpredictable.
	Attributes []*v1.KeyValue
	// The number of dropped attributes. If the value is 0, then
	// no attributes were dropped.
	DroppedAttributesCount uint32
	// Set of entities that participate in this Resource.
	//
	// Note: keys in the references MUST exist in attributes of this message.
	//
	// Status: [Development]
	EntityRefs []*v1.EntityRef
	// contains filtered or unexported fields
}

func (Resource_builder) Build

func (b0 Resource_builder) Build() *Resource

Source Files

  • resource.pb.go

Jump to