metastorev1alpha1

package
v1.36.12-2026052303540... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 4 Imported by: 3

Documentation

Index

Constants

This section is empty.

Variables

var File_parca_metastore_v1alpha1_metastore_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type CreateLocationLinesRequest

type CreateLocationLinesRequest struct {

	// Locations that have location lines to be saved.
	Locations []*Location `protobuf:"bytes,1,rep,name=locations,proto3" json:"locations,omitempty"`
	// contains filtered or unexported fields
}

CreateLocationLinesRequest contains locations and their location lines to be saved.

func (*CreateLocationLinesRequest) GetLocations

func (x *CreateLocationLinesRequest) GetLocations() []*Location

func (*CreateLocationLinesRequest) ProtoMessage

func (*CreateLocationLinesRequest) ProtoMessage()

func (*CreateLocationLinesRequest) ProtoReflect

func (*CreateLocationLinesRequest) Reset

func (x *CreateLocationLinesRequest) Reset()

func (*CreateLocationLinesRequest) SetLocations

func (x *CreateLocationLinesRequest) SetLocations(v []*Location)

func (*CreateLocationLinesRequest) String

func (x *CreateLocationLinesRequest) String() string

type CreateLocationLinesRequest_builder

type CreateLocationLinesRequest_builder struct {

	// Locations that have location lines to be saved.
	Locations []*Location
	// contains filtered or unexported fields
}

func (CreateLocationLinesRequest_builder) Build

type CreateLocationLinesResponse

type CreateLocationLinesResponse struct {
	// contains filtered or unexported fields
}

CreateLocationLinesResponse details about the location lines creation.

func (*CreateLocationLinesResponse) ProtoMessage

func (*CreateLocationLinesResponse) ProtoMessage()

func (*CreateLocationLinesResponse) ProtoReflect

func (*CreateLocationLinesResponse) Reset

func (x *CreateLocationLinesResponse) Reset()

func (*CreateLocationLinesResponse) String

func (x *CreateLocationLinesResponse) String() string

type CreateLocationLinesResponse_builder

type CreateLocationLinesResponse_builder struct {
	// contains filtered or unexported fields
}

func (CreateLocationLinesResponse_builder) Build

type Function

type Function struct {

	// id is the unique identifier for the function.
	Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	// start_line is the line number in the source file of the first line of the function.
	StartLine int64 `protobuf:"varint,2,opt,name=start_line,json=startLine,proto3" json:"start_line,omitempty"`
	// name is the name of the function.
	Name string `protobuf:"bytes,3,opt,name=name,proto3" json:"name,omitempty"`
	// system_name describes the name of the function, as identified by the
	// system. For instance, it can be a C++ mangled name.
	SystemName string `protobuf:"bytes,4,opt,name=system_name,json=systemName,proto3" json:"system_name,omitempty"`
	// filename is the name of the source file of the function.
	Filename string `protobuf:"bytes,5,opt,name=filename,proto3" json:"filename,omitempty"`
	// name_string_index is the index in the string table to the name associated with the function.
	NameStringIndex uint32 `protobuf:"varint,6,opt,name=name_string_index,json=nameStringIndex,proto3" json:"name_string_index,omitempty"`
	// system_name_string_index is the index in the string table to the system_name associated with the function.
	SystemNameStringIndex uint32 `` /* 129-byte string literal not displayed */
	// filename_string_index is the index in the string table to the filename associated with the function.
	FilenameStringIndex uint32 `protobuf:"varint,8,opt,name=filename_string_index,json=filenameStringIndex,proto3" json:"filename_string_index,omitempty"`
	// contains filtered or unexported fields
}

Function describes metadata of a source code function.

func (*Function) GetFilename

func (x *Function) GetFilename() string

func (*Function) GetFilenameStringIndex

func (x *Function) GetFilenameStringIndex() uint32

func (*Function) GetId

func (x *Function) GetId() string

func (*Function) GetName

func (x *Function) GetName() string

func (*Function) GetNameStringIndex

func (x *Function) GetNameStringIndex() uint32

func (*Function) GetStartLine

func (x *Function) GetStartLine() int64

func (*Function) GetSystemName

func (x *Function) GetSystemName() string

func (*Function) GetSystemNameStringIndex

func (x *Function) GetSystemNameStringIndex() uint32

func (*Function) ProtoMessage

func (*Function) ProtoMessage()

func (*Function) ProtoReflect

func (x *Function) ProtoReflect() protoreflect.Message

func (*Function) Reset

func (x *Function) Reset()

func (*Function) SetFilename

func (x *Function) SetFilename(v string)

func (*Function) SetFilenameStringIndex

func (x *Function) SetFilenameStringIndex(v uint32)

func (*Function) SetId

func (x *Function) SetId(v string)

func (*Function) SetName

func (x *Function) SetName(v string)

func (*Function) SetNameStringIndex

func (x *Function) SetNameStringIndex(v uint32)

func (*Function) SetStartLine

func (x *Function) SetStartLine(v int64)

func (*Function) SetSystemName

func (x *Function) SetSystemName(v string)

func (*Function) SetSystemNameStringIndex

func (x *Function) SetSystemNameStringIndex(v uint32)

func (*Function) String

func (x *Function) String() string

type Function_builder

type Function_builder struct {

	// id is the unique identifier for the function.
	Id string
	// start_line is the line number in the source file of the first line of the function.
	StartLine int64
	// name is the name of the function.
	Name string
	// system_name describes the name of the function, as identified by the
	// system. For instance, it can be a C++ mangled name.
	SystemName string
	// filename is the name of the source file of the function.
	Filename string
	// name_string_index is the index in the string table to the name associated with the function.
	NameStringIndex uint32
	// system_name_string_index is the index in the string table to the system_name associated with the function.
	SystemNameStringIndex uint32
	// filename_string_index is the index in the string table to the filename associated with the function.
	FilenameStringIndex uint32
	// contains filtered or unexported fields
}

func (Function_builder) Build

func (b0 Function_builder) Build() *Function

type FunctionsRequest

type FunctionsRequest struct {

	// IDs of functions to retrieve.
	FunctionIds []string `protobuf:"bytes,1,rep,name=function_ids,json=functionIds,proto3" json:"function_ids,omitempty"`
	// contains filtered or unexported fields
}

FunctionsRequest contains information about the functions requested.

func (*FunctionsRequest) GetFunctionIds

func (x *FunctionsRequest) GetFunctionIds() []string

func (*FunctionsRequest) ProtoMessage

func (*FunctionsRequest) ProtoMessage()

func (*FunctionsRequest) ProtoReflect

func (x *FunctionsRequest) ProtoReflect() protoreflect.Message

func (*FunctionsRequest) Reset

func (x *FunctionsRequest) Reset()

func (*FunctionsRequest) SetFunctionIds

func (x *FunctionsRequest) SetFunctionIds(v []string)

func (*FunctionsRequest) String

func (x *FunctionsRequest) String() string

type FunctionsRequest_builder

type FunctionsRequest_builder struct {

	// IDs of functions to retrieve.
	FunctionIds []string
	// contains filtered or unexported fields
}

func (FunctionsRequest_builder) Build

type FunctionsResponse

type FunctionsResponse struct {

	// Functions that are known to the backing metastore.
	Functions []*Function `protobuf:"bytes,1,rep,name=functions,proto3" json:"functions,omitempty"`
	// contains filtered or unexported fields
}

FunctionsResponse contains the requested functions.

func (*FunctionsResponse) GetFunctions

func (x *FunctionsResponse) GetFunctions() []*Function

func (*FunctionsResponse) ProtoMessage

func (*FunctionsResponse) ProtoMessage()

func (*FunctionsResponse) ProtoReflect

func (x *FunctionsResponse) ProtoReflect() protoreflect.Message

func (*FunctionsResponse) Reset

func (x *FunctionsResponse) Reset()

func (*FunctionsResponse) SetFunctions

func (x *FunctionsResponse) SetFunctions(v []*Function)

func (*FunctionsResponse) String

func (x *FunctionsResponse) String() string

type FunctionsResponse_builder

type FunctionsResponse_builder struct {

	// Functions that are known to the backing metastore.
	Functions []*Function
	// contains filtered or unexported fields
}

func (FunctionsResponse_builder) Build

type GetOrCreateFunctionsRequest

type GetOrCreateFunctionsRequest struct {

	// Functions to be created or retrieved.
	Functions []*Function `protobuf:"bytes,1,rep,name=functions,proto3" json:"functions,omitempty"`
	// contains filtered or unexported fields
}

GetOrCreateFunctionsRequest contains all information about functions that are requested to be retrieved or created if they don't already exist.

func (*GetOrCreateFunctionsRequest) GetFunctions

func (x *GetOrCreateFunctionsRequest) GetFunctions() []*Function

func (*GetOrCreateFunctionsRequest) ProtoMessage

func (*GetOrCreateFunctionsRequest) ProtoMessage()

func (*GetOrCreateFunctionsRequest) ProtoReflect

func (*GetOrCreateFunctionsRequest) Reset

func (x *GetOrCreateFunctionsRequest) Reset()

func (*GetOrCreateFunctionsRequest) SetFunctions

func (x *GetOrCreateFunctionsRequest) SetFunctions(v []*Function)

func (*GetOrCreateFunctionsRequest) String

func (x *GetOrCreateFunctionsRequest) String() string

type GetOrCreateFunctionsRequest_builder

type GetOrCreateFunctionsRequest_builder struct {

	// Functions to be created or retrieved.
	Functions []*Function
	// contains filtered or unexported fields
}

func (GetOrCreateFunctionsRequest_builder) Build

type GetOrCreateFunctionsResponse

type GetOrCreateFunctionsResponse struct {

	// Functions that are known to the backing metastore. If any functions didn't
	// exist before the request they have now been persisted and are uniquely
	// identifyable through their key.
	Functions []*Function `protobuf:"bytes,1,rep,name=functions,proto3" json:"functions,omitempty"`
	// contains filtered or unexported fields
}

GetOrCreateFunctionsResponse contains information about functions requested.

func (*GetOrCreateFunctionsResponse) GetFunctions

func (x *GetOrCreateFunctionsResponse) GetFunctions() []*Function

func (*GetOrCreateFunctionsResponse) ProtoMessage

func (*GetOrCreateFunctionsResponse) ProtoMessage()

func (*GetOrCreateFunctionsResponse) ProtoReflect

func (*GetOrCreateFunctionsResponse) Reset

func (x *GetOrCreateFunctionsResponse) Reset()

func (*GetOrCreateFunctionsResponse) SetFunctions

func (x *GetOrCreateFunctionsResponse) SetFunctions(v []*Function)

func (*GetOrCreateFunctionsResponse) String

type GetOrCreateFunctionsResponse_builder

type GetOrCreateFunctionsResponse_builder struct {

	// Functions that are known to the backing metastore. If any functions didn't
	// exist before the request they have now been persisted and are uniquely
	// identifyable through their key.
	Functions []*Function
	// contains filtered or unexported fields
}

func (GetOrCreateFunctionsResponse_builder) Build

type GetOrCreateLocationsRequest

type GetOrCreateLocationsRequest struct {

	// Locations to be created or retrieved.
	Locations []*Location `protobuf:"bytes,1,rep,name=locations,proto3" json:"locations,omitempty"`
	// contains filtered or unexported fields
}

GetOrCreateLocationsRequest contains all information about locations that are requested to be retrieved or created if they don't already exist.

func (*GetOrCreateLocationsRequest) GetLocations

func (x *GetOrCreateLocationsRequest) GetLocations() []*Location

func (*GetOrCreateLocationsRequest) ProtoMessage

func (*GetOrCreateLocationsRequest) ProtoMessage()

func (*GetOrCreateLocationsRequest) ProtoReflect

func (*GetOrCreateLocationsRequest) Reset

func (x *GetOrCreateLocationsRequest) Reset()

func (*GetOrCreateLocationsRequest) SetLocations

func (x *GetOrCreateLocationsRequest) SetLocations(v []*Location)

func (*GetOrCreateLocationsRequest) String

func (x *GetOrCreateLocationsRequest) String() string

type GetOrCreateLocationsRequest_builder

type GetOrCreateLocationsRequest_builder struct {

	// Locations to be created or retrieved.
	Locations []*Location
	// contains filtered or unexported fields
}

func (GetOrCreateLocationsRequest_builder) Build

type GetOrCreateLocationsResponse

type GetOrCreateLocationsResponse struct {

	// Locations that are known to the backing metastore. If any locations didn't
	// exist before the request they have now been persisted and are uniquely
	// identifyable through their key.
	Locations []*Location `protobuf:"bytes,1,rep,name=locations,proto3" json:"locations,omitempty"`
	// contains filtered or unexported fields
}

GetOrCreateLocationsResponse contains information about locations requested.

func (*GetOrCreateLocationsResponse) GetLocations

func (x *GetOrCreateLocationsResponse) GetLocations() []*Location

func (*GetOrCreateLocationsResponse) ProtoMessage

func (*GetOrCreateLocationsResponse) ProtoMessage()

func (*GetOrCreateLocationsResponse) ProtoReflect

func (*GetOrCreateLocationsResponse) Reset

func (x *GetOrCreateLocationsResponse) Reset()

func (*GetOrCreateLocationsResponse) SetLocations

func (x *GetOrCreateLocationsResponse) SetLocations(v []*Location)

func (*GetOrCreateLocationsResponse) String

type GetOrCreateLocationsResponse_builder

type GetOrCreateLocationsResponse_builder struct {

	// Locations that are known to the backing metastore. If any locations didn't
	// exist before the request they have now been persisted and are uniquely
	// identifyable through their key.
	Locations []*Location
	// contains filtered or unexported fields
}

func (GetOrCreateLocationsResponse_builder) Build

type GetOrCreateMappingsRequest

type GetOrCreateMappingsRequest struct {

	// Mappings to be created or retrieved.
	Mappings []*Mapping `protobuf:"bytes,1,rep,name=mappings,proto3" json:"mappings,omitempty"`
	// contains filtered or unexported fields
}

GetOrCreateMappingsRequest contains all information about mappings that are requested to be retrieved or created if they don't already exist.

func (*GetOrCreateMappingsRequest) GetMappings

func (x *GetOrCreateMappingsRequest) GetMappings() []*Mapping

func (*GetOrCreateMappingsRequest) ProtoMessage

func (*GetOrCreateMappingsRequest) ProtoMessage()

func (*GetOrCreateMappingsRequest) ProtoReflect

func (*GetOrCreateMappingsRequest) Reset

func (x *GetOrCreateMappingsRequest) Reset()

func (*GetOrCreateMappingsRequest) SetMappings

func (x *GetOrCreateMappingsRequest) SetMappings(v []*Mapping)

func (*GetOrCreateMappingsRequest) String

func (x *GetOrCreateMappingsRequest) String() string

type GetOrCreateMappingsRequest_builder

type GetOrCreateMappingsRequest_builder struct {

	// Mappings to be created or retrieved.
	Mappings []*Mapping
	// contains filtered or unexported fields
}

func (GetOrCreateMappingsRequest_builder) Build

type GetOrCreateMappingsResponse

type GetOrCreateMappingsResponse struct {

	// Mappings that are known to the backing metastore. If any mappings didn't
	// exist before the request they have now been persisted and are uniquely
	// identifyable through their key.
	Mappings []*Mapping `protobuf:"bytes,1,rep,name=mappings,proto3" json:"mappings,omitempty"`
	// contains filtered or unexported fields
}

GetOrCreateMappingsResponse contains information about mappings requested.

func (*GetOrCreateMappingsResponse) GetMappings

func (x *GetOrCreateMappingsResponse) GetMappings() []*Mapping

func (*GetOrCreateMappingsResponse) ProtoMessage

func (*GetOrCreateMappingsResponse) ProtoMessage()

func (*GetOrCreateMappingsResponse) ProtoReflect

func (*GetOrCreateMappingsResponse) Reset

func (x *GetOrCreateMappingsResponse) Reset()

func (*GetOrCreateMappingsResponse) SetMappings

func (x *GetOrCreateMappingsResponse) SetMappings(v []*Mapping)

func (*GetOrCreateMappingsResponse) String

func (x *GetOrCreateMappingsResponse) String() string

type GetOrCreateMappingsResponse_builder

type GetOrCreateMappingsResponse_builder struct {

	// Mappings that are known to the backing metastore. If any mappings didn't
	// exist before the request they have now been persisted and are uniquely
	// identifyable through their key.
	Mappings []*Mapping
	// contains filtered or unexported fields
}

func (GetOrCreateMappingsResponse_builder) Build

type GetOrCreateStacktracesRequest

type GetOrCreateStacktracesRequest struct {

	// Stacktraces to be created or retrieved.
	Stacktraces []*Stacktrace `protobuf:"bytes,1,rep,name=stacktraces,proto3" json:"stacktraces,omitempty"`
	// contains filtered or unexported fields
}

GetOrCreateStracktracesRequest contains all information about stacktraces that are requested to be retrieved or created if they don't already exist.

func (*GetOrCreateStacktracesRequest) GetStacktraces

func (x *GetOrCreateStacktracesRequest) GetStacktraces() []*Stacktrace

func (*GetOrCreateStacktracesRequest) ProtoMessage

func (*GetOrCreateStacktracesRequest) ProtoMessage()

func (*GetOrCreateStacktracesRequest) ProtoReflect

func (*GetOrCreateStacktracesRequest) Reset

func (x *GetOrCreateStacktracesRequest) Reset()

func (*GetOrCreateStacktracesRequest) SetStacktraces

func (x *GetOrCreateStacktracesRequest) SetStacktraces(v []*Stacktrace)

func (*GetOrCreateStacktracesRequest) String

type GetOrCreateStacktracesRequest_builder

type GetOrCreateStacktracesRequest_builder struct {

	// Stacktraces to be created or retrieved.
	Stacktraces []*Stacktrace
	// contains filtered or unexported fields
}

func (GetOrCreateStacktracesRequest_builder) Build

type GetOrCreateStacktracesResponse

type GetOrCreateStacktracesResponse struct {

	// Stacktraces that are known to the backing metastore. If any stacktraces
	// didn't exist before the request they have now been persisted and are
	// uniquely identifyable through their key.
	Stacktraces []*Stacktrace `protobuf:"bytes,1,rep,name=stacktraces,proto3" json:"stacktraces,omitempty"`
	// contains filtered or unexported fields
}

GetOrCreateStacktracesResponse contains information about locations requested.

func (*GetOrCreateStacktracesResponse) GetStacktraces

func (x *GetOrCreateStacktracesResponse) GetStacktraces() []*Stacktrace

func (*GetOrCreateStacktracesResponse) ProtoMessage

func (*GetOrCreateStacktracesResponse) ProtoMessage()

func (*GetOrCreateStacktracesResponse) ProtoReflect

func (*GetOrCreateStacktracesResponse) Reset

func (x *GetOrCreateStacktracesResponse) Reset()

func (*GetOrCreateStacktracesResponse) SetStacktraces

func (x *GetOrCreateStacktracesResponse) SetStacktraces(v []*Stacktrace)

func (*GetOrCreateStacktracesResponse) String

type GetOrCreateStacktracesResponse_builder

type GetOrCreateStacktracesResponse_builder struct {

	// Stacktraces that are known to the backing metastore. If any stacktraces
	// didn't exist before the request they have now been persisted and are
	// uniquely identifyable through their key.
	Stacktraces []*Stacktrace
	// contains filtered or unexported fields
}

func (GetOrCreateStacktracesResponse_builder) Build

type Line

type Line struct {

	// function_id is the ID of the function.
	FunctionId string `protobuf:"bytes,1,opt,name=function_id,json=functionId,proto3" json:"function_id,omitempty"`
	// line is the line number in the source file of the referenced function.
	Line int64 `protobuf:"varint,2,opt,name=line,proto3" json:"line,omitempty"`
	// function_index is the index in the functions table.
	FunctionIndex uint32 `protobuf:"varint,3,opt,name=function_index,json=functionIndex,proto3" json:"function_index,omitempty"`
	// contains filtered or unexported fields
}

Line describes a source code function and its line number.

func (*Line) GetFunctionId

func (x *Line) GetFunctionId() string

func (*Line) GetFunctionIndex

func (x *Line) GetFunctionIndex() uint32

func (*Line) GetLine

func (x *Line) GetLine() int64

func (*Line) ProtoMessage

func (*Line) ProtoMessage()

func (*Line) ProtoReflect

func (x *Line) ProtoReflect() protoreflect.Message

func (*Line) Reset

func (x *Line) Reset()

func (*Line) SetFunctionId

func (x *Line) SetFunctionId(v string)

func (*Line) SetFunctionIndex

func (x *Line) SetFunctionIndex(v uint32)

func (*Line) SetLine

func (x *Line) SetLine(v int64)

func (*Line) String

func (x *Line) String() string

type Line_builder

type Line_builder struct {

	// function_id is the ID of the function.
	FunctionId string
	// line is the line number in the source file of the referenced function.
	Line int64
	// function_index is the index in the functions table.
	FunctionIndex uint32
	// contains filtered or unexported fields
}

func (Line_builder) Build

func (b0 Line_builder) Build() *Line

type Location

type Location struct {

	// id is the unique identifier for the location.
	Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	// address is the memory address of the location if present.
	Address uint64 `protobuf:"varint,2,opt,name=address,proto3" json:"address,omitempty"`
	// mapping_id is the unique identifier for the mapping associated with the location.
	MappingId string `protobuf:"bytes,4,opt,name=mapping_id,json=mappingId,proto3" json:"mapping_id,omitempty"`
	// is_folded indicates whether the location is folded into the previous location.
	IsFolded bool `protobuf:"varint,5,opt,name=is_folded,json=isFolded,proto3" json:"is_folded,omitempty"`
	// lines are the call frames represented by this location. Multiple lines
	// indicate they have been inlined.
	Lines []*Line `protobuf:"bytes,6,rep,name=lines,proto3" json:"lines,omitempty"`
	// mapping_index has the index into the mapping table where mappings are sent deduplicated.
	MappingIndex uint32 `protobuf:"varint,7,opt,name=mapping_index,json=mappingIndex,proto3" json:"mapping_index,omitempty"`
	// contains filtered or unexported fields
}

Location describes a single location of a stack traces.

func (*Location) GetAddress

func (x *Location) GetAddress() uint64

func (*Location) GetId

func (x *Location) GetId() string

func (*Location) GetIsFolded

func (x *Location) GetIsFolded() bool

func (*Location) GetLines

func (x *Location) GetLines() []*Line

func (*Location) GetMappingId

func (x *Location) GetMappingId() string

func (*Location) GetMappingIndex

func (x *Location) GetMappingIndex() uint32

func (*Location) ProtoMessage

func (*Location) ProtoMessage()

func (*Location) ProtoReflect

func (x *Location) ProtoReflect() protoreflect.Message

func (*Location) Reset

func (x *Location) Reset()

func (*Location) SetAddress

func (x *Location) SetAddress(v uint64)

func (*Location) SetId

func (x *Location) SetId(v string)

func (*Location) SetIsFolded

func (x *Location) SetIsFolded(v bool)

func (*Location) SetLines

func (x *Location) SetLines(v []*Line)

func (*Location) SetMappingId

func (x *Location) SetMappingId(v string)

func (*Location) SetMappingIndex

func (x *Location) SetMappingIndex(v uint32)

func (*Location) String

func (x *Location) String() string

type LocationLinesRequest

type LocationLinesRequest struct {

	// IDs of locations to retrieve location lines for.
	LocationIds []string `protobuf:"bytes,1,rep,name=location_ids,json=locationIds,proto3" json:"location_ids,omitempty"`
	// contains filtered or unexported fields
}

LocationLinesRequest contains information about the location's lines requested.

func (*LocationLinesRequest) GetLocationIds

func (x *LocationLinesRequest) GetLocationIds() []string

func (*LocationLinesRequest) ProtoMessage

func (*LocationLinesRequest) ProtoMessage()

func (*LocationLinesRequest) ProtoReflect

func (x *LocationLinesRequest) ProtoReflect() protoreflect.Message

func (*LocationLinesRequest) Reset

func (x *LocationLinesRequest) Reset()

func (*LocationLinesRequest) SetLocationIds

func (x *LocationLinesRequest) SetLocationIds(v []string)

func (*LocationLinesRequest) String

func (x *LocationLinesRequest) String() string

type LocationLinesRequest_builder

type LocationLinesRequest_builder struct {

	// IDs of locations to retrieve location lines for.
	LocationIds []string
	// contains filtered or unexported fields
}

func (LocationLinesRequest_builder) Build

type Location_builder

type Location_builder struct {

	// id is the unique identifier for the location.
	Id string
	// address is the memory address of the location if present.
	Address uint64
	// mapping_id is the unique identifier for the mapping associated with the location.
	MappingId string
	// is_folded indicates whether the location is folded into the previous location.
	IsFolded bool
	// lines are the call frames represented by this location. Multiple lines
	// indicate they have been inlined.
	Lines []*Line
	// mapping_index has the index into the mapping table where mappings are sent deduplicated.
	MappingIndex uint32
	// contains filtered or unexported fields
}

func (Location_builder) Build

func (b0 Location_builder) Build() *Location

type LocationsRequest

type LocationsRequest struct {

	// IDs of locations to retrieve.
	LocationIds []string `protobuf:"bytes,1,rep,name=location_ids,json=locationIds,proto3" json:"location_ids,omitempty"`
	// contains filtered or unexported fields
}

LocationsRequest contains information about the locations requested.

func (*LocationsRequest) GetLocationIds

func (x *LocationsRequest) GetLocationIds() []string

func (*LocationsRequest) ProtoMessage

func (*LocationsRequest) ProtoMessage()

func (*LocationsRequest) ProtoReflect

func (x *LocationsRequest) ProtoReflect() protoreflect.Message

func (*LocationsRequest) Reset

func (x *LocationsRequest) Reset()

func (*LocationsRequest) SetLocationIds

func (x *LocationsRequest) SetLocationIds(v []string)

func (*LocationsRequest) String

func (x *LocationsRequest) String() string

type LocationsRequest_builder

type LocationsRequest_builder struct {

	// IDs of locations to retrieve.
	LocationIds []string
	// contains filtered or unexported fields
}

func (LocationsRequest_builder) Build

type LocationsResponse

type LocationsResponse struct {

	// Locations that are known to the backing metastore.
	Locations []*Location `protobuf:"bytes,1,rep,name=locations,proto3" json:"locations,omitempty"`
	// contains filtered or unexported fields
}

LocationsResponse contains the requested locations.

func (*LocationsResponse) GetLocations

func (x *LocationsResponse) GetLocations() []*Location

func (*LocationsResponse) ProtoMessage

func (*LocationsResponse) ProtoMessage()

func (*LocationsResponse) ProtoReflect

func (x *LocationsResponse) ProtoReflect() protoreflect.Message

func (*LocationsResponse) Reset

func (x *LocationsResponse) Reset()

func (*LocationsResponse) SetLocations

func (x *LocationsResponse) SetLocations(v []*Location)

func (*LocationsResponse) String

func (x *LocationsResponse) String() string

type LocationsResponse_builder

type LocationsResponse_builder struct {

	// Locations that are known to the backing metastore.
	Locations []*Location
	// contains filtered or unexported fields
}

func (LocationsResponse_builder) Build

type Mapping

type Mapping struct {

	// id is the unique identifier for the mapping.
	Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	// start is the start address of the mapping.
	Start uint64 `protobuf:"varint,2,opt,name=start,proto3" json:"start,omitempty"`
	// limit is the length of the address space of the mapping.
	Limit uint64 `protobuf:"varint,3,opt,name=limit,proto3" json:"limit,omitempty"`
	// offset in the binary that corresponds to the first mapped address.
	Offset uint64 `protobuf:"varint,4,opt,name=offset,proto3" json:"offset,omitempty"`
	// file is the name of the file associated with the mapping.
	File string `protobuf:"bytes,5,opt,name=file,proto3" json:"file,omitempty"`
	// build_id is the build ID of the mapping.
	BuildId string `protobuf:"bytes,6,opt,name=build_id,json=buildId,proto3" json:"build_id,omitempty"`
	// has_functions indicates whether the mapping has associated functions.
	HasFunctions bool `protobuf:"varint,7,opt,name=has_functions,json=hasFunctions,proto3" json:"has_functions,omitempty"`
	// has_filenames indicates whether the mapping has associated filenames.
	HasFilenames bool `protobuf:"varint,8,opt,name=has_filenames,json=hasFilenames,proto3" json:"has_filenames,omitempty"`
	// has_line_numbers indicates whether the mapping has associated line numbers.
	HasLineNumbers bool `protobuf:"varint,9,opt,name=has_line_numbers,json=hasLineNumbers,proto3" json:"has_line_numbers,omitempty"`
	// has_inline_frames indicates whether the mapping has associated inline frames.
	HasInlineFrames bool `protobuf:"varint,10,opt,name=has_inline_frames,json=hasInlineFrames,proto3" json:"has_inline_frames,omitempty"`
	// fileStringIndex is the index in the string table to the file name associated with the mapping.
	FileStringIndex uint32 `protobuf:"varint,11,opt,name=file_string_index,json=fileStringIndex,proto3" json:"file_string_index,omitempty"`
	// build_id_string_index is the index in the string table to the build ID of the mapping.
	BuildIdStringIndex uint32 `protobuf:"varint,12,opt,name=build_id_string_index,json=buildIdStringIndex,proto3" json:"build_id_string_index,omitempty"`
	// contains filtered or unexported fields
}

Mapping describes a memory mapping.

func (*Mapping) GetBuildId

func (x *Mapping) GetBuildId() string

func (*Mapping) GetBuildIdStringIndex

func (x *Mapping) GetBuildIdStringIndex() uint32

func (*Mapping) GetFile

func (x *Mapping) GetFile() string

func (*Mapping) GetFileStringIndex

func (x *Mapping) GetFileStringIndex() uint32

func (*Mapping) GetHasFilenames

func (x *Mapping) GetHasFilenames() bool

func (*Mapping) GetHasFunctions

func (x *Mapping) GetHasFunctions() bool

func (*Mapping) GetHasInlineFrames

func (x *Mapping) GetHasInlineFrames() bool

func (*Mapping) GetHasLineNumbers

func (x *Mapping) GetHasLineNumbers() bool

func (*Mapping) GetId

func (x *Mapping) GetId() string

func (*Mapping) GetLimit

func (x *Mapping) GetLimit() uint64

func (*Mapping) GetOffset

func (x *Mapping) GetOffset() uint64

func (*Mapping) GetStart

func (x *Mapping) GetStart() uint64

func (*Mapping) ProtoMessage

func (*Mapping) ProtoMessage()

func (*Mapping) ProtoReflect

func (x *Mapping) ProtoReflect() protoreflect.Message

func (*Mapping) Reset

func (x *Mapping) Reset()

func (*Mapping) SetBuildId

func (x *Mapping) SetBuildId(v string)

func (*Mapping) SetBuildIdStringIndex

func (x *Mapping) SetBuildIdStringIndex(v uint32)

func (*Mapping) SetFile

func (x *Mapping) SetFile(v string)

func (*Mapping) SetFileStringIndex

func (x *Mapping) SetFileStringIndex(v uint32)

func (*Mapping) SetHasFilenames

func (x *Mapping) SetHasFilenames(v bool)

func (*Mapping) SetHasFunctions

func (x *Mapping) SetHasFunctions(v bool)

func (*Mapping) SetHasInlineFrames

func (x *Mapping) SetHasInlineFrames(v bool)

func (*Mapping) SetHasLineNumbers

func (x *Mapping) SetHasLineNumbers(v bool)

func (*Mapping) SetId

func (x *Mapping) SetId(v string)

func (*Mapping) SetLimit

func (x *Mapping) SetLimit(v uint64)

func (*Mapping) SetOffset

func (x *Mapping) SetOffset(v uint64)

func (*Mapping) SetStart

func (x *Mapping) SetStart(v uint64)

func (*Mapping) String

func (x *Mapping) String() string

type Mapping_builder

type Mapping_builder struct {

	// id is the unique identifier for the mapping.
	Id string
	// start is the start address of the mapping.
	Start uint64
	// limit is the length of the address space of the mapping.
	Limit uint64
	// offset in the binary that corresponds to the first mapped address.
	Offset uint64
	// file is the name of the file associated with the mapping.
	File string
	// build_id is the build ID of the mapping.
	BuildId string
	// has_functions indicates whether the mapping has associated functions.
	HasFunctions bool
	// has_filenames indicates whether the mapping has associated filenames.
	HasFilenames bool
	// has_line_numbers indicates whether the mapping has associated line numbers.
	HasLineNumbers bool
	// has_inline_frames indicates whether the mapping has associated inline frames.
	HasInlineFrames bool
	// fileStringIndex is the index in the string table to the file name associated with the mapping.
	FileStringIndex uint32
	// build_id_string_index is the index in the string table to the build ID of the mapping.
	BuildIdStringIndex uint32
	// contains filtered or unexported fields
}

func (Mapping_builder) Build

func (b0 Mapping_builder) Build() *Mapping

type MappingsRequest

type MappingsRequest struct {

	// IDs of mappings to retrieve.
	MappingIds []string `protobuf:"bytes,1,rep,name=mapping_ids,json=mappingIds,proto3" json:"mapping_ids,omitempty"`
	// contains filtered or unexported fields
}

MappingsRequest contains information about the mappings requested.

func (*MappingsRequest) GetMappingIds

func (x *MappingsRequest) GetMappingIds() []string

func (*MappingsRequest) ProtoMessage

func (*MappingsRequest) ProtoMessage()

func (*MappingsRequest) ProtoReflect

func (x *MappingsRequest) ProtoReflect() protoreflect.Message

func (*MappingsRequest) Reset

func (x *MappingsRequest) Reset()

func (*MappingsRequest) SetMappingIds

func (x *MappingsRequest) SetMappingIds(v []string)

func (*MappingsRequest) String

func (x *MappingsRequest) String() string

type MappingsRequest_builder

type MappingsRequest_builder struct {

	// IDs of mappings to retrieve.
	MappingIds []string
	// contains filtered or unexported fields
}

func (MappingsRequest_builder) Build

type MappingsResponse

type MappingsResponse struct {

	// Mappings that are known to the backing metastore.
	Mappings []*Mapping `protobuf:"bytes,1,rep,name=mappings,proto3" json:"mappings,omitempty"`
	// contains filtered or unexported fields
}

MappingsResponse contains the requested mappings.

func (*MappingsResponse) GetMappings

func (x *MappingsResponse) GetMappings() []*Mapping

func (*MappingsResponse) ProtoMessage

func (*MappingsResponse) ProtoMessage()

func (*MappingsResponse) ProtoReflect

func (x *MappingsResponse) ProtoReflect() protoreflect.Message

func (*MappingsResponse) Reset

func (x *MappingsResponse) Reset()

func (*MappingsResponse) SetMappings

func (x *MappingsResponse) SetMappings(v []*Mapping)

func (*MappingsResponse) String

func (x *MappingsResponse) String() string

type MappingsResponse_builder

type MappingsResponse_builder struct {

	// Mappings that are known to the backing metastore.
	Mappings []*Mapping
	// contains filtered or unexported fields
}

func (MappingsResponse_builder) Build

type Sample

type Sample struct {

	// stacktrace_id references stack trace of the sample.
	StacktraceId string `protobuf:"bytes,1,opt,name=stacktrace_id,json=stacktraceId,proto3" json:"stacktrace_id,omitempty"`
	// labels are extra labels for a stack trace.
	Labels map[string]*SampleLabel `` /* 139-byte string literal not displayed */
	// num_labels are the num of labels.
	NumLabels map[string]*SampleNumLabel `` /* 162-byte string literal not displayed */
	// num_units are the units for the labels.
	NumUnits map[string]*SampleNumUnit `` /* 159-byte string literal not displayed */
	// contains filtered or unexported fields
}

Sample is a stack trace with optional labels.

func (*Sample) GetLabels

func (x *Sample) GetLabels() map[string]*SampleLabel

func (*Sample) GetNumLabels

func (x *Sample) GetNumLabels() map[string]*SampleNumLabel

func (*Sample) GetNumUnits

func (x *Sample) GetNumUnits() map[string]*SampleNumUnit

func (*Sample) GetStacktraceId

func (x *Sample) GetStacktraceId() string

func (*Sample) ProtoMessage

func (*Sample) ProtoMessage()

func (*Sample) ProtoReflect

func (x *Sample) ProtoReflect() protoreflect.Message

func (*Sample) Reset

func (x *Sample) Reset()

func (*Sample) SetLabels

func (x *Sample) SetLabels(v map[string]*SampleLabel)

func (*Sample) SetNumLabels

func (x *Sample) SetNumLabels(v map[string]*SampleNumLabel)

func (*Sample) SetNumUnits

func (x *Sample) SetNumUnits(v map[string]*SampleNumUnit)

func (*Sample) SetStacktraceId

func (x *Sample) SetStacktraceId(v string)

func (*Sample) String

func (x *Sample) String() string

type SampleLabel

type SampleLabel struct {

	// labels for a label in a Sample.
	Labels []string `protobuf:"bytes,1,rep,name=labels,proto3" json:"labels,omitempty"`
	// contains filtered or unexported fields
}

SampleLabel are the labels added to a Sample.

func (*SampleLabel) GetLabels

func (x *SampleLabel) GetLabels() []string

func (*SampleLabel) ProtoMessage

func (*SampleLabel) ProtoMessage()

func (*SampleLabel) ProtoReflect

func (x *SampleLabel) ProtoReflect() protoreflect.Message

func (*SampleLabel) Reset

func (x *SampleLabel) Reset()

func (*SampleLabel) SetLabels

func (x *SampleLabel) SetLabels(v []string)

func (*SampleLabel) String

func (x *SampleLabel) String() string

type SampleLabel_builder

type SampleLabel_builder struct {

	// labels for a label in a Sample.
	Labels []string
	// contains filtered or unexported fields
}

func (SampleLabel_builder) Build

func (b0 SampleLabel_builder) Build() *SampleLabel

type SampleNumLabel

type SampleNumLabel struct {

	// num_labels are the num_label of a Sample.
	NumLabels []int64 `protobuf:"varint,1,rep,packed,name=num_labels,json=numLabels,proto3" json:"num_labels,omitempty"`
	// contains filtered or unexported fields
}

SampleNumLabel are the num of labels of a Sample.

func (*SampleNumLabel) GetNumLabels

func (x *SampleNumLabel) GetNumLabels() []int64

func (*SampleNumLabel) ProtoMessage

func (*SampleNumLabel) ProtoMessage()

func (*SampleNumLabel) ProtoReflect

func (x *SampleNumLabel) ProtoReflect() protoreflect.Message

func (*SampleNumLabel) Reset

func (x *SampleNumLabel) Reset()

func (*SampleNumLabel) SetNumLabels

func (x *SampleNumLabel) SetNumLabels(v []int64)

func (*SampleNumLabel) String

func (x *SampleNumLabel) String() string

type SampleNumLabel_builder

type SampleNumLabel_builder struct {

	// num_labels are the num_label of a Sample.
	NumLabels []int64
	// contains filtered or unexported fields
}

func (SampleNumLabel_builder) Build

type SampleNumUnit

type SampleNumUnit struct {

	// units of a labels of a Sample.
	Units []string `protobuf:"bytes,1,rep,name=units,proto3" json:"units,omitempty"`
	// contains filtered or unexported fields
}

SampleNumUnit are the num units of a Sample.

func (*SampleNumUnit) GetUnits

func (x *SampleNumUnit) GetUnits() []string

func (*SampleNumUnit) ProtoMessage

func (*SampleNumUnit) ProtoMessage()

func (*SampleNumUnit) ProtoReflect

func (x *SampleNumUnit) ProtoReflect() protoreflect.Message

func (*SampleNumUnit) Reset

func (x *SampleNumUnit) Reset()

func (*SampleNumUnit) SetUnits

func (x *SampleNumUnit) SetUnits(v []string)

func (*SampleNumUnit) String

func (x *SampleNumUnit) String() string

type SampleNumUnit_builder

type SampleNumUnit_builder struct {

	// units of a labels of a Sample.
	Units []string
	// contains filtered or unexported fields
}

func (SampleNumUnit_builder) Build

type Sample_builder

type Sample_builder struct {

	// stacktrace_id references stack trace of the sample.
	StacktraceId string
	// labels are extra labels for a stack trace.
	Labels map[string]*SampleLabel
	// num_labels are the num of labels.
	NumLabels map[string]*SampleNumLabel
	// num_units are the units for the labels.
	NumUnits map[string]*SampleNumUnit
	// contains filtered or unexported fields
}

func (Sample_builder) Build

func (b0 Sample_builder) Build() *Sample

type Stacktrace

type Stacktrace struct {

	// stacktrace_id references stack trace of the stacktrace.
	Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	// locations are the locations in the stack trace.
	LocationIds []string `protobuf:"bytes,2,rep,name=location_ids,json=locationIds,proto3" json:"location_ids,omitempty"`
	// contains filtered or unexported fields
}

Stacktrace is a collection of locations.

func (*Stacktrace) GetId

func (x *Stacktrace) GetId() string

func (*Stacktrace) GetLocationIds

func (x *Stacktrace) GetLocationIds() []string

func (*Stacktrace) ProtoMessage

func (*Stacktrace) ProtoMessage()

func (*Stacktrace) ProtoReflect

func (x *Stacktrace) ProtoReflect() protoreflect.Message

func (*Stacktrace) Reset

func (x *Stacktrace) Reset()

func (*Stacktrace) SetId

func (x *Stacktrace) SetId(v string)

func (*Stacktrace) SetLocationIds

func (x *Stacktrace) SetLocationIds(v []string)

func (*Stacktrace) String

func (x *Stacktrace) String() string

type Stacktrace_builder

type Stacktrace_builder struct {

	// stacktrace_id references stack trace of the stacktrace.
	Id string
	// locations are the locations in the stack trace.
	LocationIds []string
	// contains filtered or unexported fields
}

func (Stacktrace_builder) Build

func (b0 Stacktrace_builder) Build() *Stacktrace

type StacktracesRequest

type StacktracesRequest struct {

	// IDs of stacktraces to retrieve.
	StacktraceIds []string `protobuf:"bytes,1,rep,name=stacktrace_ids,json=stacktraceIds,proto3" json:"stacktrace_ids,omitempty"`
	// contains filtered or unexported fields
}

StacktracesRequest contains information about the stacktraces requested.

func (*StacktracesRequest) GetStacktraceIds

func (x *StacktracesRequest) GetStacktraceIds() []string

func (*StacktracesRequest) ProtoMessage

func (*StacktracesRequest) ProtoMessage()

func (*StacktracesRequest) ProtoReflect

func (x *StacktracesRequest) ProtoReflect() protoreflect.Message

func (*StacktracesRequest) Reset

func (x *StacktracesRequest) Reset()

func (*StacktracesRequest) SetStacktraceIds

func (x *StacktracesRequest) SetStacktraceIds(v []string)

func (*StacktracesRequest) String

func (x *StacktracesRequest) String() string

type StacktracesRequest_builder

type StacktracesRequest_builder struct {

	// IDs of stacktraces to retrieve.
	StacktraceIds []string
	// contains filtered or unexported fields
}

func (StacktracesRequest_builder) Build

type StacktracesResponse

type StacktracesResponse struct {

	// Stacktraces that are known to the backing metastore.
	Stacktraces []*Stacktrace `protobuf:"bytes,1,rep,name=stacktraces,proto3" json:"stacktraces,omitempty"`
	// contains filtered or unexported fields
}

StacktracesRequest contains the requested stacktraces.

func (*StacktracesResponse) GetStacktraces

func (x *StacktracesResponse) GetStacktraces() []*Stacktrace

func (*StacktracesResponse) ProtoMessage

func (*StacktracesResponse) ProtoMessage()

func (*StacktracesResponse) ProtoReflect

func (x *StacktracesResponse) ProtoReflect() protoreflect.Message

func (*StacktracesResponse) Reset

func (x *StacktracesResponse) Reset()

func (*StacktracesResponse) SetStacktraces

func (x *StacktracesResponse) SetStacktraces(v []*Stacktrace)

func (*StacktracesResponse) String

func (x *StacktracesResponse) String() string

type StacktracesResponse_builder

type StacktracesResponse_builder struct {

	// Stacktraces that are known to the backing metastore.
	Stacktraces []*Stacktrace
	// contains filtered or unexported fields
}

func (StacktracesResponse_builder) Build

type UnsymbolizedLocationsRequest

type UnsymbolizedLocationsRequest struct {

	// The maximum number of locations to return.
	Limit uint32 `protobuf:"varint,1,opt,name=limit,proto3" json:"limit,omitempty"`
	// The minimum key to start returning locations from.
	MinKey string `protobuf:"bytes,2,opt,name=min_key,json=minKey,proto3" json:"min_key,omitempty"`
	// contains filtered or unexported fields
}

UnsymbolizedLocationsRequest contains information about the unsymbolized locations requested. While currently empty, this could in the future contain a sharding configuration or limit the number of locations to return.

func (*UnsymbolizedLocationsRequest) GetLimit

func (x *UnsymbolizedLocationsRequest) GetLimit() uint32

func (*UnsymbolizedLocationsRequest) GetMinKey

func (x *UnsymbolizedLocationsRequest) GetMinKey() string

func (*UnsymbolizedLocationsRequest) ProtoMessage

func (*UnsymbolizedLocationsRequest) ProtoMessage()

func (*UnsymbolizedLocationsRequest) ProtoReflect

func (*UnsymbolizedLocationsRequest) Reset

func (x *UnsymbolizedLocationsRequest) Reset()

func (*UnsymbolizedLocationsRequest) SetLimit

func (x *UnsymbolizedLocationsRequest) SetLimit(v uint32)

func (*UnsymbolizedLocationsRequest) SetMinKey

func (x *UnsymbolizedLocationsRequest) SetMinKey(v string)

func (*UnsymbolizedLocationsRequest) String

type UnsymbolizedLocationsRequest_builder

type UnsymbolizedLocationsRequest_builder struct {

	// The maximum number of locations to return.
	Limit uint32
	// The minimum key to start returning locations from.
	MinKey string
	// contains filtered or unexported fields
}

func (UnsymbolizedLocationsRequest_builder) Build

type UnsymbolizedLocationsResponse

type UnsymbolizedLocationsResponse struct {

	// Locations that have a mapping and address that should be symbolizable.
	Locations []*Location `protobuf:"bytes,1,rep,name=locations,proto3" json:"locations,omitempty"`
	// Key of the last location returned. This can be used in a subsequent call
	// to UnsymbolizedLocations to continue from the last returned location.
	MaxKey string `protobuf:"bytes,2,opt,name=max_key,json=maxKey,proto3" json:"max_key,omitempty"`
	// contains filtered or unexported fields
}

UnsymbolizedLocationsResponse contains information about the requested locations that should be symbolizable but potentially haven't been symbolized yet.

func (*UnsymbolizedLocationsResponse) GetLocations

func (x *UnsymbolizedLocationsResponse) GetLocations() []*Location

func (*UnsymbolizedLocationsResponse) GetMaxKey

func (x *UnsymbolizedLocationsResponse) GetMaxKey() string

func (*UnsymbolizedLocationsResponse) ProtoMessage

func (*UnsymbolizedLocationsResponse) ProtoMessage()

func (*UnsymbolizedLocationsResponse) ProtoReflect

func (*UnsymbolizedLocationsResponse) Reset

func (x *UnsymbolizedLocationsResponse) Reset()

func (*UnsymbolizedLocationsResponse) SetLocations

func (x *UnsymbolizedLocationsResponse) SetLocations(v []*Location)

func (*UnsymbolizedLocationsResponse) SetMaxKey

func (x *UnsymbolizedLocationsResponse) SetMaxKey(v string)

func (*UnsymbolizedLocationsResponse) String

type UnsymbolizedLocationsResponse_builder

type UnsymbolizedLocationsResponse_builder struct {

	// Locations that have a mapping and address that should be symbolizable.
	Locations []*Location
	// Key of the last location returned. This can be used in a subsequent call
	// to UnsymbolizedLocations to continue from the last returned location.
	MaxKey string
	// contains filtered or unexported fields
}

func (UnsymbolizedLocationsResponse_builder) Build

Source Files

  • metastore.pb.go

Jump to