authv1

package
v1.36.11-2024061123445... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: MIT Imports: 7 Imported by: 0

Documentation

Index

Constants

const ActorType_ApiClient_case case_ActorType_Type = 2
const ActorType_Type_not_set_case case_ActorType_Type = 0
const ActorType_UserAgent_case case_ActorType_Type = 1
const Actor_Authenticated_case case_Actor_Type = 1
const Actor_Named_case case_Actor_Type = 2
const Actor_Type_not_set_case case_Actor_Type = 0
const AuthMethodOptions_AuthMethod_not_set_case case_AuthMethodOptions_AuthMethod = 0
const AuthMethodOptions_JwtBearer_case case_AuthMethodOptions_AuthMethod = 10
const AuthMethodOptions_None_case case_AuthMethodOptions_AuthMethod = 11
const ClientAuthType_Jwt_case case_ClientAuthType_Type = 1
const ClientAuthType_Session_case case_ClientAuthType_Type = 2
const ClientAuthType_Type_not_set_case case_ClientAuthType_Type = 0

Variables

var (
	// optional o5.auth.v1.AuthMethodOptions auth = 58960757;
	E_Auth = &file_o5_auth_v1_annotations_proto_extTypes[0]
)

Extension fields to descriptorpb.MethodOptions.

var (
	// Default
	//
	// optional o5.auth.v1.AuthMethodOptions default_auth = 58960757;
	E_DefaultAuth = &file_o5_auth_v1_annotations_proto_extTypes[1]
)

Extension fields to descriptorpb.ServiceOptions.

var File_o5_auth_v1_actor_proto protoreflect.FileDescriptor
var File_o5_auth_v1_annotations_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type Actor

type Actor struct {

	// Types that are valid to be assigned to Type:
	//
	//	*Actor_Authenticated
	//	*Actor_Named
	Type isActor_Type `protobuf_oneof:"type"`
	// contains filtered or unexported fields
}

func (*Actor) ClearAuthenticated

func (x *Actor) ClearAuthenticated()

func (*Actor) ClearNamed

func (x *Actor) ClearNamed()

func (*Actor) ClearType

func (x *Actor) ClearType()

func (*Actor) GetAuthenticated

func (x *Actor) GetAuthenticated() *AuthenticatedActor

func (*Actor) GetNamed

func (x *Actor) GetNamed() *Actor_NamedActor

func (*Actor) GetType

func (x *Actor) GetType() isActor_Type

func (*Actor) HasAuthenticated

func (x *Actor) HasAuthenticated() bool

func (*Actor) HasNamed

func (x *Actor) HasNamed() bool

func (*Actor) HasType

func (x *Actor) HasType() bool

func (*Actor) ProtoMessage

func (*Actor) ProtoMessage()

func (*Actor) ProtoReflect

func (x *Actor) ProtoReflect() protoreflect.Message

func (*Actor) Reset

func (x *Actor) Reset()

func (*Actor) SetAuthenticated

func (x *Actor) SetAuthenticated(v *AuthenticatedActor)

func (*Actor) SetNamed

func (x *Actor) SetNamed(v *Actor_NamedActor)

func (*Actor) String

func (x *Actor) String() string

func (*Actor) WhichType

func (x *Actor) WhichType() case_Actor_Type

type ActorType

type ActorType struct {

	// Types that are valid to be assigned to Type:
	//
	//	*ActorType_UserAgent_
	//	*ActorType_ApiClient_
	Type isActorType_Type `protobuf_oneof:"type"`
	// contains filtered or unexported fields
}

func (*ActorType) ClearApiClient

func (x *ActorType) ClearApiClient()

func (*ActorType) ClearType

func (x *ActorType) ClearType()

func (*ActorType) ClearUserAgent

func (x *ActorType) ClearUserAgent()

func (*ActorType) GetApiClient

func (x *ActorType) GetApiClient() *ActorType_ApiClient

func (*ActorType) GetType

func (x *ActorType) GetType() isActorType_Type

func (*ActorType) GetUserAgent

func (x *ActorType) GetUserAgent() *ActorType_UserAgent

func (*ActorType) HasApiClient

func (x *ActorType) HasApiClient() bool

func (*ActorType) HasType

func (x *ActorType) HasType() bool

func (*ActorType) HasUserAgent

func (x *ActorType) HasUserAgent() bool

func (*ActorType) ProtoMessage

func (*ActorType) ProtoMessage()

func (*ActorType) ProtoReflect

func (x *ActorType) ProtoReflect() protoreflect.Message

func (*ActorType) Reset

func (x *ActorType) Reset()

func (*ActorType) SetApiClient

func (x *ActorType) SetApiClient(v *ActorType_ApiClient)

func (*ActorType) SetUserAgent

func (x *ActorType) SetUserAgent(v *ActorType_UserAgent)

func (*ActorType) String

func (x *ActorType) String() string

func (*ActorType) WhichType

func (x *ActorType) WhichType() case_ActorType_Type

type ActorType_ApiClient

type ActorType_ApiClient struct {
	ClientAuth *ClientAuthType `protobuf:"bytes,1,opt,name=client_auth,json=clientAuth,proto3" json:"client_auth,omitempty"`
	// The IP address of the client as best as can be determined
	IpAddress string `protobuf:"bytes,2,opt,name=ip_address,json=ipAddress,proto3" json:"ip_address,omitempty"`
	// contains filtered or unexported fields
}

func (*ActorType_ApiClient) ClearClientAuth

func (x *ActorType_ApiClient) ClearClientAuth()

func (*ActorType_ApiClient) GetClientAuth

func (x *ActorType_ApiClient) GetClientAuth() *ClientAuthType

func (*ActorType_ApiClient) GetIpAddress

func (x *ActorType_ApiClient) GetIpAddress() string

func (*ActorType_ApiClient) HasClientAuth

func (x *ActorType_ApiClient) HasClientAuth() bool

func (*ActorType_ApiClient) ProtoMessage

func (*ActorType_ApiClient) ProtoMessage()

func (*ActorType_ApiClient) ProtoReflect

func (x *ActorType_ApiClient) ProtoReflect() protoreflect.Message

func (*ActorType_ApiClient) Reset

func (x *ActorType_ApiClient) Reset()

func (*ActorType_ApiClient) SetClientAuth

func (x *ActorType_ApiClient) SetClientAuth(v *ClientAuthType)

func (*ActorType_ApiClient) SetIpAddress

func (x *ActorType_ApiClient) SetIpAddress(v string)

func (*ActorType_ApiClient) String

func (x *ActorType_ApiClient) String() string

type ActorType_ApiClient_

type ActorType_ApiClient_ struct {
	ApiClient *ActorType_ApiClient `protobuf:"bytes,2,opt,name=api_client,json=apiClient,proto3,oneof"`
}

type ActorType_ApiClient_builder

type ActorType_ApiClient_builder struct {
	ClientAuth *ClientAuthType
	// The IP address of the client as best as can be determined
	IpAddress string
	// contains filtered or unexported fields
}

func (ActorType_ApiClient_builder) Build

type ActorType_UserAgent

type ActorType_UserAgent struct {
	ClientAuth *ClientAuthType `protobuf:"bytes,1,opt,name=client_auth,json=clientAuth,proto3" json:"client_auth,omitempty"`
	// The provided user agent string of the client.
	UserAgent string `protobuf:"bytes,2,opt,name=user_agent,json=userAgent,proto3" json:"user_agent,omitempty"`
	// The IP address of the client as best as can be determined
	IpAddress string `protobuf:"bytes,3,opt,name=ip_address,json=ipAddress,proto3" json:"ip_address,omitempty"`
	// contains filtered or unexported fields
}

A (presumably) human user using a web browser or mobile app.

func (*ActorType_UserAgent) ClearClientAuth

func (x *ActorType_UserAgent) ClearClientAuth()

func (*ActorType_UserAgent) GetClientAuth

func (x *ActorType_UserAgent) GetClientAuth() *ClientAuthType

func (*ActorType_UserAgent) GetIpAddress

func (x *ActorType_UserAgent) GetIpAddress() string

func (*ActorType_UserAgent) GetUserAgent

func (x *ActorType_UserAgent) GetUserAgent() string

func (*ActorType_UserAgent) HasClientAuth

func (x *ActorType_UserAgent) HasClientAuth() bool

func (*ActorType_UserAgent) ProtoMessage

func (*ActorType_UserAgent) ProtoMessage()

func (*ActorType_UserAgent) ProtoReflect

func (x *ActorType_UserAgent) ProtoReflect() protoreflect.Message

func (*ActorType_UserAgent) Reset

func (x *ActorType_UserAgent) Reset()

func (*ActorType_UserAgent) SetClientAuth

func (x *ActorType_UserAgent) SetClientAuth(v *ClientAuthType)

func (*ActorType_UserAgent) SetIpAddress

func (x *ActorType_UserAgent) SetIpAddress(v string)

func (*ActorType_UserAgent) SetUserAgent

func (x *ActorType_UserAgent) SetUserAgent(v string)

func (*ActorType_UserAgent) String

func (x *ActorType_UserAgent) String() string

type ActorType_UserAgent_

type ActorType_UserAgent_ struct {
	UserAgent *ActorType_UserAgent `protobuf:"bytes,1,opt,name=user_agent,json=userAgent,proto3,oneof"`
}

type ActorType_UserAgent_builder

type ActorType_UserAgent_builder struct {
	ClientAuth *ClientAuthType
	// The provided user agent string of the client.
	UserAgent string
	// The IP address of the client as best as can be determined
	IpAddress string
	// contains filtered or unexported fields
}

func (ActorType_UserAgent_builder) Build

type ActorType_builder

type ActorType_builder struct {

	// Fields of oneof Type:
	UserAgent *ActorType_UserAgent
	ApiClient *ActorType_ApiClient
	// contains filtered or unexported fields
}

func (ActorType_builder) Build

func (b0 ActorType_builder) Build() *ActorType

type Actor_Authenticated

type Actor_Authenticated struct {
	Authenticated *AuthenticatedActor `protobuf:"bytes,1,opt,name=authenticated,proto3,oneof"`
}

type Actor_Named

type Actor_Named struct {
	Named *Actor_NamedActor `protobuf:"bytes,2,opt,name=named,proto3,oneof"`
}

type Actor_NamedActor

type Actor_NamedActor struct {
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// contains filtered or unexported fields
}

func (*Actor_NamedActor) GetName

func (x *Actor_NamedActor) GetName() string

func (*Actor_NamedActor) ProtoMessage

func (*Actor_NamedActor) ProtoMessage()

func (*Actor_NamedActor) ProtoReflect

func (x *Actor_NamedActor) ProtoReflect() protoreflect.Message

func (*Actor_NamedActor) Reset

func (x *Actor_NamedActor) Reset()

func (*Actor_NamedActor) SetName

func (x *Actor_NamedActor) SetName(v string)

func (*Actor_NamedActor) String

func (x *Actor_NamedActor) String() string

type Actor_NamedActor_builder

type Actor_NamedActor_builder struct {
	Name string
	// contains filtered or unexported fields
}

func (Actor_NamedActor_builder) Build

type Actor_builder

type Actor_builder struct {

	// Fields of oneof Type:
	Authenticated *AuthenticatedActor
	Named         *Actor_NamedActor
	// contains filtered or unexported fields
}

func (Actor_builder) Build

func (b0 Actor_builder) Build() *Actor

type AuthMethodJWTBearer

type AuthMethodJWTBearer struct {
	RequiredScopes []string `protobuf:"bytes,1,rep,name=required_scopes,json=requiredScopes,proto3" json:"required_scopes,omitempty"`
	// contains filtered or unexported fields
}

func (*AuthMethodJWTBearer) GetRequiredScopes

func (x *AuthMethodJWTBearer) GetRequiredScopes() []string

func (*AuthMethodJWTBearer) ProtoMessage

func (*AuthMethodJWTBearer) ProtoMessage()

func (*AuthMethodJWTBearer) ProtoReflect

func (x *AuthMethodJWTBearer) ProtoReflect() protoreflect.Message

func (*AuthMethodJWTBearer) Reset

func (x *AuthMethodJWTBearer) Reset()

func (*AuthMethodJWTBearer) SetRequiredScopes

func (x *AuthMethodJWTBearer) SetRequiredScopes(v []string)

func (*AuthMethodJWTBearer) String

func (x *AuthMethodJWTBearer) String() string

type AuthMethodJWTBearer_builder

type AuthMethodJWTBearer_builder struct {
	RequiredScopes []string
	// contains filtered or unexported fields
}

func (AuthMethodJWTBearer_builder) Build

type AuthMethodNone

type AuthMethodNone struct {
	PassThroughHeaders []string `protobuf:"bytes,1,rep,name=pass_through_headers,json=passThroughHeaders,proto3" json:"pass_through_headers,omitempty"`
	// contains filtered or unexported fields
}

func (*AuthMethodNone) GetPassThroughHeaders

func (x *AuthMethodNone) GetPassThroughHeaders() []string

func (*AuthMethodNone) ProtoMessage

func (*AuthMethodNone) ProtoMessage()

func (*AuthMethodNone) ProtoReflect

func (x *AuthMethodNone) ProtoReflect() protoreflect.Message

func (*AuthMethodNone) Reset

func (x *AuthMethodNone) Reset()

func (*AuthMethodNone) SetPassThroughHeaders

func (x *AuthMethodNone) SetPassThroughHeaders(v []string)

func (*AuthMethodNone) String

func (x *AuthMethodNone) String() string

type AuthMethodNone_builder

type AuthMethodNone_builder struct {
	PassThroughHeaders []string
	// contains filtered or unexported fields
}

func (AuthMethodNone_builder) Build

type AuthMethodOptions

type AuthMethodOptions struct {

	// Types that are valid to be assigned to AuthMethod:
	//
	//	*AuthMethodOptions_JwtBearer
	//	*AuthMethodOptions_None
	AuthMethod isAuthMethodOptions_AuthMethod `protobuf_oneof:"auth_method"`
	// contains filtered or unexported fields
}

func (*AuthMethodOptions) ClearAuthMethod

func (x *AuthMethodOptions) ClearAuthMethod()

func (*AuthMethodOptions) ClearJwtBearer

func (x *AuthMethodOptions) ClearJwtBearer()

func (*AuthMethodOptions) ClearNone

func (x *AuthMethodOptions) ClearNone()

func (*AuthMethodOptions) GetAuthMethod

func (x *AuthMethodOptions) GetAuthMethod() isAuthMethodOptions_AuthMethod

func (*AuthMethodOptions) GetJwtBearer

func (x *AuthMethodOptions) GetJwtBearer() *AuthMethodJWTBearer

func (*AuthMethodOptions) GetNone

func (x *AuthMethodOptions) GetNone() *AuthMethodNone

func (*AuthMethodOptions) HasAuthMethod

func (x *AuthMethodOptions) HasAuthMethod() bool

func (*AuthMethodOptions) HasJwtBearer

func (x *AuthMethodOptions) HasJwtBearer() bool

func (*AuthMethodOptions) HasNone

func (x *AuthMethodOptions) HasNone() bool

func (*AuthMethodOptions) ProtoMessage

func (*AuthMethodOptions) ProtoMessage()

func (*AuthMethodOptions) ProtoReflect

func (x *AuthMethodOptions) ProtoReflect() protoreflect.Message

func (*AuthMethodOptions) Reset

func (x *AuthMethodOptions) Reset()

func (*AuthMethodOptions) SetJwtBearer

func (x *AuthMethodOptions) SetJwtBearer(v *AuthMethodJWTBearer)

func (*AuthMethodOptions) SetNone

func (x *AuthMethodOptions) SetNone(v *AuthMethodNone)

func (*AuthMethodOptions) String

func (x *AuthMethodOptions) String() string

func (*AuthMethodOptions) WhichAuthMethod

func (x *AuthMethodOptions) WhichAuthMethod() case_AuthMethodOptions_AuthMethod

type AuthMethodOptions_JwtBearer

type AuthMethodOptions_JwtBearer struct {
	JwtBearer *AuthMethodJWTBearer `protobuf:"bytes,10,opt,name=jwt_bearer,json=jwtBearer,proto3,oneof"`
}

type AuthMethodOptions_None

type AuthMethodOptions_None struct {
	None *AuthMethodNone `protobuf:"bytes,11,opt,name=none,proto3,oneof"`
}

type AuthMethodOptions_builder

type AuthMethodOptions_builder struct {

	// Fields of oneof AuthMethod:
	JwtBearer *AuthMethodJWTBearer
	None      *AuthMethodNone
	// contains filtered or unexported fields
}

func (AuthMethodOptions_builder) Build

type AuthenticatedActor

type AuthenticatedActor struct {

	// The unique identifier of the actor, derived from the various actor type
	// methods.
	Id    string     `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	Type  *ActorType `protobuf:"bytes,2,opt,name=type,proto3" json:"type,omitempty"`
	Claim *Claim     `protobuf:"bytes,3,opt,name=claim,proto3" json:"claim,omitempty"`
	// Arbitrary tags that are defined by the authorizing system to quickly
	// identify the user e.g. the user's email address, API Key Name, etc.
	// Must not be used in authorization logic, and should not be used as a
	// the primary source of the actor's identity.
	ActorTags map[string]string `` /* 162-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*AuthenticatedActor) ClearClaim

func (x *AuthenticatedActor) ClearClaim()

func (*AuthenticatedActor) ClearType

func (x *AuthenticatedActor) ClearType()

func (*AuthenticatedActor) GetActorTags

func (x *AuthenticatedActor) GetActorTags() map[string]string

func (*AuthenticatedActor) GetClaim

func (x *AuthenticatedActor) GetClaim() *Claim

func (*AuthenticatedActor) GetId

func (x *AuthenticatedActor) GetId() string

func (*AuthenticatedActor) GetType

func (x *AuthenticatedActor) GetType() *ActorType

func (*AuthenticatedActor) HasClaim

func (x *AuthenticatedActor) HasClaim() bool

func (*AuthenticatedActor) HasType

func (x *AuthenticatedActor) HasType() bool

func (*AuthenticatedActor) ProtoMessage

func (*AuthenticatedActor) ProtoMessage()

func (*AuthenticatedActor) ProtoReflect

func (x *AuthenticatedActor) ProtoReflect() protoreflect.Message

func (*AuthenticatedActor) Reset

func (x *AuthenticatedActor) Reset()

func (*AuthenticatedActor) SetActorTags

func (x *AuthenticatedActor) SetActorTags(v map[string]string)

func (*AuthenticatedActor) SetClaim

func (x *AuthenticatedActor) SetClaim(v *Claim)

func (*AuthenticatedActor) SetId

func (x *AuthenticatedActor) SetId(v string)

func (*AuthenticatedActor) SetType

func (x *AuthenticatedActor) SetType(v *ActorType)

func (*AuthenticatedActor) String

func (x *AuthenticatedActor) String() string

type AuthenticatedActor_builder

type AuthenticatedActor_builder struct {

	// The unique identifier of the actor, derived from the various actor type
	// methods.
	Id    string
	Type  *ActorType
	Claim *Claim
	// Arbitrary tags that are defined by the authorizing system to quickly
	// identify the user e.g. the user's email address, API Key Name, etc.
	// Must not be used in authorization logic, and should not be used as a
	// the primary source of the actor's identity.
	ActorTags map[string]string
	// contains filtered or unexported fields
}

func (AuthenticatedActor_builder) Build

type Claim

type Claim struct {

	// The actor is only authorized to view and access resources which
	// match **ALL** of the filters.
	// Keys are globally unique, values are UUIDs.
	TenantFilter map[string]string `` /* 171-byte string literal not displayed */
	Scopes       []string          `protobuf:"bytes,2,rep,name=scopes,proto3" json:"scopes,omitempty"`
	// contains filtered or unexported fields
}

func (*Claim) GetScopes

func (x *Claim) GetScopes() []string

func (*Claim) GetTenantFilter

func (x *Claim) GetTenantFilter() map[string]string

func (*Claim) ProtoMessage

func (*Claim) ProtoMessage()

func (*Claim) ProtoReflect

func (x *Claim) ProtoReflect() protoreflect.Message

func (*Claim) Reset

func (x *Claim) Reset()

func (*Claim) SetScopes

func (x *Claim) SetScopes(v []string)

func (*Claim) SetTenantFilter

func (x *Claim) SetTenantFilter(v map[string]string)

func (*Claim) String

func (x *Claim) String() string

type Claim_builder

type Claim_builder struct {

	// The actor is only authorized to view and access resources which
	// match **ALL** of the filters.
	// Keys are globally unique, values are UUIDs.
	TenantFilter map[string]string
	Scopes       []string
	// contains filtered or unexported fields
}

func (Claim_builder) Build

func (b0 Claim_builder) Build() *Claim

type ClientAuthType

type ClientAuthType struct {

	// Types that are valid to be assigned to Type:
	//
	//	*ClientAuthType_Jwt
	//	*ClientAuthType_Session
	Type isClientAuthType_Type `protobuf_oneof:"type"`
	// contains filtered or unexported fields
}

func (*ClientAuthType) ClearJwt

func (x *ClientAuthType) ClearJwt()

func (*ClientAuthType) ClearSession

func (x *ClientAuthType) ClearSession()

func (*ClientAuthType) ClearType

func (x *ClientAuthType) ClearType()

func (*ClientAuthType) GetJwt

func (*ClientAuthType) GetSession

func (x *ClientAuthType) GetSession() *ClientAuthType_SessionAuth

func (*ClientAuthType) GetType

func (x *ClientAuthType) GetType() isClientAuthType_Type

func (*ClientAuthType) HasJwt

func (x *ClientAuthType) HasJwt() bool

func (*ClientAuthType) HasSession

func (x *ClientAuthType) HasSession() bool

func (*ClientAuthType) HasType

func (x *ClientAuthType) HasType() bool

func (*ClientAuthType) ProtoMessage

func (*ClientAuthType) ProtoMessage()

func (*ClientAuthType) ProtoReflect

func (x *ClientAuthType) ProtoReflect() protoreflect.Message

func (*ClientAuthType) Reset

func (x *ClientAuthType) Reset()

func (*ClientAuthType) SetJwt

func (x *ClientAuthType) SetJwt(v *ClientAuthType_JWTAuth)

func (*ClientAuthType) SetSession

func (x *ClientAuthType) SetSession(v *ClientAuthType_SessionAuth)

func (*ClientAuthType) String

func (x *ClientAuthType) String() string

func (*ClientAuthType) WhichType

func (x *ClientAuthType) WhichType() case_ClientAuthType_Type

type ClientAuthType_JWTAuth

type ClientAuthType_JWTAuth struct {
	JwtId    string                 `protobuf:"bytes,1,opt,name=jwt_id,json=jwtId,proto3" json:"jwt_id,omitempty"`
	Issuer   string                 `protobuf:"bytes,2,opt,name=issuer,proto3" json:"issuer,omitempty"`
	IssuedAt *timestamppb.Timestamp `protobuf:"bytes,3,opt,name=issued_at,json=issuedAt,proto3" json:"issued_at,omitempty"`
	// contains filtered or unexported fields
}

func (*ClientAuthType_JWTAuth) ClearIssuedAt

func (x *ClientAuthType_JWTAuth) ClearIssuedAt()

func (*ClientAuthType_JWTAuth) GetIssuedAt

func (x *ClientAuthType_JWTAuth) GetIssuedAt() *timestamppb.Timestamp

func (*ClientAuthType_JWTAuth) GetIssuer

func (x *ClientAuthType_JWTAuth) GetIssuer() string

func (*ClientAuthType_JWTAuth) GetJwtId

func (x *ClientAuthType_JWTAuth) GetJwtId() string

func (*ClientAuthType_JWTAuth) HasIssuedAt

func (x *ClientAuthType_JWTAuth) HasIssuedAt() bool

func (*ClientAuthType_JWTAuth) ProtoMessage

func (*ClientAuthType_JWTAuth) ProtoMessage()

func (*ClientAuthType_JWTAuth) ProtoReflect

func (x *ClientAuthType_JWTAuth) ProtoReflect() protoreflect.Message

func (*ClientAuthType_JWTAuth) Reset

func (x *ClientAuthType_JWTAuth) Reset()

func (*ClientAuthType_JWTAuth) SetIssuedAt

func (x *ClientAuthType_JWTAuth) SetIssuedAt(v *timestamppb.Timestamp)

func (*ClientAuthType_JWTAuth) SetIssuer

func (x *ClientAuthType_JWTAuth) SetIssuer(v string)

func (*ClientAuthType_JWTAuth) SetJwtId

func (x *ClientAuthType_JWTAuth) SetJwtId(v string)

func (*ClientAuthType_JWTAuth) String

func (x *ClientAuthType_JWTAuth) String() string

type ClientAuthType_JWTAuth_builder

type ClientAuthType_JWTAuth_builder struct {
	JwtId    string
	Issuer   string
	IssuedAt *timestamppb.Timestamp
	// contains filtered or unexported fields
}

func (ClientAuthType_JWTAuth_builder) Build

type ClientAuthType_Jwt

type ClientAuthType_Jwt struct {
	Jwt *ClientAuthType_JWTAuth `protobuf:"bytes,1,opt,name=jwt,proto3,oneof"`
}

type ClientAuthType_Session

type ClientAuthType_Session struct {
	Session *ClientAuthType_SessionAuth `protobuf:"bytes,2,opt,name=session,proto3,oneof"`
}

type ClientAuthType_SessionAuth

type ClientAuthType_SessionAuth struct {

	// The identity of the system which stored and evaluated the session.
	SessionManager string `protobuf:"bytes,1,opt,name=session_manager,json=sessionManager,proto3" json:"session_manager,omitempty"`
	// The session ID as defined by the session manager
	SessionId string `protobuf:"bytes,2,opt,name=session_id,json=sessionId,proto3" json:"session_id,omitempty"`
	// The time at which the session was verified by the session manager.
	VerifiedAt *timestamppb.Timestamp `protobuf:"bytes,3,opt,name=verified_at,json=verifiedAt,proto3" json:"verified_at,omitempty"`
	// The time at which the session began at the session manager. (e.g. the
	// time a refresh token was used to create a new session)
	AuthenticatedAt *timestamppb.Timestamp `protobuf:"bytes,4,opt,name=authenticated_at,json=authenticatedAt,proto3" json:"authenticated_at,omitempty"`
	// contains filtered or unexported fields
}

func (*ClientAuthType_SessionAuth) ClearAuthenticatedAt

func (x *ClientAuthType_SessionAuth) ClearAuthenticatedAt()

func (*ClientAuthType_SessionAuth) ClearVerifiedAt

func (x *ClientAuthType_SessionAuth) ClearVerifiedAt()

func (*ClientAuthType_SessionAuth) GetAuthenticatedAt

func (x *ClientAuthType_SessionAuth) GetAuthenticatedAt() *timestamppb.Timestamp

func (*ClientAuthType_SessionAuth) GetSessionId

func (x *ClientAuthType_SessionAuth) GetSessionId() string

func (*ClientAuthType_SessionAuth) GetSessionManager

func (x *ClientAuthType_SessionAuth) GetSessionManager() string

func (*ClientAuthType_SessionAuth) GetVerifiedAt

func (x *ClientAuthType_SessionAuth) GetVerifiedAt() *timestamppb.Timestamp

func (*ClientAuthType_SessionAuth) HasAuthenticatedAt

func (x *ClientAuthType_SessionAuth) HasAuthenticatedAt() bool

func (*ClientAuthType_SessionAuth) HasVerifiedAt

func (x *ClientAuthType_SessionAuth) HasVerifiedAt() bool

func (*ClientAuthType_SessionAuth) ProtoMessage

func (*ClientAuthType_SessionAuth) ProtoMessage()

func (*ClientAuthType_SessionAuth) ProtoReflect

func (*ClientAuthType_SessionAuth) Reset

func (x *ClientAuthType_SessionAuth) Reset()

func (*ClientAuthType_SessionAuth) SetAuthenticatedAt

func (x *ClientAuthType_SessionAuth) SetAuthenticatedAt(v *timestamppb.Timestamp)

func (*ClientAuthType_SessionAuth) SetSessionId

func (x *ClientAuthType_SessionAuth) SetSessionId(v string)

func (*ClientAuthType_SessionAuth) SetSessionManager

func (x *ClientAuthType_SessionAuth) SetSessionManager(v string)

func (*ClientAuthType_SessionAuth) SetVerifiedAt

func (x *ClientAuthType_SessionAuth) SetVerifiedAt(v *timestamppb.Timestamp)

func (*ClientAuthType_SessionAuth) String

func (x *ClientAuthType_SessionAuth) String() string

type ClientAuthType_SessionAuth_builder

type ClientAuthType_SessionAuth_builder struct {

	// The identity of the system which stored and evaluated the session.
	SessionManager string
	// The session ID as defined by the session manager
	SessionId string
	// The time at which the session was verified by the session manager.
	VerifiedAt *timestamppb.Timestamp
	// The time at which the session began at the session manager. (e.g. the
	// time a refresh token was used to create a new session)
	AuthenticatedAt *timestamppb.Timestamp
	// contains filtered or unexported fields
}

func (ClientAuthType_SessionAuth_builder) Build

type ClientAuthType_builder

type ClientAuthType_builder struct {

	// Fields of oneof Type:
	Jwt     *ClientAuthType_JWTAuth
	Session *ClientAuthType_SessionAuth
	// contains filtered or unexported fields
}

func (ClientAuthType_builder) Build

Source Files

  • actor.pb.go
  • annotations.pb.go

Directories

Path Synopsis

Jump to