service

package
v1.36.11-2024061123445... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var File_o5_auth_v1_service_auth_service_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type RealmAccess

type RealmAccess struct {
	RealmId   string `protobuf:"bytes,1,opt,name=realm_id,json=realmId,proto3" json:"realm_id,omitempty"`
	RealmName string `protobuf:"bytes,2,opt,name=realm_name,json=realmName,proto3" json:"realm_name,omitempty"`
	// API URL for this realm
	BaseUrl string `protobuf:"bytes,3,opt,name=base_url,json=baseUrl,proto3" json:"base_url,omitempty"`
	// The sub-realms are separated by tenant ID.
	MultiTenant bool `protobuf:"varint,4,opt,name=multi_tenant,json=multiTenant,proto3" json:"multi_tenant,omitempty"`
	// when not set on a multi-tenant realm, the user has access to all tenants,
	// i.e. super-admin.
	TenantId *string `protobuf:"bytes,5,opt,name=tenant_id,json=tenantId,proto3,oneof" json:"tenant_id,omitempty"`
	// Key-value pairs of metadata for this realm, which are interpreted in the
	// context of the realm type
	Metadata map[string]string `` /* 144-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*RealmAccess) ClearTenantId

func (x *RealmAccess) ClearTenantId()

func (*RealmAccess) GetBaseUrl

func (x *RealmAccess) GetBaseUrl() string

func (*RealmAccess) GetMetadata

func (x *RealmAccess) GetMetadata() map[string]string

func (*RealmAccess) GetMultiTenant

func (x *RealmAccess) GetMultiTenant() bool

func (*RealmAccess) GetRealmId

func (x *RealmAccess) GetRealmId() string

func (*RealmAccess) GetRealmName

func (x *RealmAccess) GetRealmName() string

func (*RealmAccess) GetTenantId

func (x *RealmAccess) GetTenantId() string

func (*RealmAccess) HasTenantId

func (x *RealmAccess) HasTenantId() bool

func (*RealmAccess) ProtoMessage

func (*RealmAccess) ProtoMessage()

func (*RealmAccess) ProtoReflect

func (x *RealmAccess) ProtoReflect() protoreflect.Message

func (*RealmAccess) Reset

func (x *RealmAccess) Reset()

func (*RealmAccess) SetBaseUrl

func (x *RealmAccess) SetBaseUrl(v string)

func (*RealmAccess) SetMetadata

func (x *RealmAccess) SetMetadata(v map[string]string)

func (*RealmAccess) SetMultiTenant

func (x *RealmAccess) SetMultiTenant(v bool)

func (*RealmAccess) SetRealmId

func (x *RealmAccess) SetRealmId(v string)

func (*RealmAccess) SetRealmName

func (x *RealmAccess) SetRealmName(v string)

func (*RealmAccess) SetTenantId

func (x *RealmAccess) SetTenantId(v string)

func (*RealmAccess) String

func (x *RealmAccess) String() string

type RealmAccess_builder

type RealmAccess_builder struct {
	RealmId   string
	RealmName string
	// API URL for this realm
	BaseUrl string
	// The sub-realms are separated by tenant ID.
	MultiTenant bool
	// when not set on a multi-tenant realm, the user has access to all tenants,
	// i.e. super-admin.
	TenantId *string
	// Key-value pairs of metadata for this realm, which are interpreted in the
	// context of the realm type
	Metadata map[string]string
	// contains filtered or unexported fields
}

func (RealmAccess_builder) Build

func (b0 RealmAccess_builder) Build() *RealmAccess

type WhoamiRequest

type WhoamiRequest struct {
	// contains filtered or unexported fields
}

func (*WhoamiRequest) ProtoMessage

func (*WhoamiRequest) ProtoMessage()

func (*WhoamiRequest) ProtoReflect

func (x *WhoamiRequest) ProtoReflect() protoreflect.Message

func (*WhoamiRequest) Reset

func (x *WhoamiRequest) Reset()

func (*WhoamiRequest) String

func (x *WhoamiRequest) String() string

type WhoamiRequest_builder

type WhoamiRequest_builder struct {
	// contains filtered or unexported fields
}

func (WhoamiRequest_builder) Build

type WhoamiResponse

type WhoamiResponse struct {
	RealmAccess []*RealmAccess `protobuf:"bytes,1,rep,name=realm_access,json=realmAccess,proto3" json:"realm_access,omitempty"`
	// contains filtered or unexported fields
}

func (*WhoamiResponse) GetRealmAccess

func (x *WhoamiResponse) GetRealmAccess() []*RealmAccess

func (*WhoamiResponse) ProtoMessage

func (*WhoamiResponse) ProtoMessage()

func (*WhoamiResponse) ProtoReflect

func (x *WhoamiResponse) ProtoReflect() protoreflect.Message

func (*WhoamiResponse) Reset

func (x *WhoamiResponse) Reset()

func (*WhoamiResponse) SetRealmAccess

func (x *WhoamiResponse) SetRealmAccess(v []*RealmAccess)

func (*WhoamiResponse) String

func (x *WhoamiResponse) String() string

type WhoamiResponse_builder

type WhoamiResponse_builder struct {
	RealmAccess []*RealmAccess
	// contains filtered or unexported fields
}

func (WhoamiResponse_builder) Build

Source Files

  • auth_service.pb.go

Jump to