Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterDatabaseServer(s grpc.ServiceRegistrar, srv DatabaseServer)
- type DatabaseClient
- type DatabaseServer
- type Database_StreamExecuteClient
- type Database_StreamExecuteServer
- type UnimplementedDatabaseServer
- func (UnimplementedDatabaseServer) CloseSession(context.Context, *v1alpha1.CloseSessionRequest) (*v1alpha1.CloseSessionResponse, error)
- func (UnimplementedDatabaseServer) CreateSession(context.Context, *v1alpha1.CreateSessionRequest) (*v1alpha1.CreateSessionResponse, error)
- func (UnimplementedDatabaseServer) Execute(context.Context, *v1alpha1.ExecuteRequest) (*v1alpha1.ExecuteResponse, error)
- func (UnimplementedDatabaseServer) Prepare(context.Context, *v1alpha1.PrepareRequest) (*v1alpha1.PrepareResponse, error)
- func (UnimplementedDatabaseServer) StreamExecute(*v1alpha1.ExecuteRequest, grpc.ServerStreamingServer[v1alpha1.ExecuteResponse]) error
- type UnsafeDatabaseServer
Constants ¶
const ( Database_CreateSession_FullMethodName = "/psdb.v1alpha1.Database/CreateSession" Database_Execute_FullMethodName = "/psdb.v1alpha1.Database/Execute" Database_StreamExecute_FullMethodName = "/psdb.v1alpha1.Database/StreamExecute" Database_Prepare_FullMethodName = "/psdb.v1alpha1.Database/Prepare" Database_CloseSession_FullMethodName = "/psdb.v1alpha1.Database/CloseSession" )
Variables ¶
var Database_ServiceDesc = grpc.ServiceDesc{ ServiceName: "psdb.v1alpha1.Database", HandlerType: (*DatabaseServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "CreateSession", Handler: _Database_CreateSession_Handler, }, { MethodName: "Execute", Handler: _Database_Execute_Handler, }, { MethodName: "Prepare", Handler: _Database_Prepare_Handler, }, { MethodName: "CloseSession", Handler: _Database_CloseSession_Handler, }, }, Streams: []grpc.StreamDesc{ { StreamName: "StreamExecute", Handler: _Database_StreamExecute_Handler, ServerStreams: true, }, }, Metadata: "psdb/v1alpha1/database.proto", }
Database_ServiceDesc is the grpc.ServiceDesc for Database service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterDatabaseServer ¶
func RegisterDatabaseServer(s grpc.ServiceRegistrar, srv DatabaseServer)
Types ¶
type DatabaseClient ¶
type DatabaseClient interface {
CreateSession(ctx context.Context, in *v1alpha1.CreateSessionRequest, opts ...grpc.CallOption) (*v1alpha1.CreateSessionResponse, error)
Execute(ctx context.Context, in *v1alpha1.ExecuteRequest, opts ...grpc.CallOption) (*v1alpha1.ExecuteResponse, error)
StreamExecute(ctx context.Context, in *v1alpha1.ExecuteRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[v1alpha1.ExecuteResponse], error)
Prepare(ctx context.Context, in *v1alpha1.PrepareRequest, opts ...grpc.CallOption) (*v1alpha1.PrepareResponse, error)
CloseSession(ctx context.Context, in *v1alpha1.CloseSessionRequest, opts ...grpc.CallOption) (*v1alpha1.CloseSessionResponse, error)
}
DatabaseClient is the client API for Database service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewDatabaseClient ¶
func NewDatabaseClient(cc grpc.ClientConnInterface) DatabaseClient
type DatabaseServer ¶
type DatabaseServer interface {
CreateSession(context.Context, *v1alpha1.CreateSessionRequest) (*v1alpha1.CreateSessionResponse, error)
Execute(context.Context, *v1alpha1.ExecuteRequest) (*v1alpha1.ExecuteResponse, error)
StreamExecute(*v1alpha1.ExecuteRequest, grpc.ServerStreamingServer[v1alpha1.ExecuteResponse]) error
Prepare(context.Context, *v1alpha1.PrepareRequest) (*v1alpha1.PrepareResponse, error)
CloseSession(context.Context, *v1alpha1.CloseSessionRequest) (*v1alpha1.CloseSessionResponse, error)
}
DatabaseServer is the server API for Database service. All implementations should embed UnimplementedDatabaseServer for forward compatibility.
type Database_StreamExecuteClient ¶
type Database_StreamExecuteClient = grpc.ServerStreamingClient[v1alpha1.ExecuteResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type Database_StreamExecuteServer ¶
type Database_StreamExecuteServer = grpc.ServerStreamingServer[v1alpha1.ExecuteResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type UnimplementedDatabaseServer ¶
type UnimplementedDatabaseServer struct{}
UnimplementedDatabaseServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedDatabaseServer) CloseSession ¶
func (UnimplementedDatabaseServer) CloseSession(context.Context, *v1alpha1.CloseSessionRequest) (*v1alpha1.CloseSessionResponse, error)
func (UnimplementedDatabaseServer) CreateSession ¶
func (UnimplementedDatabaseServer) CreateSession(context.Context, *v1alpha1.CreateSessionRequest) (*v1alpha1.CreateSessionResponse, error)
func (UnimplementedDatabaseServer) Execute ¶
func (UnimplementedDatabaseServer) Execute(context.Context, *v1alpha1.ExecuteRequest) (*v1alpha1.ExecuteResponse, error)
func (UnimplementedDatabaseServer) Prepare ¶
func (UnimplementedDatabaseServer) Prepare(context.Context, *v1alpha1.PrepareRequest) (*v1alpha1.PrepareResponse, error)
func (UnimplementedDatabaseServer) StreamExecute ¶
func (UnimplementedDatabaseServer) StreamExecute(*v1alpha1.ExecuteRequest, grpc.ServerStreamingServer[v1alpha1.ExecuteResponse]) error
type UnsafeDatabaseServer ¶
type UnsafeDatabaseServer interface {
// contains filtered or unexported methods
}
UnsafeDatabaseServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to DatabaseServer will result in compilation errors.
Source Files
¶
- database_grpc.pb.go