Documentation
¶
Index ¶
Constants ¶
const (
Connect_Sync_FullMethodName = "/psdbconnect.v1alpha1.Connect/Sync"
)
Variables ¶
var Connect_ServiceDesc = grpc.ServiceDesc{ ServiceName: "psdbconnect.v1alpha1.Connect", HandlerType: (*ConnectServer)(nil), Methods: []grpc.MethodDesc{}, Streams: []grpc.StreamDesc{ { StreamName: "Sync", Handler: _Connect_Sync_Handler, ServerStreams: true, }, }, Metadata: "psdbconnect/v1alpha1/connect.proto", }
Connect_ServiceDesc is the grpc.ServiceDesc for Connect service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterConnectServer ¶
func RegisterConnectServer(s grpc.ServiceRegistrar, srv ConnectServer)
Types ¶
type ConnectClient ¶
type ConnectClient interface {
// Sync will continuously stream data from a PlanetScale database given a table, keyspace and shard.
// Sync also allows you to incrementally sync data from a table given a TableCursor that is returned as part of the SyncResponse.
// If the last known position is empty, Sync will download all the rows for a given table in a shard
// and then wait to stream any changes to the table (inserts/updates/deletes)
// If the last known position is not empty, Sync will pickup where the last Sync session left off and stream
// any changes to the table since the last Sync session.
Sync(ctx context.Context, in *v1alpha1.SyncRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[v1alpha1.SyncResponse], error)
}
ConnectClient is the client API for Connect service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewConnectClient ¶
func NewConnectClient(cc grpc.ClientConnInterface) ConnectClient
type ConnectServer ¶
type ConnectServer interface {
// Sync will continuously stream data from a PlanetScale database given a table, keyspace and shard.
// Sync also allows you to incrementally sync data from a table given a TableCursor that is returned as part of the SyncResponse.
// If the last known position is empty, Sync will download all the rows for a given table in a shard
// and then wait to stream any changes to the table (inserts/updates/deletes)
// If the last known position is not empty, Sync will pickup where the last Sync session left off and stream
// any changes to the table since the last Sync session.
Sync(*v1alpha1.SyncRequest, grpc.ServerStreamingServer[v1alpha1.SyncResponse]) error
}
ConnectServer is the server API for Connect service. All implementations should embed UnimplementedConnectServer for forward compatibility.
type Connect_SyncClient ¶
type Connect_SyncClient = grpc.ServerStreamingClient[v1alpha1.SyncResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type Connect_SyncServer ¶
type Connect_SyncServer = grpc.ServerStreamingServer[v1alpha1.SyncResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type UnimplementedConnectServer ¶
type UnimplementedConnectServer struct{}
UnimplementedConnectServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedConnectServer) Sync ¶
type UnsafeConnectServer ¶
type UnsafeConnectServer interface {
// contains filtered or unexported methods
}
UnsafeConnectServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ConnectServer will result in compilation errors.
Source Files
¶
- connect_grpc.pb.go