Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterQueryServer(s grpc.ServiceRegistrar, srv QueryServer)
- type QueryClient
- type QueryServer
- type Query_BeginStreamExecuteClient
- type Query_BeginStreamExecuteServer
- type Query_GetSchemaClient
- type Query_GetSchemaServer
- type Query_MessageStreamClient
- type Query_MessageStreamServer
- type Query_ReserveBeginStreamExecuteClient
- type Query_ReserveBeginStreamExecuteServer
- type Query_ReserveStreamExecuteClient
- type Query_ReserveStreamExecuteServer
- type Query_StreamExecuteClient
- type Query_StreamExecuteServer
- type Query_StreamHealthClient
- type Query_StreamHealthServer
- type Query_VStreamClient
- type Query_VStreamResultsClient
- type Query_VStreamResultsServer
- type Query_VStreamRowsClient
- type Query_VStreamRowsServer
- type Query_VStreamServer
- type Query_VStreamTablesClient
- type Query_VStreamTablesServer
- type UnimplementedQueryServer
- func (UnimplementedQueryServer) Begin(context.Context, *v19.BeginRequest) (*v19.BeginResponse, error)
- func (UnimplementedQueryServer) BeginExecute(context.Context, *v19.BeginExecuteRequest) (*v19.BeginExecuteResponse, error)
- func (UnimplementedQueryServer) BeginStreamExecute(*v19.BeginStreamExecuteRequest, ...) error
- func (UnimplementedQueryServer) Commit(context.Context, *v19.CommitRequest) (*v19.CommitResponse, error)
- func (UnimplementedQueryServer) CommitPrepared(context.Context, *v19.CommitPreparedRequest) (*v19.CommitPreparedResponse, error)
- func (UnimplementedQueryServer) ConcludeTransaction(context.Context, *v19.ConcludeTransactionRequest) (*v19.ConcludeTransactionResponse, error)
- func (UnimplementedQueryServer) CreateTransaction(context.Context, *v19.CreateTransactionRequest) (*v19.CreateTransactionResponse, error)
- func (UnimplementedQueryServer) Execute(context.Context, *v19.ExecuteRequest) (*v19.ExecuteResponse, error)
- func (UnimplementedQueryServer) GetSchema(*v19.GetSchemaRequest, grpc.ServerStreamingServer[v19.GetSchemaResponse]) error
- func (UnimplementedQueryServer) MessageAck(context.Context, *v19.MessageAckRequest) (*v19.MessageAckResponse, error)
- func (UnimplementedQueryServer) MessageStream(*v19.MessageStreamRequest, ...) error
- func (UnimplementedQueryServer) Prepare(context.Context, *v19.PrepareRequest) (*v19.PrepareResponse, error)
- func (UnimplementedQueryServer) ReadTransaction(context.Context, *v19.ReadTransactionRequest) (*v19.ReadTransactionResponse, error)
- func (UnimplementedQueryServer) Release(context.Context, *v19.ReleaseRequest) (*v19.ReleaseResponse, error)
- func (UnimplementedQueryServer) ReserveBeginExecute(context.Context, *v19.ReserveBeginExecuteRequest) (*v19.ReserveBeginExecuteResponse, error)
- func (UnimplementedQueryServer) ReserveBeginStreamExecute(*v19.ReserveBeginStreamExecuteRequest, ...) error
- func (UnimplementedQueryServer) ReserveExecute(context.Context, *v19.ReserveExecuteRequest) (*v19.ReserveExecuteResponse, error)
- func (UnimplementedQueryServer) ReserveStreamExecute(*v19.ReserveStreamExecuteRequest, ...) error
- func (UnimplementedQueryServer) Rollback(context.Context, *v19.RollbackRequest) (*v19.RollbackResponse, error)
- func (UnimplementedQueryServer) RollbackPrepared(context.Context, *v19.RollbackPreparedRequest) (*v19.RollbackPreparedResponse, error)
- func (UnimplementedQueryServer) SetRollback(context.Context, *v19.SetRollbackRequest) (*v19.SetRollbackResponse, error)
- func (UnimplementedQueryServer) StartCommit(context.Context, *v19.StartCommitRequest) (*v19.StartCommitResponse, error)
- func (UnimplementedQueryServer) StreamExecute(*v19.StreamExecuteRequest, ...) error
- func (UnimplementedQueryServer) StreamHealth(*v19.StreamHealthRequest, grpc.ServerStreamingServer[v19.StreamHealthResponse]) error
- func (UnimplementedQueryServer) VStream(*v191.VStreamRequest, grpc.ServerStreamingServer[v191.VStreamResponse]) error
- func (UnimplementedQueryServer) VStreamResults(*v191.VStreamResultsRequest, ...) error
- func (UnimplementedQueryServer) VStreamRows(*v191.VStreamRowsRequest, grpc.ServerStreamingServer[v191.VStreamRowsResponse]) error
- func (UnimplementedQueryServer) VStreamTables(*v191.VStreamTablesRequest, ...) error
- type UnsafeQueryServer
Constants ¶
const ( Query_Execute_FullMethodName = "/vitess.queryservice.v19.Query/Execute" Query_StreamExecute_FullMethodName = "/vitess.queryservice.v19.Query/StreamExecute" Query_Begin_FullMethodName = "/vitess.queryservice.v19.Query/Begin" Query_Commit_FullMethodName = "/vitess.queryservice.v19.Query/Commit" Query_Rollback_FullMethodName = "/vitess.queryservice.v19.Query/Rollback" Query_Prepare_FullMethodName = "/vitess.queryservice.v19.Query/Prepare" Query_CommitPrepared_FullMethodName = "/vitess.queryservice.v19.Query/CommitPrepared" Query_RollbackPrepared_FullMethodName = "/vitess.queryservice.v19.Query/RollbackPrepared" Query_CreateTransaction_FullMethodName = "/vitess.queryservice.v19.Query/CreateTransaction" Query_StartCommit_FullMethodName = "/vitess.queryservice.v19.Query/StartCommit" Query_SetRollback_FullMethodName = "/vitess.queryservice.v19.Query/SetRollback" Query_ConcludeTransaction_FullMethodName = "/vitess.queryservice.v19.Query/ConcludeTransaction" Query_ReadTransaction_FullMethodName = "/vitess.queryservice.v19.Query/ReadTransaction" Query_BeginExecute_FullMethodName = "/vitess.queryservice.v19.Query/BeginExecute" Query_BeginStreamExecute_FullMethodName = "/vitess.queryservice.v19.Query/BeginStreamExecute" Query_MessageStream_FullMethodName = "/vitess.queryservice.v19.Query/MessageStream" Query_MessageAck_FullMethodName = "/vitess.queryservice.v19.Query/MessageAck" Query_ReserveExecute_FullMethodName = "/vitess.queryservice.v19.Query/ReserveExecute" Query_ReserveBeginExecute_FullMethodName = "/vitess.queryservice.v19.Query/ReserveBeginExecute" Query_ReserveStreamExecute_FullMethodName = "/vitess.queryservice.v19.Query/ReserveStreamExecute" Query_ReserveBeginStreamExecute_FullMethodName = "/vitess.queryservice.v19.Query/ReserveBeginStreamExecute" Query_Release_FullMethodName = "/vitess.queryservice.v19.Query/Release" Query_StreamHealth_FullMethodName = "/vitess.queryservice.v19.Query/StreamHealth" Query_VStream_FullMethodName = "/vitess.queryservice.v19.Query/VStream" Query_VStreamRows_FullMethodName = "/vitess.queryservice.v19.Query/VStreamRows" Query_VStreamTables_FullMethodName = "/vitess.queryservice.v19.Query/VStreamTables" Query_VStreamResults_FullMethodName = "/vitess.queryservice.v19.Query/VStreamResults" Query_GetSchema_FullMethodName = "/vitess.queryservice.v19.Query/GetSchema" )
Variables ¶
var Query_ServiceDesc = grpc.ServiceDesc{ ServiceName: "vitess.queryservice.v19.Query", HandlerType: (*QueryServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "Execute", Handler: _Query_Execute_Handler, }, { MethodName: "Begin", Handler: _Query_Begin_Handler, }, { MethodName: "Commit", Handler: _Query_Commit_Handler, }, { MethodName: "Rollback", Handler: _Query_Rollback_Handler, }, { MethodName: "Prepare", Handler: _Query_Prepare_Handler, }, { MethodName: "CommitPrepared", Handler: _Query_CommitPrepared_Handler, }, { MethodName: "RollbackPrepared", Handler: _Query_RollbackPrepared_Handler, }, { MethodName: "CreateTransaction", Handler: _Query_CreateTransaction_Handler, }, { MethodName: "StartCommit", Handler: _Query_StartCommit_Handler, }, { MethodName: "SetRollback", Handler: _Query_SetRollback_Handler, }, { MethodName: "ConcludeTransaction", Handler: _Query_ConcludeTransaction_Handler, }, { MethodName: "ReadTransaction", Handler: _Query_ReadTransaction_Handler, }, { MethodName: "BeginExecute", Handler: _Query_BeginExecute_Handler, }, { MethodName: "MessageAck", Handler: _Query_MessageAck_Handler, }, { MethodName: "ReserveExecute", Handler: _Query_ReserveExecute_Handler, }, { MethodName: "ReserveBeginExecute", Handler: _Query_ReserveBeginExecute_Handler, }, { MethodName: "Release", Handler: _Query_Release_Handler, }, }, Streams: []grpc.StreamDesc{ { StreamName: "StreamExecute", Handler: _Query_StreamExecute_Handler, ServerStreams: true, }, { StreamName: "BeginStreamExecute", Handler: _Query_BeginStreamExecute_Handler, ServerStreams: true, }, { StreamName: "MessageStream", Handler: _Query_MessageStream_Handler, ServerStreams: true, }, { StreamName: "ReserveStreamExecute", Handler: _Query_ReserveStreamExecute_Handler, ServerStreams: true, }, { StreamName: "ReserveBeginStreamExecute", Handler: _Query_ReserveBeginStreamExecute_Handler, ServerStreams: true, }, { StreamName: "StreamHealth", Handler: _Query_StreamHealth_Handler, ServerStreams: true, }, { StreamName: "VStream", Handler: _Query_VStream_Handler, ServerStreams: true, }, { StreamName: "VStreamRows", Handler: _Query_VStreamRows_Handler, ServerStreams: true, }, { StreamName: "VStreamTables", Handler: _Query_VStreamTables_Handler, ServerStreams: true, }, { StreamName: "VStreamResults", Handler: _Query_VStreamResults_Handler, ServerStreams: true, }, { StreamName: "GetSchema", Handler: _Query_GetSchema_Handler, ServerStreams: true, }, }, Metadata: "vitess/queryservice/v19/queryservice.proto", }
Query_ServiceDesc is the grpc.ServiceDesc for Query service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterQueryServer ¶
func RegisterQueryServer(s grpc.ServiceRegistrar, srv QueryServer)
Types ¶
type QueryClient ¶
type QueryClient interface {
// Execute executes the specified SQL query (might be in a
// transaction context, if Query.transaction_id is set).
Execute(ctx context.Context, in *v19.ExecuteRequest, opts ...grpc.CallOption) (*v19.ExecuteResponse, error)
// StreamExecute executes a streaming query. Use this method if the
// query returns a large number of rows. The first QueryResult will
// contain the Fields, subsequent QueryResult messages will contain
// the rows.
StreamExecute(ctx context.Context, in *v19.StreamExecuteRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[v19.StreamExecuteResponse], error)
// Begin a transaction.
Begin(ctx context.Context, in *v19.BeginRequest, opts ...grpc.CallOption) (*v19.BeginResponse, error)
// Commit a transaction.
Commit(ctx context.Context, in *v19.CommitRequest, opts ...grpc.CallOption) (*v19.CommitResponse, error)
// Rollback a transaction.
Rollback(ctx context.Context, in *v19.RollbackRequest, opts ...grpc.CallOption) (*v19.RollbackResponse, error)
// Prepare preares a transaction.
Prepare(ctx context.Context, in *v19.PrepareRequest, opts ...grpc.CallOption) (*v19.PrepareResponse, error)
// CommitPrepared commits a prepared transaction.
CommitPrepared(ctx context.Context, in *v19.CommitPreparedRequest, opts ...grpc.CallOption) (*v19.CommitPreparedResponse, error)
// RollbackPrepared rolls back a prepared transaction.
RollbackPrepared(ctx context.Context, in *v19.RollbackPreparedRequest, opts ...grpc.CallOption) (*v19.RollbackPreparedResponse, error)
// CreateTransaction creates the metadata for a 2pc transaction.
CreateTransaction(ctx context.Context, in *v19.CreateTransactionRequest, opts ...grpc.CallOption) (*v19.CreateTransactionResponse, error)
// StartCommit initiates a commit for a 2pc transaction.
StartCommit(ctx context.Context, in *v19.StartCommitRequest, opts ...grpc.CallOption) (*v19.StartCommitResponse, error)
// SetRollback marks the 2pc transaction for rollback.
SetRollback(ctx context.Context, in *v19.SetRollbackRequest, opts ...grpc.CallOption) (*v19.SetRollbackResponse, error)
// ConcludeTransaction marks the 2pc transaction as resolved.
ConcludeTransaction(ctx context.Context, in *v19.ConcludeTransactionRequest, opts ...grpc.CallOption) (*v19.ConcludeTransactionResponse, error)
// ReadTransaction returns the 2pc transaction info.
ReadTransaction(ctx context.Context, in *v19.ReadTransactionRequest, opts ...grpc.CallOption) (*v19.ReadTransactionResponse, error)
// BeginExecute executes a begin and the specified SQL query.
BeginExecute(ctx context.Context, in *v19.BeginExecuteRequest, opts ...grpc.CallOption) (*v19.BeginExecuteResponse, error)
// BeginStreamExecute executes a begin and the specified SQL query.
BeginStreamExecute(ctx context.Context, in *v19.BeginStreamExecuteRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[v19.BeginStreamExecuteResponse], error)
// MessageStream streams messages from a message table.
MessageStream(ctx context.Context, in *v19.MessageStreamRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[v19.MessageStreamResponse], error)
// MessageAck acks messages for a table.
MessageAck(ctx context.Context, in *v19.MessageAckRequest, opts ...grpc.CallOption) (*v19.MessageAckResponse, error)
// ReserveExecute executes a query on a reserved connection
ReserveExecute(ctx context.Context, in *v19.ReserveExecuteRequest, opts ...grpc.CallOption) (*v19.ReserveExecuteResponse, error)
// ReserveBeginExecute starts a transaction and executes a query in the transaction on a reserved connection
ReserveBeginExecute(ctx context.Context, in *v19.ReserveBeginExecuteRequest, opts ...grpc.CallOption) (*v19.ReserveBeginExecuteResponse, error)
// ReserveStreamExecute executes a streaming query on a reserved connection
ReserveStreamExecute(ctx context.Context, in *v19.ReserveStreamExecuteRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[v19.ReserveStreamExecuteResponse], error)
// ReserveBeginStreamExecute starts a transaction and executes a streaming query in the transaction on a reserved connection
ReserveBeginStreamExecute(ctx context.Context, in *v19.ReserveBeginStreamExecuteRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[v19.ReserveBeginStreamExecuteResponse], error)
// Release releases the connection
Release(ctx context.Context, in *v19.ReleaseRequest, opts ...grpc.CallOption) (*v19.ReleaseResponse, error)
// StreamHealth runs a streaming RPC to the tablet, that returns the
// current health of the tablet on a regular basis.
StreamHealth(ctx context.Context, in *v19.StreamHealthRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[v19.StreamHealthResponse], error)
// VStream streams vreplication events.
VStream(ctx context.Context, in *v191.VStreamRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[v191.VStreamResponse], error)
// VStreamRows streams rows from the specified starting point.
VStreamRows(ctx context.Context, in *v191.VStreamRowsRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[v191.VStreamRowsResponse], error)
// VStreamTables streams rows from the specified starting point.
VStreamTables(ctx context.Context, in *v191.VStreamTablesRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[v191.VStreamTablesResponse], error)
// VStreamResults streams results along with the gtid of the snapshot.
VStreamResults(ctx context.Context, in *v191.VStreamResultsRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[v191.VStreamResultsResponse], error)
// GetSchema returns the schema information.
GetSchema(ctx context.Context, in *v19.GetSchemaRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[v19.GetSchemaResponse], error)
}
QueryClient is the client API for Query service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
Query defines the tablet query service, implemented by vttablet.
func NewQueryClient ¶
func NewQueryClient(cc grpc.ClientConnInterface) QueryClient
type QueryServer ¶
type QueryServer interface {
// Execute executes the specified SQL query (might be in a
// transaction context, if Query.transaction_id is set).
Execute(context.Context, *v19.ExecuteRequest) (*v19.ExecuteResponse, error)
// StreamExecute executes a streaming query. Use this method if the
// query returns a large number of rows. The first QueryResult will
// contain the Fields, subsequent QueryResult messages will contain
// the rows.
StreamExecute(*v19.StreamExecuteRequest, grpc.ServerStreamingServer[v19.StreamExecuteResponse]) error
// Begin a transaction.
Begin(context.Context, *v19.BeginRequest) (*v19.BeginResponse, error)
// Commit a transaction.
Commit(context.Context, *v19.CommitRequest) (*v19.CommitResponse, error)
// Rollback a transaction.
Rollback(context.Context, *v19.RollbackRequest) (*v19.RollbackResponse, error)
// Prepare preares a transaction.
Prepare(context.Context, *v19.PrepareRequest) (*v19.PrepareResponse, error)
// CommitPrepared commits a prepared transaction.
CommitPrepared(context.Context, *v19.CommitPreparedRequest) (*v19.CommitPreparedResponse, error)
// RollbackPrepared rolls back a prepared transaction.
RollbackPrepared(context.Context, *v19.RollbackPreparedRequest) (*v19.RollbackPreparedResponse, error)
// CreateTransaction creates the metadata for a 2pc transaction.
CreateTransaction(context.Context, *v19.CreateTransactionRequest) (*v19.CreateTransactionResponse, error)
// StartCommit initiates a commit for a 2pc transaction.
StartCommit(context.Context, *v19.StartCommitRequest) (*v19.StartCommitResponse, error)
// SetRollback marks the 2pc transaction for rollback.
SetRollback(context.Context, *v19.SetRollbackRequest) (*v19.SetRollbackResponse, error)
// ConcludeTransaction marks the 2pc transaction as resolved.
ConcludeTransaction(context.Context, *v19.ConcludeTransactionRequest) (*v19.ConcludeTransactionResponse, error)
// ReadTransaction returns the 2pc transaction info.
ReadTransaction(context.Context, *v19.ReadTransactionRequest) (*v19.ReadTransactionResponse, error)
// BeginExecute executes a begin and the specified SQL query.
BeginExecute(context.Context, *v19.BeginExecuteRequest) (*v19.BeginExecuteResponse, error)
// BeginStreamExecute executes a begin and the specified SQL query.
BeginStreamExecute(*v19.BeginStreamExecuteRequest, grpc.ServerStreamingServer[v19.BeginStreamExecuteResponse]) error
// MessageStream streams messages from a message table.
MessageStream(*v19.MessageStreamRequest, grpc.ServerStreamingServer[v19.MessageStreamResponse]) error
// MessageAck acks messages for a table.
MessageAck(context.Context, *v19.MessageAckRequest) (*v19.MessageAckResponse, error)
// ReserveExecute executes a query on a reserved connection
ReserveExecute(context.Context, *v19.ReserveExecuteRequest) (*v19.ReserveExecuteResponse, error)
// ReserveBeginExecute starts a transaction and executes a query in the transaction on a reserved connection
ReserveBeginExecute(context.Context, *v19.ReserveBeginExecuteRequest) (*v19.ReserveBeginExecuteResponse, error)
// ReserveStreamExecute executes a streaming query on a reserved connection
ReserveStreamExecute(*v19.ReserveStreamExecuteRequest, grpc.ServerStreamingServer[v19.ReserveStreamExecuteResponse]) error
// ReserveBeginStreamExecute starts a transaction and executes a streaming query in the transaction on a reserved connection
ReserveBeginStreamExecute(*v19.ReserveBeginStreamExecuteRequest, grpc.ServerStreamingServer[v19.ReserveBeginStreamExecuteResponse]) error
// Release releases the connection
Release(context.Context, *v19.ReleaseRequest) (*v19.ReleaseResponse, error)
// StreamHealth runs a streaming RPC to the tablet, that returns the
// current health of the tablet on a regular basis.
StreamHealth(*v19.StreamHealthRequest, grpc.ServerStreamingServer[v19.StreamHealthResponse]) error
// VStream streams vreplication events.
VStream(*v191.VStreamRequest, grpc.ServerStreamingServer[v191.VStreamResponse]) error
// VStreamRows streams rows from the specified starting point.
VStreamRows(*v191.VStreamRowsRequest, grpc.ServerStreamingServer[v191.VStreamRowsResponse]) error
// VStreamTables streams rows from the specified starting point.
VStreamTables(*v191.VStreamTablesRequest, grpc.ServerStreamingServer[v191.VStreamTablesResponse]) error
// VStreamResults streams results along with the gtid of the snapshot.
VStreamResults(*v191.VStreamResultsRequest, grpc.ServerStreamingServer[v191.VStreamResultsResponse]) error
// GetSchema returns the schema information.
GetSchema(*v19.GetSchemaRequest, grpc.ServerStreamingServer[v19.GetSchemaResponse]) error
}
QueryServer is the server API for Query service. All implementations should embed UnimplementedQueryServer for forward compatibility.
Query defines the tablet query service, implemented by vttablet.
type Query_BeginStreamExecuteClient ¶
type Query_BeginStreamExecuteClient = grpc.ServerStreamingClient[v19.BeginStreamExecuteResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type Query_BeginStreamExecuteServer ¶
type Query_BeginStreamExecuteServer = grpc.ServerStreamingServer[v19.BeginStreamExecuteResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type Query_GetSchemaClient ¶
type Query_GetSchemaClient = grpc.ServerStreamingClient[v19.GetSchemaResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type Query_GetSchemaServer ¶
type Query_GetSchemaServer = grpc.ServerStreamingServer[v19.GetSchemaResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type Query_MessageStreamClient ¶
type Query_MessageStreamClient = grpc.ServerStreamingClient[v19.MessageStreamResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type Query_MessageStreamServer ¶
type Query_MessageStreamServer = grpc.ServerStreamingServer[v19.MessageStreamResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type Query_ReserveBeginStreamExecuteClient ¶
type Query_ReserveBeginStreamExecuteClient = grpc.ServerStreamingClient[v19.ReserveBeginStreamExecuteResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type Query_ReserveBeginStreamExecuteServer ¶
type Query_ReserveBeginStreamExecuteServer = grpc.ServerStreamingServer[v19.ReserveBeginStreamExecuteResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type Query_ReserveStreamExecuteClient ¶
type Query_ReserveStreamExecuteClient = grpc.ServerStreamingClient[v19.ReserveStreamExecuteResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type Query_ReserveStreamExecuteServer ¶
type Query_ReserveStreamExecuteServer = grpc.ServerStreamingServer[v19.ReserveStreamExecuteResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type Query_StreamExecuteClient ¶
type Query_StreamExecuteClient = grpc.ServerStreamingClient[v19.StreamExecuteResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type Query_StreamExecuteServer ¶
type Query_StreamExecuteServer = grpc.ServerStreamingServer[v19.StreamExecuteResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type Query_StreamHealthClient ¶
type Query_StreamHealthClient = grpc.ServerStreamingClient[v19.StreamHealthResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type Query_StreamHealthServer ¶
type Query_StreamHealthServer = grpc.ServerStreamingServer[v19.StreamHealthResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type Query_VStreamClient ¶
type Query_VStreamClient = grpc.ServerStreamingClient[v191.VStreamResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type Query_VStreamResultsClient ¶
type Query_VStreamResultsClient = grpc.ServerStreamingClient[v191.VStreamResultsResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type Query_VStreamResultsServer ¶
type Query_VStreamResultsServer = grpc.ServerStreamingServer[v191.VStreamResultsResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type Query_VStreamRowsClient ¶
type Query_VStreamRowsClient = grpc.ServerStreamingClient[v191.VStreamRowsResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type Query_VStreamRowsServer ¶
type Query_VStreamRowsServer = grpc.ServerStreamingServer[v191.VStreamRowsResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type Query_VStreamServer ¶
type Query_VStreamServer = grpc.ServerStreamingServer[v191.VStreamResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type Query_VStreamTablesClient ¶
type Query_VStreamTablesClient = grpc.ServerStreamingClient[v191.VStreamTablesResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type Query_VStreamTablesServer ¶
type Query_VStreamTablesServer = grpc.ServerStreamingServer[v191.VStreamTablesResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type UnimplementedQueryServer ¶
type UnimplementedQueryServer struct{}
UnimplementedQueryServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedQueryServer) Begin ¶
func (UnimplementedQueryServer) Begin(context.Context, *v19.BeginRequest) (*v19.BeginResponse, error)
func (UnimplementedQueryServer) BeginExecute ¶
func (UnimplementedQueryServer) BeginExecute(context.Context, *v19.BeginExecuteRequest) (*v19.BeginExecuteResponse, error)
func (UnimplementedQueryServer) BeginStreamExecute ¶
func (UnimplementedQueryServer) BeginStreamExecute(*v19.BeginStreamExecuteRequest, grpc.ServerStreamingServer[v19.BeginStreamExecuteResponse]) error
func (UnimplementedQueryServer) Commit ¶
func (UnimplementedQueryServer) Commit(context.Context, *v19.CommitRequest) (*v19.CommitResponse, error)
func (UnimplementedQueryServer) CommitPrepared ¶
func (UnimplementedQueryServer) CommitPrepared(context.Context, *v19.CommitPreparedRequest) (*v19.CommitPreparedResponse, error)
func (UnimplementedQueryServer) ConcludeTransaction ¶
func (UnimplementedQueryServer) ConcludeTransaction(context.Context, *v19.ConcludeTransactionRequest) (*v19.ConcludeTransactionResponse, error)
func (UnimplementedQueryServer) CreateTransaction ¶
func (UnimplementedQueryServer) CreateTransaction(context.Context, *v19.CreateTransactionRequest) (*v19.CreateTransactionResponse, error)
func (UnimplementedQueryServer) Execute ¶
func (UnimplementedQueryServer) Execute(context.Context, *v19.ExecuteRequest) (*v19.ExecuteResponse, error)
func (UnimplementedQueryServer) GetSchema ¶
func (UnimplementedQueryServer) GetSchema(*v19.GetSchemaRequest, grpc.ServerStreamingServer[v19.GetSchemaResponse]) error
func (UnimplementedQueryServer) MessageAck ¶
func (UnimplementedQueryServer) MessageAck(context.Context, *v19.MessageAckRequest) (*v19.MessageAckResponse, error)
func (UnimplementedQueryServer) MessageStream ¶
func (UnimplementedQueryServer) MessageStream(*v19.MessageStreamRequest, grpc.ServerStreamingServer[v19.MessageStreamResponse]) error
func (UnimplementedQueryServer) Prepare ¶
func (UnimplementedQueryServer) Prepare(context.Context, *v19.PrepareRequest) (*v19.PrepareResponse, error)
func (UnimplementedQueryServer) ReadTransaction ¶
func (UnimplementedQueryServer) ReadTransaction(context.Context, *v19.ReadTransactionRequest) (*v19.ReadTransactionResponse, error)
func (UnimplementedQueryServer) Release ¶
func (UnimplementedQueryServer) Release(context.Context, *v19.ReleaseRequest) (*v19.ReleaseResponse, error)
func (UnimplementedQueryServer) ReserveBeginExecute ¶
func (UnimplementedQueryServer) ReserveBeginExecute(context.Context, *v19.ReserveBeginExecuteRequest) (*v19.ReserveBeginExecuteResponse, error)
func (UnimplementedQueryServer) ReserveBeginStreamExecute ¶
func (UnimplementedQueryServer) ReserveBeginStreamExecute(*v19.ReserveBeginStreamExecuteRequest, grpc.ServerStreamingServer[v19.ReserveBeginStreamExecuteResponse]) error
func (UnimplementedQueryServer) ReserveExecute ¶
func (UnimplementedQueryServer) ReserveExecute(context.Context, *v19.ReserveExecuteRequest) (*v19.ReserveExecuteResponse, error)
func (UnimplementedQueryServer) ReserveStreamExecute ¶
func (UnimplementedQueryServer) ReserveStreamExecute(*v19.ReserveStreamExecuteRequest, grpc.ServerStreamingServer[v19.ReserveStreamExecuteResponse]) error
func (UnimplementedQueryServer) Rollback ¶
func (UnimplementedQueryServer) Rollback(context.Context, *v19.RollbackRequest) (*v19.RollbackResponse, error)
func (UnimplementedQueryServer) RollbackPrepared ¶
func (UnimplementedQueryServer) RollbackPrepared(context.Context, *v19.RollbackPreparedRequest) (*v19.RollbackPreparedResponse, error)
func (UnimplementedQueryServer) SetRollback ¶
func (UnimplementedQueryServer) SetRollback(context.Context, *v19.SetRollbackRequest) (*v19.SetRollbackResponse, error)
func (UnimplementedQueryServer) StartCommit ¶
func (UnimplementedQueryServer) StartCommit(context.Context, *v19.StartCommitRequest) (*v19.StartCommitResponse, error)
func (UnimplementedQueryServer) StreamExecute ¶
func (UnimplementedQueryServer) StreamExecute(*v19.StreamExecuteRequest, grpc.ServerStreamingServer[v19.StreamExecuteResponse]) error
func (UnimplementedQueryServer) StreamHealth ¶
func (UnimplementedQueryServer) StreamHealth(*v19.StreamHealthRequest, grpc.ServerStreamingServer[v19.StreamHealthResponse]) error
func (UnimplementedQueryServer) VStream ¶
func (UnimplementedQueryServer) VStream(*v191.VStreamRequest, grpc.ServerStreamingServer[v191.VStreamResponse]) error
func (UnimplementedQueryServer) VStreamResults ¶
func (UnimplementedQueryServer) VStreamResults(*v191.VStreamResultsRequest, grpc.ServerStreamingServer[v191.VStreamResultsResponse]) error
func (UnimplementedQueryServer) VStreamRows ¶
func (UnimplementedQueryServer) VStreamRows(*v191.VStreamRowsRequest, grpc.ServerStreamingServer[v191.VStreamRowsResponse]) error
func (UnimplementedQueryServer) VStreamTables ¶
func (UnimplementedQueryServer) VStreamTables(*v191.VStreamTablesRequest, grpc.ServerStreamingServer[v191.VStreamTablesResponse]) error
type UnsafeQueryServer ¶
type UnsafeQueryServer interface {
// contains filtered or unexported methods
}
UnsafeQueryServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to QueryServer will result in compilation errors.
Source Files
¶
- queryservice_grpc.pb.go