Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterVitessServer(s grpc.ServiceRegistrar, srv VitessServer)
- type UnimplementedVitessServer
- func (UnimplementedVitessServer) BinlogDumpGTID(*dev.BinlogDumpGTIDRequest, grpc.ServerStreamingServer[dev.BinlogDumpResponse]) error
- func (UnimplementedVitessServer) CloseSession(context.Context, *dev.CloseSessionRequest) (*dev.CloseSessionResponse, error)
- func (UnimplementedVitessServer) Execute(context.Context, *dev.ExecuteRequest) (*dev.ExecuteResponse, error)
- func (UnimplementedVitessServer) ExecuteBatch(context.Context, *dev.ExecuteBatchRequest) (*dev.ExecuteBatchResponse, error)
- func (UnimplementedVitessServer) ExecuteMulti(context.Context, *dev.ExecuteMultiRequest) (*dev.ExecuteMultiResponse, error)
- func (UnimplementedVitessServer) Prepare(context.Context, *dev.PrepareRequest) (*dev.PrepareResponse, error)
- func (UnimplementedVitessServer) StreamExecute(*dev.StreamExecuteRequest, ...) error
- func (UnimplementedVitessServer) StreamExecuteMulti(*dev.StreamExecuteMultiRequest, ...) error
- func (UnimplementedVitessServer) VStream(*dev.VStreamRequest, grpc.ServerStreamingServer[dev.VStreamResponse]) error
- type UnsafeVitessServer
- type VitessClient
- type VitessServer
- type Vitess_BinlogDumpGTIDClient
- type Vitess_BinlogDumpGTIDServer
- type Vitess_StreamExecuteClient
- type Vitess_StreamExecuteMultiClient
- type Vitess_StreamExecuteMultiServer
- type Vitess_StreamExecuteServer
- type Vitess_VStreamClient
- type Vitess_VStreamServer
Constants ¶
const ( Vitess_Execute_FullMethodName = "/vitess.vtgateservice.dev.Vitess/Execute" Vitess_ExecuteMulti_FullMethodName = "/vitess.vtgateservice.dev.Vitess/ExecuteMulti" Vitess_ExecuteBatch_FullMethodName = "/vitess.vtgateservice.dev.Vitess/ExecuteBatch" Vitess_StreamExecute_FullMethodName = "/vitess.vtgateservice.dev.Vitess/StreamExecute" Vitess_StreamExecuteMulti_FullMethodName = "/vitess.vtgateservice.dev.Vitess/StreamExecuteMulti" Vitess_VStream_FullMethodName = "/vitess.vtgateservice.dev.Vitess/VStream" Vitess_Prepare_FullMethodName = "/vitess.vtgateservice.dev.Vitess/Prepare" Vitess_CloseSession_FullMethodName = "/vitess.vtgateservice.dev.Vitess/CloseSession" Vitess_BinlogDumpGTID_FullMethodName = "/vitess.vtgateservice.dev.Vitess/BinlogDumpGTID" )
Variables ¶
var Vitess_ServiceDesc = grpc.ServiceDesc{ ServiceName: "vitess.vtgateservice.dev.Vitess", HandlerType: (*VitessServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "Execute", Handler: _Vitess_Execute_Handler, }, { MethodName: "ExecuteMulti", Handler: _Vitess_ExecuteMulti_Handler, }, { MethodName: "ExecuteBatch", Handler: _Vitess_ExecuteBatch_Handler, }, { MethodName: "Prepare", Handler: _Vitess_Prepare_Handler, }, { MethodName: "CloseSession", Handler: _Vitess_CloseSession_Handler, }, }, Streams: []grpc.StreamDesc{ { StreamName: "StreamExecute", Handler: _Vitess_StreamExecute_Handler, ServerStreams: true, }, { StreamName: "StreamExecuteMulti", Handler: _Vitess_StreamExecuteMulti_Handler, ServerStreams: true, }, { StreamName: "VStream", Handler: _Vitess_VStream_Handler, ServerStreams: true, }, { StreamName: "BinlogDumpGTID", Handler: _Vitess_BinlogDumpGTID_Handler, ServerStreams: true, }, }, Metadata: "vitess/vtgateservice/dev/vtgateservice.proto", }
Vitess_ServiceDesc is the grpc.ServiceDesc for Vitess service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterVitessServer ¶
func RegisterVitessServer(s grpc.ServiceRegistrar, srv VitessServer)
Types ¶
type UnimplementedVitessServer ¶
type UnimplementedVitessServer struct{}
UnimplementedVitessServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedVitessServer) BinlogDumpGTID ¶
func (UnimplementedVitessServer) BinlogDumpGTID(*dev.BinlogDumpGTIDRequest, grpc.ServerStreamingServer[dev.BinlogDumpResponse]) error
func (UnimplementedVitessServer) CloseSession ¶
func (UnimplementedVitessServer) CloseSession(context.Context, *dev.CloseSessionRequest) (*dev.CloseSessionResponse, error)
func (UnimplementedVitessServer) Execute ¶
func (UnimplementedVitessServer) Execute(context.Context, *dev.ExecuteRequest) (*dev.ExecuteResponse, error)
func (UnimplementedVitessServer) ExecuteBatch ¶
func (UnimplementedVitessServer) ExecuteBatch(context.Context, *dev.ExecuteBatchRequest) (*dev.ExecuteBatchResponse, error)
func (UnimplementedVitessServer) ExecuteMulti ¶
func (UnimplementedVitessServer) ExecuteMulti(context.Context, *dev.ExecuteMultiRequest) (*dev.ExecuteMultiResponse, error)
func (UnimplementedVitessServer) Prepare ¶
func (UnimplementedVitessServer) Prepare(context.Context, *dev.PrepareRequest) (*dev.PrepareResponse, error)
func (UnimplementedVitessServer) StreamExecute ¶
func (UnimplementedVitessServer) StreamExecute(*dev.StreamExecuteRequest, grpc.ServerStreamingServer[dev.StreamExecuteResponse]) error
func (UnimplementedVitessServer) StreamExecuteMulti ¶
func (UnimplementedVitessServer) StreamExecuteMulti(*dev.StreamExecuteMultiRequest, grpc.ServerStreamingServer[dev.StreamExecuteMultiResponse]) error
func (UnimplementedVitessServer) VStream ¶
func (UnimplementedVitessServer) VStream(*dev.VStreamRequest, grpc.ServerStreamingServer[dev.VStreamResponse]) error
type UnsafeVitessServer ¶
type UnsafeVitessServer interface {
// contains filtered or unexported methods
}
UnsafeVitessServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to VitessServer will result in compilation errors.
type VitessClient ¶
type VitessClient interface {
// Execute tries to route the query to the right shard.
// It depends on the query and bind variables to provide enough
// information in conjunction with the vindexes to route the query.
// API group: v3
Execute(ctx context.Context, in *dev.ExecuteRequest, opts ...grpc.CallOption) (*dev.ExecuteResponse, error)
// ExecuteMulti executes multiple queries on the right shards.
ExecuteMulti(ctx context.Context, in *dev.ExecuteMultiRequest, opts ...grpc.CallOption) (*dev.ExecuteMultiResponse, error)
// ExecuteBatch tries to route the list of queries on the right shards.
// It depends on the query and bind variables to provide enough
// information in conjunction with the vindexes to route the query.
// API group: v3
ExecuteBatch(ctx context.Context, in *dev.ExecuteBatchRequest, opts ...grpc.CallOption) (*dev.ExecuteBatchResponse, error)
// StreamExecute executes a streaming query based on shards.
// It depends on the query and bind variables to provide enough
// information in conjunction with the vindexes to route the query.
// Use this method if the query returns a large number of rows.
// API group: v3
StreamExecute(ctx context.Context, in *dev.StreamExecuteRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[dev.StreamExecuteResponse], error)
// StreamExecuteMulti executes multiple streaming queries.
StreamExecuteMulti(ctx context.Context, in *dev.StreamExecuteMultiRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[dev.StreamExecuteMultiResponse], error)
// VStream streams binlog events from the requested sources.
VStream(ctx context.Context, in *dev.VStreamRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[dev.VStreamResponse], error)
// Prepare is used by the MySQL server plugin as part of supporting prepared statements.
Prepare(ctx context.Context, in *dev.PrepareRequest, opts ...grpc.CallOption) (*dev.PrepareResponse, error)
// CloseSession closes the session, rolling back any implicit transactions.
// This has the same effect as if a "rollback" statement was executed,
// but does not affect the query statistics.
CloseSession(ctx context.Context, in *dev.CloseSessionRequest, opts ...grpc.CallOption) (*dev.CloseSessionResponse, error)
// BinlogDumpGTID streams raw binlog events from a specific keyspace/shard
// using GTID-based replication. This is the vtgate-level gRPC equivalent
// of COM_BINLOG_DUMP_GTID.
BinlogDumpGTID(ctx context.Context, in *dev.BinlogDumpGTIDRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[dev.BinlogDumpResponse], error)
}
VitessClient is the client API for Vitess service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
Vitess is the main service to access a Vitess cluster. It is the API that vtgate exposes to serve all queries.
func NewVitessClient ¶
func NewVitessClient(cc grpc.ClientConnInterface) VitessClient
type VitessServer ¶
type VitessServer interface {
// Execute tries to route the query to the right shard.
// It depends on the query and bind variables to provide enough
// information in conjunction with the vindexes to route the query.
// API group: v3
Execute(context.Context, *dev.ExecuteRequest) (*dev.ExecuteResponse, error)
// ExecuteMulti executes multiple queries on the right shards.
ExecuteMulti(context.Context, *dev.ExecuteMultiRequest) (*dev.ExecuteMultiResponse, error)
// ExecuteBatch tries to route the list of queries on the right shards.
// It depends on the query and bind variables to provide enough
// information in conjunction with the vindexes to route the query.
// API group: v3
ExecuteBatch(context.Context, *dev.ExecuteBatchRequest) (*dev.ExecuteBatchResponse, error)
// StreamExecute executes a streaming query based on shards.
// It depends on the query and bind variables to provide enough
// information in conjunction with the vindexes to route the query.
// Use this method if the query returns a large number of rows.
// API group: v3
StreamExecute(*dev.StreamExecuteRequest, grpc.ServerStreamingServer[dev.StreamExecuteResponse]) error
// StreamExecuteMulti executes multiple streaming queries.
StreamExecuteMulti(*dev.StreamExecuteMultiRequest, grpc.ServerStreamingServer[dev.StreamExecuteMultiResponse]) error
// VStream streams binlog events from the requested sources.
VStream(*dev.VStreamRequest, grpc.ServerStreamingServer[dev.VStreamResponse]) error
// Prepare is used by the MySQL server plugin as part of supporting prepared statements.
Prepare(context.Context, *dev.PrepareRequest) (*dev.PrepareResponse, error)
// CloseSession closes the session, rolling back any implicit transactions.
// This has the same effect as if a "rollback" statement was executed,
// but does not affect the query statistics.
CloseSession(context.Context, *dev.CloseSessionRequest) (*dev.CloseSessionResponse, error)
// BinlogDumpGTID streams raw binlog events from a specific keyspace/shard
// using GTID-based replication. This is the vtgate-level gRPC equivalent
// of COM_BINLOG_DUMP_GTID.
BinlogDumpGTID(*dev.BinlogDumpGTIDRequest, grpc.ServerStreamingServer[dev.BinlogDumpResponse]) error
}
VitessServer is the server API for Vitess service. All implementations should embed UnimplementedVitessServer for forward compatibility.
Vitess is the main service to access a Vitess cluster. It is the API that vtgate exposes to serve all queries.
type Vitess_BinlogDumpGTIDClient ¶
type Vitess_BinlogDumpGTIDClient = grpc.ServerStreamingClient[dev.BinlogDumpResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type Vitess_BinlogDumpGTIDServer ¶
type Vitess_BinlogDumpGTIDServer = grpc.ServerStreamingServer[dev.BinlogDumpResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type Vitess_StreamExecuteClient ¶
type Vitess_StreamExecuteClient = grpc.ServerStreamingClient[dev.StreamExecuteResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type Vitess_StreamExecuteMultiClient ¶
type Vitess_StreamExecuteMultiClient = grpc.ServerStreamingClient[dev.StreamExecuteMultiResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type Vitess_StreamExecuteMultiServer ¶
type Vitess_StreamExecuteMultiServer = grpc.ServerStreamingServer[dev.StreamExecuteMultiResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type Vitess_StreamExecuteServer ¶
type Vitess_StreamExecuteServer = grpc.ServerStreamingServer[dev.StreamExecuteResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type Vitess_VStreamClient ¶
type Vitess_VStreamClient = grpc.ServerStreamingClient[dev.VStreamResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type Vitess_VStreamServer ¶
type Vitess_VStreamServer = grpc.ServerStreamingServer[dev.VStreamResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
Source Files
¶
- vtgateservice_grpc.pb.go