dev

package
v1.36.11-2025072813344... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 7 Imported by: 2

Documentation

Index

Constants

This section is empty.

Variables

var (
	BackupInfo_Status_name = map[int32]string{
		0: "UNKNOWN",
		1: "INCOMPLETE",
		2: "COMPLETE",
		3: "INVALID",
		4: "VALID",
	}
	BackupInfo_Status_value = map[string]int32{
		"UNKNOWN":    0,
		"INCOMPLETE": 1,
		"COMPLETE":   2,
		"INVALID":    3,
		"VALID":      4,
	}
)

Enum value maps for BackupInfo_Status.

var File_vitess_mysqlctl_dev_mysqlctl_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type ApplyBinlogFileRequest

type ApplyBinlogFileRequest struct {
	BinlogFileName        string    `protobuf:"bytes,1,opt,name=binlog_file_name,json=binlogFileName,proto3" json:"binlog_file_name,omitempty"`
	BinlogRestorePosition string    `` /* 126-byte string literal not displayed */
	BinlogRestoreDatetime *dev.Time `` /* 126-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*ApplyBinlogFileRequest) ClearBinlogRestoreDatetime

func (x *ApplyBinlogFileRequest) ClearBinlogRestoreDatetime()

func (*ApplyBinlogFileRequest) GetBinlogFileName

func (x *ApplyBinlogFileRequest) GetBinlogFileName() string

func (*ApplyBinlogFileRequest) GetBinlogRestoreDatetime

func (x *ApplyBinlogFileRequest) GetBinlogRestoreDatetime() *dev.Time

func (*ApplyBinlogFileRequest) GetBinlogRestorePosition

func (x *ApplyBinlogFileRequest) GetBinlogRestorePosition() string

func (*ApplyBinlogFileRequest) HasBinlogRestoreDatetime

func (x *ApplyBinlogFileRequest) HasBinlogRestoreDatetime() bool

func (*ApplyBinlogFileRequest) ProtoMessage

func (*ApplyBinlogFileRequest) ProtoMessage()

func (*ApplyBinlogFileRequest) ProtoReflect

func (x *ApplyBinlogFileRequest) ProtoReflect() protoreflect.Message

func (*ApplyBinlogFileRequest) Reset

func (x *ApplyBinlogFileRequest) Reset()

func (*ApplyBinlogFileRequest) SetBinlogFileName

func (x *ApplyBinlogFileRequest) SetBinlogFileName(v string)

func (*ApplyBinlogFileRequest) SetBinlogRestoreDatetime

func (x *ApplyBinlogFileRequest) SetBinlogRestoreDatetime(v *dev.Time)

func (*ApplyBinlogFileRequest) SetBinlogRestorePosition

func (x *ApplyBinlogFileRequest) SetBinlogRestorePosition(v string)

func (*ApplyBinlogFileRequest) String

func (x *ApplyBinlogFileRequest) String() string

type ApplyBinlogFileRequest_builder

type ApplyBinlogFileRequest_builder struct {
	BinlogFileName        string
	BinlogRestorePosition string
	BinlogRestoreDatetime *dev.Time
	// contains filtered or unexported fields
}

func (ApplyBinlogFileRequest_builder) Build

type ApplyBinlogFileResponse

type ApplyBinlogFileResponse struct {
	// contains filtered or unexported fields
}

func (*ApplyBinlogFileResponse) ProtoMessage

func (*ApplyBinlogFileResponse) ProtoMessage()

func (*ApplyBinlogFileResponse) ProtoReflect

func (x *ApplyBinlogFileResponse) ProtoReflect() protoreflect.Message

func (*ApplyBinlogFileResponse) Reset

func (x *ApplyBinlogFileResponse) Reset()

func (*ApplyBinlogFileResponse) String

func (x *ApplyBinlogFileResponse) String() string

type ApplyBinlogFileResponse_builder

type ApplyBinlogFileResponse_builder struct {
	// contains filtered or unexported fields
}

func (ApplyBinlogFileResponse_builder) Build

type BackupInfo

type BackupInfo struct {
	Name        string            `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	Directory   string            `protobuf:"bytes,2,opt,name=directory,proto3" json:"directory,omitempty"`
	Keyspace    string            `protobuf:"bytes,3,opt,name=keyspace,proto3" json:"keyspace,omitempty"`
	Shard       string            `protobuf:"bytes,4,opt,name=shard,proto3" json:"shard,omitempty"`
	TabletAlias *dev1.TabletAlias `protobuf:"bytes,5,opt,name=tablet_alias,json=tabletAlias,proto3" json:"tablet_alias,omitempty"`
	Time        *dev.Time         `protobuf:"bytes,6,opt,name=time,proto3" json:"time,omitempty"`
	// Engine is the name of the backupengine implementation used to create
	// this backup.
	Engine string            `protobuf:"bytes,7,opt,name=engine,proto3" json:"engine,omitempty"`
	Status BackupInfo_Status `protobuf:"varint,8,opt,name=status,proto3,enum=vitess.mysqlctl.dev.BackupInfo_Status" json:"status,omitempty"`
	// contains filtered or unexported fields
}

BackupInfo is the read-only attributes of a mysqlctl/backupstorage.BackupHandle.

func (*BackupInfo) ClearTabletAlias

func (x *BackupInfo) ClearTabletAlias()

func (*BackupInfo) ClearTime

func (x *BackupInfo) ClearTime()

func (*BackupInfo) GetDirectory

func (x *BackupInfo) GetDirectory() string

func (*BackupInfo) GetEngine

func (x *BackupInfo) GetEngine() string

func (*BackupInfo) GetKeyspace

func (x *BackupInfo) GetKeyspace() string

func (*BackupInfo) GetName

func (x *BackupInfo) GetName() string

func (*BackupInfo) GetShard

func (x *BackupInfo) GetShard() string

func (*BackupInfo) GetStatus

func (x *BackupInfo) GetStatus() BackupInfo_Status

func (*BackupInfo) GetTabletAlias

func (x *BackupInfo) GetTabletAlias() *dev1.TabletAlias

func (*BackupInfo) GetTime

func (x *BackupInfo) GetTime() *dev.Time

func (*BackupInfo) HasTabletAlias

func (x *BackupInfo) HasTabletAlias() bool

func (*BackupInfo) HasTime

func (x *BackupInfo) HasTime() bool

func (*BackupInfo) ProtoMessage

func (*BackupInfo) ProtoMessage()

func (*BackupInfo) ProtoReflect

func (x *BackupInfo) ProtoReflect() protoreflect.Message

func (*BackupInfo) Reset

func (x *BackupInfo) Reset()

func (*BackupInfo) SetDirectory

func (x *BackupInfo) SetDirectory(v string)

func (*BackupInfo) SetEngine

func (x *BackupInfo) SetEngine(v string)

func (*BackupInfo) SetKeyspace

func (x *BackupInfo) SetKeyspace(v string)

func (*BackupInfo) SetName

func (x *BackupInfo) SetName(v string)

func (*BackupInfo) SetShard

func (x *BackupInfo) SetShard(v string)

func (*BackupInfo) SetStatus

func (x *BackupInfo) SetStatus(v BackupInfo_Status)

func (*BackupInfo) SetTabletAlias

func (x *BackupInfo) SetTabletAlias(v *dev1.TabletAlias)

func (*BackupInfo) SetTime

func (x *BackupInfo) SetTime(v *dev.Time)

func (*BackupInfo) String

func (x *BackupInfo) String() string

type BackupInfo_Status

type BackupInfo_Status int32

Status is an enum representing the possible status of a backup.

const (
	BackupInfo_UNKNOWN    BackupInfo_Status = 0
	BackupInfo_INCOMPLETE BackupInfo_Status = 1
	BackupInfo_COMPLETE   BackupInfo_Status = 2
	// A backup status of INVALID should be set if the backup is complete
	// but unusable in some way (partial upload, corrupt file, etc).
	BackupInfo_INVALID BackupInfo_Status = 3
	// A backup status of VALID should be set if the backup is both
	// complete and usuable.
	BackupInfo_VALID BackupInfo_Status = 4
)

func (BackupInfo_Status) Descriptor

func (BackupInfo_Status) Enum

func (BackupInfo_Status) Number

func (BackupInfo_Status) String

func (x BackupInfo_Status) String() string

func (BackupInfo_Status) Type

type BackupInfo_builder

type BackupInfo_builder struct {
	Name        string
	Directory   string
	Keyspace    string
	Shard       string
	TabletAlias *dev1.TabletAlias
	Time        *dev.Time
	// Engine is the name of the backupengine implementation used to create
	// this backup.
	Engine string
	Status BackupInfo_Status
	// contains filtered or unexported fields
}

func (BackupInfo_builder) Build

func (b0 BackupInfo_builder) Build() *BackupInfo

type HostMetricsRequest

type HostMetricsRequest struct {
	// contains filtered or unexported fields
}

func (*HostMetricsRequest) ProtoMessage

func (*HostMetricsRequest) ProtoMessage()

func (*HostMetricsRequest) ProtoReflect

func (x *HostMetricsRequest) ProtoReflect() protoreflect.Message

func (*HostMetricsRequest) Reset

func (x *HostMetricsRequest) Reset()

func (*HostMetricsRequest) String

func (x *HostMetricsRequest) String() string

type HostMetricsRequest_builder

type HostMetricsRequest_builder struct {
	// contains filtered or unexported fields
}

func (HostMetricsRequest_builder) Build

type HostMetricsResponse

type HostMetricsResponse struct {

	// Metrics is a map (metric name -> metric value/error) so that the client has as much
	// information as possible about all the checked metrics.
	Metrics map[string]*HostMetricsResponse_Metric `` /* 141-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*HostMetricsResponse) GetMetrics

func (*HostMetricsResponse) ProtoMessage

func (*HostMetricsResponse) ProtoMessage()

func (*HostMetricsResponse) ProtoReflect

func (x *HostMetricsResponse) ProtoReflect() protoreflect.Message

func (*HostMetricsResponse) Reset

func (x *HostMetricsResponse) Reset()

func (*HostMetricsResponse) SetMetrics

func (*HostMetricsResponse) String

func (x *HostMetricsResponse) String() string

type HostMetricsResponse_Metric

type HostMetricsResponse_Metric struct {

	// Name of the metric
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Value is the metric value
	Value float64 `protobuf:"fixed64,2,opt,name=value,proto3" json:"value,omitempty"`
	// Error indicates an error retrieving the value
	Error *dev2.RPCError `protobuf:"bytes,3,opt,name=error,proto3" json:"error,omitempty"`
	// contains filtered or unexported fields
}

func (*HostMetricsResponse_Metric) ClearError

func (x *HostMetricsResponse_Metric) ClearError()

func (*HostMetricsResponse_Metric) GetError

func (x *HostMetricsResponse_Metric) GetError() *dev2.RPCError

func (*HostMetricsResponse_Metric) GetName

func (x *HostMetricsResponse_Metric) GetName() string

func (*HostMetricsResponse_Metric) GetValue

func (x *HostMetricsResponse_Metric) GetValue() float64

func (*HostMetricsResponse_Metric) HasError

func (x *HostMetricsResponse_Metric) HasError() bool

func (*HostMetricsResponse_Metric) ProtoMessage

func (*HostMetricsResponse_Metric) ProtoMessage()

func (*HostMetricsResponse_Metric) ProtoReflect

func (*HostMetricsResponse_Metric) Reset

func (x *HostMetricsResponse_Metric) Reset()

func (*HostMetricsResponse_Metric) SetError

func (x *HostMetricsResponse_Metric) SetError(v *dev2.RPCError)

func (*HostMetricsResponse_Metric) SetName

func (x *HostMetricsResponse_Metric) SetName(v string)

func (*HostMetricsResponse_Metric) SetValue

func (x *HostMetricsResponse_Metric) SetValue(v float64)

func (*HostMetricsResponse_Metric) String

func (x *HostMetricsResponse_Metric) String() string

type HostMetricsResponse_Metric_builder

type HostMetricsResponse_Metric_builder struct {

	// Name of the metric
	Name string
	// Value is the metric value
	Value float64
	// Error indicates an error retrieving the value
	Error *dev2.RPCError
	// contains filtered or unexported fields
}

func (HostMetricsResponse_Metric_builder) Build

type HostMetricsResponse_builder

type HostMetricsResponse_builder struct {

	// Metrics is a map (metric name -> metric value/error) so that the client has as much
	// information as possible about all the checked metrics.
	Metrics map[string]*HostMetricsResponse_Metric
	// contains filtered or unexported fields
}

func (HostMetricsResponse_builder) Build

type ReadBinlogFilesTimestampsRequest

type ReadBinlogFilesTimestampsRequest struct {
	BinlogFileNames []string `protobuf:"bytes,1,rep,name=binlog_file_names,json=binlogFileNames,proto3" json:"binlog_file_names,omitempty"`
	// contains filtered or unexported fields
}

func (*ReadBinlogFilesTimestampsRequest) GetBinlogFileNames

func (x *ReadBinlogFilesTimestampsRequest) GetBinlogFileNames() []string

func (*ReadBinlogFilesTimestampsRequest) ProtoMessage

func (*ReadBinlogFilesTimestampsRequest) ProtoMessage()

func (*ReadBinlogFilesTimestampsRequest) ProtoReflect

func (*ReadBinlogFilesTimestampsRequest) Reset

func (*ReadBinlogFilesTimestampsRequest) SetBinlogFileNames

func (x *ReadBinlogFilesTimestampsRequest) SetBinlogFileNames(v []string)

func (*ReadBinlogFilesTimestampsRequest) String

type ReadBinlogFilesTimestampsRequest_builder

type ReadBinlogFilesTimestampsRequest_builder struct {
	BinlogFileNames []string
	// contains filtered or unexported fields
}

func (ReadBinlogFilesTimestampsRequest_builder) Build

type ReadBinlogFilesTimestampsResponse

type ReadBinlogFilesTimestampsResponse struct {

	// FirstTimestamp is the timestamp of the first found transaction searching in order of given binlog files
	FirstTimestamp *dev.Time `protobuf:"bytes,1,opt,name=first_timestamp,json=firstTimestamp,proto3" json:"first_timestamp,omitempty"`
	// FirstTimestampBinlog is the name of the binary log in which the first timestamp is found
	FirstTimestampBinlog string `protobuf:"bytes,2,opt,name=first_timestamp_binlog,json=firstTimestampBinlog,proto3" json:"first_timestamp_binlog,omitempty"`
	// LastTimestamp is the timestamp of the last found transaction in given binlog files
	LastTimestamp *dev.Time `protobuf:"bytes,3,opt,name=last_timestamp,json=lastTimestamp,proto3" json:"last_timestamp,omitempty"`
	// LastTimestampBinlog is the name of the binary log in which the last timestamp is found
	LastTimestampBinlog string `protobuf:"bytes,4,opt,name=last_timestamp_binlog,json=lastTimestampBinlog,proto3" json:"last_timestamp_binlog,omitempty"`
	// contains filtered or unexported fields
}

func (*ReadBinlogFilesTimestampsResponse) ClearFirstTimestamp

func (x *ReadBinlogFilesTimestampsResponse) ClearFirstTimestamp()

func (*ReadBinlogFilesTimestampsResponse) ClearLastTimestamp

func (x *ReadBinlogFilesTimestampsResponse) ClearLastTimestamp()

func (*ReadBinlogFilesTimestampsResponse) GetFirstTimestamp

func (x *ReadBinlogFilesTimestampsResponse) GetFirstTimestamp() *dev.Time

func (*ReadBinlogFilesTimestampsResponse) GetFirstTimestampBinlog

func (x *ReadBinlogFilesTimestampsResponse) GetFirstTimestampBinlog() string

func (*ReadBinlogFilesTimestampsResponse) GetLastTimestamp

func (x *ReadBinlogFilesTimestampsResponse) GetLastTimestamp() *dev.Time

func (*ReadBinlogFilesTimestampsResponse) GetLastTimestampBinlog

func (x *ReadBinlogFilesTimestampsResponse) GetLastTimestampBinlog() string

func (*ReadBinlogFilesTimestampsResponse) HasFirstTimestamp

func (x *ReadBinlogFilesTimestampsResponse) HasFirstTimestamp() bool

func (*ReadBinlogFilesTimestampsResponse) HasLastTimestamp

func (x *ReadBinlogFilesTimestampsResponse) HasLastTimestamp() bool

func (*ReadBinlogFilesTimestampsResponse) ProtoMessage

func (*ReadBinlogFilesTimestampsResponse) ProtoMessage()

func (*ReadBinlogFilesTimestampsResponse) ProtoReflect

func (*ReadBinlogFilesTimestampsResponse) Reset

func (*ReadBinlogFilesTimestampsResponse) SetFirstTimestamp

func (x *ReadBinlogFilesTimestampsResponse) SetFirstTimestamp(v *dev.Time)

func (*ReadBinlogFilesTimestampsResponse) SetFirstTimestampBinlog

func (x *ReadBinlogFilesTimestampsResponse) SetFirstTimestampBinlog(v string)

func (*ReadBinlogFilesTimestampsResponse) SetLastTimestamp

func (x *ReadBinlogFilesTimestampsResponse) SetLastTimestamp(v *dev.Time)

func (*ReadBinlogFilesTimestampsResponse) SetLastTimestampBinlog

func (x *ReadBinlogFilesTimestampsResponse) SetLastTimestampBinlog(v string)

func (*ReadBinlogFilesTimestampsResponse) String

type ReadBinlogFilesTimestampsResponse_builder

type ReadBinlogFilesTimestampsResponse_builder struct {

	// FirstTimestamp is the timestamp of the first found transaction searching in order of given binlog files
	FirstTimestamp *dev.Time
	// FirstTimestampBinlog is the name of the binary log in which the first timestamp is found
	FirstTimestampBinlog string
	// LastTimestamp is the timestamp of the last found transaction in given binlog files
	LastTimestamp *dev.Time
	// LastTimestampBinlog is the name of the binary log in which the last timestamp is found
	LastTimestampBinlog string
	// contains filtered or unexported fields
}

func (ReadBinlogFilesTimestampsResponse_builder) Build

type RefreshConfigRequest

type RefreshConfigRequest struct {
	// contains filtered or unexported fields
}

func (*RefreshConfigRequest) ProtoMessage

func (*RefreshConfigRequest) ProtoMessage()

func (*RefreshConfigRequest) ProtoReflect

func (x *RefreshConfigRequest) ProtoReflect() protoreflect.Message

func (*RefreshConfigRequest) Reset

func (x *RefreshConfigRequest) Reset()

func (*RefreshConfigRequest) String

func (x *RefreshConfigRequest) String() string

type RefreshConfigRequest_builder

type RefreshConfigRequest_builder struct {
	// contains filtered or unexported fields
}

func (RefreshConfigRequest_builder) Build

type RefreshConfigResponse

type RefreshConfigResponse struct {
	// contains filtered or unexported fields
}

func (*RefreshConfigResponse) ProtoMessage

func (*RefreshConfigResponse) ProtoMessage()

func (*RefreshConfigResponse) ProtoReflect

func (x *RefreshConfigResponse) ProtoReflect() protoreflect.Message

func (*RefreshConfigResponse) Reset

func (x *RefreshConfigResponse) Reset()

func (*RefreshConfigResponse) String

func (x *RefreshConfigResponse) String() string

type RefreshConfigResponse_builder

type RefreshConfigResponse_builder struct {
	// contains filtered or unexported fields
}

func (RefreshConfigResponse_builder) Build

type ReinitConfigRequest

type ReinitConfigRequest struct {
	// contains filtered or unexported fields
}

func (*ReinitConfigRequest) ProtoMessage

func (*ReinitConfigRequest) ProtoMessage()

func (*ReinitConfigRequest) ProtoReflect

func (x *ReinitConfigRequest) ProtoReflect() protoreflect.Message

func (*ReinitConfigRequest) Reset

func (x *ReinitConfigRequest) Reset()

func (*ReinitConfigRequest) String

func (x *ReinitConfigRequest) String() string

type ReinitConfigRequest_builder

type ReinitConfigRequest_builder struct {
	// contains filtered or unexported fields
}

func (ReinitConfigRequest_builder) Build

type ReinitConfigResponse

type ReinitConfigResponse struct {
	// contains filtered or unexported fields
}

func (*ReinitConfigResponse) ProtoMessage

func (*ReinitConfigResponse) ProtoMessage()

func (*ReinitConfigResponse) ProtoReflect

func (x *ReinitConfigResponse) ProtoReflect() protoreflect.Message

func (*ReinitConfigResponse) Reset

func (x *ReinitConfigResponse) Reset()

func (*ReinitConfigResponse) String

func (x *ReinitConfigResponse) String() string

type ReinitConfigResponse_builder

type ReinitConfigResponse_builder struct {
	// contains filtered or unexported fields
}

func (ReinitConfigResponse_builder) Build

type RunMysqlUpgradeRequest

type RunMysqlUpgradeRequest struct {
	// contains filtered or unexported fields
}

func (*RunMysqlUpgradeRequest) ProtoMessage

func (*RunMysqlUpgradeRequest) ProtoMessage()

func (*RunMysqlUpgradeRequest) ProtoReflect

func (x *RunMysqlUpgradeRequest) ProtoReflect() protoreflect.Message

func (*RunMysqlUpgradeRequest) Reset

func (x *RunMysqlUpgradeRequest) Reset()

func (*RunMysqlUpgradeRequest) String

func (x *RunMysqlUpgradeRequest) String() string

type RunMysqlUpgradeRequest_builder

type RunMysqlUpgradeRequest_builder struct {
	// contains filtered or unexported fields
}

func (RunMysqlUpgradeRequest_builder) Build

type RunMysqlUpgradeResponse

type RunMysqlUpgradeResponse struct {
	// contains filtered or unexported fields
}

func (*RunMysqlUpgradeResponse) ProtoMessage

func (*RunMysqlUpgradeResponse) ProtoMessage()

func (*RunMysqlUpgradeResponse) ProtoReflect

func (x *RunMysqlUpgradeResponse) ProtoReflect() protoreflect.Message

func (*RunMysqlUpgradeResponse) Reset

func (x *RunMysqlUpgradeResponse) Reset()

func (*RunMysqlUpgradeResponse) String

func (x *RunMysqlUpgradeResponse) String() string

type RunMysqlUpgradeResponse_builder

type RunMysqlUpgradeResponse_builder struct {
	// contains filtered or unexported fields
}

func (RunMysqlUpgradeResponse_builder) Build

type ShutdownRequest

type ShutdownRequest struct {
	WaitForMysqld        bool          `protobuf:"varint,1,opt,name=wait_for_mysqld,json=waitForMysqld,proto3" json:"wait_for_mysqld,omitempty"`
	MysqlShutdownTimeout *dev.Duration `protobuf:"bytes,2,opt,name=mysql_shutdown_timeout,json=mysqlShutdownTimeout,proto3" json:"mysql_shutdown_timeout,omitempty"`
	// contains filtered or unexported fields
}

func (*ShutdownRequest) ClearMysqlShutdownTimeout

func (x *ShutdownRequest) ClearMysqlShutdownTimeout()

func (*ShutdownRequest) GetMysqlShutdownTimeout

func (x *ShutdownRequest) GetMysqlShutdownTimeout() *dev.Duration

func (*ShutdownRequest) GetWaitForMysqld

func (x *ShutdownRequest) GetWaitForMysqld() bool

func (*ShutdownRequest) HasMysqlShutdownTimeout

func (x *ShutdownRequest) HasMysqlShutdownTimeout() bool

func (*ShutdownRequest) ProtoMessage

func (*ShutdownRequest) ProtoMessage()

func (*ShutdownRequest) ProtoReflect

func (x *ShutdownRequest) ProtoReflect() protoreflect.Message

func (*ShutdownRequest) Reset

func (x *ShutdownRequest) Reset()

func (*ShutdownRequest) SetMysqlShutdownTimeout

func (x *ShutdownRequest) SetMysqlShutdownTimeout(v *dev.Duration)

func (*ShutdownRequest) SetWaitForMysqld

func (x *ShutdownRequest) SetWaitForMysqld(v bool)

func (*ShutdownRequest) String

func (x *ShutdownRequest) String() string

type ShutdownRequest_builder

type ShutdownRequest_builder struct {
	WaitForMysqld        bool
	MysqlShutdownTimeout *dev.Duration
	// contains filtered or unexported fields
}

func (ShutdownRequest_builder) Build

type ShutdownResponse

type ShutdownResponse struct {
	// contains filtered or unexported fields
}

func (*ShutdownResponse) ProtoMessage

func (*ShutdownResponse) ProtoMessage()

func (*ShutdownResponse) ProtoReflect

func (x *ShutdownResponse) ProtoReflect() protoreflect.Message

func (*ShutdownResponse) Reset

func (x *ShutdownResponse) Reset()

func (*ShutdownResponse) String

func (x *ShutdownResponse) String() string

type ShutdownResponse_builder

type ShutdownResponse_builder struct {
	// contains filtered or unexported fields
}

func (ShutdownResponse_builder) Build

type StartRequest

type StartRequest struct {
	MysqldArgs []string `protobuf:"bytes,1,rep,name=mysqld_args,json=mysqldArgs,proto3" json:"mysqld_args,omitempty"`
	// contains filtered or unexported fields
}

func (*StartRequest) GetMysqldArgs

func (x *StartRequest) GetMysqldArgs() []string

func (*StartRequest) ProtoMessage

func (*StartRequest) ProtoMessage()

func (*StartRequest) ProtoReflect

func (x *StartRequest) ProtoReflect() protoreflect.Message

func (*StartRequest) Reset

func (x *StartRequest) Reset()

func (*StartRequest) SetMysqldArgs

func (x *StartRequest) SetMysqldArgs(v []string)

func (*StartRequest) String

func (x *StartRequest) String() string

type StartRequest_builder

type StartRequest_builder struct {
	MysqldArgs []string
	// contains filtered or unexported fields
}

func (StartRequest_builder) Build

func (b0 StartRequest_builder) Build() *StartRequest

type StartResponse

type StartResponse struct {
	// contains filtered or unexported fields
}

func (*StartResponse) ProtoMessage

func (*StartResponse) ProtoMessage()

func (*StartResponse) ProtoReflect

func (x *StartResponse) ProtoReflect() protoreflect.Message

func (*StartResponse) Reset

func (x *StartResponse) Reset()

func (*StartResponse) String

func (x *StartResponse) String() string

type StartResponse_builder

type StartResponse_builder struct {
	// contains filtered or unexported fields
}

func (StartResponse_builder) Build

type VersionStringRequest

type VersionStringRequest struct {
	// contains filtered or unexported fields
}

func (*VersionStringRequest) ProtoMessage

func (*VersionStringRequest) ProtoMessage()

func (*VersionStringRequest) ProtoReflect

func (x *VersionStringRequest) ProtoReflect() protoreflect.Message

func (*VersionStringRequest) Reset

func (x *VersionStringRequest) Reset()

func (*VersionStringRequest) String

func (x *VersionStringRequest) String() string

type VersionStringRequest_builder

type VersionStringRequest_builder struct {
	// contains filtered or unexported fields
}

func (VersionStringRequest_builder) Build

type VersionStringResponse

type VersionStringResponse struct {
	Version string `protobuf:"bytes,1,opt,name=version,proto3" json:"version,omitempty"`
	// contains filtered or unexported fields
}

func (*VersionStringResponse) GetVersion

func (x *VersionStringResponse) GetVersion() string

func (*VersionStringResponse) ProtoMessage

func (*VersionStringResponse) ProtoMessage()

func (*VersionStringResponse) ProtoReflect

func (x *VersionStringResponse) ProtoReflect() protoreflect.Message

func (*VersionStringResponse) Reset

func (x *VersionStringResponse) Reset()

func (*VersionStringResponse) SetVersion

func (x *VersionStringResponse) SetVersion(v string)

func (*VersionStringResponse) String

func (x *VersionStringResponse) String() string

type VersionStringResponse_builder

type VersionStringResponse_builder struct {
	Version string
	// contains filtered or unexported fields
}

func (VersionStringResponse_builder) Build

Source Files

  • mysqlctl.pb.go

Jump to