Documentation
¶
Index ¶
- Variables
- type Configuration
- func (x *Configuration) GetAgeBadRateAfterSec() int64
- func (x *Configuration) GetBadRateIncrease() float64
- func (x *Configuration) GetEmergencyDecrease() float64
- func (x *Configuration) GetIgnoreNSlowestRdonlys() int32
- func (x *Configuration) GetIgnoreNSlowestReplicas() int32
- func (x *Configuration) GetInitialRate() int64
- func (x *Configuration) GetMaxDurationBetweenIncreasesSec() int64
- func (x *Configuration) GetMaxIncrease() float64
- func (x *Configuration) GetMaxRateApproachThreshold() float64
- func (x *Configuration) GetMaxReplicationLagSec() int64
- func (x *Configuration) GetMinDurationBetweenDecreasesSec() int64
- func (x *Configuration) GetMinDurationBetweenIncreasesSec() int64
- func (x *Configuration) GetSpreadBacklogAcrossSec() int64
- func (x *Configuration) GetTargetReplicationLagSec() int64
- func (*Configuration) ProtoMessage()
- func (x *Configuration) ProtoReflect() protoreflect.Message
- func (x *Configuration) Reset()
- func (x *Configuration) SetAgeBadRateAfterSec(v int64)
- func (x *Configuration) SetBadRateIncrease(v float64)
- func (x *Configuration) SetEmergencyDecrease(v float64)
- func (x *Configuration) SetIgnoreNSlowestRdonlys(v int32)
- func (x *Configuration) SetIgnoreNSlowestReplicas(v int32)
- func (x *Configuration) SetInitialRate(v int64)
- func (x *Configuration) SetMaxDurationBetweenIncreasesSec(v int64)
- func (x *Configuration) SetMaxIncrease(v float64)
- func (x *Configuration) SetMaxRateApproachThreshold(v float64)
- func (x *Configuration) SetMaxReplicationLagSec(v int64)
- func (x *Configuration) SetMinDurationBetweenDecreasesSec(v int64)
- func (x *Configuration) SetMinDurationBetweenIncreasesSec(v int64)
- func (x *Configuration) SetSpreadBacklogAcrossSec(v int64)
- func (x *Configuration) SetTargetReplicationLagSec(v int64)
- func (x *Configuration) String() string
- type Configuration_builder
- type GetConfigurationRequest
- func (x *GetConfigurationRequest) GetThrottlerName() string
- func (*GetConfigurationRequest) ProtoMessage()
- func (x *GetConfigurationRequest) ProtoReflect() protoreflect.Message
- func (x *GetConfigurationRequest) Reset()
- func (x *GetConfigurationRequest) SetThrottlerName(v string)
- func (x *GetConfigurationRequest) String() string
- type GetConfigurationRequest_builder
- type GetConfigurationResponse
- func (x *GetConfigurationResponse) GetConfigurations() map[string]*Configuration
- func (*GetConfigurationResponse) ProtoMessage()
- func (x *GetConfigurationResponse) ProtoReflect() protoreflect.Message
- func (x *GetConfigurationResponse) Reset()
- func (x *GetConfigurationResponse) SetConfigurations(v map[string]*Configuration)
- func (x *GetConfigurationResponse) String() string
- type GetConfigurationResponse_builder
- type MaxRatesRequest
- type MaxRatesRequest_builder
- type MaxRatesResponse
- type MaxRatesResponse_builder
- type ResetConfigurationRequest
- func (x *ResetConfigurationRequest) GetThrottlerName() string
- func (*ResetConfigurationRequest) ProtoMessage()
- func (x *ResetConfigurationRequest) ProtoReflect() protoreflect.Message
- func (x *ResetConfigurationRequest) Reset()
- func (x *ResetConfigurationRequest) SetThrottlerName(v string)
- func (x *ResetConfigurationRequest) String() string
- type ResetConfigurationRequest_builder
- type ResetConfigurationResponse
- func (x *ResetConfigurationResponse) GetNames() []string
- func (*ResetConfigurationResponse) ProtoMessage()
- func (x *ResetConfigurationResponse) ProtoReflect() protoreflect.Message
- func (x *ResetConfigurationResponse) Reset()
- func (x *ResetConfigurationResponse) SetNames(v []string)
- func (x *ResetConfigurationResponse) String() string
- type ResetConfigurationResponse_builder
- type SetMaxRateRequest
- type SetMaxRateRequest_builder
- type SetMaxRateResponse
- type SetMaxRateResponse_builder
- type UpdateConfigurationRequest
- func (x *UpdateConfigurationRequest) ClearConfiguration()
- func (x *UpdateConfigurationRequest) GetConfiguration() *Configuration
- func (x *UpdateConfigurationRequest) GetCopyZeroValues() bool
- func (x *UpdateConfigurationRequest) GetThrottlerName() string
- func (x *UpdateConfigurationRequest) HasConfiguration() bool
- func (*UpdateConfigurationRequest) ProtoMessage()
- func (x *UpdateConfigurationRequest) ProtoReflect() protoreflect.Message
- func (x *UpdateConfigurationRequest) Reset()
- func (x *UpdateConfigurationRequest) SetConfiguration(v *Configuration)
- func (x *UpdateConfigurationRequest) SetCopyZeroValues(v bool)
- func (x *UpdateConfigurationRequest) SetThrottlerName(v string)
- func (x *UpdateConfigurationRequest) String() string
- type UpdateConfigurationRequest_builder
- type UpdateConfigurationResponse
- func (x *UpdateConfigurationResponse) GetNames() []string
- func (*UpdateConfigurationResponse) ProtoMessage()
- func (x *UpdateConfigurationResponse) ProtoReflect() protoreflect.Message
- func (x *UpdateConfigurationResponse) Reset()
- func (x *UpdateConfigurationResponse) SetNames(v []string)
- func (x *UpdateConfigurationResponse) String() string
- type UpdateConfigurationResponse_builder
Constants ¶
This section is empty.
Variables ¶
var File_vitess_throttlerdata_dev_throttlerdata_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Configuration ¶
type Configuration struct {
// target_replication_lag_sec is the replication lag (in seconds) the
// MaxReplicationLagModule tries to aim for.
// If it is within the target, it tries to increase the throttler
// rate, otherwise it will lower it based on an educated guess of the
// replica's throughput.
TargetReplicationLagSec int64 `` /* 135-byte string literal not displayed */
// max_replication_lag_sec is meant as a last resort.
// By default, the module tries to find out the system maximum capacity while
// trying to keep the replication lag around "target_replication_lag_sec".
// Usually, we'll wait min_duration_between_(increases|decreases)_sec to see
// the effect of a throttler rate change on the replication lag.
// But if the lag goes above this field's value we will go into an "emergency"
// state and throttle more aggressively (see "emergency_decrease" below).
// This is the only way to ensure that the system will recover.
MaxReplicationLagSec int64 `` /* 126-byte string literal not displayed */
// initial_rate is the rate at which the module will start.
InitialRate int64 `protobuf:"varint,3,opt,name=initial_rate,json=initialRate,proto3" json:"initial_rate,omitempty"`
// max_increase defines by how much we will increase the rate
// e.g. 0.05 increases the rate by 5% while 1.0 by 100%.
// Note that any increase will let the system wait for at least
// (1 / MaxIncrease) seconds. If we wait for shorter periods of time, we
// won't notice if the rate increase also increases the replication lag.
// (If the system was already at its maximum capacity (e.g. 1k QPS) and we
// increase the rate by e.g. 5% to 1050 QPS, it will take 20 seconds until
// 1000 extra queries are buffered and the lag increases by 1 second.)
MaxIncrease float64 `protobuf:"fixed64,4,opt,name=max_increase,json=maxIncrease,proto3" json:"max_increase,omitempty"`
// emergency_decrease defines by how much we will decrease the current rate
// if the observed replication lag is above "max_replication_lag_sec".
// E.g. 0.50 decreases the current rate by 50%.
EmergencyDecrease float64 `protobuf:"fixed64,5,opt,name=emergency_decrease,json=emergencyDecrease,proto3" json:"emergency_decrease,omitempty"`
// min_duration_between_increases_sec specifies how long we'll wait at least
// for the last rate increase to have an effect on the system.
MinDurationBetweenIncreasesSec int64 `` /* 158-byte string literal not displayed */
// max_duration_between_increases_sec specifies how long we'll wait at most
// for the last rate increase to have an effect on the system.
MaxDurationBetweenIncreasesSec int64 `` /* 158-byte string literal not displayed */
// min_duration_between_decreases_sec specifies how long we'll wait at least
// for the last rate decrease to have an effect on the system.
MinDurationBetweenDecreasesSec int64 `` /* 158-byte string literal not displayed */
// spread_backlog_across_sec is used when we set the throttler rate after
// we guessed the rate of a replica and determined its backlog.
// For example, at a guessed rate of 100 QPS and a lag of 10s, the replica has
// a backlog of 1000 queries.
// When we set the new, decreased throttler rate, we factor in how long it
// will take the replica to go through the backlog (in addition to new
// requests). This field specifies over which timespan we plan to spread this.
// For example, for a backlog of 1000 queries spread over 5s means that we
// have to further reduce the rate by 200 QPS or the backlog will not be
// processed within the 5 seconds.
SpreadBacklogAcrossSec int64 `` /* 132-byte string literal not displayed */
// ignore_n_slowest_replicas will ignore replication lag updates from the
// N slowest REPLICA tablets. Under certain circumstances, replicas are still
// considered e.g. a) if the lag is at most max_replication_lag_sec, b) there
// are less than N+1 replicas or c) the lag increased on each replica such
// that all replicas were ignored in a row.
IgnoreNSlowestReplicas int32 `` /* 133-byte string literal not displayed */
// ignore_n_slowest_rdonlys does the same thing as ignore_n_slowest_replicas
// but for RDONLY tablets. Note that these two settings are independent.
IgnoreNSlowestRdonlys int32 `` /* 130-byte string literal not displayed */
// age_bad_rate_after_sec is the duration after which an unchanged bad rate
// will "age out" and increase by "bad_rate_increase".
// Bad rates are tracked by the code in memory.go and serve as an upper bound
// for future rate changes. This ensures that the adaptive throttler does not
// try known too high (bad) rates over and over again.
// To avoid that temporary degradations permanently reduce the maximum rate,
// a stable bad rate "ages out" after "age_bad_rate_after_sec".
AgeBadRateAfterSec int64 `protobuf:"varint,12,opt,name=age_bad_rate_after_sec,json=ageBadRateAfterSec,proto3" json:"age_bad_rate_after_sec,omitempty"`
// bad_rate_increase defines the percentage by which a bad rate will be
// increased when it's aging out.
BadRateIncrease float64 `protobuf:"fixed64,13,opt,name=bad_rate_increase,json=badRateIncrease,proto3" json:"bad_rate_increase,omitempty"`
// max_rate_approach_threshold is the fraction of the current rate limit that the actual
// rate must exceed for the throttler to increase the limit when the replication lag
// is below target_replication_lag_sec. For example, assuming the actual replication lag
// is below target_replication_lag_sec, if the current rate limit is 100, then the actual
// rate must exceed 100*max_rate_approach_threshold for the throttler to increase the current
// limit.
MaxRateApproachThreshold float64 `` /* 140-byte string literal not displayed */
// contains filtered or unexported fields
}
Configuration holds the configuration parameters for the MaxReplicationLagModule which adaptively adjusts the throttling rate based on the observed replication lag across all replicas.
func (*Configuration) GetAgeBadRateAfterSec ¶
func (x *Configuration) GetAgeBadRateAfterSec() int64
func (*Configuration) GetBadRateIncrease ¶
func (x *Configuration) GetBadRateIncrease() float64
func (*Configuration) GetEmergencyDecrease ¶
func (x *Configuration) GetEmergencyDecrease() float64
func (*Configuration) GetIgnoreNSlowestRdonlys ¶
func (x *Configuration) GetIgnoreNSlowestRdonlys() int32
func (*Configuration) GetIgnoreNSlowestReplicas ¶
func (x *Configuration) GetIgnoreNSlowestReplicas() int32
func (*Configuration) GetInitialRate ¶
func (x *Configuration) GetInitialRate() int64
func (*Configuration) GetMaxDurationBetweenIncreasesSec ¶
func (x *Configuration) GetMaxDurationBetweenIncreasesSec() int64
func (*Configuration) GetMaxIncrease ¶
func (x *Configuration) GetMaxIncrease() float64
func (*Configuration) GetMaxRateApproachThreshold ¶
func (x *Configuration) GetMaxRateApproachThreshold() float64
func (*Configuration) GetMaxReplicationLagSec ¶
func (x *Configuration) GetMaxReplicationLagSec() int64
func (*Configuration) GetMinDurationBetweenDecreasesSec ¶
func (x *Configuration) GetMinDurationBetweenDecreasesSec() int64
func (*Configuration) GetMinDurationBetweenIncreasesSec ¶
func (x *Configuration) GetMinDurationBetweenIncreasesSec() int64
func (*Configuration) GetSpreadBacklogAcrossSec ¶
func (x *Configuration) GetSpreadBacklogAcrossSec() int64
func (*Configuration) GetTargetReplicationLagSec ¶
func (x *Configuration) GetTargetReplicationLagSec() int64
func (*Configuration) ProtoMessage ¶
func (*Configuration) ProtoMessage()
func (*Configuration) ProtoReflect ¶
func (x *Configuration) ProtoReflect() protoreflect.Message
func (*Configuration) Reset ¶
func (x *Configuration) Reset()
func (*Configuration) SetAgeBadRateAfterSec ¶
func (x *Configuration) SetAgeBadRateAfterSec(v int64)
func (*Configuration) SetBadRateIncrease ¶
func (x *Configuration) SetBadRateIncrease(v float64)
func (*Configuration) SetEmergencyDecrease ¶
func (x *Configuration) SetEmergencyDecrease(v float64)
func (*Configuration) SetIgnoreNSlowestRdonlys ¶
func (x *Configuration) SetIgnoreNSlowestRdonlys(v int32)
func (*Configuration) SetIgnoreNSlowestReplicas ¶
func (x *Configuration) SetIgnoreNSlowestReplicas(v int32)
func (*Configuration) SetInitialRate ¶
func (x *Configuration) SetInitialRate(v int64)
func (*Configuration) SetMaxDurationBetweenIncreasesSec ¶
func (x *Configuration) SetMaxDurationBetweenIncreasesSec(v int64)
func (*Configuration) SetMaxIncrease ¶
func (x *Configuration) SetMaxIncrease(v float64)
func (*Configuration) SetMaxRateApproachThreshold ¶
func (x *Configuration) SetMaxRateApproachThreshold(v float64)
func (*Configuration) SetMaxReplicationLagSec ¶
func (x *Configuration) SetMaxReplicationLagSec(v int64)
func (*Configuration) SetMinDurationBetweenDecreasesSec ¶
func (x *Configuration) SetMinDurationBetweenDecreasesSec(v int64)
func (*Configuration) SetMinDurationBetweenIncreasesSec ¶
func (x *Configuration) SetMinDurationBetweenIncreasesSec(v int64)
func (*Configuration) SetSpreadBacklogAcrossSec ¶
func (x *Configuration) SetSpreadBacklogAcrossSec(v int64)
func (*Configuration) SetTargetReplicationLagSec ¶
func (x *Configuration) SetTargetReplicationLagSec(v int64)
func (*Configuration) String ¶
func (x *Configuration) String() string
type Configuration_builder ¶
type Configuration_builder struct {
// target_replication_lag_sec is the replication lag (in seconds) the
// MaxReplicationLagModule tries to aim for.
// If it is within the target, it tries to increase the throttler
// rate, otherwise it will lower it based on an educated guess of the
// replica's throughput.
TargetReplicationLagSec int64
// max_replication_lag_sec is meant as a last resort.
// By default, the module tries to find out the system maximum capacity while
// trying to keep the replication lag around "target_replication_lag_sec".
// Usually, we'll wait min_duration_between_(increases|decreases)_sec to see
// the effect of a throttler rate change on the replication lag.
// But if the lag goes above this field's value we will go into an "emergency"
// state and throttle more aggressively (see "emergency_decrease" below).
// This is the only way to ensure that the system will recover.
MaxReplicationLagSec int64
// initial_rate is the rate at which the module will start.
InitialRate int64
// max_increase defines by how much we will increase the rate
// e.g. 0.05 increases the rate by 5% while 1.0 by 100%.
// Note that any increase will let the system wait for at least
// (1 / MaxIncrease) seconds. If we wait for shorter periods of time, we
// won't notice if the rate increase also increases the replication lag.
// (If the system was already at its maximum capacity (e.g. 1k QPS) and we
// increase the rate by e.g. 5% to 1050 QPS, it will take 20 seconds until
// 1000 extra queries are buffered and the lag increases by 1 second.)
MaxIncrease float64
// emergency_decrease defines by how much we will decrease the current rate
// if the observed replication lag is above "max_replication_lag_sec".
// E.g. 0.50 decreases the current rate by 50%.
EmergencyDecrease float64
// min_duration_between_increases_sec specifies how long we'll wait at least
// for the last rate increase to have an effect on the system.
MinDurationBetweenIncreasesSec int64
// max_duration_between_increases_sec specifies how long we'll wait at most
// for the last rate increase to have an effect on the system.
MaxDurationBetweenIncreasesSec int64
// min_duration_between_decreases_sec specifies how long we'll wait at least
// for the last rate decrease to have an effect on the system.
MinDurationBetweenDecreasesSec int64
// spread_backlog_across_sec is used when we set the throttler rate after
// we guessed the rate of a replica and determined its backlog.
// For example, at a guessed rate of 100 QPS and a lag of 10s, the replica has
// a backlog of 1000 queries.
// When we set the new, decreased throttler rate, we factor in how long it
// will take the replica to go through the backlog (in addition to new
// requests). This field specifies over which timespan we plan to spread this.
// For example, for a backlog of 1000 queries spread over 5s means that we
// have to further reduce the rate by 200 QPS or the backlog will not be
// processed within the 5 seconds.
SpreadBacklogAcrossSec int64
// ignore_n_slowest_replicas will ignore replication lag updates from the
// N slowest REPLICA tablets. Under certain circumstances, replicas are still
// considered e.g. a) if the lag is at most max_replication_lag_sec, b) there
// are less than N+1 replicas or c) the lag increased on each replica such
// that all replicas were ignored in a row.
IgnoreNSlowestReplicas int32
// ignore_n_slowest_rdonlys does the same thing as ignore_n_slowest_replicas
// but for RDONLY tablets. Note that these two settings are independent.
IgnoreNSlowestRdonlys int32
// age_bad_rate_after_sec is the duration after which an unchanged bad rate
// will "age out" and increase by "bad_rate_increase".
// Bad rates are tracked by the code in memory.go and serve as an upper bound
// for future rate changes. This ensures that the adaptive throttler does not
// try known too high (bad) rates over and over again.
// To avoid that temporary degradations permanently reduce the maximum rate,
// a stable bad rate "ages out" after "age_bad_rate_after_sec".
AgeBadRateAfterSec int64
// bad_rate_increase defines the percentage by which a bad rate will be
// increased when it's aging out.
BadRateIncrease float64
// max_rate_approach_threshold is the fraction of the current rate limit that the actual
// rate must exceed for the throttler to increase the limit when the replication lag
// is below target_replication_lag_sec. For example, assuming the actual replication lag
// is below target_replication_lag_sec, if the current rate limit is 100, then the actual
// rate must exceed 100*max_rate_approach_threshold for the throttler to increase the current
// limit.
MaxRateApproachThreshold float64
// contains filtered or unexported fields
}
func (Configuration_builder) Build ¶
func (b0 Configuration_builder) Build() *Configuration
type GetConfigurationRequest ¶
type GetConfigurationRequest struct {
// throttler_name specifies which throttler to select. If empty, all active
// throttlers will be selected.
ThrottlerName string `protobuf:"bytes,1,opt,name=throttler_name,json=throttlerName,proto3" json:"throttler_name,omitempty"`
// contains filtered or unexported fields
}
GetConfigurationRequest is the payload for the GetConfiguration RPC.
func (*GetConfigurationRequest) GetThrottlerName ¶
func (x *GetConfigurationRequest) GetThrottlerName() string
func (*GetConfigurationRequest) ProtoMessage ¶
func (*GetConfigurationRequest) ProtoMessage()
func (*GetConfigurationRequest) ProtoReflect ¶
func (x *GetConfigurationRequest) ProtoReflect() protoreflect.Message
func (*GetConfigurationRequest) Reset ¶
func (x *GetConfigurationRequest) Reset()
func (*GetConfigurationRequest) SetThrottlerName ¶
func (x *GetConfigurationRequest) SetThrottlerName(v string)
func (*GetConfigurationRequest) String ¶
func (x *GetConfigurationRequest) String() string
type GetConfigurationRequest_builder ¶
type GetConfigurationRequest_builder struct {
// throttler_name specifies which throttler to select. If empty, all active
// throttlers will be selected.
ThrottlerName string
// contains filtered or unexported fields
}
func (GetConfigurationRequest_builder) Build ¶
func (b0 GetConfigurationRequest_builder) Build() *GetConfigurationRequest
type GetConfigurationResponse ¶
type GetConfigurationResponse struct {
// max_rates returns the configurations for each throttler.
// It's keyed by the throttler name.
Configurations map[string]*Configuration `` /* 155-byte string literal not displayed */
// contains filtered or unexported fields
}
GetConfigurationResponse is returned by the GetConfiguration RPC.
func (*GetConfigurationResponse) GetConfigurations ¶
func (x *GetConfigurationResponse) GetConfigurations() map[string]*Configuration
func (*GetConfigurationResponse) ProtoMessage ¶
func (*GetConfigurationResponse) ProtoMessage()
func (*GetConfigurationResponse) ProtoReflect ¶
func (x *GetConfigurationResponse) ProtoReflect() protoreflect.Message
func (*GetConfigurationResponse) Reset ¶
func (x *GetConfigurationResponse) Reset()
func (*GetConfigurationResponse) SetConfigurations ¶
func (x *GetConfigurationResponse) SetConfigurations(v map[string]*Configuration)
func (*GetConfigurationResponse) String ¶
func (x *GetConfigurationResponse) String() string
type GetConfigurationResponse_builder ¶
type GetConfigurationResponse_builder struct {
// max_rates returns the configurations for each throttler.
// It's keyed by the throttler name.
Configurations map[string]*Configuration
// contains filtered or unexported fields
}
func (GetConfigurationResponse_builder) Build ¶
func (b0 GetConfigurationResponse_builder) Build() *GetConfigurationResponse
type MaxRatesRequest ¶
type MaxRatesRequest struct {
// contains filtered or unexported fields
}
MaxRatesRequest is the payload for the MaxRates RPC.
func (*MaxRatesRequest) ProtoMessage ¶
func (*MaxRatesRequest) ProtoMessage()
func (*MaxRatesRequest) ProtoReflect ¶
func (x *MaxRatesRequest) ProtoReflect() protoreflect.Message
func (*MaxRatesRequest) Reset ¶
func (x *MaxRatesRequest) Reset()
func (*MaxRatesRequest) String ¶
func (x *MaxRatesRequest) String() string
type MaxRatesRequest_builder ¶
type MaxRatesRequest_builder struct {
// contains filtered or unexported fields
}
func (MaxRatesRequest_builder) Build ¶
func (b0 MaxRatesRequest_builder) Build() *MaxRatesRequest
type MaxRatesResponse ¶
type MaxRatesResponse struct {
// max_rates returns the max rate for each throttler. It's keyed by the
// throttler name.
Rates map[string]int64 `` /* 138-byte string literal not displayed */
// contains filtered or unexported fields
}
MaxRatesResponse is returned by the MaxRates RPC.
func (*MaxRatesResponse) GetRates ¶
func (x *MaxRatesResponse) GetRates() map[string]int64
func (*MaxRatesResponse) ProtoMessage ¶
func (*MaxRatesResponse) ProtoMessage()
func (*MaxRatesResponse) ProtoReflect ¶
func (x *MaxRatesResponse) ProtoReflect() protoreflect.Message
func (*MaxRatesResponse) Reset ¶
func (x *MaxRatesResponse) Reset()
func (*MaxRatesResponse) SetRates ¶
func (x *MaxRatesResponse) SetRates(v map[string]int64)
func (*MaxRatesResponse) String ¶
func (x *MaxRatesResponse) String() string
type MaxRatesResponse_builder ¶
type MaxRatesResponse_builder struct {
// max_rates returns the max rate for each throttler. It's keyed by the
// throttler name.
Rates map[string]int64
// contains filtered or unexported fields
}
func (MaxRatesResponse_builder) Build ¶
func (b0 MaxRatesResponse_builder) Build() *MaxRatesResponse
type ResetConfigurationRequest ¶
type ResetConfigurationRequest struct {
// throttler_name specifies which throttler to reset. If empty, all active
// throttlers will be reset.
ThrottlerName string `protobuf:"bytes,1,opt,name=throttler_name,json=throttlerName,proto3" json:"throttler_name,omitempty"`
// contains filtered or unexported fields
}
ResetConfigurationRequest is the payload for the ResetConfiguration RPC.
func (*ResetConfigurationRequest) GetThrottlerName ¶
func (x *ResetConfigurationRequest) GetThrottlerName() string
func (*ResetConfigurationRequest) ProtoMessage ¶
func (*ResetConfigurationRequest) ProtoMessage()
func (*ResetConfigurationRequest) ProtoReflect ¶
func (x *ResetConfigurationRequest) ProtoReflect() protoreflect.Message
func (*ResetConfigurationRequest) Reset ¶
func (x *ResetConfigurationRequest) Reset()
func (*ResetConfigurationRequest) SetThrottlerName ¶
func (x *ResetConfigurationRequest) SetThrottlerName(v string)
func (*ResetConfigurationRequest) String ¶
func (x *ResetConfigurationRequest) String() string
type ResetConfigurationRequest_builder ¶
type ResetConfigurationRequest_builder struct {
// throttler_name specifies which throttler to reset. If empty, all active
// throttlers will be reset.
ThrottlerName string
// contains filtered or unexported fields
}
func (ResetConfigurationRequest_builder) Build ¶
func (b0 ResetConfigurationRequest_builder) Build() *ResetConfigurationRequest
type ResetConfigurationResponse ¶
type ResetConfigurationResponse struct {
// names is the list of throttler names which were updated.
Names []string `protobuf:"bytes,1,rep,name=names,proto3" json:"names,omitempty"`
// contains filtered or unexported fields
}
ResetConfigurationResponse is returned by the ResetConfiguration RPC.
func (*ResetConfigurationResponse) GetNames ¶
func (x *ResetConfigurationResponse) GetNames() []string
func (*ResetConfigurationResponse) ProtoMessage ¶
func (*ResetConfigurationResponse) ProtoMessage()
func (*ResetConfigurationResponse) ProtoReflect ¶
func (x *ResetConfigurationResponse) ProtoReflect() protoreflect.Message
func (*ResetConfigurationResponse) Reset ¶
func (x *ResetConfigurationResponse) Reset()
func (*ResetConfigurationResponse) SetNames ¶
func (x *ResetConfigurationResponse) SetNames(v []string)
func (*ResetConfigurationResponse) String ¶
func (x *ResetConfigurationResponse) String() string
type ResetConfigurationResponse_builder ¶
type ResetConfigurationResponse_builder struct {
// names is the list of throttler names which were updated.
Names []string
// contains filtered or unexported fields
}
func (ResetConfigurationResponse_builder) Build ¶
func (b0 ResetConfigurationResponse_builder) Build() *ResetConfigurationResponse
type SetMaxRateRequest ¶
type SetMaxRateRequest struct {
Rate int64 `protobuf:"varint,1,opt,name=rate,proto3" json:"rate,omitempty"`
// contains filtered or unexported fields
}
SetMaxRateRequest is the payload for the SetMaxRate RPC.
func (*SetMaxRateRequest) GetRate ¶
func (x *SetMaxRateRequest) GetRate() int64
func (*SetMaxRateRequest) ProtoMessage ¶
func (*SetMaxRateRequest) ProtoMessage()
func (*SetMaxRateRequest) ProtoReflect ¶
func (x *SetMaxRateRequest) ProtoReflect() protoreflect.Message
func (*SetMaxRateRequest) Reset ¶
func (x *SetMaxRateRequest) Reset()
func (*SetMaxRateRequest) SetRate ¶
func (x *SetMaxRateRequest) SetRate(v int64)
func (*SetMaxRateRequest) String ¶
func (x *SetMaxRateRequest) String() string
type SetMaxRateRequest_builder ¶
type SetMaxRateRequest_builder struct {
Rate int64
// contains filtered or unexported fields
}
func (SetMaxRateRequest_builder) Build ¶
func (b0 SetMaxRateRequest_builder) Build() *SetMaxRateRequest
type SetMaxRateResponse ¶
type SetMaxRateResponse struct {
// names is the list of throttler names which were updated.
Names []string `protobuf:"bytes,1,rep,name=names,proto3" json:"names,omitempty"`
// contains filtered or unexported fields
}
SetMaxRateResponse is returned by the SetMaxRate RPC.
func (*SetMaxRateResponse) GetNames ¶
func (x *SetMaxRateResponse) GetNames() []string
func (*SetMaxRateResponse) ProtoMessage ¶
func (*SetMaxRateResponse) ProtoMessage()
func (*SetMaxRateResponse) ProtoReflect ¶
func (x *SetMaxRateResponse) ProtoReflect() protoreflect.Message
func (*SetMaxRateResponse) Reset ¶
func (x *SetMaxRateResponse) Reset()
func (*SetMaxRateResponse) SetNames ¶
func (x *SetMaxRateResponse) SetNames(v []string)
func (*SetMaxRateResponse) String ¶
func (x *SetMaxRateResponse) String() string
type SetMaxRateResponse_builder ¶
type SetMaxRateResponse_builder struct {
// names is the list of throttler names which were updated.
Names []string
// contains filtered or unexported fields
}
func (SetMaxRateResponse_builder) Build ¶
func (b0 SetMaxRateResponse_builder) Build() *SetMaxRateResponse
type UpdateConfigurationRequest ¶
type UpdateConfigurationRequest struct {
// throttler_name specifies which throttler to update. If empty, all active
// throttlers will be updated.
ThrottlerName string `protobuf:"bytes,1,opt,name=throttler_name,json=throttlerName,proto3" json:"throttler_name,omitempty"`
// configuration is the new (partial) configuration.
Configuration *Configuration `protobuf:"bytes,2,opt,name=configuration,proto3" json:"configuration,omitempty"`
// copy_zero_values specifies whether fields with zero values should be copied
// as well.
CopyZeroValues bool `protobuf:"varint,3,opt,name=copy_zero_values,json=copyZeroValues,proto3" json:"copy_zero_values,omitempty"`
// contains filtered or unexported fields
}
UpdateConfigurationRequest is the payload for the UpdateConfiguration RPC.
func (*UpdateConfigurationRequest) ClearConfiguration ¶
func (x *UpdateConfigurationRequest) ClearConfiguration()
func (*UpdateConfigurationRequest) GetConfiguration ¶
func (x *UpdateConfigurationRequest) GetConfiguration() *Configuration
func (*UpdateConfigurationRequest) GetCopyZeroValues ¶
func (x *UpdateConfigurationRequest) GetCopyZeroValues() bool
func (*UpdateConfigurationRequest) GetThrottlerName ¶
func (x *UpdateConfigurationRequest) GetThrottlerName() string
func (*UpdateConfigurationRequest) HasConfiguration ¶
func (x *UpdateConfigurationRequest) HasConfiguration() bool
func (*UpdateConfigurationRequest) ProtoMessage ¶
func (*UpdateConfigurationRequest) ProtoMessage()
func (*UpdateConfigurationRequest) ProtoReflect ¶
func (x *UpdateConfigurationRequest) ProtoReflect() protoreflect.Message
func (*UpdateConfigurationRequest) Reset ¶
func (x *UpdateConfigurationRequest) Reset()
func (*UpdateConfigurationRequest) SetConfiguration ¶
func (x *UpdateConfigurationRequest) SetConfiguration(v *Configuration)
func (*UpdateConfigurationRequest) SetCopyZeroValues ¶
func (x *UpdateConfigurationRequest) SetCopyZeroValues(v bool)
func (*UpdateConfigurationRequest) SetThrottlerName ¶
func (x *UpdateConfigurationRequest) SetThrottlerName(v string)
func (*UpdateConfigurationRequest) String ¶
func (x *UpdateConfigurationRequest) String() string
type UpdateConfigurationRequest_builder ¶
type UpdateConfigurationRequest_builder struct {
// throttler_name specifies which throttler to update. If empty, all active
// throttlers will be updated.
ThrottlerName string
// configuration is the new (partial) configuration.
Configuration *Configuration
// copy_zero_values specifies whether fields with zero values should be copied
// as well.
CopyZeroValues bool
// contains filtered or unexported fields
}
func (UpdateConfigurationRequest_builder) Build ¶
func (b0 UpdateConfigurationRequest_builder) Build() *UpdateConfigurationRequest
type UpdateConfigurationResponse ¶
type UpdateConfigurationResponse struct {
// names is the list of throttler names which were updated.
Names []string `protobuf:"bytes,1,rep,name=names,proto3" json:"names,omitempty"`
// contains filtered or unexported fields
}
UpdateConfigurationResponse is returned by the UpdateConfiguration RPC.
func (*UpdateConfigurationResponse) GetNames ¶
func (x *UpdateConfigurationResponse) GetNames() []string
func (*UpdateConfigurationResponse) ProtoMessage ¶
func (*UpdateConfigurationResponse) ProtoMessage()
func (*UpdateConfigurationResponse) ProtoReflect ¶
func (x *UpdateConfigurationResponse) ProtoReflect() protoreflect.Message
func (*UpdateConfigurationResponse) Reset ¶
func (x *UpdateConfigurationResponse) Reset()
func (*UpdateConfigurationResponse) SetNames ¶
func (x *UpdateConfigurationResponse) SetNames(v []string)
func (*UpdateConfigurationResponse) String ¶
func (x *UpdateConfigurationResponse) String() string
type UpdateConfigurationResponse_builder ¶
type UpdateConfigurationResponse_builder struct {
// names is the list of throttler names which were updated.
Names []string
// contains filtered or unexported fields
}
func (UpdateConfigurationResponse_builder) Build ¶
func (b0 UpdateConfigurationResponse_builder) Build() *UpdateConfigurationResponse
Source Files
¶
- throttlerdata.pb.go