dev

package
v1.36.12-2026041419212... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var File_vitess_vttest_dev_vttest_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type Keyspace

type Keyspace struct {

	// name has to be unique in a VTTestTopology.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// shards inside this keyspace. Ignored if redirect is set.
	Shards []*Shard `protobuf:"bytes,2,rep,name=shards,proto3" json:"shards,omitempty"`
	// number of replica tablets to instantiate. This includes the primary tablet.
	ReplicaCount int32 `protobuf:"varint,6,opt,name=replica_count,json=replicaCount,proto3" json:"replica_count,omitempty"`
	// number of rdonly tablets to instantiate.
	RdonlyCount int32 `protobuf:"varint,7,opt,name=rdonly_count,json=rdonlyCount,proto3" json:"rdonly_count,omitempty"`
	// contains filtered or unexported fields
}

Keyspace describes a single keyspace.

func (*Keyspace) GetName

func (x *Keyspace) GetName() string

func (*Keyspace) GetRdonlyCount

func (x *Keyspace) GetRdonlyCount() int32

func (*Keyspace) GetReplicaCount

func (x *Keyspace) GetReplicaCount() int32

func (*Keyspace) GetShards

func (x *Keyspace) GetShards() []*Shard

func (*Keyspace) ProtoMessage

func (*Keyspace) ProtoMessage()

func (*Keyspace) ProtoReflect

func (x *Keyspace) ProtoReflect() protoreflect.Message

func (*Keyspace) Reset

func (x *Keyspace) Reset()

func (*Keyspace) SetName

func (x *Keyspace) SetName(v string)

func (*Keyspace) SetRdonlyCount

func (x *Keyspace) SetRdonlyCount(v int32)

func (*Keyspace) SetReplicaCount

func (x *Keyspace) SetReplicaCount(v int32)

func (*Keyspace) SetShards

func (x *Keyspace) SetShards(v []*Shard)

func (*Keyspace) String

func (x *Keyspace) String() string

type Keyspace_builder

type Keyspace_builder struct {

	// name has to be unique in a VTTestTopology.
	Name string
	// shards inside this keyspace. Ignored if redirect is set.
	Shards []*Shard
	// number of replica tablets to instantiate. This includes the primary tablet.
	ReplicaCount int32
	// number of rdonly tablets to instantiate.
	RdonlyCount int32
	// contains filtered or unexported fields
}

func (Keyspace_builder) Build

func (b0 Keyspace_builder) Build() *Keyspace

type Shard

type Shard struct {

	// name has to be unique in a keyspace. For unsharded keyspaces, it
	// should be '0'. For sharded keyspace, it should be derived from
	// the keyrange, like '-80' or '40-80'.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// db_name_override is the mysql db name for this shard. Has to be
	// globally unique. If not specified, we will by default use
	// 'vt_<keyspace>_<shard>'.
	DbNameOverride string `protobuf:"bytes,2,opt,name=db_name_override,json=dbNameOverride,proto3" json:"db_name_override,omitempty"`
	// contains filtered or unexported fields
}

Shard describes a single shard in a keyspace.

func (*Shard) GetDbNameOverride

func (x *Shard) GetDbNameOverride() string

func (*Shard) GetName

func (x *Shard) GetName() string

func (*Shard) ProtoMessage

func (*Shard) ProtoMessage()

func (*Shard) ProtoReflect

func (x *Shard) ProtoReflect() protoreflect.Message

func (*Shard) Reset

func (x *Shard) Reset()

func (*Shard) SetDbNameOverride

func (x *Shard) SetDbNameOverride(v string)

func (*Shard) SetName

func (x *Shard) SetName(v string)

func (*Shard) String

func (x *Shard) String() string

type Shard_builder

type Shard_builder struct {

	// name has to be unique in a keyspace. For unsharded keyspaces, it
	// should be '0'. For sharded keyspace, it should be derived from
	// the keyrange, like '-80' or '40-80'.
	Name string
	// db_name_override is the mysql db name for this shard. Has to be
	// globally unique. If not specified, we will by default use
	// 'vt_<keyspace>_<shard>'.
	DbNameOverride string
	// contains filtered or unexported fields
}

func (Shard_builder) Build

func (b0 Shard_builder) Build() *Shard

type VTTestTopology

type VTTestTopology struct {

	// all keyspaces in the topology.
	Keyspaces []*Keyspace `protobuf:"bytes,1,rep,name=keyspaces,proto3" json:"keyspaces,omitempty"`
	// list of cells the keyspaces reside in. Vtgate is started in only the first cell.
	Cells []string `protobuf:"bytes,2,rep,name=cells,proto3" json:"cells,omitempty"`
	// routing rules for the topology.
	RoutingRules *dev.RoutingRules `protobuf:"bytes,3,opt,name=routing_rules,json=routingRules,proto3" json:"routing_rules,omitempty"`
	// mirror rules for the topology.
	MirrorRules *dev.MirrorRules `protobuf:"bytes,4,opt,name=mirror_rules,json=mirrorRules,proto3" json:"mirror_rules,omitempty"`
	// contains filtered or unexported fields
}

VTTestTopology describes the keyspaces in the topology.

func (*VTTestTopology) ClearMirrorRules

func (x *VTTestTopology) ClearMirrorRules()

func (*VTTestTopology) ClearRoutingRules

func (x *VTTestTopology) ClearRoutingRules()

func (*VTTestTopology) GetCells

func (x *VTTestTopology) GetCells() []string

func (*VTTestTopology) GetKeyspaces

func (x *VTTestTopology) GetKeyspaces() []*Keyspace

func (*VTTestTopology) GetMirrorRules

func (x *VTTestTopology) GetMirrorRules() *dev.MirrorRules

func (*VTTestTopology) GetRoutingRules

func (x *VTTestTopology) GetRoutingRules() *dev.RoutingRules

func (*VTTestTopology) HasMirrorRules

func (x *VTTestTopology) HasMirrorRules() bool

func (*VTTestTopology) HasRoutingRules

func (x *VTTestTopology) HasRoutingRules() bool

func (*VTTestTopology) ProtoMessage

func (*VTTestTopology) ProtoMessage()

func (*VTTestTopology) ProtoReflect

func (x *VTTestTopology) ProtoReflect() protoreflect.Message

func (*VTTestTopology) Reset

func (x *VTTestTopology) Reset()

func (*VTTestTopology) SetCells

func (x *VTTestTopology) SetCells(v []string)

func (*VTTestTopology) SetKeyspaces

func (x *VTTestTopology) SetKeyspaces(v []*Keyspace)

func (*VTTestTopology) SetMirrorRules

func (x *VTTestTopology) SetMirrorRules(v *dev.MirrorRules)

func (*VTTestTopology) SetRoutingRules

func (x *VTTestTopology) SetRoutingRules(v *dev.RoutingRules)

func (*VTTestTopology) String

func (x *VTTestTopology) String() string

type VTTestTopology_builder

type VTTestTopology_builder struct {

	// all keyspaces in the topology.
	Keyspaces []*Keyspace
	// list of cells the keyspaces reside in. Vtgate is started in only the first cell.
	Cells []string
	// routing rules for the topology.
	RoutingRules *dev.RoutingRules
	// mirror rules for the topology.
	MirrorRules *dev.MirrorRules
	// contains filtered or unexported fields
}

func (VTTestTopology_builder) Build

Source Files

  • vttest.pb.go

Jump to