client

package
v1.36.11-2024061717285... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 5 Imported by: 3

Documentation

Index

Constants

This section is empty.

Variables

var (
	MetricType_name = map[int32]string{
		0: "COUNTER",
		1: "GAUGE",
		2: "SUMMARY",
		3: "UNTYPED",
		4: "HISTOGRAM",
		5: "GAUGE_HISTOGRAM",
	}
	MetricType_value = map[string]int32{
		"COUNTER":         0,
		"GAUGE":           1,
		"SUMMARY":         2,
		"UNTYPED":         3,
		"HISTOGRAM":       4,
		"GAUGE_HISTOGRAM": 5,
	}
)

Enum value maps for MetricType.

var File_io_prometheus_client_metrics_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type Bucket

type Bucket struct {
	CumulativeCount      *uint64   `protobuf:"varint,1,opt,name=cumulative_count,json=cumulativeCount" json:"cumulative_count,omitempty"`                   // Cumulative in increasing order.
	CumulativeCountFloat *float64  `protobuf:"fixed64,4,opt,name=cumulative_count_float,json=cumulativeCountFloat" json:"cumulative_count_float,omitempty"` // Overrides cumulative_count if > 0.
	UpperBound           *float64  `protobuf:"fixed64,2,opt,name=upper_bound,json=upperBound" json:"upper_bound,omitempty"`                                 // Inclusive.
	Exemplar             *Exemplar `protobuf:"bytes,3,opt,name=exemplar" json:"exemplar,omitempty"`
	// contains filtered or unexported fields
}

A Bucket of a conventional histogram, each of which is treated as an individual counter-like time series by Prometheus.

func (*Bucket) ClearCumulativeCount

func (x *Bucket) ClearCumulativeCount()

func (*Bucket) ClearCumulativeCountFloat

func (x *Bucket) ClearCumulativeCountFloat()

func (*Bucket) ClearExemplar

func (x *Bucket) ClearExemplar()

func (*Bucket) ClearUpperBound

func (x *Bucket) ClearUpperBound()

func (*Bucket) GetCumulativeCount

func (x *Bucket) GetCumulativeCount() uint64

func (*Bucket) GetCumulativeCountFloat

func (x *Bucket) GetCumulativeCountFloat() float64

func (*Bucket) GetExemplar

func (x *Bucket) GetExemplar() *Exemplar

func (*Bucket) GetUpperBound

func (x *Bucket) GetUpperBound() float64

func (*Bucket) HasCumulativeCount

func (x *Bucket) HasCumulativeCount() bool

func (*Bucket) HasCumulativeCountFloat

func (x *Bucket) HasCumulativeCountFloat() bool

func (*Bucket) HasExemplar

func (x *Bucket) HasExemplar() bool

func (*Bucket) HasUpperBound

func (x *Bucket) HasUpperBound() bool

func (*Bucket) ProtoMessage

func (*Bucket) ProtoMessage()

func (*Bucket) ProtoReflect

func (x *Bucket) ProtoReflect() protoreflect.Message

func (*Bucket) Reset

func (x *Bucket) Reset()

func (*Bucket) SetCumulativeCount

func (x *Bucket) SetCumulativeCount(v uint64)

func (*Bucket) SetCumulativeCountFloat

func (x *Bucket) SetCumulativeCountFloat(v float64)

func (*Bucket) SetExemplar

func (x *Bucket) SetExemplar(v *Exemplar)

func (*Bucket) SetUpperBound

func (x *Bucket) SetUpperBound(v float64)

func (*Bucket) String

func (x *Bucket) String() string

type BucketSpan

type BucketSpan struct {
	Offset *int32  `protobuf:"zigzag32,1,opt,name=offset" json:"offset,omitempty"` // Gap to previous span, or starting point for 1st span (which can be negative).
	Length *uint32 `protobuf:"varint,2,opt,name=length" json:"length,omitempty"`   // Length of consecutive buckets.
	// contains filtered or unexported fields
}

A BucketSpan defines a number of consecutive buckets in a native histogram with their offset. Logically, it would be more straightforward to include the bucket counts in the Span. However, the protobuf representation is more compact in the way the data is structured here (with all the buckets in a single array separate from the Spans).

func (*BucketSpan) ClearLength

func (x *BucketSpan) ClearLength()

func (*BucketSpan) ClearOffset

func (x *BucketSpan) ClearOffset()

func (*BucketSpan) GetLength

func (x *BucketSpan) GetLength() uint32

func (*BucketSpan) GetOffset

func (x *BucketSpan) GetOffset() int32

func (*BucketSpan) HasLength

func (x *BucketSpan) HasLength() bool

func (*BucketSpan) HasOffset

func (x *BucketSpan) HasOffset() bool

func (*BucketSpan) ProtoMessage

func (*BucketSpan) ProtoMessage()

func (*BucketSpan) ProtoReflect

func (x *BucketSpan) ProtoReflect() protoreflect.Message

func (*BucketSpan) Reset

func (x *BucketSpan) Reset()

func (*BucketSpan) SetLength

func (x *BucketSpan) SetLength(v uint32)

func (*BucketSpan) SetOffset

func (x *BucketSpan) SetOffset(v int32)

func (*BucketSpan) String

func (x *BucketSpan) String() string

type BucketSpan_builder

type BucketSpan_builder struct {
	Offset *int32
	Length *uint32
	// contains filtered or unexported fields
}

func (BucketSpan_builder) Build

func (b0 BucketSpan_builder) Build() *BucketSpan

type Bucket_builder

type Bucket_builder struct {
	CumulativeCount      *uint64
	CumulativeCountFloat *float64
	UpperBound           *float64
	Exemplar             *Exemplar
	// contains filtered or unexported fields
}

func (Bucket_builder) Build

func (b0 Bucket_builder) Build() *Bucket

type Counter

type Counter struct {
	Value            *float64               `protobuf:"fixed64,1,opt,name=value" json:"value,omitempty"`
	Exemplar         *Exemplar              `protobuf:"bytes,2,opt,name=exemplar" json:"exemplar,omitempty"`
	CreatedTimestamp *timestamppb.Timestamp `protobuf:"bytes,3,opt,name=created_timestamp,json=createdTimestamp" json:"created_timestamp,omitempty"`
	// contains filtered or unexported fields
}

func (*Counter) ClearCreatedTimestamp

func (x *Counter) ClearCreatedTimestamp()

func (*Counter) ClearExemplar

func (x *Counter) ClearExemplar()

func (*Counter) ClearValue

func (x *Counter) ClearValue()

func (*Counter) GetCreatedTimestamp

func (x *Counter) GetCreatedTimestamp() *timestamppb.Timestamp

func (*Counter) GetExemplar

func (x *Counter) GetExemplar() *Exemplar

func (*Counter) GetValue

func (x *Counter) GetValue() float64

func (*Counter) HasCreatedTimestamp

func (x *Counter) HasCreatedTimestamp() bool

func (*Counter) HasExemplar

func (x *Counter) HasExemplar() bool

func (*Counter) HasValue

func (x *Counter) HasValue() bool

func (*Counter) ProtoMessage

func (*Counter) ProtoMessage()

func (*Counter) ProtoReflect

func (x *Counter) ProtoReflect() protoreflect.Message

func (*Counter) Reset

func (x *Counter) Reset()

func (*Counter) SetCreatedTimestamp

func (x *Counter) SetCreatedTimestamp(v *timestamppb.Timestamp)

func (*Counter) SetExemplar

func (x *Counter) SetExemplar(v *Exemplar)

func (*Counter) SetValue

func (x *Counter) SetValue(v float64)

func (*Counter) String

func (x *Counter) String() string

type Counter_builder

type Counter_builder struct {
	Value            *float64
	Exemplar         *Exemplar
	CreatedTimestamp *timestamppb.Timestamp
	// contains filtered or unexported fields
}

func (Counter_builder) Build

func (b0 Counter_builder) Build() *Counter

type Exemplar

type Exemplar struct {
	Label     []*LabelPair           `protobuf:"bytes,1,rep,name=label" json:"label,omitempty"`
	Value     *float64               `protobuf:"fixed64,2,opt,name=value" json:"value,omitempty"`
	Timestamp *timestamppb.Timestamp `protobuf:"bytes,3,opt,name=timestamp" json:"timestamp,omitempty"` // OpenMetrics-style.
	// contains filtered or unexported fields
}

func (*Exemplar) ClearTimestamp

func (x *Exemplar) ClearTimestamp()

func (*Exemplar) ClearValue

func (x *Exemplar) ClearValue()

func (*Exemplar) GetLabel

func (x *Exemplar) GetLabel() []*LabelPair

func (*Exemplar) GetTimestamp

func (x *Exemplar) GetTimestamp() *timestamppb.Timestamp

func (*Exemplar) GetValue

func (x *Exemplar) GetValue() float64

func (*Exemplar) HasTimestamp

func (x *Exemplar) HasTimestamp() bool

func (*Exemplar) HasValue

func (x *Exemplar) HasValue() bool

func (*Exemplar) ProtoMessage

func (*Exemplar) ProtoMessage()

func (*Exemplar) ProtoReflect

func (x *Exemplar) ProtoReflect() protoreflect.Message

func (*Exemplar) Reset

func (x *Exemplar) Reset()

func (*Exemplar) SetLabel

func (x *Exemplar) SetLabel(v []*LabelPair)

func (*Exemplar) SetTimestamp

func (x *Exemplar) SetTimestamp(v *timestamppb.Timestamp)

func (*Exemplar) SetValue

func (x *Exemplar) SetValue(v float64)

func (*Exemplar) String

func (x *Exemplar) String() string

type Exemplar_builder

type Exemplar_builder struct {
	Label     []*LabelPair
	Value     *float64
	Timestamp *timestamppb.Timestamp
	// contains filtered or unexported fields
}

func (Exemplar_builder) Build

func (b0 Exemplar_builder) Build() *Exemplar

type Gauge

type Gauge struct {
	Value *float64 `protobuf:"fixed64,1,opt,name=value" json:"value,omitempty"`
	// contains filtered or unexported fields
}

func (*Gauge) ClearValue

func (x *Gauge) ClearValue()

func (*Gauge) GetValue

func (x *Gauge) GetValue() float64

func (*Gauge) HasValue

func (x *Gauge) HasValue() bool

func (*Gauge) ProtoMessage

func (*Gauge) ProtoMessage()

func (*Gauge) ProtoReflect

func (x *Gauge) ProtoReflect() protoreflect.Message

func (*Gauge) Reset

func (x *Gauge) Reset()

func (*Gauge) SetValue

func (x *Gauge) SetValue(v float64)

func (*Gauge) String

func (x *Gauge) String() string

type Gauge_builder

type Gauge_builder struct {
	Value *float64
	// contains filtered or unexported fields
}

func (Gauge_builder) Build

func (b0 Gauge_builder) Build() *Gauge

type Histogram

type Histogram struct {
	SampleCount      *uint64  `protobuf:"varint,1,opt,name=sample_count,json=sampleCount" json:"sample_count,omitempty"`
	SampleCountFloat *float64 `protobuf:"fixed64,4,opt,name=sample_count_float,json=sampleCountFloat" json:"sample_count_float,omitempty"` // Overrides sample_count if > 0.
	SampleSum        *float64 `protobuf:"fixed64,2,opt,name=sample_sum,json=sampleSum" json:"sample_sum,omitempty"`
	// Buckets for the conventional histogram.
	Bucket           []*Bucket              `protobuf:"bytes,3,rep,name=bucket" json:"bucket,omitempty"` // Ordered in increasing order of upper_bound, +Inf bucket is optional.
	CreatedTimestamp *timestamppb.Timestamp `protobuf:"bytes,15,opt,name=created_timestamp,json=createdTimestamp" json:"created_timestamp,omitempty"`
	// schema defines the bucket schema. Currently, valid numbers are -4 <= n <= 8.
	// They are all for base-2 bucket schemas, where 1 is a bucket boundary in each case, and
	// then each power of two is divided into 2^n logarithmic buckets.
	// Or in other words, each bucket boundary is the previous boundary times 2^(2^-n).
	// In the future, more bucket schemas may be added using numbers < -4 or > 8.
	Schema         *int32   `protobuf:"zigzag32,5,opt,name=schema" json:"schema,omitempty"`
	ZeroThreshold  *float64 `protobuf:"fixed64,6,opt,name=zero_threshold,json=zeroThreshold" json:"zero_threshold,omitempty"`      // Breadth of the zero bucket.
	ZeroCount      *uint64  `protobuf:"varint,7,opt,name=zero_count,json=zeroCount" json:"zero_count,omitempty"`                   // Count in zero bucket.
	ZeroCountFloat *float64 `protobuf:"fixed64,8,opt,name=zero_count_float,json=zeroCountFloat" json:"zero_count_float,omitempty"` // Overrides sb_zero_count if > 0.
	// Negative buckets for the native histogram.
	NegativeSpan []*BucketSpan `protobuf:"bytes,9,rep,name=negative_span,json=negativeSpan" json:"negative_span,omitempty"`
	// Use either "negative_delta" or "negative_count", the former for
	// regular histograms with integer counts, the latter for float
	// histograms.
	NegativeDelta []int64   `protobuf:"zigzag64,10,rep,name=negative_delta,json=negativeDelta" json:"negative_delta,omitempty"` // Count delta of each bucket compared to previous one (or to zero for 1st bucket).
	NegativeCount []float64 `protobuf:"fixed64,11,rep,name=negative_count,json=negativeCount" json:"negative_count,omitempty"`  // Absolute count of each bucket.
	// Positive buckets for the native histogram.
	// Use a no-op span (offset 0, length 0) for a native histogram without any
	// observations yet and with a zero_threshold of 0. Otherwise, it would be
	// indistinguishable from a classic histogram.
	PositiveSpan []*BucketSpan `protobuf:"bytes,12,rep,name=positive_span,json=positiveSpan" json:"positive_span,omitempty"`
	// Use either "positive_delta" or "positive_count", the former for
	// regular histograms with integer counts, the latter for float
	// histograms.
	PositiveDelta []int64   `protobuf:"zigzag64,13,rep,name=positive_delta,json=positiveDelta" json:"positive_delta,omitempty"` // Count delta of each bucket compared to previous one (or to zero for 1st bucket).
	PositiveCount []float64 `protobuf:"fixed64,14,rep,name=positive_count,json=positiveCount" json:"positive_count,omitempty"`  // Absolute count of each bucket.
	// Only used for native histograms. These exemplars MUST have a timestamp.
	Exemplars []*Exemplar `protobuf:"bytes,16,rep,name=exemplars" json:"exemplars,omitempty"`
	// contains filtered or unexported fields
}

func (*Histogram) ClearCreatedTimestamp

func (x *Histogram) ClearCreatedTimestamp()

func (*Histogram) ClearSampleCount

func (x *Histogram) ClearSampleCount()

func (*Histogram) ClearSampleCountFloat

func (x *Histogram) ClearSampleCountFloat()

func (*Histogram) ClearSampleSum

func (x *Histogram) ClearSampleSum()

func (*Histogram) ClearSchema

func (x *Histogram) ClearSchema()

func (*Histogram) ClearZeroCount

func (x *Histogram) ClearZeroCount()

func (*Histogram) ClearZeroCountFloat

func (x *Histogram) ClearZeroCountFloat()

func (*Histogram) ClearZeroThreshold

func (x *Histogram) ClearZeroThreshold()

func (*Histogram) GetBucket

func (x *Histogram) GetBucket() []*Bucket

func (*Histogram) GetCreatedTimestamp

func (x *Histogram) GetCreatedTimestamp() *timestamppb.Timestamp

func (*Histogram) GetExemplars

func (x *Histogram) GetExemplars() []*Exemplar

func (*Histogram) GetNegativeCount

func (x *Histogram) GetNegativeCount() []float64

func (*Histogram) GetNegativeDelta

func (x *Histogram) GetNegativeDelta() []int64

func (*Histogram) GetNegativeSpan

func (x *Histogram) GetNegativeSpan() []*BucketSpan

func (*Histogram) GetPositiveCount

func (x *Histogram) GetPositiveCount() []float64

func (*Histogram) GetPositiveDelta

func (x *Histogram) GetPositiveDelta() []int64

func (*Histogram) GetPositiveSpan

func (x *Histogram) GetPositiveSpan() []*BucketSpan

func (*Histogram) GetSampleCount

func (x *Histogram) GetSampleCount() uint64

func (*Histogram) GetSampleCountFloat

func (x *Histogram) GetSampleCountFloat() float64

func (*Histogram) GetSampleSum

func (x *Histogram) GetSampleSum() float64

func (*Histogram) GetSchema

func (x *Histogram) GetSchema() int32

func (*Histogram) GetZeroCount

func (x *Histogram) GetZeroCount() uint64

func (*Histogram) GetZeroCountFloat

func (x *Histogram) GetZeroCountFloat() float64

func (*Histogram) GetZeroThreshold

func (x *Histogram) GetZeroThreshold() float64

func (*Histogram) HasCreatedTimestamp

func (x *Histogram) HasCreatedTimestamp() bool

func (*Histogram) HasSampleCount

func (x *Histogram) HasSampleCount() bool

func (*Histogram) HasSampleCountFloat

func (x *Histogram) HasSampleCountFloat() bool

func (*Histogram) HasSampleSum

func (x *Histogram) HasSampleSum() bool

func (*Histogram) HasSchema

func (x *Histogram) HasSchema() bool

func (*Histogram) HasZeroCount

func (x *Histogram) HasZeroCount() bool

func (*Histogram) HasZeroCountFloat

func (x *Histogram) HasZeroCountFloat() bool

func (*Histogram) HasZeroThreshold

func (x *Histogram) HasZeroThreshold() bool

func (*Histogram) ProtoMessage

func (*Histogram) ProtoMessage()

func (*Histogram) ProtoReflect

func (x *Histogram) ProtoReflect() protoreflect.Message

func (*Histogram) Reset

func (x *Histogram) Reset()

func (*Histogram) SetBucket

func (x *Histogram) SetBucket(v []*Bucket)

func (*Histogram) SetCreatedTimestamp

func (x *Histogram) SetCreatedTimestamp(v *timestamppb.Timestamp)

func (*Histogram) SetExemplars

func (x *Histogram) SetExemplars(v []*Exemplar)

func (*Histogram) SetNegativeCount

func (x *Histogram) SetNegativeCount(v []float64)

func (*Histogram) SetNegativeDelta

func (x *Histogram) SetNegativeDelta(v []int64)

func (*Histogram) SetNegativeSpan

func (x *Histogram) SetNegativeSpan(v []*BucketSpan)

func (*Histogram) SetPositiveCount

func (x *Histogram) SetPositiveCount(v []float64)

func (*Histogram) SetPositiveDelta

func (x *Histogram) SetPositiveDelta(v []int64)

func (*Histogram) SetPositiveSpan

func (x *Histogram) SetPositiveSpan(v []*BucketSpan)

func (*Histogram) SetSampleCount

func (x *Histogram) SetSampleCount(v uint64)

func (*Histogram) SetSampleCountFloat

func (x *Histogram) SetSampleCountFloat(v float64)

func (*Histogram) SetSampleSum

func (x *Histogram) SetSampleSum(v float64)

func (*Histogram) SetSchema

func (x *Histogram) SetSchema(v int32)

func (*Histogram) SetZeroCount

func (x *Histogram) SetZeroCount(v uint64)

func (*Histogram) SetZeroCountFloat

func (x *Histogram) SetZeroCountFloat(v float64)

func (*Histogram) SetZeroThreshold

func (x *Histogram) SetZeroThreshold(v float64)

func (*Histogram) String

func (x *Histogram) String() string

type Histogram_builder

type Histogram_builder struct {
	SampleCount      *uint64
	SampleCountFloat *float64
	SampleSum        *float64
	// Buckets for the conventional histogram.
	Bucket           []*Bucket
	CreatedTimestamp *timestamppb.Timestamp
	// schema defines the bucket schema. Currently, valid numbers are -4 <= n <= 8.
	// They are all for base-2 bucket schemas, where 1 is a bucket boundary in each case, and
	// then each power of two is divided into 2^n logarithmic buckets.
	// Or in other words, each bucket boundary is the previous boundary times 2^(2^-n).
	// In the future, more bucket schemas may be added using numbers < -4 or > 8.
	Schema         *int32
	ZeroThreshold  *float64
	ZeroCount      *uint64
	ZeroCountFloat *float64
	// Negative buckets for the native histogram.
	NegativeSpan []*BucketSpan
	// Use either "negative_delta" or "negative_count", the former for
	// regular histograms with integer counts, the latter for float
	// histograms.
	NegativeDelta []int64
	NegativeCount []float64
	// Positive buckets for the native histogram.
	// Use a no-op span (offset 0, length 0) for a native histogram without any
	// observations yet and with a zero_threshold of 0. Otherwise, it would be
	// indistinguishable from a classic histogram.
	PositiveSpan []*BucketSpan
	// Use either "positive_delta" or "positive_count", the former for
	// regular histograms with integer counts, the latter for float
	// histograms.
	PositiveDelta []int64
	PositiveCount []float64
	// Only used for native histograms. These exemplars MUST have a timestamp.
	Exemplars []*Exemplar
	// contains filtered or unexported fields
}

func (Histogram_builder) Build

func (b0 Histogram_builder) Build() *Histogram

type LabelPair

type LabelPair struct {
	Name  *string `protobuf:"bytes,1,opt,name=name" json:"name,omitempty"`
	Value *string `protobuf:"bytes,2,opt,name=value" json:"value,omitempty"`
	// contains filtered or unexported fields
}

func (*LabelPair) ClearName

func (x *LabelPair) ClearName()

func (*LabelPair) ClearValue

func (x *LabelPair) ClearValue()

func (*LabelPair) GetName

func (x *LabelPair) GetName() string

func (*LabelPair) GetValue

func (x *LabelPair) GetValue() string

func (*LabelPair) HasName

func (x *LabelPair) HasName() bool

func (*LabelPair) HasValue

func (x *LabelPair) HasValue() bool

func (*LabelPair) ProtoMessage

func (*LabelPair) ProtoMessage()

func (*LabelPair) ProtoReflect

func (x *LabelPair) ProtoReflect() protoreflect.Message

func (*LabelPair) Reset

func (x *LabelPair) Reset()

func (*LabelPair) SetName

func (x *LabelPair) SetName(v string)

func (*LabelPair) SetValue

func (x *LabelPair) SetValue(v string)

func (*LabelPair) String

func (x *LabelPair) String() string

type LabelPair_builder

type LabelPair_builder struct {
	Name  *string
	Value *string
	// contains filtered or unexported fields
}

func (LabelPair_builder) Build

func (b0 LabelPair_builder) Build() *LabelPair

type Metric

type Metric struct {
	Label       []*LabelPair `protobuf:"bytes,1,rep,name=label" json:"label,omitempty"`
	Gauge       *Gauge       `protobuf:"bytes,2,opt,name=gauge" json:"gauge,omitempty"`
	Counter     *Counter     `protobuf:"bytes,3,opt,name=counter" json:"counter,omitempty"`
	Summary     *Summary     `protobuf:"bytes,4,opt,name=summary" json:"summary,omitempty"`
	Untyped     *Untyped     `protobuf:"bytes,5,opt,name=untyped" json:"untyped,omitempty"`
	Histogram   *Histogram   `protobuf:"bytes,7,opt,name=histogram" json:"histogram,omitempty"`
	TimestampMs *int64       `protobuf:"varint,6,opt,name=timestamp_ms,json=timestampMs" json:"timestamp_ms,omitempty"`
	// contains filtered or unexported fields
}

func (*Metric) ClearCounter

func (x *Metric) ClearCounter()

func (*Metric) ClearGauge

func (x *Metric) ClearGauge()

func (*Metric) ClearHistogram

func (x *Metric) ClearHistogram()

func (*Metric) ClearSummary

func (x *Metric) ClearSummary()

func (*Metric) ClearTimestampMs

func (x *Metric) ClearTimestampMs()

func (*Metric) ClearUntyped

func (x *Metric) ClearUntyped()

func (*Metric) GetCounter

func (x *Metric) GetCounter() *Counter

func (*Metric) GetGauge

func (x *Metric) GetGauge() *Gauge

func (*Metric) GetHistogram

func (x *Metric) GetHistogram() *Histogram

func (*Metric) GetLabel

func (x *Metric) GetLabel() []*LabelPair

func (*Metric) GetSummary

func (x *Metric) GetSummary() *Summary

func (*Metric) GetTimestampMs

func (x *Metric) GetTimestampMs() int64

func (*Metric) GetUntyped

func (x *Metric) GetUntyped() *Untyped

func (*Metric) HasCounter

func (x *Metric) HasCounter() bool

func (*Metric) HasGauge

func (x *Metric) HasGauge() bool

func (*Metric) HasHistogram

func (x *Metric) HasHistogram() bool

func (*Metric) HasSummary

func (x *Metric) HasSummary() bool

func (*Metric) HasTimestampMs

func (x *Metric) HasTimestampMs() bool

func (*Metric) HasUntyped

func (x *Metric) HasUntyped() bool

func (*Metric) ProtoMessage

func (*Metric) ProtoMessage()

func (*Metric) ProtoReflect

func (x *Metric) ProtoReflect() protoreflect.Message

func (*Metric) Reset

func (x *Metric) Reset()

func (*Metric) SetCounter

func (x *Metric) SetCounter(v *Counter)

func (*Metric) SetGauge

func (x *Metric) SetGauge(v *Gauge)

func (*Metric) SetHistogram

func (x *Metric) SetHistogram(v *Histogram)

func (*Metric) SetLabel

func (x *Metric) SetLabel(v []*LabelPair)

func (*Metric) SetSummary

func (x *Metric) SetSummary(v *Summary)

func (*Metric) SetTimestampMs

func (x *Metric) SetTimestampMs(v int64)

func (*Metric) SetUntyped

func (x *Metric) SetUntyped(v *Untyped)

func (*Metric) String

func (x *Metric) String() string

type MetricFamily

type MetricFamily struct {
	Name   *string     `protobuf:"bytes,1,opt,name=name" json:"name,omitempty"`
	Help   *string     `protobuf:"bytes,2,opt,name=help" json:"help,omitempty"`
	Type   *MetricType `protobuf:"varint,3,opt,name=type,enum=io.prometheus.client.MetricType" json:"type,omitempty"`
	Metric []*Metric   `protobuf:"bytes,4,rep,name=metric" json:"metric,omitempty"`
	Unit   *string     `protobuf:"bytes,5,opt,name=unit" json:"unit,omitempty"`
	// contains filtered or unexported fields
}

func (*MetricFamily) ClearHelp

func (x *MetricFamily) ClearHelp()

func (*MetricFamily) ClearName

func (x *MetricFamily) ClearName()

func (*MetricFamily) ClearType

func (x *MetricFamily) ClearType()

func (*MetricFamily) ClearUnit

func (x *MetricFamily) ClearUnit()

func (*MetricFamily) GetHelp

func (x *MetricFamily) GetHelp() string

func (*MetricFamily) GetMetric

func (x *MetricFamily) GetMetric() []*Metric

func (*MetricFamily) GetName

func (x *MetricFamily) GetName() string

func (*MetricFamily) GetType

func (x *MetricFamily) GetType() MetricType

func (*MetricFamily) GetUnit

func (x *MetricFamily) GetUnit() string

func (*MetricFamily) HasHelp

func (x *MetricFamily) HasHelp() bool

func (*MetricFamily) HasName

func (x *MetricFamily) HasName() bool

func (*MetricFamily) HasType

func (x *MetricFamily) HasType() bool

func (*MetricFamily) HasUnit

func (x *MetricFamily) HasUnit() bool

func (*MetricFamily) ProtoMessage

func (*MetricFamily) ProtoMessage()

func (*MetricFamily) ProtoReflect

func (x *MetricFamily) ProtoReflect() protoreflect.Message

func (*MetricFamily) Reset

func (x *MetricFamily) Reset()

func (*MetricFamily) SetHelp

func (x *MetricFamily) SetHelp(v string)

func (*MetricFamily) SetMetric

func (x *MetricFamily) SetMetric(v []*Metric)

func (*MetricFamily) SetName

func (x *MetricFamily) SetName(v string)

func (*MetricFamily) SetType

func (x *MetricFamily) SetType(v MetricType)

func (*MetricFamily) SetUnit

func (x *MetricFamily) SetUnit(v string)

func (*MetricFamily) String

func (x *MetricFamily) String() string

type MetricFamily_builder

type MetricFamily_builder struct {
	Name   *string
	Help   *string
	Type   *MetricType
	Metric []*Metric
	Unit   *string
	// contains filtered or unexported fields
}

func (MetricFamily_builder) Build

func (b0 MetricFamily_builder) Build() *MetricFamily

type MetricType

type MetricType int32
const (
	// COUNTER must use the Metric field "counter".
	MetricType_COUNTER MetricType = 0
	// GAUGE must use the Metric field "gauge".
	MetricType_GAUGE MetricType = 1
	// SUMMARY must use the Metric field "summary".
	MetricType_SUMMARY MetricType = 2
	// UNTYPED must use the Metric field "untyped".
	MetricType_UNTYPED MetricType = 3
	// HISTOGRAM must use the Metric field "histogram".
	MetricType_HISTOGRAM MetricType = 4
	// GAUGE_HISTOGRAM must use the Metric field "histogram".
	MetricType_GAUGE_HISTOGRAM MetricType = 5
)

func (MetricType) Descriptor

func (MetricType) Descriptor() protoreflect.EnumDescriptor

func (MetricType) Enum

func (x MetricType) Enum() *MetricType

func (MetricType) Number

func (x MetricType) Number() protoreflect.EnumNumber

func (MetricType) String

func (x MetricType) String() string

func (MetricType) Type

type Metric_builder

type Metric_builder struct {
	Label       []*LabelPair
	Gauge       *Gauge
	Counter     *Counter
	Summary     *Summary
	Untyped     *Untyped
	Histogram   *Histogram
	TimestampMs *int64
	// contains filtered or unexported fields
}

func (Metric_builder) Build

func (b0 Metric_builder) Build() *Metric

type Quantile

type Quantile struct {
	Quantile *float64 `protobuf:"fixed64,1,opt,name=quantile" json:"quantile,omitempty"`
	Value    *float64 `protobuf:"fixed64,2,opt,name=value" json:"value,omitempty"`
	// contains filtered or unexported fields
}

func (*Quantile) ClearQuantile

func (x *Quantile) ClearQuantile()

func (*Quantile) ClearValue

func (x *Quantile) ClearValue()

func (*Quantile) GetQuantile

func (x *Quantile) GetQuantile() float64

func (*Quantile) GetValue

func (x *Quantile) GetValue() float64

func (*Quantile) HasQuantile

func (x *Quantile) HasQuantile() bool

func (*Quantile) HasValue

func (x *Quantile) HasValue() bool

func (*Quantile) ProtoMessage

func (*Quantile) ProtoMessage()

func (*Quantile) ProtoReflect

func (x *Quantile) ProtoReflect() protoreflect.Message

func (*Quantile) Reset

func (x *Quantile) Reset()

func (*Quantile) SetQuantile

func (x *Quantile) SetQuantile(v float64)

func (*Quantile) SetValue

func (x *Quantile) SetValue(v float64)

func (*Quantile) String

func (x *Quantile) String() string

type Quantile_builder

type Quantile_builder struct {
	Quantile *float64
	Value    *float64
	// contains filtered or unexported fields
}

func (Quantile_builder) Build

func (b0 Quantile_builder) Build() *Quantile

type Summary

type Summary struct {
	SampleCount      *uint64                `protobuf:"varint,1,opt,name=sample_count,json=sampleCount" json:"sample_count,omitempty"`
	SampleSum        *float64               `protobuf:"fixed64,2,opt,name=sample_sum,json=sampleSum" json:"sample_sum,omitempty"`
	Quantile         []*Quantile            `protobuf:"bytes,3,rep,name=quantile" json:"quantile,omitempty"`
	CreatedTimestamp *timestamppb.Timestamp `protobuf:"bytes,4,opt,name=created_timestamp,json=createdTimestamp" json:"created_timestamp,omitempty"`
	// contains filtered or unexported fields
}

func (*Summary) ClearCreatedTimestamp

func (x *Summary) ClearCreatedTimestamp()

func (*Summary) ClearSampleCount

func (x *Summary) ClearSampleCount()

func (*Summary) ClearSampleSum

func (x *Summary) ClearSampleSum()

func (*Summary) GetCreatedTimestamp

func (x *Summary) GetCreatedTimestamp() *timestamppb.Timestamp

func (*Summary) GetQuantile

func (x *Summary) GetQuantile() []*Quantile

func (*Summary) GetSampleCount

func (x *Summary) GetSampleCount() uint64

func (*Summary) GetSampleSum

func (x *Summary) GetSampleSum() float64

func (*Summary) HasCreatedTimestamp

func (x *Summary) HasCreatedTimestamp() bool

func (*Summary) HasSampleCount

func (x *Summary) HasSampleCount() bool

func (*Summary) HasSampleSum

func (x *Summary) HasSampleSum() bool

func (*Summary) ProtoMessage

func (*Summary) ProtoMessage()

func (*Summary) ProtoReflect

func (x *Summary) ProtoReflect() protoreflect.Message

func (*Summary) Reset

func (x *Summary) Reset()

func (*Summary) SetCreatedTimestamp

func (x *Summary) SetCreatedTimestamp(v *timestamppb.Timestamp)

func (*Summary) SetQuantile

func (x *Summary) SetQuantile(v []*Quantile)

func (*Summary) SetSampleCount

func (x *Summary) SetSampleCount(v uint64)

func (*Summary) SetSampleSum

func (x *Summary) SetSampleSum(v float64)

func (*Summary) String

func (x *Summary) String() string

type Summary_builder

type Summary_builder struct {
	SampleCount      *uint64
	SampleSum        *float64
	Quantile         []*Quantile
	CreatedTimestamp *timestamppb.Timestamp
	// contains filtered or unexported fields
}

func (Summary_builder) Build

func (b0 Summary_builder) Build() *Summary

type Untyped

type Untyped struct {
	Value *float64 `protobuf:"fixed64,1,opt,name=value" json:"value,omitempty"`
	// contains filtered or unexported fields
}

func (*Untyped) ClearValue

func (x *Untyped) ClearValue()

func (*Untyped) GetValue

func (x *Untyped) GetValue() float64

func (*Untyped) HasValue

func (x *Untyped) HasValue() bool

func (*Untyped) ProtoMessage

func (*Untyped) ProtoMessage()

func (*Untyped) ProtoReflect

func (x *Untyped) ProtoReflect() protoreflect.Message

func (*Untyped) Reset

func (x *Untyped) Reset()

func (*Untyped) SetValue

func (x *Untyped) SetValue(v float64)

func (*Untyped) String

func (x *Untyped) String() string

type Untyped_builder

type Untyped_builder struct {
	Value *float64
	// contains filtered or unexported fields
}

func (Untyped_builder) Build

func (b0 Untyped_builder) Build() *Untyped

Source Files

  • metrics.pb.go

Jump to