raft_log

package
v1.36.11-2025012415382... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	RaftCommand_name = map[int32]string{
		0: "RAFT_COMMAND_UNKNOWN",
		1: "RAFT_COMMAND_ADD_BLOCK_METADATA",
		2: "RAFT_COMMAND_GET_COMPACTION_PLAN_UPDATE",
		3: "RAFT_COMMAND_UPDATE_COMPACTION_PLAN",
	}
	RaftCommand_value = map[string]int32{
		"RAFT_COMMAND_UNKNOWN":                    0,
		"RAFT_COMMAND_ADD_BLOCK_METADATA":         1,
		"RAFT_COMMAND_GET_COMPACTION_PLAN_UPDATE": 2,
		"RAFT_COMMAND_UPDATE_COMPACTION_PLAN":     3,
	}
)

Enum value maps for RaftCommand.

var File_metastore_v1_raft_log_raft_log_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type AddBlockMetadataRequest

type AddBlockMetadataRequest struct {
	Metadata *v1.BlockMeta `protobuf:"bytes,1,opt,name=metadata,proto3" json:"metadata,omitempty"`
	// contains filtered or unexported fields
}

func (*AddBlockMetadataRequest) ClearMetadata

func (x *AddBlockMetadataRequest) ClearMetadata()

func (*AddBlockMetadataRequest) GetMetadata

func (x *AddBlockMetadataRequest) GetMetadata() *v1.BlockMeta

func (*AddBlockMetadataRequest) HasMetadata

func (x *AddBlockMetadataRequest) HasMetadata() bool

func (*AddBlockMetadataRequest) ProtoMessage

func (*AddBlockMetadataRequest) ProtoMessage()

func (*AddBlockMetadataRequest) ProtoReflect

func (x *AddBlockMetadataRequest) ProtoReflect() protoreflect.Message

func (*AddBlockMetadataRequest) Reset

func (x *AddBlockMetadataRequest) Reset()

func (*AddBlockMetadataRequest) SetMetadata

func (x *AddBlockMetadataRequest) SetMetadata(v *v1.BlockMeta)

func (*AddBlockMetadataRequest) String

func (x *AddBlockMetadataRequest) String() string

type AddBlockMetadataRequest_builder

type AddBlockMetadataRequest_builder struct {
	Metadata *v1.BlockMeta
	// contains filtered or unexported fields
}

func (AddBlockMetadataRequest_builder) Build

type AddBlockMetadataResponse

type AddBlockMetadataResponse struct {
	// contains filtered or unexported fields
}

func (*AddBlockMetadataResponse) ProtoMessage

func (*AddBlockMetadataResponse) ProtoMessage()

func (*AddBlockMetadataResponse) ProtoReflect

func (x *AddBlockMetadataResponse) ProtoReflect() protoreflect.Message

func (*AddBlockMetadataResponse) Reset

func (x *AddBlockMetadataResponse) Reset()

func (*AddBlockMetadataResponse) String

func (x *AddBlockMetadataResponse) String() string

type AddBlockMetadataResponse_builder

type AddBlockMetadataResponse_builder struct {
	// contains filtered or unexported fields
}

func (AddBlockMetadataResponse_builder) Build

type AssignedCompactionJob

type AssignedCompactionJob struct {
	State *CompactionJobState `protobuf:"bytes,1,opt,name=state,proto3" json:"state,omitempty"`
	Plan  *CompactionJobPlan  `protobuf:"bytes,2,opt,name=plan,proto3" json:"plan,omitempty"`
	// contains filtered or unexported fields
}

func (*AssignedCompactionJob) ClearPlan

func (x *AssignedCompactionJob) ClearPlan()

func (*AssignedCompactionJob) ClearState

func (x *AssignedCompactionJob) ClearState()

func (*AssignedCompactionJob) GetPlan

func (*AssignedCompactionJob) GetState

func (*AssignedCompactionJob) HasPlan

func (x *AssignedCompactionJob) HasPlan() bool

func (*AssignedCompactionJob) HasState

func (x *AssignedCompactionJob) HasState() bool

func (*AssignedCompactionJob) ProtoMessage

func (*AssignedCompactionJob) ProtoMessage()

func (*AssignedCompactionJob) ProtoReflect

func (x *AssignedCompactionJob) ProtoReflect() protoreflect.Message

func (*AssignedCompactionJob) Reset

func (x *AssignedCompactionJob) Reset()

func (*AssignedCompactionJob) SetPlan

func (*AssignedCompactionJob) SetState

func (x *AssignedCompactionJob) SetState(v *CompactionJobState)

func (*AssignedCompactionJob) String

func (x *AssignedCompactionJob) String() string

type AssignedCompactionJob_builder

type AssignedCompactionJob_builder struct {
	State *CompactionJobState
	Plan  *CompactionJobPlan
	// contains filtered or unexported fields
}

func (AssignedCompactionJob_builder) Build

type CompactionJobPlan

type CompactionJobPlan struct {
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Blocks to be compacted.
	Tenant          string   `protobuf:"bytes,2,opt,name=tenant,proto3" json:"tenant,omitempty"`
	Shard           uint32   `protobuf:"varint,3,opt,name=shard,proto3" json:"shard,omitempty"`
	CompactionLevel uint32   `protobuf:"varint,4,opt,name=compaction_level,json=compactionLevel,proto3" json:"compaction_level,omitempty"`
	SourceBlocks    []string `protobuf:"bytes,5,rep,name=source_blocks,json=sourceBlocks,proto3" json:"source_blocks,omitempty"`
	// Objects to be deleted.
	Tombstones []*v1.Tombstones `protobuf:"bytes,6,rep,name=tombstones,proto3" json:"tombstones,omitempty"`
	// contains filtered or unexported fields
}

func (*CompactionJobPlan) GetCompactionLevel

func (x *CompactionJobPlan) GetCompactionLevel() uint32

func (*CompactionJobPlan) GetName

func (x *CompactionJobPlan) GetName() string

func (*CompactionJobPlan) GetShard

func (x *CompactionJobPlan) GetShard() uint32

func (*CompactionJobPlan) GetSourceBlocks

func (x *CompactionJobPlan) GetSourceBlocks() []string

func (*CompactionJobPlan) GetTenant

func (x *CompactionJobPlan) GetTenant() string

func (*CompactionJobPlan) GetTombstones

func (x *CompactionJobPlan) GetTombstones() []*v1.Tombstones

func (*CompactionJobPlan) ProtoMessage

func (*CompactionJobPlan) ProtoMessage()

func (*CompactionJobPlan) ProtoReflect

func (x *CompactionJobPlan) ProtoReflect() protoreflect.Message

func (*CompactionJobPlan) Reset

func (x *CompactionJobPlan) Reset()

func (*CompactionJobPlan) SetCompactionLevel

func (x *CompactionJobPlan) SetCompactionLevel(v uint32)

func (*CompactionJobPlan) SetName

func (x *CompactionJobPlan) SetName(v string)

func (*CompactionJobPlan) SetShard

func (x *CompactionJobPlan) SetShard(v uint32)

func (*CompactionJobPlan) SetSourceBlocks

func (x *CompactionJobPlan) SetSourceBlocks(v []string)

func (*CompactionJobPlan) SetTenant

func (x *CompactionJobPlan) SetTenant(v string)

func (*CompactionJobPlan) SetTombstones

func (x *CompactionJobPlan) SetTombstones(v []*v1.Tombstones)

func (*CompactionJobPlan) String

func (x *CompactionJobPlan) String() string

type CompactionJobPlan_builder

type CompactionJobPlan_builder struct {
	Name string
	// Blocks to be compacted.
	Tenant          string
	Shard           uint32
	CompactionLevel uint32
	SourceBlocks    []string
	// Objects to be deleted.
	Tombstones []*v1.Tombstones
	// contains filtered or unexported fields
}

func (CompactionJobPlan_builder) Build

type CompactionJobState

type CompactionJobState struct {
	Name            string                 `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	CompactionLevel uint32                 `protobuf:"varint,2,opt,name=compaction_level,json=compactionLevel,proto3" json:"compaction_level,omitempty"`
	Status          v1.CompactionJobStatus `protobuf:"varint,3,opt,name=status,proto3,enum=metastore.v1.CompactionJobStatus" json:"status,omitempty"`
	Token           uint64                 `protobuf:"varint,4,opt,name=token,proto3" json:"token,omitempty"`
	LeaseExpiresAt  int64                  `protobuf:"varint,5,opt,name=lease_expires_at,json=leaseExpiresAt,proto3" json:"lease_expires_at,omitempty"`
	AddedAt         int64                  `protobuf:"varint,6,opt,name=added_at,json=addedAt,proto3" json:"added_at,omitempty"`
	Failures        uint32                 `protobuf:"varint,7,opt,name=failures,proto3" json:"failures,omitempty"`
	// contains filtered or unexported fields
}

CompactionJobState is produced in response to the compaction worker status update request.

Compaction level and other attributes that affect the scheduling order or status update handling should be included into the message.

func (*CompactionJobState) GetAddedAt

func (x *CompactionJobState) GetAddedAt() int64

func (*CompactionJobState) GetCompactionLevel

func (x *CompactionJobState) GetCompactionLevel() uint32

func (*CompactionJobState) GetFailures

func (x *CompactionJobState) GetFailures() uint32

func (*CompactionJobState) GetLeaseExpiresAt

func (x *CompactionJobState) GetLeaseExpiresAt() int64

func (*CompactionJobState) GetName

func (x *CompactionJobState) GetName() string

func (*CompactionJobState) GetStatus

func (x *CompactionJobState) GetStatus() v1.CompactionJobStatus

func (*CompactionJobState) GetToken

func (x *CompactionJobState) GetToken() uint64

func (*CompactionJobState) ProtoMessage

func (*CompactionJobState) ProtoMessage()

func (*CompactionJobState) ProtoReflect

func (x *CompactionJobState) ProtoReflect() protoreflect.Message

func (*CompactionJobState) Reset

func (x *CompactionJobState) Reset()

func (*CompactionJobState) SetAddedAt

func (x *CompactionJobState) SetAddedAt(v int64)

func (*CompactionJobState) SetCompactionLevel

func (x *CompactionJobState) SetCompactionLevel(v uint32)

func (*CompactionJobState) SetFailures

func (x *CompactionJobState) SetFailures(v uint32)

func (*CompactionJobState) SetLeaseExpiresAt

func (x *CompactionJobState) SetLeaseExpiresAt(v int64)

func (*CompactionJobState) SetName

func (x *CompactionJobState) SetName(v string)

func (*CompactionJobState) SetStatus

func (x *CompactionJobState) SetStatus(v v1.CompactionJobStatus)

func (*CompactionJobState) SetToken

func (x *CompactionJobState) SetToken(v uint64)

func (*CompactionJobState) String

func (x *CompactionJobState) String() string

type CompactionJobState_builder

type CompactionJobState_builder struct {
	Name            string
	CompactionLevel uint32
	Status          v1.CompactionJobStatus
	Token           uint64
	LeaseExpiresAt  int64
	AddedAt         int64
	Failures        uint32
	// contains filtered or unexported fields
}

func (CompactionJobState_builder) Build

type CompactionJobStatusUpdate

type CompactionJobStatusUpdate struct {
	Name   string                 `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	Token  uint64                 `protobuf:"varint,2,opt,name=token,proto3" json:"token,omitempty"`
	Status v1.CompactionJobStatus `protobuf:"varint,3,opt,name=status,proto3,enum=metastore.v1.CompactionJobStatus" json:"status,omitempty"`
	// contains filtered or unexported fields
}

func (*CompactionJobStatusUpdate) GetName

func (x *CompactionJobStatusUpdate) GetName() string

func (*CompactionJobStatusUpdate) GetStatus

func (*CompactionJobStatusUpdate) GetToken

func (x *CompactionJobStatusUpdate) GetToken() uint64

func (*CompactionJobStatusUpdate) ProtoMessage

func (*CompactionJobStatusUpdate) ProtoMessage()

func (*CompactionJobStatusUpdate) ProtoReflect

func (*CompactionJobStatusUpdate) Reset

func (x *CompactionJobStatusUpdate) Reset()

func (*CompactionJobStatusUpdate) SetName

func (x *CompactionJobStatusUpdate) SetName(v string)

func (*CompactionJobStatusUpdate) SetStatus

func (*CompactionJobStatusUpdate) SetToken

func (x *CompactionJobStatusUpdate) SetToken(v uint64)

func (*CompactionJobStatusUpdate) String

func (x *CompactionJobStatusUpdate) String() string

type CompactionJobStatusUpdate_builder

type CompactionJobStatusUpdate_builder struct {
	Name   string
	Token  uint64
	Status v1.CompactionJobStatus
	// contains filtered or unexported fields
}

func (CompactionJobStatusUpdate_builder) Build

type CompactionPlanUpdate

type CompactionPlanUpdate struct {
	NewJobs       []*NewCompactionJob       `protobuf:"bytes,1,rep,name=new_jobs,json=newJobs,proto3" json:"new_jobs,omitempty"`
	AssignedJobs  []*AssignedCompactionJob  `protobuf:"bytes,2,rep,name=assigned_jobs,json=assignedJobs,proto3" json:"assigned_jobs,omitempty"`
	UpdatedJobs   []*UpdatedCompactionJob   `protobuf:"bytes,3,rep,name=updated_jobs,json=updatedJobs,proto3" json:"updated_jobs,omitempty"`
	CompletedJobs []*CompletedCompactionJob `protobuf:"bytes,4,rep,name=completed_jobs,json=completedJobs,proto3" json:"completed_jobs,omitempty"`
	// contains filtered or unexported fields
}

func (*CompactionPlanUpdate) GetAssignedJobs

func (x *CompactionPlanUpdate) GetAssignedJobs() []*AssignedCompactionJob

func (*CompactionPlanUpdate) GetCompletedJobs

func (x *CompactionPlanUpdate) GetCompletedJobs() []*CompletedCompactionJob

func (*CompactionPlanUpdate) GetNewJobs

func (x *CompactionPlanUpdate) GetNewJobs() []*NewCompactionJob

func (*CompactionPlanUpdate) GetUpdatedJobs

func (x *CompactionPlanUpdate) GetUpdatedJobs() []*UpdatedCompactionJob

func (*CompactionPlanUpdate) ProtoMessage

func (*CompactionPlanUpdate) ProtoMessage()

func (*CompactionPlanUpdate) ProtoReflect

func (x *CompactionPlanUpdate) ProtoReflect() protoreflect.Message

func (*CompactionPlanUpdate) Reset

func (x *CompactionPlanUpdate) Reset()

func (*CompactionPlanUpdate) SetAssignedJobs

func (x *CompactionPlanUpdate) SetAssignedJobs(v []*AssignedCompactionJob)

func (*CompactionPlanUpdate) SetCompletedJobs

func (x *CompactionPlanUpdate) SetCompletedJobs(v []*CompletedCompactionJob)

func (*CompactionPlanUpdate) SetNewJobs

func (x *CompactionPlanUpdate) SetNewJobs(v []*NewCompactionJob)

func (*CompactionPlanUpdate) SetUpdatedJobs

func (x *CompactionPlanUpdate) SetUpdatedJobs(v []*UpdatedCompactionJob)

func (*CompactionPlanUpdate) String

func (x *CompactionPlanUpdate) String() string

type CompactionPlanUpdate_builder

type CompactionPlanUpdate_builder struct {
	NewJobs       []*NewCompactionJob
	AssignedJobs  []*AssignedCompactionJob
	UpdatedJobs   []*UpdatedCompactionJob
	CompletedJobs []*CompletedCompactionJob
	// contains filtered or unexported fields
}

func (CompactionPlanUpdate_builder) Build

type CompletedCompactionJob

type CompletedCompactionJob struct {
	State           *CompactionJobState `protobuf:"bytes,1,opt,name=state,proto3" json:"state,omitempty"`
	CompactedBlocks *v1.CompactedBlocks `protobuf:"bytes,2,opt,name=compacted_blocks,json=compactedBlocks,proto3" json:"compacted_blocks,omitempty"`
	// contains filtered or unexported fields
}

func (*CompletedCompactionJob) ClearCompactedBlocks

func (x *CompletedCompactionJob) ClearCompactedBlocks()

func (*CompletedCompactionJob) ClearState

func (x *CompletedCompactionJob) ClearState()

func (*CompletedCompactionJob) GetCompactedBlocks

func (x *CompletedCompactionJob) GetCompactedBlocks() *v1.CompactedBlocks

func (*CompletedCompactionJob) GetState

func (*CompletedCompactionJob) HasCompactedBlocks

func (x *CompletedCompactionJob) HasCompactedBlocks() bool

func (*CompletedCompactionJob) HasState

func (x *CompletedCompactionJob) HasState() bool

func (*CompletedCompactionJob) ProtoMessage

func (*CompletedCompactionJob) ProtoMessage()

func (*CompletedCompactionJob) ProtoReflect

func (x *CompletedCompactionJob) ProtoReflect() protoreflect.Message

func (*CompletedCompactionJob) Reset

func (x *CompletedCompactionJob) Reset()

func (*CompletedCompactionJob) SetCompactedBlocks

func (x *CompletedCompactionJob) SetCompactedBlocks(v *v1.CompactedBlocks)

func (*CompletedCompactionJob) SetState

func (*CompletedCompactionJob) String

func (x *CompletedCompactionJob) String() string

type CompletedCompactionJob_builder

type CompletedCompactionJob_builder struct {
	State           *CompactionJobState
	CompactedBlocks *v1.CompactedBlocks
	// contains filtered or unexported fields
}

func (CompletedCompactionJob_builder) Build

type GetCompactionPlanUpdateRequest

type GetCompactionPlanUpdateRequest struct {

	// CompactionJobStatusUpdate is a change
	// requested by the compaction worker.
	StatusUpdates []*CompactionJobStatusUpdate `protobuf:"bytes,1,rep,name=status_updates,json=statusUpdates,proto3" json:"status_updates,omitempty"`
	AssignJobsMax uint32                       `protobuf:"varint,2,opt,name=assign_jobs_max,json=assignJobsMax,proto3" json:"assign_jobs_max,omitempty"`
	// contains filtered or unexported fields
}

GetCompactionPlanUpdateRequest requests CompactionPlanUpdate. The resulting plan should be proposed to the raft members. This is a read-only operation: it MUST NOT alter the state.

func (*GetCompactionPlanUpdateRequest) GetAssignJobsMax

func (x *GetCompactionPlanUpdateRequest) GetAssignJobsMax() uint32

func (*GetCompactionPlanUpdateRequest) GetStatusUpdates

func (*GetCompactionPlanUpdateRequest) ProtoMessage

func (*GetCompactionPlanUpdateRequest) ProtoMessage()

func (*GetCompactionPlanUpdateRequest) ProtoReflect

func (*GetCompactionPlanUpdateRequest) Reset

func (x *GetCompactionPlanUpdateRequest) Reset()

func (*GetCompactionPlanUpdateRequest) SetAssignJobsMax

func (x *GetCompactionPlanUpdateRequest) SetAssignJobsMax(v uint32)

func (*GetCompactionPlanUpdateRequest) SetStatusUpdates

func (*GetCompactionPlanUpdateRequest) String

type GetCompactionPlanUpdateRequest_builder

type GetCompactionPlanUpdateRequest_builder struct {

	// CompactionJobStatusUpdate is a change
	// requested by the compaction worker.
	StatusUpdates []*CompactionJobStatusUpdate
	AssignJobsMax uint32
	// contains filtered or unexported fields
}

func (GetCompactionPlanUpdateRequest_builder) Build

type GetCompactionPlanUpdateResponse

type GetCompactionPlanUpdateResponse struct {
	Term       uint64                `protobuf:"varint,1,opt,name=term,proto3" json:"term,omitempty"`
	PlanUpdate *CompactionPlanUpdate `protobuf:"bytes,2,opt,name=plan_update,json=planUpdate,proto3" json:"plan_update,omitempty"`
	// contains filtered or unexported fields
}

GetCompactionPlanUpdateResponse includes the planned change. The plan should be proposed to the raft members.

func (*GetCompactionPlanUpdateResponse) ClearPlanUpdate

func (x *GetCompactionPlanUpdateResponse) ClearPlanUpdate()

func (*GetCompactionPlanUpdateResponse) GetPlanUpdate

func (*GetCompactionPlanUpdateResponse) GetTerm

func (*GetCompactionPlanUpdateResponse) HasPlanUpdate

func (x *GetCompactionPlanUpdateResponse) HasPlanUpdate() bool

func (*GetCompactionPlanUpdateResponse) ProtoMessage

func (*GetCompactionPlanUpdateResponse) ProtoMessage()

func (*GetCompactionPlanUpdateResponse) ProtoReflect

func (*GetCompactionPlanUpdateResponse) Reset

func (*GetCompactionPlanUpdateResponse) SetPlanUpdate

func (*GetCompactionPlanUpdateResponse) SetTerm

func (*GetCompactionPlanUpdateResponse) String

type GetCompactionPlanUpdateResponse_builder

type GetCompactionPlanUpdateResponse_builder struct {
	Term       uint64
	PlanUpdate *CompactionPlanUpdate
	// contains filtered or unexported fields
}

func (GetCompactionPlanUpdateResponse_builder) Build

type NewCompactionJob

type NewCompactionJob struct {
	State *CompactionJobState `protobuf:"bytes,1,opt,name=state,proto3" json:"state,omitempty"`
	Plan  *CompactionJobPlan  `protobuf:"bytes,2,opt,name=plan,proto3" json:"plan,omitempty"`
	// contains filtered or unexported fields
}

func (*NewCompactionJob) ClearPlan

func (x *NewCompactionJob) ClearPlan()

func (*NewCompactionJob) ClearState

func (x *NewCompactionJob) ClearState()

func (*NewCompactionJob) GetPlan

func (x *NewCompactionJob) GetPlan() *CompactionJobPlan

func (*NewCompactionJob) GetState

func (x *NewCompactionJob) GetState() *CompactionJobState

func (*NewCompactionJob) HasPlan

func (x *NewCompactionJob) HasPlan() bool

func (*NewCompactionJob) HasState

func (x *NewCompactionJob) HasState() bool

func (*NewCompactionJob) ProtoMessage

func (*NewCompactionJob) ProtoMessage()

func (*NewCompactionJob) ProtoReflect

func (x *NewCompactionJob) ProtoReflect() protoreflect.Message

func (*NewCompactionJob) Reset

func (x *NewCompactionJob) Reset()

func (*NewCompactionJob) SetPlan

func (x *NewCompactionJob) SetPlan(v *CompactionJobPlan)

func (*NewCompactionJob) SetState

func (x *NewCompactionJob) SetState(v *CompactionJobState)

func (*NewCompactionJob) String

func (x *NewCompactionJob) String() string

type NewCompactionJob_builder

type NewCompactionJob_builder struct {
	State *CompactionJobState
	Plan  *CompactionJobPlan
	// contains filtered or unexported fields
}

func (NewCompactionJob_builder) Build

type RaftCommand

type RaftCommand int32
const (
	RaftCommand_RAFT_COMMAND_UNKNOWN                    RaftCommand = 0
	RaftCommand_RAFT_COMMAND_ADD_BLOCK_METADATA         RaftCommand = 1
	RaftCommand_RAFT_COMMAND_GET_COMPACTION_PLAN_UPDATE RaftCommand = 2
	RaftCommand_RAFT_COMMAND_UPDATE_COMPACTION_PLAN     RaftCommand = 3
)

func (RaftCommand) Descriptor

func (RaftCommand) Enum

func (x RaftCommand) Enum() *RaftCommand

func (RaftCommand) Number

func (x RaftCommand) Number() protoreflect.EnumNumber

func (RaftCommand) String

func (x RaftCommand) String() string

func (RaftCommand) Type

type UpdateCompactionPlanRequest

type UpdateCompactionPlanRequest struct {
	Term       uint64                `protobuf:"varint,1,opt,name=term,proto3" json:"term,omitempty"`
	PlanUpdate *CompactionPlanUpdate `protobuf:"bytes,2,opt,name=plan_update,json=planUpdate,proto3" json:"plan_update,omitempty"`
	// contains filtered or unexported fields
}

UpdateCompactionPlanRequest proposes compaction plan changes.

func (*UpdateCompactionPlanRequest) ClearPlanUpdate

func (x *UpdateCompactionPlanRequest) ClearPlanUpdate()

func (*UpdateCompactionPlanRequest) GetPlanUpdate

func (*UpdateCompactionPlanRequest) GetTerm

func (x *UpdateCompactionPlanRequest) GetTerm() uint64

func (*UpdateCompactionPlanRequest) HasPlanUpdate

func (x *UpdateCompactionPlanRequest) HasPlanUpdate() bool

func (*UpdateCompactionPlanRequest) ProtoMessage

func (*UpdateCompactionPlanRequest) ProtoMessage()

func (*UpdateCompactionPlanRequest) ProtoReflect

func (*UpdateCompactionPlanRequest) Reset

func (x *UpdateCompactionPlanRequest) Reset()

func (*UpdateCompactionPlanRequest) SetPlanUpdate

func (*UpdateCompactionPlanRequest) SetTerm

func (x *UpdateCompactionPlanRequest) SetTerm(v uint64)

func (*UpdateCompactionPlanRequest) String

func (x *UpdateCompactionPlanRequest) String() string

type UpdateCompactionPlanRequest_builder

type UpdateCompactionPlanRequest_builder struct {
	Term       uint64
	PlanUpdate *CompactionPlanUpdate
	// contains filtered or unexported fields
}

func (UpdateCompactionPlanRequest_builder) Build

type UpdateCompactionPlanResponse

type UpdateCompactionPlanResponse struct {
	PlanUpdate *CompactionPlanUpdate `protobuf:"bytes,1,opt,name=plan_update,json=planUpdate,proto3" json:"plan_update,omitempty"`
	// contains filtered or unexported fields
}

func (*UpdateCompactionPlanResponse) ClearPlanUpdate

func (x *UpdateCompactionPlanResponse) ClearPlanUpdate()

func (*UpdateCompactionPlanResponse) GetPlanUpdate

func (*UpdateCompactionPlanResponse) HasPlanUpdate

func (x *UpdateCompactionPlanResponse) HasPlanUpdate() bool

func (*UpdateCompactionPlanResponse) ProtoMessage

func (*UpdateCompactionPlanResponse) ProtoMessage()

func (*UpdateCompactionPlanResponse) ProtoReflect

func (*UpdateCompactionPlanResponse) Reset

func (x *UpdateCompactionPlanResponse) Reset()

func (*UpdateCompactionPlanResponse) SetPlanUpdate

func (*UpdateCompactionPlanResponse) String

type UpdateCompactionPlanResponse_builder

type UpdateCompactionPlanResponse_builder struct {
	PlanUpdate *CompactionPlanUpdate
	// contains filtered or unexported fields
}

func (UpdateCompactionPlanResponse_builder) Build

type UpdatedCompactionJob

type UpdatedCompactionJob struct {
	State *CompactionJobState `protobuf:"bytes,1,opt,name=state,proto3" json:"state,omitempty"`
	// contains filtered or unexported fields
}

func (*UpdatedCompactionJob) ClearState

func (x *UpdatedCompactionJob) ClearState()

func (*UpdatedCompactionJob) GetState

func (*UpdatedCompactionJob) HasState

func (x *UpdatedCompactionJob) HasState() bool

func (*UpdatedCompactionJob) ProtoMessage

func (*UpdatedCompactionJob) ProtoMessage()

func (*UpdatedCompactionJob) ProtoReflect

func (x *UpdatedCompactionJob) ProtoReflect() protoreflect.Message

func (*UpdatedCompactionJob) Reset

func (x *UpdatedCompactionJob) Reset()

func (*UpdatedCompactionJob) SetState

func (x *UpdatedCompactionJob) SetState(v *CompactionJobState)

func (*UpdatedCompactionJob) String

func (x *UpdatedCompactionJob) String() string

type UpdatedCompactionJob_builder

type UpdatedCompactionJob_builder struct {
	State *CompactionJobState
	// contains filtered or unexported fields
}

func (UpdatedCompactionJob_builder) Build

Source Files

  • raft_log.pb.go

Jump to