querierv1

package
v1.36.11-2025012415382... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	ProfileFormat_name = map[int32]string{
		0: "PROFILE_FORMAT_UNSPECIFIED",
		1: "PROFILE_FORMAT_FLAMEGRAPH",
		2: "PROFILE_FORMAT_TREE",
	}
	ProfileFormat_value = map[string]int32{
		"PROFILE_FORMAT_UNSPECIFIED": 0,
		"PROFILE_FORMAT_FLAMEGRAPH":  1,
		"PROFILE_FORMAT_TREE":        2,
	}
)

Enum value maps for ProfileFormat.

var File_querier_v1_querier_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type AnalyzeQueryRequest

type AnalyzeQueryRequest struct {
	Start int64  `protobuf:"varint,2,opt,name=start,proto3" json:"start,omitempty"`
	End   int64  `protobuf:"varint,3,opt,name=end,proto3" json:"end,omitempty"`
	Query string `protobuf:"bytes,4,opt,name=query,proto3" json:"query,omitempty"`
	// contains filtered or unexported fields
}

func (*AnalyzeQueryRequest) GetEnd

func (x *AnalyzeQueryRequest) GetEnd() int64

func (*AnalyzeQueryRequest) GetQuery

func (x *AnalyzeQueryRequest) GetQuery() string

func (*AnalyzeQueryRequest) GetStart

func (x *AnalyzeQueryRequest) GetStart() int64

func (*AnalyzeQueryRequest) ProtoMessage

func (*AnalyzeQueryRequest) ProtoMessage()

func (*AnalyzeQueryRequest) ProtoReflect

func (x *AnalyzeQueryRequest) ProtoReflect() protoreflect.Message

func (*AnalyzeQueryRequest) Reset

func (x *AnalyzeQueryRequest) Reset()

func (*AnalyzeQueryRequest) SetEnd

func (x *AnalyzeQueryRequest) SetEnd(v int64)

func (*AnalyzeQueryRequest) SetQuery

func (x *AnalyzeQueryRequest) SetQuery(v string)

func (*AnalyzeQueryRequest) SetStart

func (x *AnalyzeQueryRequest) SetStart(v int64)

func (*AnalyzeQueryRequest) String

func (x *AnalyzeQueryRequest) String() string

type AnalyzeQueryRequest_builder

type AnalyzeQueryRequest_builder struct {
	Start int64
	End   int64
	Query string
	// contains filtered or unexported fields
}

func (AnalyzeQueryRequest_builder) Build

type AnalyzeQueryResponse

type AnalyzeQueryResponse struct {
	QueryScopes []*QueryScope `protobuf:"bytes,1,rep,name=query_scopes,json=queryScopes,proto3" json:"query_scopes,omitempty"` // detailed view of what the query will require
	QueryImpact *QueryImpact  `protobuf:"bytes,2,opt,name=query_impact,json=queryImpact,proto3" json:"query_impact,omitempty"` // summary of the query impact / performance
	// contains filtered or unexported fields
}

func (*AnalyzeQueryResponse) ClearQueryImpact

func (x *AnalyzeQueryResponse) ClearQueryImpact()

func (*AnalyzeQueryResponse) GetQueryImpact

func (x *AnalyzeQueryResponse) GetQueryImpact() *QueryImpact

func (*AnalyzeQueryResponse) GetQueryScopes

func (x *AnalyzeQueryResponse) GetQueryScopes() []*QueryScope

func (*AnalyzeQueryResponse) HasQueryImpact

func (x *AnalyzeQueryResponse) HasQueryImpact() bool

func (*AnalyzeQueryResponse) ProtoMessage

func (*AnalyzeQueryResponse) ProtoMessage()

func (*AnalyzeQueryResponse) ProtoReflect

func (x *AnalyzeQueryResponse) ProtoReflect() protoreflect.Message

func (*AnalyzeQueryResponse) Reset

func (x *AnalyzeQueryResponse) Reset()

func (*AnalyzeQueryResponse) SetQueryImpact

func (x *AnalyzeQueryResponse) SetQueryImpact(v *QueryImpact)

func (*AnalyzeQueryResponse) SetQueryScopes

func (x *AnalyzeQueryResponse) SetQueryScopes(v []*QueryScope)

func (*AnalyzeQueryResponse) String

func (x *AnalyzeQueryResponse) String() string

type AnalyzeQueryResponse_builder

type AnalyzeQueryResponse_builder struct {
	QueryScopes []*QueryScope
	QueryImpact *QueryImpact
	// contains filtered or unexported fields
}

func (AnalyzeQueryResponse_builder) Build

type DiffRequest

type DiffRequest struct {
	Left  *SelectMergeStacktracesRequest `protobuf:"bytes,1,opt,name=left,proto3" json:"left,omitempty"`
	Right *SelectMergeStacktracesRequest `protobuf:"bytes,2,opt,name=right,proto3" json:"right,omitempty"`
	// contains filtered or unexported fields
}

func (*DiffRequest) ClearLeft

func (x *DiffRequest) ClearLeft()

func (*DiffRequest) ClearRight

func (x *DiffRequest) ClearRight()

func (*DiffRequest) GetLeft

func (*DiffRequest) GetRight

func (*DiffRequest) HasLeft

func (x *DiffRequest) HasLeft() bool

func (*DiffRequest) HasRight

func (x *DiffRequest) HasRight() bool

func (*DiffRequest) ProtoMessage

func (*DiffRequest) ProtoMessage()

func (*DiffRequest) ProtoReflect

func (x *DiffRequest) ProtoReflect() protoreflect.Message

func (*DiffRequest) Reset

func (x *DiffRequest) Reset()

func (*DiffRequest) SetLeft

func (*DiffRequest) SetRight

func (*DiffRequest) String

func (x *DiffRequest) String() string

type DiffRequest_builder

type DiffRequest_builder struct {
	Left  *SelectMergeStacktracesRequest
	Right *SelectMergeStacktracesRequest
	// contains filtered or unexported fields
}

func (DiffRequest_builder) Build

func (b0 DiffRequest_builder) Build() *DiffRequest

type DiffResponse

type DiffResponse struct {
	Flamegraph *FlameGraphDiff `protobuf:"bytes,1,opt,name=flamegraph,proto3" json:"flamegraph,omitempty"`
	// contains filtered or unexported fields
}

func (*DiffResponse) ClearFlamegraph

func (x *DiffResponse) ClearFlamegraph()

func (*DiffResponse) GetFlamegraph

func (x *DiffResponse) GetFlamegraph() *FlameGraphDiff

func (*DiffResponse) HasFlamegraph

func (x *DiffResponse) HasFlamegraph() bool

func (*DiffResponse) ProtoMessage

func (*DiffResponse) ProtoMessage()

func (*DiffResponse) ProtoReflect

func (x *DiffResponse) ProtoReflect() protoreflect.Message

func (*DiffResponse) Reset

func (x *DiffResponse) Reset()

func (*DiffResponse) SetFlamegraph

func (x *DiffResponse) SetFlamegraph(v *FlameGraphDiff)

func (*DiffResponse) String

func (x *DiffResponse) String() string

type DiffResponse_builder

type DiffResponse_builder struct {
	Flamegraph *FlameGraphDiff
	// contains filtered or unexported fields
}

func (DiffResponse_builder) Build

func (b0 DiffResponse_builder) Build() *DiffResponse

type FlameGraph

type FlameGraph struct {
	Names   []string `protobuf:"bytes,1,rep,name=names,proto3" json:"names,omitempty"`
	Levels  []*Level `protobuf:"bytes,2,rep,name=levels,proto3" json:"levels,omitempty"`
	Total   int64    `protobuf:"varint,3,opt,name=total,proto3" json:"total,omitempty"`
	MaxSelf int64    `protobuf:"varint,4,opt,name=max_self,json=maxSelf,proto3" json:"max_self,omitempty"`
	// contains filtered or unexported fields
}

func (*FlameGraph) GetLevels

func (x *FlameGraph) GetLevels() []*Level

func (*FlameGraph) GetMaxSelf

func (x *FlameGraph) GetMaxSelf() int64

func (*FlameGraph) GetNames

func (x *FlameGraph) GetNames() []string

func (*FlameGraph) GetTotal

func (x *FlameGraph) GetTotal() int64

func (*FlameGraph) ProtoMessage

func (*FlameGraph) ProtoMessage()

func (*FlameGraph) ProtoReflect

func (x *FlameGraph) ProtoReflect() protoreflect.Message

func (*FlameGraph) Reset

func (x *FlameGraph) Reset()

func (*FlameGraph) SetLevels

func (x *FlameGraph) SetLevels(v []*Level)

func (*FlameGraph) SetMaxSelf

func (x *FlameGraph) SetMaxSelf(v int64)

func (*FlameGraph) SetNames

func (x *FlameGraph) SetNames(v []string)

func (*FlameGraph) SetTotal

func (x *FlameGraph) SetTotal(v int64)

func (*FlameGraph) String

func (x *FlameGraph) String() string

type FlameGraphDiff

type FlameGraphDiff struct {
	Names      []string `protobuf:"bytes,1,rep,name=names,proto3" json:"names,omitempty"`
	Levels     []*Level `protobuf:"bytes,2,rep,name=levels,proto3" json:"levels,omitempty"`
	Total      int64    `protobuf:"varint,3,opt,name=total,proto3" json:"total,omitempty"`
	MaxSelf    int64    `protobuf:"varint,4,opt,name=max_self,json=maxSelf,proto3" json:"max_self,omitempty"`
	LeftTicks  int64    `protobuf:"varint,5,opt,name=leftTicks,proto3" json:"leftTicks,omitempty"`
	RightTicks int64    `protobuf:"varint,6,opt,name=rightTicks,proto3" json:"rightTicks,omitempty"`
	// contains filtered or unexported fields
}

func (*FlameGraphDiff) GetLeftTicks

func (x *FlameGraphDiff) GetLeftTicks() int64

func (*FlameGraphDiff) GetLevels

func (x *FlameGraphDiff) GetLevels() []*Level

func (*FlameGraphDiff) GetMaxSelf

func (x *FlameGraphDiff) GetMaxSelf() int64

func (*FlameGraphDiff) GetNames

func (x *FlameGraphDiff) GetNames() []string

func (*FlameGraphDiff) GetRightTicks

func (x *FlameGraphDiff) GetRightTicks() int64

func (*FlameGraphDiff) GetTotal

func (x *FlameGraphDiff) GetTotal() int64

func (*FlameGraphDiff) ProtoMessage

func (*FlameGraphDiff) ProtoMessage()

func (*FlameGraphDiff) ProtoReflect

func (x *FlameGraphDiff) ProtoReflect() protoreflect.Message

func (*FlameGraphDiff) Reset

func (x *FlameGraphDiff) Reset()

func (*FlameGraphDiff) SetLeftTicks

func (x *FlameGraphDiff) SetLeftTicks(v int64)

func (*FlameGraphDiff) SetLevels

func (x *FlameGraphDiff) SetLevels(v []*Level)

func (*FlameGraphDiff) SetMaxSelf

func (x *FlameGraphDiff) SetMaxSelf(v int64)

func (*FlameGraphDiff) SetNames

func (x *FlameGraphDiff) SetNames(v []string)

func (*FlameGraphDiff) SetRightTicks

func (x *FlameGraphDiff) SetRightTicks(v int64)

func (*FlameGraphDiff) SetTotal

func (x *FlameGraphDiff) SetTotal(v int64)

func (*FlameGraphDiff) String

func (x *FlameGraphDiff) String() string

type FlameGraphDiff_builder

type FlameGraphDiff_builder struct {
	Names      []string
	Levels     []*Level
	Total      int64
	MaxSelf    int64
	LeftTicks  int64
	RightTicks int64
	// contains filtered or unexported fields
}

func (FlameGraphDiff_builder) Build

type FlameGraph_builder

type FlameGraph_builder struct {
	Names   []string
	Levels  []*Level
	Total   int64
	MaxSelf int64
	// contains filtered or unexported fields
}

func (FlameGraph_builder) Build

func (b0 FlameGraph_builder) Build() *FlameGraph

type Level

type Level struct {
	Values []int64 `protobuf:"varint,1,rep,packed,name=values,proto3" json:"values,omitempty"`
	// contains filtered or unexported fields
}

func (*Level) GetValues

func (x *Level) GetValues() []int64

func (*Level) ProtoMessage

func (*Level) ProtoMessage()

func (*Level) ProtoReflect

func (x *Level) ProtoReflect() protoreflect.Message

func (*Level) Reset

func (x *Level) Reset()

func (*Level) SetValues

func (x *Level) SetValues(v []int64)

func (*Level) String

func (x *Level) String() string

type Level_builder

type Level_builder struct {
	Values []int64
	// contains filtered or unexported fields
}

func (Level_builder) Build

func (b0 Level_builder) Build() *Level

type ProfileFormat

type ProfileFormat int32
const (
	ProfileFormat_PROFILE_FORMAT_UNSPECIFIED ProfileFormat = 0
	ProfileFormat_PROFILE_FORMAT_FLAMEGRAPH  ProfileFormat = 1
	ProfileFormat_PROFILE_FORMAT_TREE        ProfileFormat = 2
)

func (ProfileFormat) Descriptor

func (ProfileFormat) Enum

func (x ProfileFormat) Enum() *ProfileFormat

func (ProfileFormat) Number

func (ProfileFormat) String

func (x ProfileFormat) String() string

func (ProfileFormat) Type

type ProfileTypesRequest

type ProfileTypesRequest struct {

	// Milliseconds since epoch. If missing or zero, only the ingesters will be
	// queried.
	Start int64 `protobuf:"varint,1,opt,name=start,proto3" json:"start,omitempty"`
	// Milliseconds since epoch. If missing or zero, only the ingesters will be
	// queried.
	End int64 `protobuf:"varint,2,opt,name=end,proto3" json:"end,omitempty"`
	// contains filtered or unexported fields
}

func (*ProfileTypesRequest) GetEnd

func (x *ProfileTypesRequest) GetEnd() int64

func (*ProfileTypesRequest) GetStart

func (x *ProfileTypesRequest) GetStart() int64

func (*ProfileTypesRequest) ProtoMessage

func (*ProfileTypesRequest) ProtoMessage()

func (*ProfileTypesRequest) ProtoReflect

func (x *ProfileTypesRequest) ProtoReflect() protoreflect.Message

func (*ProfileTypesRequest) Reset

func (x *ProfileTypesRequest) Reset()

func (*ProfileTypesRequest) SetEnd

func (x *ProfileTypesRequest) SetEnd(v int64)

func (*ProfileTypesRequest) SetStart

func (x *ProfileTypesRequest) SetStart(v int64)

func (*ProfileTypesRequest) String

func (x *ProfileTypesRequest) String() string

type ProfileTypesRequest_builder

type ProfileTypesRequest_builder struct {

	// Milliseconds since epoch. If missing or zero, only the ingesters will be
	// queried.
	Start int64
	// Milliseconds since epoch. If missing or zero, only the ingesters will be
	// queried.
	End int64
	// contains filtered or unexported fields
}

func (ProfileTypesRequest_builder) Build

type ProfileTypesResponse

type ProfileTypesResponse struct {
	ProfileTypes []*v1.ProfileType `protobuf:"bytes,1,rep,name=profile_types,json=profileTypes,proto3" json:"profile_types,omitempty"`
	// contains filtered or unexported fields
}

func (*ProfileTypesResponse) GetProfileTypes

func (x *ProfileTypesResponse) GetProfileTypes() []*v1.ProfileType

func (*ProfileTypesResponse) ProtoMessage

func (*ProfileTypesResponse) ProtoMessage()

func (*ProfileTypesResponse) ProtoReflect

func (x *ProfileTypesResponse) ProtoReflect() protoreflect.Message

func (*ProfileTypesResponse) Reset

func (x *ProfileTypesResponse) Reset()

func (*ProfileTypesResponse) SetProfileTypes

func (x *ProfileTypesResponse) SetProfileTypes(v []*v1.ProfileType)

func (*ProfileTypesResponse) String

func (x *ProfileTypesResponse) String() string

type ProfileTypesResponse_builder

type ProfileTypesResponse_builder struct {
	ProfileTypes []*v1.ProfileType
	// contains filtered or unexported fields
}

func (ProfileTypesResponse_builder) Build

type QueryImpact

type QueryImpact struct {
	TotalBytesInTimeRange uint64 `` /* 131-byte string literal not displayed */
	TotalQueriedSeries    uint64 `protobuf:"varint,3,opt,name=total_queried_series,json=totalQueriedSeries,proto3" json:"total_queried_series,omitempty"`
	DeduplicationNeeded   bool   `protobuf:"varint,4,opt,name=deduplication_needed,json=deduplicationNeeded,proto3" json:"deduplication_needed,omitempty"`
	// contains filtered or unexported fields
}

func (*QueryImpact) GetDeduplicationNeeded

func (x *QueryImpact) GetDeduplicationNeeded() bool

func (*QueryImpact) GetTotalBytesInTimeRange

func (x *QueryImpact) GetTotalBytesInTimeRange() uint64

func (*QueryImpact) GetTotalQueriedSeries

func (x *QueryImpact) GetTotalQueriedSeries() uint64

func (*QueryImpact) ProtoMessage

func (*QueryImpact) ProtoMessage()

func (*QueryImpact) ProtoReflect

func (x *QueryImpact) ProtoReflect() protoreflect.Message

func (*QueryImpact) Reset

func (x *QueryImpact) Reset()

func (*QueryImpact) SetDeduplicationNeeded

func (x *QueryImpact) SetDeduplicationNeeded(v bool)

func (*QueryImpact) SetTotalBytesInTimeRange

func (x *QueryImpact) SetTotalBytesInTimeRange(v uint64)

func (*QueryImpact) SetTotalQueriedSeries

func (x *QueryImpact) SetTotalQueriedSeries(v uint64)

func (*QueryImpact) String

func (x *QueryImpact) String() string

type QueryImpact_builder

type QueryImpact_builder struct {
	TotalBytesInTimeRange uint64
	TotalQueriedSeries    uint64
	DeduplicationNeeded   bool
	// contains filtered or unexported fields
}

func (QueryImpact_builder) Build

func (b0 QueryImpact_builder) Build() *QueryImpact

type QueryScope

type QueryScope struct {
	ComponentType  string `protobuf:"bytes,1,opt,name=component_type,json=componentType,proto3" json:"component_type,omitempty"`     // a descriptive high level name of the component processing one part of the query (e.g., "short term storage")
	ComponentCount uint64 `protobuf:"varint,2,opt,name=component_count,json=componentCount,proto3" json:"component_count,omitempty"` // how many components of this type will process the query (indicator of read-path replication)
	BlockCount     uint64 `protobuf:"varint,3,opt,name=block_count,json=blockCount,proto3" json:"block_count,omitempty"`
	SeriesCount    uint64 `protobuf:"varint,4,opt,name=series_count,json=seriesCount,proto3" json:"series_count,omitempty"`
	ProfileCount   uint64 `protobuf:"varint,5,opt,name=profile_count,json=profileCount,proto3" json:"profile_count,omitempty"`
	SampleCount    uint64 `protobuf:"varint,6,opt,name=sample_count,json=sampleCount,proto3" json:"sample_count,omitempty"`
	IndexBytes     uint64 `protobuf:"varint,7,opt,name=index_bytes,json=indexBytes,proto3" json:"index_bytes,omitempty"`
	ProfileBytes   uint64 `protobuf:"varint,8,opt,name=profile_bytes,json=profileBytes,proto3" json:"profile_bytes,omitempty"`
	SymbolBytes    uint64 `protobuf:"varint,9,opt,name=symbol_bytes,json=symbolBytes,proto3" json:"symbol_bytes,omitempty"`
	// contains filtered or unexported fields
}

func (*QueryScope) GetBlockCount

func (x *QueryScope) GetBlockCount() uint64

func (*QueryScope) GetComponentCount

func (x *QueryScope) GetComponentCount() uint64

func (*QueryScope) GetComponentType

func (x *QueryScope) GetComponentType() string

func (*QueryScope) GetIndexBytes

func (x *QueryScope) GetIndexBytes() uint64

func (*QueryScope) GetProfileBytes

func (x *QueryScope) GetProfileBytes() uint64

func (*QueryScope) GetProfileCount

func (x *QueryScope) GetProfileCount() uint64

func (*QueryScope) GetSampleCount

func (x *QueryScope) GetSampleCount() uint64

func (*QueryScope) GetSeriesCount

func (x *QueryScope) GetSeriesCount() uint64

func (*QueryScope) GetSymbolBytes

func (x *QueryScope) GetSymbolBytes() uint64

func (*QueryScope) ProtoMessage

func (*QueryScope) ProtoMessage()

func (*QueryScope) ProtoReflect

func (x *QueryScope) ProtoReflect() protoreflect.Message

func (*QueryScope) Reset

func (x *QueryScope) Reset()

func (*QueryScope) SetBlockCount

func (x *QueryScope) SetBlockCount(v uint64)

func (*QueryScope) SetComponentCount

func (x *QueryScope) SetComponentCount(v uint64)

func (*QueryScope) SetComponentType

func (x *QueryScope) SetComponentType(v string)

func (*QueryScope) SetIndexBytes

func (x *QueryScope) SetIndexBytes(v uint64)

func (*QueryScope) SetProfileBytes

func (x *QueryScope) SetProfileBytes(v uint64)

func (*QueryScope) SetProfileCount

func (x *QueryScope) SetProfileCount(v uint64)

func (*QueryScope) SetSampleCount

func (x *QueryScope) SetSampleCount(v uint64)

func (*QueryScope) SetSeriesCount

func (x *QueryScope) SetSeriesCount(v uint64)

func (*QueryScope) SetSymbolBytes

func (x *QueryScope) SetSymbolBytes(v uint64)

func (*QueryScope) String

func (x *QueryScope) String() string

type QueryScope_builder

type QueryScope_builder struct {
	ComponentType  string
	ComponentCount uint64
	BlockCount     uint64
	SeriesCount    uint64
	ProfileCount   uint64
	SampleCount    uint64
	IndexBytes     uint64
	ProfileBytes   uint64
	SymbolBytes    uint64
	// contains filtered or unexported fields
}

func (QueryScope_builder) Build

func (b0 QueryScope_builder) Build() *QueryScope

type SelectMergeProfileRequest

type SelectMergeProfileRequest struct {
	ProfileTypeID string `protobuf:"bytes,1,opt,name=profile_typeID,json=profileTypeID,proto3" json:"profile_typeID,omitempty"`
	LabelSelector string `protobuf:"bytes,2,opt,name=label_selector,json=labelSelector,proto3" json:"label_selector,omitempty"`
	// Milliseconds since epoch.
	Start int64 `protobuf:"varint,3,opt,name=start,proto3" json:"start,omitempty"`
	// Milliseconds since epoch.
	End int64 `protobuf:"varint,4,opt,name=end,proto3" json:"end,omitempty"`
	// Limit the nodes returned to only show the node with the max_node's biggest total
	MaxNodes *int64 `protobuf:"varint,5,opt,name=max_nodes,json=maxNodes,proto3,oneof" json:"max_nodes,omitempty"`
	// Select stack traces that match the provided selector.
	StackTraceSelector *v1.StackTraceSelector `protobuf:"bytes,6,opt,name=stack_trace_selector,json=stackTraceSelector,proto3,oneof" json:"stack_trace_selector,omitempty"`
	// contains filtered or unexported fields
}

func (*SelectMergeProfileRequest) ClearMaxNodes

func (x *SelectMergeProfileRequest) ClearMaxNodes()

func (*SelectMergeProfileRequest) ClearStackTraceSelector

func (x *SelectMergeProfileRequest) ClearStackTraceSelector()

func (*SelectMergeProfileRequest) GetEnd

func (x *SelectMergeProfileRequest) GetEnd() int64

func (*SelectMergeProfileRequest) GetLabelSelector

func (x *SelectMergeProfileRequest) GetLabelSelector() string

func (*SelectMergeProfileRequest) GetMaxNodes

func (x *SelectMergeProfileRequest) GetMaxNodes() int64

func (*SelectMergeProfileRequest) GetProfileTypeID

func (x *SelectMergeProfileRequest) GetProfileTypeID() string

func (*SelectMergeProfileRequest) GetStackTraceSelector

func (x *SelectMergeProfileRequest) GetStackTraceSelector() *v1.StackTraceSelector

func (*SelectMergeProfileRequest) GetStart

func (x *SelectMergeProfileRequest) GetStart() int64

func (*SelectMergeProfileRequest) HasMaxNodes

func (x *SelectMergeProfileRequest) HasMaxNodes() bool

func (*SelectMergeProfileRequest) HasStackTraceSelector

func (x *SelectMergeProfileRequest) HasStackTraceSelector() bool

func (*SelectMergeProfileRequest) ProtoMessage

func (*SelectMergeProfileRequest) ProtoMessage()

func (*SelectMergeProfileRequest) ProtoReflect

func (*SelectMergeProfileRequest) Reset

func (x *SelectMergeProfileRequest) Reset()

func (*SelectMergeProfileRequest) SetEnd

func (x *SelectMergeProfileRequest) SetEnd(v int64)

func (*SelectMergeProfileRequest) SetLabelSelector

func (x *SelectMergeProfileRequest) SetLabelSelector(v string)

func (*SelectMergeProfileRequest) SetMaxNodes

func (x *SelectMergeProfileRequest) SetMaxNodes(v int64)

func (*SelectMergeProfileRequest) SetProfileTypeID

func (x *SelectMergeProfileRequest) SetProfileTypeID(v string)

func (*SelectMergeProfileRequest) SetStackTraceSelector

func (x *SelectMergeProfileRequest) SetStackTraceSelector(v *v1.StackTraceSelector)

func (*SelectMergeProfileRequest) SetStart

func (x *SelectMergeProfileRequest) SetStart(v int64)

func (*SelectMergeProfileRequest) String

func (x *SelectMergeProfileRequest) String() string

type SelectMergeProfileRequest_builder

type SelectMergeProfileRequest_builder struct {
	ProfileTypeID string
	LabelSelector string
	// Milliseconds since epoch.
	Start int64
	// Milliseconds since epoch.
	End int64
	// Limit the nodes returned to only show the node with the max_node's biggest total
	MaxNodes *int64
	// Select stack traces that match the provided selector.
	StackTraceSelector *v1.StackTraceSelector
	// contains filtered or unexported fields
}

func (SelectMergeProfileRequest_builder) Build

type SelectMergeSpanProfileRequest

type SelectMergeSpanProfileRequest struct {
	ProfileTypeID string   `protobuf:"bytes,1,opt,name=profile_typeID,json=profileTypeID,proto3" json:"profile_typeID,omitempty"`
	LabelSelector string   `protobuf:"bytes,2,opt,name=label_selector,json=labelSelector,proto3" json:"label_selector,omitempty"`
	SpanSelector  []string `protobuf:"bytes,3,rep,name=span_selector,json=spanSelector,proto3" json:"span_selector,omitempty"`
	// Milliseconds since epoch.
	Start int64 `protobuf:"varint,4,opt,name=start,proto3" json:"start,omitempty"`
	// Milliseconds since epoch.
	End int64 `protobuf:"varint,5,opt,name=end,proto3" json:"end,omitempty"`
	// Limit the nodes returned to only show the node with the max_node's biggest total
	MaxNodes *int64 `protobuf:"varint,6,opt,name=max_nodes,json=maxNodes,proto3,oneof" json:"max_nodes,omitempty"`
	// Profile format specifies the format of profile to be returned.
	// If not specified, the profile will be returned in flame graph format.
	Format ProfileFormat `protobuf:"varint,7,opt,name=format,proto3,enum=querier.v1.ProfileFormat" json:"format,omitempty"`
	// contains filtered or unexported fields
}

func (*SelectMergeSpanProfileRequest) ClearMaxNodes

func (x *SelectMergeSpanProfileRequest) ClearMaxNodes()

func (*SelectMergeSpanProfileRequest) GetEnd

func (*SelectMergeSpanProfileRequest) GetFormat

func (*SelectMergeSpanProfileRequest) GetLabelSelector

func (x *SelectMergeSpanProfileRequest) GetLabelSelector() string

func (*SelectMergeSpanProfileRequest) GetMaxNodes

func (x *SelectMergeSpanProfileRequest) GetMaxNodes() int64

func (*SelectMergeSpanProfileRequest) GetProfileTypeID

func (x *SelectMergeSpanProfileRequest) GetProfileTypeID() string

func (*SelectMergeSpanProfileRequest) GetSpanSelector

func (x *SelectMergeSpanProfileRequest) GetSpanSelector() []string

func (*SelectMergeSpanProfileRequest) GetStart

func (x *SelectMergeSpanProfileRequest) GetStart() int64

func (*SelectMergeSpanProfileRequest) HasMaxNodes

func (x *SelectMergeSpanProfileRequest) HasMaxNodes() bool

func (*SelectMergeSpanProfileRequest) ProtoMessage

func (*SelectMergeSpanProfileRequest) ProtoMessage()

func (*SelectMergeSpanProfileRequest) ProtoReflect

func (*SelectMergeSpanProfileRequest) Reset

func (x *SelectMergeSpanProfileRequest) Reset()

func (*SelectMergeSpanProfileRequest) SetEnd

func (x *SelectMergeSpanProfileRequest) SetEnd(v int64)

func (*SelectMergeSpanProfileRequest) SetFormat

func (*SelectMergeSpanProfileRequest) SetLabelSelector

func (x *SelectMergeSpanProfileRequest) SetLabelSelector(v string)

func (*SelectMergeSpanProfileRequest) SetMaxNodes

func (x *SelectMergeSpanProfileRequest) SetMaxNodes(v int64)

func (*SelectMergeSpanProfileRequest) SetProfileTypeID

func (x *SelectMergeSpanProfileRequest) SetProfileTypeID(v string)

func (*SelectMergeSpanProfileRequest) SetSpanSelector

func (x *SelectMergeSpanProfileRequest) SetSpanSelector(v []string)

func (*SelectMergeSpanProfileRequest) SetStart

func (x *SelectMergeSpanProfileRequest) SetStart(v int64)

func (*SelectMergeSpanProfileRequest) String

type SelectMergeSpanProfileRequest_builder

type SelectMergeSpanProfileRequest_builder struct {
	ProfileTypeID string
	LabelSelector string
	SpanSelector  []string
	// Milliseconds since epoch.
	Start int64
	// Milliseconds since epoch.
	End int64
	// Limit the nodes returned to only show the node with the max_node's biggest total
	MaxNodes *int64
	// Profile format specifies the format of profile to be returned.
	// If not specified, the profile will be returned in flame graph format.
	Format ProfileFormat
	// contains filtered or unexported fields
}

func (SelectMergeSpanProfileRequest_builder) Build

type SelectMergeSpanProfileResponse

type SelectMergeSpanProfileResponse struct {
	Flamegraph *FlameGraph `protobuf:"bytes,1,opt,name=flamegraph,proto3" json:"flamegraph,omitempty"`
	// Pyroscope tree bytes.
	Tree []byte `protobuf:"bytes,2,opt,name=tree,proto3" json:"tree,omitempty"`
	// contains filtered or unexported fields
}

func (*SelectMergeSpanProfileResponse) ClearFlamegraph

func (x *SelectMergeSpanProfileResponse) ClearFlamegraph()

func (*SelectMergeSpanProfileResponse) GetFlamegraph

func (x *SelectMergeSpanProfileResponse) GetFlamegraph() *FlameGraph

func (*SelectMergeSpanProfileResponse) GetTree

func (x *SelectMergeSpanProfileResponse) GetTree() []byte

func (*SelectMergeSpanProfileResponse) HasFlamegraph

func (x *SelectMergeSpanProfileResponse) HasFlamegraph() bool

func (*SelectMergeSpanProfileResponse) ProtoMessage

func (*SelectMergeSpanProfileResponse) ProtoMessage()

func (*SelectMergeSpanProfileResponse) ProtoReflect

func (*SelectMergeSpanProfileResponse) Reset

func (x *SelectMergeSpanProfileResponse) Reset()

func (*SelectMergeSpanProfileResponse) SetFlamegraph

func (x *SelectMergeSpanProfileResponse) SetFlamegraph(v *FlameGraph)

func (*SelectMergeSpanProfileResponse) SetTree

func (x *SelectMergeSpanProfileResponse) SetTree(v []byte)

func (*SelectMergeSpanProfileResponse) String

type SelectMergeSpanProfileResponse_builder

type SelectMergeSpanProfileResponse_builder struct {
	Flamegraph *FlameGraph
	// Pyroscope tree bytes.
	Tree []byte
	// contains filtered or unexported fields
}

func (SelectMergeSpanProfileResponse_builder) Build

type SelectMergeStacktracesRequest

type SelectMergeStacktracesRequest struct {
	ProfileTypeID string `protobuf:"bytes,1,opt,name=profile_typeID,json=profileTypeID,proto3" json:"profile_typeID,omitempty"`
	LabelSelector string `protobuf:"bytes,2,opt,name=label_selector,json=labelSelector,proto3" json:"label_selector,omitempty"`
	// Milliseconds since epoch.
	Start int64 `protobuf:"varint,3,opt,name=start,proto3" json:"start,omitempty"`
	// Milliseconds since epoch.
	End int64 `protobuf:"varint,4,opt,name=end,proto3" json:"end,omitempty"`
	// Limit the nodes returned to only show the node with the max_node's biggest total
	MaxNodes *int64 `protobuf:"varint,5,opt,name=max_nodes,json=maxNodes,proto3,oneof" json:"max_nodes,omitempty"`
	// Profile format specifies the format of profile to be returned.
	// If not specified, the profile will be returned in flame graph format.
	Format ProfileFormat `protobuf:"varint,6,opt,name=format,proto3,enum=querier.v1.ProfileFormat" json:"format,omitempty"`
	// contains filtered or unexported fields
}

func (*SelectMergeStacktracesRequest) ClearMaxNodes

func (x *SelectMergeStacktracesRequest) ClearMaxNodes()

func (*SelectMergeStacktracesRequest) GetEnd

func (*SelectMergeStacktracesRequest) GetFormat

func (*SelectMergeStacktracesRequest) GetLabelSelector

func (x *SelectMergeStacktracesRequest) GetLabelSelector() string

func (*SelectMergeStacktracesRequest) GetMaxNodes

func (x *SelectMergeStacktracesRequest) GetMaxNodes() int64

func (*SelectMergeStacktracesRequest) GetProfileTypeID

func (x *SelectMergeStacktracesRequest) GetProfileTypeID() string

func (*SelectMergeStacktracesRequest) GetStart

func (x *SelectMergeStacktracesRequest) GetStart() int64

func (*SelectMergeStacktracesRequest) HasMaxNodes

func (x *SelectMergeStacktracesRequest) HasMaxNodes() bool

func (*SelectMergeStacktracesRequest) ProtoMessage

func (*SelectMergeStacktracesRequest) ProtoMessage()

func (*SelectMergeStacktracesRequest) ProtoReflect

func (*SelectMergeStacktracesRequest) Reset

func (x *SelectMergeStacktracesRequest) Reset()

func (*SelectMergeStacktracesRequest) SetEnd

func (x *SelectMergeStacktracesRequest) SetEnd(v int64)

func (*SelectMergeStacktracesRequest) SetFormat

func (*SelectMergeStacktracesRequest) SetLabelSelector

func (x *SelectMergeStacktracesRequest) SetLabelSelector(v string)

func (*SelectMergeStacktracesRequest) SetMaxNodes

func (x *SelectMergeStacktracesRequest) SetMaxNodes(v int64)

func (*SelectMergeStacktracesRequest) SetProfileTypeID

func (x *SelectMergeStacktracesRequest) SetProfileTypeID(v string)

func (*SelectMergeStacktracesRequest) SetStart

func (x *SelectMergeStacktracesRequest) SetStart(v int64)

func (*SelectMergeStacktracesRequest) String

type SelectMergeStacktracesRequest_builder

type SelectMergeStacktracesRequest_builder struct {
	ProfileTypeID string
	LabelSelector string
	// Milliseconds since epoch.
	Start int64
	// Milliseconds since epoch.
	End int64
	// Limit the nodes returned to only show the node with the max_node's biggest total
	MaxNodes *int64
	// Profile format specifies the format of profile to be returned.
	// If not specified, the profile will be returned in flame graph format.
	Format ProfileFormat
	// contains filtered or unexported fields
}

func (SelectMergeStacktracesRequest_builder) Build

type SelectMergeStacktracesResponse

type SelectMergeStacktracesResponse struct {
	Flamegraph *FlameGraph `protobuf:"bytes,1,opt,name=flamegraph,proto3" json:"flamegraph,omitempty"`
	// Pyroscope tree bytes.
	Tree []byte `protobuf:"bytes,2,opt,name=tree,proto3" json:"tree,omitempty"`
	// contains filtered or unexported fields
}

func (*SelectMergeStacktracesResponse) ClearFlamegraph

func (x *SelectMergeStacktracesResponse) ClearFlamegraph()

func (*SelectMergeStacktracesResponse) GetFlamegraph

func (x *SelectMergeStacktracesResponse) GetFlamegraph() *FlameGraph

func (*SelectMergeStacktracesResponse) GetTree

func (x *SelectMergeStacktracesResponse) GetTree() []byte

func (*SelectMergeStacktracesResponse) HasFlamegraph

func (x *SelectMergeStacktracesResponse) HasFlamegraph() bool

func (*SelectMergeStacktracesResponse) ProtoMessage

func (*SelectMergeStacktracesResponse) ProtoMessage()

func (*SelectMergeStacktracesResponse) ProtoReflect

func (*SelectMergeStacktracesResponse) Reset

func (x *SelectMergeStacktracesResponse) Reset()

func (*SelectMergeStacktracesResponse) SetFlamegraph

func (x *SelectMergeStacktracesResponse) SetFlamegraph(v *FlameGraph)

func (*SelectMergeStacktracesResponse) SetTree

func (x *SelectMergeStacktracesResponse) SetTree(v []byte)

func (*SelectMergeStacktracesResponse) String

type SelectMergeStacktracesResponse_builder

type SelectMergeStacktracesResponse_builder struct {
	Flamegraph *FlameGraph
	// Pyroscope tree bytes.
	Tree []byte
	// contains filtered or unexported fields
}

func (SelectMergeStacktracesResponse_builder) Build

type SelectSeriesRequest

type SelectSeriesRequest struct {
	ProfileTypeID string `protobuf:"bytes,1,opt,name=profile_typeID,json=profileTypeID,proto3" json:"profile_typeID,omitempty"`
	LabelSelector string `protobuf:"bytes,2,opt,name=label_selector,json=labelSelector,proto3" json:"label_selector,omitempty"`
	// Milliseconds since epoch.
	Start int64 `protobuf:"varint,3,opt,name=start,proto3" json:"start,omitempty"`
	// Milliseconds since epoch.
	End     int64    `protobuf:"varint,4,opt,name=end,proto3" json:"end,omitempty"`
	GroupBy []string `protobuf:"bytes,5,rep,name=group_by,json=groupBy,proto3" json:"group_by,omitempty"`
	Step    float64  `protobuf:"fixed64,6,opt,name=step,proto3" json:"step,omitempty"`
	// Query resolution step width in seconds
	Aggregation *v1.TimeSeriesAggregationType `protobuf:"varint,7,opt,name=aggregation,proto3,enum=types.v1.TimeSeriesAggregationType,oneof" json:"aggregation,omitempty"`
	// Select stack traces that match the provided selector.
	StackTraceSelector *v1.StackTraceSelector `protobuf:"bytes,8,opt,name=stack_trace_selector,json=stackTraceSelector,proto3,oneof" json:"stack_trace_selector,omitempty"`
	// Select the top N series by total value.
	Limit *int64 `protobuf:"varint,9,opt,name=limit,proto3,oneof" json:"limit,omitempty"`
	// contains filtered or unexported fields
}

func (*SelectSeriesRequest) ClearAggregation

func (x *SelectSeriesRequest) ClearAggregation()

func (*SelectSeriesRequest) ClearLimit

func (x *SelectSeriesRequest) ClearLimit()

func (*SelectSeriesRequest) ClearStackTraceSelector

func (x *SelectSeriesRequest) ClearStackTraceSelector()

func (*SelectSeriesRequest) GetAggregation

func (x *SelectSeriesRequest) GetAggregation() v1.TimeSeriesAggregationType

func (*SelectSeriesRequest) GetEnd

func (x *SelectSeriesRequest) GetEnd() int64

func (*SelectSeriesRequest) GetGroupBy

func (x *SelectSeriesRequest) GetGroupBy() []string

func (*SelectSeriesRequest) GetLabelSelector

func (x *SelectSeriesRequest) GetLabelSelector() string

func (*SelectSeriesRequest) GetLimit

func (x *SelectSeriesRequest) GetLimit() int64

func (*SelectSeriesRequest) GetProfileTypeID

func (x *SelectSeriesRequest) GetProfileTypeID() string

func (*SelectSeriesRequest) GetStackTraceSelector

func (x *SelectSeriesRequest) GetStackTraceSelector() *v1.StackTraceSelector

func (*SelectSeriesRequest) GetStart

func (x *SelectSeriesRequest) GetStart() int64

func (*SelectSeriesRequest) GetStep

func (x *SelectSeriesRequest) GetStep() float64

func (*SelectSeriesRequest) HasAggregation

func (x *SelectSeriesRequest) HasAggregation() bool

func (*SelectSeriesRequest) HasLimit

func (x *SelectSeriesRequest) HasLimit() bool

func (*SelectSeriesRequest) HasStackTraceSelector

func (x *SelectSeriesRequest) HasStackTraceSelector() bool

func (*SelectSeriesRequest) ProtoMessage

func (*SelectSeriesRequest) ProtoMessage()

func (*SelectSeriesRequest) ProtoReflect

func (x *SelectSeriesRequest) ProtoReflect() protoreflect.Message

func (*SelectSeriesRequest) Reset

func (x *SelectSeriesRequest) Reset()

func (*SelectSeriesRequest) SetAggregation

func (x *SelectSeriesRequest) SetAggregation(v v1.TimeSeriesAggregationType)

func (*SelectSeriesRequest) SetEnd

func (x *SelectSeriesRequest) SetEnd(v int64)

func (*SelectSeriesRequest) SetGroupBy

func (x *SelectSeriesRequest) SetGroupBy(v []string)

func (*SelectSeriesRequest) SetLabelSelector

func (x *SelectSeriesRequest) SetLabelSelector(v string)

func (*SelectSeriesRequest) SetLimit

func (x *SelectSeriesRequest) SetLimit(v int64)

func (*SelectSeriesRequest) SetProfileTypeID

func (x *SelectSeriesRequest) SetProfileTypeID(v string)

func (*SelectSeriesRequest) SetStackTraceSelector

func (x *SelectSeriesRequest) SetStackTraceSelector(v *v1.StackTraceSelector)

func (*SelectSeriesRequest) SetStart

func (x *SelectSeriesRequest) SetStart(v int64)

func (*SelectSeriesRequest) SetStep

func (x *SelectSeriesRequest) SetStep(v float64)

func (*SelectSeriesRequest) String

func (x *SelectSeriesRequest) String() string

type SelectSeriesRequest_builder

type SelectSeriesRequest_builder struct {
	ProfileTypeID string
	LabelSelector string
	// Milliseconds since epoch.
	Start int64
	// Milliseconds since epoch.
	End     int64
	GroupBy []string
	Step    float64
	// Query resolution step width in seconds
	Aggregation *v1.TimeSeriesAggregationType
	// Select stack traces that match the provided selector.
	StackTraceSelector *v1.StackTraceSelector
	// Select the top N series by total value.
	Limit *int64
	// contains filtered or unexported fields
}

func (SelectSeriesRequest_builder) Build

type SelectSeriesResponse

type SelectSeriesResponse struct {
	Series []*v1.Series `protobuf:"bytes,1,rep,name=series,proto3" json:"series,omitempty"`
	// contains filtered or unexported fields
}

func (*SelectSeriesResponse) GetSeries

func (x *SelectSeriesResponse) GetSeries() []*v1.Series

func (*SelectSeriesResponse) ProtoMessage

func (*SelectSeriesResponse) ProtoMessage()

func (*SelectSeriesResponse) ProtoReflect

func (x *SelectSeriesResponse) ProtoReflect() protoreflect.Message

func (*SelectSeriesResponse) Reset

func (x *SelectSeriesResponse) Reset()

func (*SelectSeriesResponse) SetSeries

func (x *SelectSeriesResponse) SetSeries(v []*v1.Series)

func (*SelectSeriesResponse) String

func (x *SelectSeriesResponse) String() string

type SelectSeriesResponse_builder

type SelectSeriesResponse_builder struct {
	Series []*v1.Series
	// contains filtered or unexported fields
}

func (SelectSeriesResponse_builder) Build

type SeriesRequest

type SeriesRequest struct {
	Matchers   []string `protobuf:"bytes,1,rep,name=matchers,proto3" json:"matchers,omitempty"`
	LabelNames []string `protobuf:"bytes,2,rep,name=label_names,json=labelNames,proto3" json:"label_names,omitempty"`
	// Milliseconds since epoch. If missing or zero, only the ingesters will be
	// queried.
	Start int64 `protobuf:"varint,3,opt,name=start,proto3" json:"start,omitempty"`
	// Milliseconds since epoch. If missing or zero, only the ingesters will be
	// queried.
	End int64 `protobuf:"varint,4,opt,name=end,proto3" json:"end,omitempty"`
	// contains filtered or unexported fields
}

func (*SeriesRequest) GetEnd

func (x *SeriesRequest) GetEnd() int64

func (*SeriesRequest) GetLabelNames

func (x *SeriesRequest) GetLabelNames() []string

func (*SeriesRequest) GetMatchers

func (x *SeriesRequest) GetMatchers() []string

func (*SeriesRequest) GetStart

func (x *SeriesRequest) GetStart() int64

func (*SeriesRequest) ProtoMessage

func (*SeriesRequest) ProtoMessage()

func (*SeriesRequest) ProtoReflect

func (x *SeriesRequest) ProtoReflect() protoreflect.Message

func (*SeriesRequest) Reset

func (x *SeriesRequest) Reset()

func (*SeriesRequest) SetEnd

func (x *SeriesRequest) SetEnd(v int64)

func (*SeriesRequest) SetLabelNames

func (x *SeriesRequest) SetLabelNames(v []string)

func (*SeriesRequest) SetMatchers

func (x *SeriesRequest) SetMatchers(v []string)

func (*SeriesRequest) SetStart

func (x *SeriesRequest) SetStart(v int64)

func (*SeriesRequest) String

func (x *SeriesRequest) String() string

type SeriesRequest_builder

type SeriesRequest_builder struct {
	Matchers   []string
	LabelNames []string
	// Milliseconds since epoch. If missing or zero, only the ingesters will be
	// queried.
	Start int64
	// Milliseconds since epoch. If missing or zero, only the ingesters will be
	// queried.
	End int64
	// contains filtered or unexported fields
}

func (SeriesRequest_builder) Build

type SeriesResponse

type SeriesResponse struct {
	LabelsSet []*v1.Labels `protobuf:"bytes,2,rep,name=labels_set,json=labelsSet,proto3" json:"labels_set,omitempty"`
	// contains filtered or unexported fields
}

func (*SeriesResponse) GetLabelsSet

func (x *SeriesResponse) GetLabelsSet() []*v1.Labels

func (*SeriesResponse) ProtoMessage

func (*SeriesResponse) ProtoMessage()

func (*SeriesResponse) ProtoReflect

func (x *SeriesResponse) ProtoReflect() protoreflect.Message

func (*SeriesResponse) Reset

func (x *SeriesResponse) Reset()

func (*SeriesResponse) SetLabelsSet

func (x *SeriesResponse) SetLabelsSet(v []*v1.Labels)

func (*SeriesResponse) String

func (x *SeriesResponse) String() string

type SeriesResponse_builder

type SeriesResponse_builder struct {
	LabelsSet []*v1.Labels
	// contains filtered or unexported fields
}

func (SeriesResponse_builder) Build

Source Files

  • querier.pb.go

Jump to