Documentation
¶
Index ¶
- Variables
- type CommitAuthor
- func (x *CommitAuthor) GetAvatarURL() string
- func (x *CommitAuthor) GetLogin() string
- func (*CommitAuthor) ProtoMessage()
- func (x *CommitAuthor) ProtoReflect() protoreflect.Message
- func (x *CommitAuthor) Reset()
- func (x *CommitAuthor) SetAvatarURL(v string)
- func (x *CommitAuthor) SetLogin(v string)
- func (x *CommitAuthor) String() string
- type CommitAuthor_builder
- type CommitInfo
- func (x *CommitInfo) ClearAuthor()
- func (x *CommitInfo) GetAuthor() *CommitAuthor
- func (x *CommitInfo) GetDate() string
- func (x *CommitInfo) GetMessage() string
- func (x *CommitInfo) GetSha() string
- func (x *CommitInfo) GetURL() string
- func (x *CommitInfo) HasAuthor() bool
- func (*CommitInfo) ProtoMessage()
- func (x *CommitInfo) ProtoReflect() protoreflect.Message
- func (x *CommitInfo) Reset()
- func (x *CommitInfo) SetAuthor(v *CommitAuthor)
- func (x *CommitInfo) SetDate(v string)
- func (x *CommitInfo) SetMessage(v string)
- func (x *CommitInfo) SetSha(v string)
- func (x *CommitInfo) SetURL(v string)
- func (x *CommitInfo) String() string
- type CommitInfo_builder
- type GetCommitRequest
- func (x *GetCommitRequest) GetRef() string
- func (x *GetCommitRequest) GetRepositoryURL() string
- func (*GetCommitRequest) ProtoMessage()
- func (x *GetCommitRequest) ProtoReflect() protoreflect.Message
- func (x *GetCommitRequest) Reset()
- func (x *GetCommitRequest) SetRef(v string)
- func (x *GetCommitRequest) SetRepositoryURL(v string)
- func (x *GetCommitRequest) String() string
- type GetCommitRequest_builder
- type GetCommitResponse
- func (x *GetCommitResponse) ClearAuthor()
- func (x *GetCommitResponse) GetAuthor() *CommitAuthor
- func (x *GetCommitResponse) GetDate() string
- func (x *GetCommitResponse) GetMessage() string
- func (x *GetCommitResponse) GetSha() string
- func (x *GetCommitResponse) GetURL() string
- func (x *GetCommitResponse) HasAuthor() bool
- func (*GetCommitResponse) ProtoMessage()
- func (x *GetCommitResponse) ProtoReflect() protoreflect.Message
- func (x *GetCommitResponse) Reset()
- func (x *GetCommitResponse) SetAuthor(v *CommitAuthor)
- func (x *GetCommitResponse) SetDate(v string)
- func (x *GetCommitResponse) SetMessage(v string)
- func (x *GetCommitResponse) SetSha(v string)
- func (x *GetCommitResponse) SetURL(v string)
- func (x *GetCommitResponse) String() string
- type GetCommitResponse_builder
- type GetCommitsRequest
- func (x *GetCommitsRequest) GetRefs() []string
- func (x *GetCommitsRequest) GetRepositoryUrl() string
- func (*GetCommitsRequest) ProtoMessage()
- func (x *GetCommitsRequest) ProtoReflect() protoreflect.Message
- func (x *GetCommitsRequest) Reset()
- func (x *GetCommitsRequest) SetRefs(v []string)
- func (x *GetCommitsRequest) SetRepositoryUrl(v string)
- func (x *GetCommitsRequest) String() string
- type GetCommitsRequest_builder
- type GetCommitsResponse
- func (x *GetCommitsResponse) GetCommits() []*CommitInfo
- func (*GetCommitsResponse) ProtoMessage()
- func (x *GetCommitsResponse) ProtoReflect() protoreflect.Message
- func (x *GetCommitsResponse) Reset()
- func (x *GetCommitsResponse) SetCommits(v []*CommitInfo)
- func (x *GetCommitsResponse) String() string
- type GetCommitsResponse_builder
- type GetFileRequest
- func (x *GetFileRequest) GetLocalPath() string
- func (x *GetFileRequest) GetRef() string
- func (x *GetFileRequest) GetRepositoryURL() string
- func (x *GetFileRequest) GetRootPath() string
- func (*GetFileRequest) ProtoMessage()
- func (x *GetFileRequest) ProtoReflect() protoreflect.Message
- func (x *GetFileRequest) Reset()
- func (x *GetFileRequest) SetLocalPath(v string)
- func (x *GetFileRequest) SetRef(v string)
- func (x *GetFileRequest) SetRepositoryURL(v string)
- func (x *GetFileRequest) SetRootPath(v string)
- func (x *GetFileRequest) String() string
- type GetFileRequest_builder
- type GetFileResponse
- func (x *GetFileResponse) GetContent() string
- func (x *GetFileResponse) GetURL() string
- func (*GetFileResponse) ProtoMessage()
- func (x *GetFileResponse) ProtoReflect() protoreflect.Message
- func (x *GetFileResponse) Reset()
- func (x *GetFileResponse) SetContent(v string)
- func (x *GetFileResponse) SetURL(v string)
- func (x *GetFileResponse) String() string
- type GetFileResponse_builder
- type GithubAppRequest
- type GithubAppRequest_builder
- type GithubAppResponse
- type GithubAppResponse_builder
- type GithubLoginRequest
- func (x *GithubLoginRequest) GetAuthorizationCode() string
- func (*GithubLoginRequest) ProtoMessage()
- func (x *GithubLoginRequest) ProtoReflect() protoreflect.Message
- func (x *GithubLoginRequest) Reset()
- func (x *GithubLoginRequest) SetAuthorizationCode(v string)
- func (x *GithubLoginRequest) String() string
- type GithubLoginRequest_builder
- type GithubLoginResponse
- func (x *GithubLoginResponse) GetCookie() string
- func (x *GithubLoginResponse) GetRefreshTokenExpiresAt() int64
- func (x *GithubLoginResponse) GetToken() string
- func (x *GithubLoginResponse) GetTokenExpiresAt() int64
- func (*GithubLoginResponse) ProtoMessage()
- func (x *GithubLoginResponse) ProtoReflect() protoreflect.Message
- func (x *GithubLoginResponse) Reset()
- func (x *GithubLoginResponse) SetCookie(v string)
- func (x *GithubLoginResponse) SetRefreshTokenExpiresAt(v int64)
- func (x *GithubLoginResponse) SetToken(v string)
- func (x *GithubLoginResponse) SetTokenExpiresAt(v int64)
- func (x *GithubLoginResponse) String() string
- type GithubLoginResponse_builder
- type GithubRefreshRequest
- type GithubRefreshRequest_builder
- type GithubRefreshResponse
- func (x *GithubRefreshResponse) GetCookie() string
- func (x *GithubRefreshResponse) GetRefreshTokenExpiresAt() int64
- func (x *GithubRefreshResponse) GetToken() string
- func (x *GithubRefreshResponse) GetTokenExpiresAt() int64
- func (*GithubRefreshResponse) ProtoMessage()
- func (x *GithubRefreshResponse) ProtoReflect() protoreflect.Message
- func (x *GithubRefreshResponse) Reset()
- func (x *GithubRefreshResponse) SetCookie(v string)
- func (x *GithubRefreshResponse) SetRefreshTokenExpiresAt(v int64)
- func (x *GithubRefreshResponse) SetToken(v string)
- func (x *GithubRefreshResponse) SetTokenExpiresAt(v int64)
- func (x *GithubRefreshResponse) String() string
- type GithubRefreshResponse_builder
Constants ¶
This section is empty.
Variables ¶
var File_vcs_v1_vcs_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type CommitAuthor ¶
type CommitAuthor struct {
// the author login
Login string `protobuf:"bytes,1,opt,name=login,proto3" json:"login,omitempty"`
// the author avatar URL
AvatarURL string `protobuf:"bytes,2,opt,name=avatarURL,proto3" json:"avatarURL,omitempty"`
// contains filtered or unexported fields
}
func (*CommitAuthor) GetAvatarURL ¶
func (x *CommitAuthor) GetAvatarURL() string
func (*CommitAuthor) GetLogin ¶
func (x *CommitAuthor) GetLogin() string
func (*CommitAuthor) ProtoMessage ¶
func (*CommitAuthor) ProtoMessage()
func (*CommitAuthor) ProtoReflect ¶
func (x *CommitAuthor) ProtoReflect() protoreflect.Message
func (*CommitAuthor) Reset ¶
func (x *CommitAuthor) Reset()
func (*CommitAuthor) SetAvatarURL ¶
func (x *CommitAuthor) SetAvatarURL(v string)
func (*CommitAuthor) SetLogin ¶
func (x *CommitAuthor) SetLogin(v string)
func (*CommitAuthor) String ¶
func (x *CommitAuthor) String() string
type CommitAuthor_builder ¶
type CommitAuthor_builder struct {
// the author login
Login string
// the author avatar URL
AvatarURL string
// contains filtered or unexported fields
}
func (CommitAuthor_builder) Build ¶
func (b0 CommitAuthor_builder) Build() *CommitAuthor
type CommitInfo ¶
type CommitInfo struct {
// the commit message
Message string `protobuf:"bytes,1,opt,name=message,proto3" json:"message,omitempty"`
// the commit author login
Author *CommitAuthor `protobuf:"bytes,2,opt,name=author,proto3" json:"author,omitempty"`
// the commit date
Date string `protobuf:"bytes,3,opt,name=date,proto3" json:"date,omitempty"`
// the commit sha
Sha string `protobuf:"bytes,4,opt,name=sha,proto3" json:"sha,omitempty"`
// the full URL to the commit
URL string `protobuf:"bytes,5,opt,name=URL,proto3" json:"URL,omitempty"`
// contains filtered or unexported fields
}
func (*CommitInfo) ClearAuthor ¶
func (x *CommitInfo) ClearAuthor()
func (*CommitInfo) GetAuthor ¶
func (x *CommitInfo) GetAuthor() *CommitAuthor
func (*CommitInfo) GetDate ¶
func (x *CommitInfo) GetDate() string
func (*CommitInfo) GetMessage ¶
func (x *CommitInfo) GetMessage() string
func (*CommitInfo) GetSha ¶
func (x *CommitInfo) GetSha() string
func (*CommitInfo) GetURL ¶
func (x *CommitInfo) GetURL() string
func (*CommitInfo) HasAuthor ¶
func (x *CommitInfo) HasAuthor() bool
func (*CommitInfo) ProtoMessage ¶
func (*CommitInfo) ProtoMessage()
func (*CommitInfo) ProtoReflect ¶
func (x *CommitInfo) ProtoReflect() protoreflect.Message
func (*CommitInfo) Reset ¶
func (x *CommitInfo) Reset()
func (*CommitInfo) SetAuthor ¶
func (x *CommitInfo) SetAuthor(v *CommitAuthor)
func (*CommitInfo) SetDate ¶
func (x *CommitInfo) SetDate(v string)
func (*CommitInfo) SetMessage ¶
func (x *CommitInfo) SetMessage(v string)
func (*CommitInfo) SetSha ¶
func (x *CommitInfo) SetSha(v string)
func (*CommitInfo) SetURL ¶
func (x *CommitInfo) SetURL(v string)
func (*CommitInfo) String ¶
func (x *CommitInfo) String() string
type CommitInfo_builder ¶
type CommitInfo_builder struct {
// the commit message
Message string
// the commit author login
Author *CommitAuthor
// the commit date
Date string
// the commit sha
Sha string
// the full URL to the commit
URL string
// contains filtered or unexported fields
}
func (CommitInfo_builder) Build ¶
func (b0 CommitInfo_builder) Build() *CommitInfo
type GetCommitRequest ¶
type GetCommitRequest struct {
// the full path to the repository
RepositoryURL string `protobuf:"bytes,1,opt,name=repositoryURL,proto3" json:"repositoryURL,omitempty"`
// the vcs ref to get the file from
Ref string `protobuf:"bytes,2,opt,name=ref,proto3" json:"ref,omitempty"`
// contains filtered or unexported fields
}
func (*GetCommitRequest) GetRef ¶
func (x *GetCommitRequest) GetRef() string
func (*GetCommitRequest) GetRepositoryURL ¶
func (x *GetCommitRequest) GetRepositoryURL() string
func (*GetCommitRequest) ProtoMessage ¶
func (*GetCommitRequest) ProtoMessage()
func (*GetCommitRequest) ProtoReflect ¶
func (x *GetCommitRequest) ProtoReflect() protoreflect.Message
func (*GetCommitRequest) Reset ¶
func (x *GetCommitRequest) Reset()
func (*GetCommitRequest) SetRef ¶
func (x *GetCommitRequest) SetRef(v string)
func (*GetCommitRequest) SetRepositoryURL ¶
func (x *GetCommitRequest) SetRepositoryURL(v string)
func (*GetCommitRequest) String ¶
func (x *GetCommitRequest) String() string
type GetCommitRequest_builder ¶
type GetCommitRequest_builder struct {
// the full path to the repository
RepositoryURL string
// the vcs ref to get the file from
Ref string
// contains filtered or unexported fields
}
func (GetCommitRequest_builder) Build ¶
func (b0 GetCommitRequest_builder) Build() *GetCommitRequest
type GetCommitResponse ¶
type GetCommitResponse struct {
// the commit message
Message string `protobuf:"bytes,1,opt,name=message,proto3" json:"message,omitempty"`
// the commit author login
Author *CommitAuthor `protobuf:"bytes,2,opt,name=author,proto3" json:"author,omitempty"`
// the commit date
Date string `protobuf:"bytes,3,opt,name=date,proto3" json:"date,omitempty"`
// the commit sha
Sha string `protobuf:"bytes,4,opt,name=sha,proto3" json:"sha,omitempty"`
// the full URL to the commit
URL string `protobuf:"bytes,5,opt,name=URL,proto3" json:"URL,omitempty"`
// contains filtered or unexported fields
}
func (*GetCommitResponse) ClearAuthor ¶
func (x *GetCommitResponse) ClearAuthor()
func (*GetCommitResponse) GetAuthor ¶
func (x *GetCommitResponse) GetAuthor() *CommitAuthor
func (*GetCommitResponse) GetDate ¶
func (x *GetCommitResponse) GetDate() string
func (*GetCommitResponse) GetMessage ¶
func (x *GetCommitResponse) GetMessage() string
func (*GetCommitResponse) GetSha ¶
func (x *GetCommitResponse) GetSha() string
func (*GetCommitResponse) GetURL ¶
func (x *GetCommitResponse) GetURL() string
func (*GetCommitResponse) HasAuthor ¶
func (x *GetCommitResponse) HasAuthor() bool
func (*GetCommitResponse) ProtoMessage ¶
func (*GetCommitResponse) ProtoMessage()
func (*GetCommitResponse) ProtoReflect ¶
func (x *GetCommitResponse) ProtoReflect() protoreflect.Message
func (*GetCommitResponse) Reset ¶
func (x *GetCommitResponse) Reset()
func (*GetCommitResponse) SetAuthor ¶
func (x *GetCommitResponse) SetAuthor(v *CommitAuthor)
func (*GetCommitResponse) SetDate ¶
func (x *GetCommitResponse) SetDate(v string)
func (*GetCommitResponse) SetMessage ¶
func (x *GetCommitResponse) SetMessage(v string)
func (*GetCommitResponse) SetSha ¶
func (x *GetCommitResponse) SetSha(v string)
func (*GetCommitResponse) SetURL ¶
func (x *GetCommitResponse) SetURL(v string)
func (*GetCommitResponse) String ¶
func (x *GetCommitResponse) String() string
type GetCommitResponse_builder ¶
type GetCommitResponse_builder struct {
// the commit message
Message string
// the commit author login
Author *CommitAuthor
// the commit date
Date string
// the commit sha
Sha string
// the full URL to the commit
URL string
// contains filtered or unexported fields
}
func (GetCommitResponse_builder) Build ¶
func (b0 GetCommitResponse_builder) Build() *GetCommitResponse
type GetCommitsRequest ¶
type GetCommitsRequest struct {
RepositoryUrl string `protobuf:"bytes,1,opt,name=repository_url,json=repositoryUrl,proto3" json:"repository_url,omitempty"`
Refs []string `protobuf:"bytes,2,rep,name=refs,proto3" json:"refs,omitempty"`
// contains filtered or unexported fields
}
New messages for the GetCommits method
func (*GetCommitsRequest) GetRefs ¶
func (x *GetCommitsRequest) GetRefs() []string
func (*GetCommitsRequest) GetRepositoryUrl ¶
func (x *GetCommitsRequest) GetRepositoryUrl() string
func (*GetCommitsRequest) ProtoMessage ¶
func (*GetCommitsRequest) ProtoMessage()
func (*GetCommitsRequest) ProtoReflect ¶
func (x *GetCommitsRequest) ProtoReflect() protoreflect.Message
func (*GetCommitsRequest) Reset ¶
func (x *GetCommitsRequest) Reset()
func (*GetCommitsRequest) SetRefs ¶
func (x *GetCommitsRequest) SetRefs(v []string)
func (*GetCommitsRequest) SetRepositoryUrl ¶
func (x *GetCommitsRequest) SetRepositoryUrl(v string)
func (*GetCommitsRequest) String ¶
func (x *GetCommitsRequest) String() string
type GetCommitsRequest_builder ¶
type GetCommitsRequest_builder struct {
RepositoryUrl string
Refs []string
// contains filtered or unexported fields
}
func (GetCommitsRequest_builder) Build ¶
func (b0 GetCommitsRequest_builder) Build() *GetCommitsRequest
type GetCommitsResponse ¶
type GetCommitsResponse struct {
Commits []*CommitInfo `protobuf:"bytes,1,rep,name=commits,proto3" json:"commits,omitempty"`
// contains filtered or unexported fields
}
func (*GetCommitsResponse) GetCommits ¶
func (x *GetCommitsResponse) GetCommits() []*CommitInfo
func (*GetCommitsResponse) ProtoMessage ¶
func (*GetCommitsResponse) ProtoMessage()
func (*GetCommitsResponse) ProtoReflect ¶
func (x *GetCommitsResponse) ProtoReflect() protoreflect.Message
func (*GetCommitsResponse) Reset ¶
func (x *GetCommitsResponse) Reset()
func (*GetCommitsResponse) SetCommits ¶
func (x *GetCommitsResponse) SetCommits(v []*CommitInfo)
func (*GetCommitsResponse) String ¶
func (x *GetCommitsResponse) String() string
type GetCommitsResponse_builder ¶
type GetCommitsResponse_builder struct {
Commits []*CommitInfo
// contains filtered or unexported fields
}
func (GetCommitsResponse_builder) Build ¶
func (b0 GetCommitsResponse_builder) Build() *GetCommitsResponse
type GetFileRequest ¶
type GetFileRequest struct {
// the full path to the repository
RepositoryURL string `protobuf:"bytes,1,opt,name=repositoryURL,proto3" json:"repositoryURL,omitempty"`
// the vcs ref to get the file from
Ref string `protobuf:"bytes,2,opt,name=ref,proto3" json:"ref,omitempty"`
// the path to the file as provided by the symbols
LocalPath string `protobuf:"bytes,3,opt,name=localPath,proto3" json:"localPath,omitempty"`
// the root path where the project lives inside the repository
RootPath string `protobuf:"bytes,4,opt,name=rootPath,proto3" json:"rootPath,omitempty"`
// contains filtered or unexported fields
}
func (*GetFileRequest) GetLocalPath ¶
func (x *GetFileRequest) GetLocalPath() string
func (*GetFileRequest) GetRef ¶
func (x *GetFileRequest) GetRef() string
func (*GetFileRequest) GetRepositoryURL ¶
func (x *GetFileRequest) GetRepositoryURL() string
func (*GetFileRequest) GetRootPath ¶
func (x *GetFileRequest) GetRootPath() string
func (*GetFileRequest) ProtoMessage ¶
func (*GetFileRequest) ProtoMessage()
func (*GetFileRequest) ProtoReflect ¶
func (x *GetFileRequest) ProtoReflect() protoreflect.Message
func (*GetFileRequest) Reset ¶
func (x *GetFileRequest) Reset()
func (*GetFileRequest) SetLocalPath ¶
func (x *GetFileRequest) SetLocalPath(v string)
func (*GetFileRequest) SetRef ¶
func (x *GetFileRequest) SetRef(v string)
func (*GetFileRequest) SetRepositoryURL ¶
func (x *GetFileRequest) SetRepositoryURL(v string)
func (*GetFileRequest) SetRootPath ¶
func (x *GetFileRequest) SetRootPath(v string)
func (*GetFileRequest) String ¶
func (x *GetFileRequest) String() string
type GetFileRequest_builder ¶
type GetFileRequest_builder struct {
// the full path to the repository
RepositoryURL string
// the vcs ref to get the file from
Ref string
// the path to the file as provided by the symbols
LocalPath string
// the root path where the project lives inside the repository
RootPath string
// contains filtered or unexported fields
}
func (GetFileRequest_builder) Build ¶
func (b0 GetFileRequest_builder) Build() *GetFileRequest
type GetFileResponse ¶
type GetFileResponse struct {
// base64 content of the file
Content string `protobuf:"bytes,1,opt,name=content,proto3" json:"content,omitempty"`
// the full URL to the file
URL string `protobuf:"bytes,2,opt,name=URL,proto3" json:"URL,omitempty"`
// contains filtered or unexported fields
}
func (*GetFileResponse) GetContent ¶
func (x *GetFileResponse) GetContent() string
func (*GetFileResponse) GetURL ¶
func (x *GetFileResponse) GetURL() string
func (*GetFileResponse) ProtoMessage ¶
func (*GetFileResponse) ProtoMessage()
func (*GetFileResponse) ProtoReflect ¶
func (x *GetFileResponse) ProtoReflect() protoreflect.Message
func (*GetFileResponse) Reset ¶
func (x *GetFileResponse) Reset()
func (*GetFileResponse) SetContent ¶
func (x *GetFileResponse) SetContent(v string)
func (*GetFileResponse) SetURL ¶
func (x *GetFileResponse) SetURL(v string)
func (*GetFileResponse) String ¶
func (x *GetFileResponse) String() string
type GetFileResponse_builder ¶
type GetFileResponse_builder struct {
// base64 content of the file
Content string
// the full URL to the file
URL string
// contains filtered or unexported fields
}
func (GetFileResponse_builder) Build ¶
func (b0 GetFileResponse_builder) Build() *GetFileResponse
type GithubAppRequest ¶
type GithubAppRequest struct {
// contains filtered or unexported fields
}
func (*GithubAppRequest) ProtoMessage ¶
func (*GithubAppRequest) ProtoMessage()
func (*GithubAppRequest) ProtoReflect ¶
func (x *GithubAppRequest) ProtoReflect() protoreflect.Message
func (*GithubAppRequest) Reset ¶
func (x *GithubAppRequest) Reset()
func (*GithubAppRequest) String ¶
func (x *GithubAppRequest) String() string
type GithubAppRequest_builder ¶
type GithubAppRequest_builder struct {
// contains filtered or unexported fields
}
func (GithubAppRequest_builder) Build ¶
func (b0 GithubAppRequest_builder) Build() *GithubAppRequest
type GithubAppResponse ¶
type GithubAppResponse struct {
ClientID string `protobuf:"bytes,1,opt,name=clientID,proto3" json:"clientID,omitempty"`
// contains filtered or unexported fields
}
func (*GithubAppResponse) GetClientID ¶
func (x *GithubAppResponse) GetClientID() string
func (*GithubAppResponse) ProtoMessage ¶
func (*GithubAppResponse) ProtoMessage()
func (*GithubAppResponse) ProtoReflect ¶
func (x *GithubAppResponse) ProtoReflect() protoreflect.Message
func (*GithubAppResponse) Reset ¶
func (x *GithubAppResponse) Reset()
func (*GithubAppResponse) SetClientID ¶
func (x *GithubAppResponse) SetClientID(v string)
func (*GithubAppResponse) String ¶
func (x *GithubAppResponse) String() string
type GithubAppResponse_builder ¶
type GithubAppResponse_builder struct {
ClientID string
// contains filtered or unexported fields
}
func (GithubAppResponse_builder) Build ¶
func (b0 GithubAppResponse_builder) Build() *GithubAppResponse
type GithubLoginRequest ¶
type GithubLoginRequest struct {
AuthorizationCode string `protobuf:"bytes,1,opt,name=authorizationCode,proto3" json:"authorizationCode,omitempty"`
// contains filtered or unexported fields
}
func (*GithubLoginRequest) GetAuthorizationCode ¶
func (x *GithubLoginRequest) GetAuthorizationCode() string
func (*GithubLoginRequest) ProtoMessage ¶
func (*GithubLoginRequest) ProtoMessage()
func (*GithubLoginRequest) ProtoReflect ¶
func (x *GithubLoginRequest) ProtoReflect() protoreflect.Message
func (*GithubLoginRequest) Reset ¶
func (x *GithubLoginRequest) Reset()
func (*GithubLoginRequest) SetAuthorizationCode ¶
func (x *GithubLoginRequest) SetAuthorizationCode(v string)
func (*GithubLoginRequest) String ¶
func (x *GithubLoginRequest) String() string
type GithubLoginRequest_builder ¶
type GithubLoginRequest_builder struct {
AuthorizationCode string
// contains filtered or unexported fields
}
func (GithubLoginRequest_builder) Build ¶
func (b0 GithubLoginRequest_builder) Build() *GithubLoginRequest
type GithubLoginResponse ¶
type GithubLoginResponse struct {
// Deprecated
// In future version, this cookie won't be sent. Now, old cookie is sent alongside the new expected
// data (token, token_expires_at and refresh_token_expires_at). Frontend will be responsible of computing
// its own cookie from the new data.
// Remove after completing https://github.com/grafana/explore-profiles/issues/187
Cookie string `protobuf:"bytes,1,opt,name=cookie,proto3" json:"cookie,omitempty"`
// base64 encoded encrypted token
Token string `protobuf:"bytes,2,opt,name=token,proto3" json:"token,omitempty"`
// Unix ms timestamp of when the token expires.
TokenExpiresAt int64 `protobuf:"varint,3,opt,name=token_expires_at,json=tokenExpiresAt,proto3" json:"token_expires_at,omitempty"`
// Unix ms timestamp of when the refresh token expires.
RefreshTokenExpiresAt int64 `` /* 129-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*GithubLoginResponse) GetCookie ¶
func (x *GithubLoginResponse) GetCookie() string
func (*GithubLoginResponse) GetRefreshTokenExpiresAt ¶
func (x *GithubLoginResponse) GetRefreshTokenExpiresAt() int64
func (*GithubLoginResponse) GetToken ¶
func (x *GithubLoginResponse) GetToken() string
func (*GithubLoginResponse) GetTokenExpiresAt ¶
func (x *GithubLoginResponse) GetTokenExpiresAt() int64
func (*GithubLoginResponse) ProtoMessage ¶
func (*GithubLoginResponse) ProtoMessage()
func (*GithubLoginResponse) ProtoReflect ¶
func (x *GithubLoginResponse) ProtoReflect() protoreflect.Message
func (*GithubLoginResponse) Reset ¶
func (x *GithubLoginResponse) Reset()
func (*GithubLoginResponse) SetCookie ¶
func (x *GithubLoginResponse) SetCookie(v string)
func (*GithubLoginResponse) SetRefreshTokenExpiresAt ¶
func (x *GithubLoginResponse) SetRefreshTokenExpiresAt(v int64)
func (*GithubLoginResponse) SetToken ¶
func (x *GithubLoginResponse) SetToken(v string)
func (*GithubLoginResponse) SetTokenExpiresAt ¶
func (x *GithubLoginResponse) SetTokenExpiresAt(v int64)
func (*GithubLoginResponse) String ¶
func (x *GithubLoginResponse) String() string
type GithubLoginResponse_builder ¶
type GithubLoginResponse_builder struct {
// Deprecated
// In future version, this cookie won't be sent. Now, old cookie is sent alongside the new expected
// data (token, token_expires_at and refresh_token_expires_at). Frontend will be responsible of computing
// its own cookie from the new data.
// Remove after completing https://github.com/grafana/explore-profiles/issues/187
Cookie string
// base64 encoded encrypted token
Token string
// Unix ms timestamp of when the token expires.
TokenExpiresAt int64
// Unix ms timestamp of when the refresh token expires.
RefreshTokenExpiresAt int64
// contains filtered or unexported fields
}
func (GithubLoginResponse_builder) Build ¶
func (b0 GithubLoginResponse_builder) Build() *GithubLoginResponse
type GithubRefreshRequest ¶
type GithubRefreshRequest struct {
// contains filtered or unexported fields
}
func (*GithubRefreshRequest) ProtoMessage ¶
func (*GithubRefreshRequest) ProtoMessage()
func (*GithubRefreshRequest) ProtoReflect ¶
func (x *GithubRefreshRequest) ProtoReflect() protoreflect.Message
func (*GithubRefreshRequest) Reset ¶
func (x *GithubRefreshRequest) Reset()
func (*GithubRefreshRequest) String ¶
func (x *GithubRefreshRequest) String() string
type GithubRefreshRequest_builder ¶
type GithubRefreshRequest_builder struct {
// contains filtered or unexported fields
}
func (GithubRefreshRequest_builder) Build ¶
func (b0 GithubRefreshRequest_builder) Build() *GithubRefreshRequest
type GithubRefreshResponse ¶
type GithubRefreshResponse struct {
// Deprecated
// In future version, this cookie won't be sent. Now, old cookie is sent alongside the new expected
// data (token, token_expires_at and refresh_token_expires_at). Frontend will be responsible of computing
// its own cookie from the new data.
// Remove after completing https://github.com/grafana/explore-profiles/issues/187
Cookie string `protobuf:"bytes,1,opt,name=cookie,proto3" json:"cookie,omitempty"`
// base64 encoded encrypted token
Token string `protobuf:"bytes,2,opt,name=token,proto3" json:"token,omitempty"`
// Unix ms timestamp of when the token expires.
TokenExpiresAt int64 `protobuf:"varint,3,opt,name=token_expires_at,json=tokenExpiresAt,proto3" json:"token_expires_at,omitempty"`
// Unix ms timestamp of when the refresh token expires.
RefreshTokenExpiresAt int64 `` /* 129-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*GithubRefreshResponse) GetCookie ¶
func (x *GithubRefreshResponse) GetCookie() string
func (*GithubRefreshResponse) GetRefreshTokenExpiresAt ¶
func (x *GithubRefreshResponse) GetRefreshTokenExpiresAt() int64
func (*GithubRefreshResponse) GetToken ¶
func (x *GithubRefreshResponse) GetToken() string
func (*GithubRefreshResponse) GetTokenExpiresAt ¶
func (x *GithubRefreshResponse) GetTokenExpiresAt() int64
func (*GithubRefreshResponse) ProtoMessage ¶
func (*GithubRefreshResponse) ProtoMessage()
func (*GithubRefreshResponse) ProtoReflect ¶
func (x *GithubRefreshResponse) ProtoReflect() protoreflect.Message
func (*GithubRefreshResponse) Reset ¶
func (x *GithubRefreshResponse) Reset()
func (*GithubRefreshResponse) SetCookie ¶
func (x *GithubRefreshResponse) SetCookie(v string)
func (*GithubRefreshResponse) SetRefreshTokenExpiresAt ¶
func (x *GithubRefreshResponse) SetRefreshTokenExpiresAt(v int64)
func (*GithubRefreshResponse) SetToken ¶
func (x *GithubRefreshResponse) SetToken(v string)
func (*GithubRefreshResponse) SetTokenExpiresAt ¶
func (x *GithubRefreshResponse) SetTokenExpiresAt(v int64)
func (*GithubRefreshResponse) String ¶
func (x *GithubRefreshResponse) String() string
type GithubRefreshResponse_builder ¶
type GithubRefreshResponse_builder struct {
// Deprecated
// In future version, this cookie won't be sent. Now, old cookie is sent alongside the new expected
// data (token, token_expires_at and refresh_token_expires_at). Frontend will be responsible of computing
// its own cookie from the new data.
// Remove after completing https://github.com/grafana/explore-profiles/issues/187
Cookie string
// base64 encoded encrypted token
Token string
// Unix ms timestamp of when the token expires.
TokenExpiresAt int64
// Unix ms timestamp of when the refresh token expires.
RefreshTokenExpiresAt int64
// contains filtered or unexported fields
}
func (GithubRefreshResponse_builder) Build ¶
func (b0 GithubRefreshResponse_builder) Build() *GithubRefreshResponse
Source Files
¶
- vcs.pb.go
Click to show internal directories.
Click to hide internal directories.