restate

package
v1.36.11-2023121308304... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: MIT Imports: 7 Imported by: 2

Documentation

Index

Constants

const InvokeRequest_Argument_not_set_case case_InvokeRequest_Argument = 0
const InvokeRequest_Json_case case_InvokeRequest_Argument = 4
const InvokeRequest_Pb_case case_InvokeRequest_Argument = 3
const ResolveAwakeableRequest_BytesResult_case case_ResolveAwakeableRequest_Result = 2
const ResolveAwakeableRequest_JsonResult_case case_ResolveAwakeableRequest_Result = 3
const ResolveAwakeableRequest_Result_not_set_case case_ResolveAwakeableRequest_Result = 0

Variables

var (
	ServiceType_name = map[int32]string{
		0: "UNKEYED",
		1: "KEYED",
		2: "SINGLETON",
	}
	ServiceType_value = map[string]int32{
		"UNKEYED":   0,
		"KEYED":     1,
		"SINGLETON": 2,
	}
)

Enum value maps for ServiceType.

var (
	FieldType_name = map[int32]string{
		0: "KEY",
		1: "EVENT_PAYLOAD",
		2: "EVENT_METADATA",
	}
	FieldType_value = map[string]int32{
		"KEY":            0,
		"EVENT_PAYLOAD":  1,
		"EVENT_METADATA": 2,
	}
)

Enum value maps for FieldType.

var (
	// optional dev.restate.ext.FieldType field = 51234;
	E_Field = &file_dev_restate_ext_proto_extTypes[1]
)

Extension fields to descriptorpb.FieldOptions.

var (
	// optional dev.restate.ext.ServiceType service_type = 51234;
	E_ServiceType = &file_dev_restate_ext_proto_extTypes[0]
)

Extension fields to descriptorpb.ServiceOptions.

var File_dev_restate_events_proto protoreflect.FileDescriptor
var File_dev_restate_ext_proto protoreflect.FileDescriptor
var File_dev_restate_services_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type Event

type Event struct {
	OrderingKey string            `protobuf:"bytes,1,opt,name=ordering_key,json=orderingKey,proto3" json:"ordering_key,omitempty"`
	Key         []byte            `protobuf:"bytes,2,opt,name=key,proto3" json:"key,omitempty"`
	Payload     []byte            `protobuf:"bytes,3,opt,name=payload,proto3" json:"payload,omitempty"`
	Attributes  map[string]string `` /* 148-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*Event) GetAttributes

func (x *Event) GetAttributes() map[string]string

func (*Event) GetKey

func (x *Event) GetKey() []byte

func (*Event) GetOrderingKey

func (x *Event) GetOrderingKey() string

func (*Event) GetPayload

func (x *Event) GetPayload() []byte

func (*Event) ProtoMessage

func (*Event) ProtoMessage()

func (*Event) ProtoReflect

func (x *Event) ProtoReflect() protoreflect.Message

func (*Event) Reset

func (x *Event) Reset()

func (*Event) SetAttributes

func (x *Event) SetAttributes(v map[string]string)

func (*Event) SetKey

func (x *Event) SetKey(v []byte)

func (*Event) SetOrderingKey

func (x *Event) SetOrderingKey(v string)

func (*Event) SetPayload

func (x *Event) SetPayload(v []byte)

func (*Event) String

func (x *Event) String() string

type Event_builder

type Event_builder struct {
	OrderingKey string
	Key         []byte
	Payload     []byte
	Attributes  map[string]string
	// contains filtered or unexported fields
}

func (Event_builder) Build

func (b0 Event_builder) Build() *Event

type FieldType

type FieldType int32
const (
	// protolint:disable:next ENUM_FIELD_NAMES_ZERO_VALUE_END_WITH
	// Note: only string fields can be used for service key fields
	FieldType_KEY FieldType = 0
	// Flag a field as event payload. When receiving events, this field will be filled with the event payload.
	// Note: only string fields can be used for event payload fields
	FieldType_EVENT_PAYLOAD FieldType = 1
	// Flag a field as event metadata. When receiving events, this field will be filled with the event metadata.
	// Note: only type map<string, string> can be used for event payload fields
	FieldType_EVENT_METADATA FieldType = 2
)

func (FieldType) Descriptor

func (FieldType) Descriptor() protoreflect.EnumDescriptor

func (FieldType) Enum

func (x FieldType) Enum() *FieldType

func (FieldType) Number

func (x FieldType) Number() protoreflect.EnumNumber

func (FieldType) String

func (x FieldType) String() string

func (FieldType) Type

type InvokeRequest

type InvokeRequest struct {

	// Fully qualified name of the service, e.g. `counter.Counter`
	Service string `protobuf:"bytes,1,opt,name=service,proto3" json:"service,omitempty"`
	// Method name of the service to invoke, e.g. `Add`
	Method string `protobuf:"bytes,2,opt,name=method,proto3" json:"method,omitempty"`
	// Argument of the invocation.
	// You can pass the invocation argument either as protobuf or as JSON.
	// In case of JSON, the argument will be automatically transcoded to protobuf before sending it to the target service.
	//
	// Types that are valid to be assigned to Argument:
	//
	//	*InvokeRequest_Pb
	//	*InvokeRequest_Json
	Argument isInvokeRequest_Argument `protobuf_oneof:"argument"`
	// contains filtered or unexported fields
}

func (*InvokeRequest) ClearArgument

func (x *InvokeRequest) ClearArgument()

func (*InvokeRequest) ClearJson

func (x *InvokeRequest) ClearJson()

func (*InvokeRequest) ClearPb

func (x *InvokeRequest) ClearPb()

func (*InvokeRequest) GetArgument

func (x *InvokeRequest) GetArgument() isInvokeRequest_Argument

func (*InvokeRequest) GetJson

func (x *InvokeRequest) GetJson() *structpb.Struct

func (*InvokeRequest) GetMethod

func (x *InvokeRequest) GetMethod() string

func (*InvokeRequest) GetPb

func (x *InvokeRequest) GetPb() []byte

func (*InvokeRequest) GetService

func (x *InvokeRequest) GetService() string

func (*InvokeRequest) HasArgument

func (x *InvokeRequest) HasArgument() bool

func (*InvokeRequest) HasJson

func (x *InvokeRequest) HasJson() bool

func (*InvokeRequest) HasPb

func (x *InvokeRequest) HasPb() bool

func (*InvokeRequest) ProtoMessage

func (*InvokeRequest) ProtoMessage()

func (*InvokeRequest) ProtoReflect

func (x *InvokeRequest) ProtoReflect() protoreflect.Message

func (*InvokeRequest) Reset

func (x *InvokeRequest) Reset()

func (*InvokeRequest) SetJson

func (x *InvokeRequest) SetJson(v *structpb.Struct)

func (*InvokeRequest) SetMethod

func (x *InvokeRequest) SetMethod(v string)

func (*InvokeRequest) SetPb

func (x *InvokeRequest) SetPb(v []byte)

func (*InvokeRequest) SetService

func (x *InvokeRequest) SetService(v string)

func (*InvokeRequest) String

func (x *InvokeRequest) String() string

func (*InvokeRequest) WhichArgument

func (x *InvokeRequest) WhichArgument() case_InvokeRequest_Argument

type InvokeRequest_Json

type InvokeRequest_Json struct {
	Json *structpb.Struct `protobuf:"bytes,4,opt,name=json,json=argument,proto3,oneof"`
}

type InvokeRequest_Pb

type InvokeRequest_Pb struct {
	Pb []byte `protobuf:"bytes,3,opt,name=pb,proto3,oneof"`
}

type InvokeRequest_builder

type InvokeRequest_builder struct {

	// Fully qualified name of the service, e.g. `counter.Counter`
	Service string
	// Method name of the service to invoke, e.g. `Add`
	Method string

	// Fields of oneof Argument:
	Pb   []byte
	Json *structpb.Struct
	// contains filtered or unexported fields
}

func (InvokeRequest_builder) Build

type InvokeResponse

type InvokeResponse struct {

	// Generated unique invocation identifier.
	// It can be used to retrieve the status of the invocation and cancel it.
	Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	// contains filtered or unexported fields
}

func (*InvokeResponse) GetId

func (x *InvokeResponse) GetId() string

func (*InvokeResponse) ProtoMessage

func (*InvokeResponse) ProtoMessage()

func (*InvokeResponse) ProtoReflect

func (x *InvokeResponse) ProtoReflect() protoreflect.Message

func (*InvokeResponse) Reset

func (x *InvokeResponse) Reset()

func (*InvokeResponse) SetId

func (x *InvokeResponse) SetId(v string)

func (*InvokeResponse) String

func (x *InvokeResponse) String() string

type InvokeResponse_builder

type InvokeResponse_builder struct {

	// Generated unique invocation identifier.
	// It can be used to retrieve the status of the invocation and cancel it.
	Id string
	// contains filtered or unexported fields
}

func (InvokeResponse_builder) Build

type RejectAwakeableRequest

type RejectAwakeableRequest struct {

	// Base64 encoded identifier of the Awakeable to reject.
	Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	// Rejection reason.
	Reason string `protobuf:"bytes,2,opt,name=reason,proto3" json:"reason,omitempty"`
	// contains filtered or unexported fields
}

func (*RejectAwakeableRequest) GetId

func (x *RejectAwakeableRequest) GetId() string

func (*RejectAwakeableRequest) GetReason

func (x *RejectAwakeableRequest) GetReason() string

func (*RejectAwakeableRequest) ProtoMessage

func (*RejectAwakeableRequest) ProtoMessage()

func (*RejectAwakeableRequest) ProtoReflect

func (x *RejectAwakeableRequest) ProtoReflect() protoreflect.Message

func (*RejectAwakeableRequest) Reset

func (x *RejectAwakeableRequest) Reset()

func (*RejectAwakeableRequest) SetId

func (x *RejectAwakeableRequest) SetId(v string)

func (*RejectAwakeableRequest) SetReason

func (x *RejectAwakeableRequest) SetReason(v string)

func (*RejectAwakeableRequest) String

func (x *RejectAwakeableRequest) String() string

type RejectAwakeableRequest_builder

type RejectAwakeableRequest_builder struct {

	// Base64 encoded identifier of the Awakeable to reject.
	Id string
	// Rejection reason.
	Reason string
	// contains filtered or unexported fields
}

func (RejectAwakeableRequest_builder) Build

type ResolveAwakeableRequest

type ResolveAwakeableRequest struct {

	// Base64 encoded identifier of the Awakeable to resolve.
	Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	// Types that are valid to be assigned to Result:
	//
	//	*ResolveAwakeableRequest_BytesResult
	//	*ResolveAwakeableRequest_JsonResult
	Result isResolveAwakeableRequest_Result `protobuf_oneof:"result"`
	// contains filtered or unexported fields
}

func (*ResolveAwakeableRequest) ClearBytesResult

func (x *ResolveAwakeableRequest) ClearBytesResult()

func (*ResolveAwakeableRequest) ClearJsonResult

func (x *ResolveAwakeableRequest) ClearJsonResult()

func (*ResolveAwakeableRequest) ClearResult

func (x *ResolveAwakeableRequest) ClearResult()

func (*ResolveAwakeableRequest) GetBytesResult

func (x *ResolveAwakeableRequest) GetBytesResult() []byte

func (*ResolveAwakeableRequest) GetId

func (x *ResolveAwakeableRequest) GetId() string

func (*ResolveAwakeableRequest) GetJsonResult

func (x *ResolveAwakeableRequest) GetJsonResult() *structpb.Value

func (*ResolveAwakeableRequest) GetResult

func (x *ResolveAwakeableRequest) GetResult() isResolveAwakeableRequest_Result

func (*ResolveAwakeableRequest) HasBytesResult

func (x *ResolveAwakeableRequest) HasBytesResult() bool

func (*ResolveAwakeableRequest) HasJsonResult

func (x *ResolveAwakeableRequest) HasJsonResult() bool

func (*ResolveAwakeableRequest) HasResult

func (x *ResolveAwakeableRequest) HasResult() bool

func (*ResolveAwakeableRequest) ProtoMessage

func (*ResolveAwakeableRequest) ProtoMessage()

func (*ResolveAwakeableRequest) ProtoReflect

func (x *ResolveAwakeableRequest) ProtoReflect() protoreflect.Message

func (*ResolveAwakeableRequest) Reset

func (x *ResolveAwakeableRequest) Reset()

func (*ResolveAwakeableRequest) SetBytesResult

func (x *ResolveAwakeableRequest) SetBytesResult(v []byte)

func (*ResolveAwakeableRequest) SetId

func (x *ResolveAwakeableRequest) SetId(v string)

func (*ResolveAwakeableRequest) SetJsonResult

func (x *ResolveAwakeableRequest) SetJsonResult(v *structpb.Value)

func (*ResolveAwakeableRequest) String

func (x *ResolveAwakeableRequest) String() string

func (*ResolveAwakeableRequest) WhichResult

func (x *ResolveAwakeableRequest) WhichResult() case_ResolveAwakeableRequest_Result

type ResolveAwakeableRequest_BytesResult

type ResolveAwakeableRequest_BytesResult struct {
	BytesResult []byte `protobuf:"bytes,2,opt,name=bytes_result,json=bytesResult,proto3,oneof"`
}

type ResolveAwakeableRequest_JsonResult

type ResolveAwakeableRequest_JsonResult struct {
	// When executing requests to the ingress using JSON, you can pass a json_result directly for ease of use.
	// json_result will be sent back to the awakeable as string encoded JSON, not as Protobuf value.
	JsonResult *structpb.Value `protobuf:"bytes,3,opt,name=json_result,json=jsonResult,proto3,oneof"`
}

type ResolveAwakeableRequest_builder

type ResolveAwakeableRequest_builder struct {

	// Base64 encoded identifier of the Awakeable to resolve.
	Id string
	// Fields of oneof Result:
	BytesResult []byte
	// When executing requests to the ingress using JSON, you can pass a json_result directly for ease of use.
	// json_result will be sent back to the awakeable as string encoded JSON, not as Protobuf value.
	JsonResult *structpb.Value
	// contains filtered or unexported fields
}

func (ResolveAwakeableRequest_builder) Build

type ServiceType

type ServiceType int32
const (
	// protolint:disable:next ENUM_FIELD_NAMES_ZERO_VALUE_END_WITH
	ServiceType_UNKEYED   ServiceType = 0
	ServiceType_KEYED     ServiceType = 1
	ServiceType_SINGLETON ServiceType = 2
)

func (ServiceType) Descriptor

func (ServiceType) Enum

func (x ServiceType) Enum() *ServiceType

func (ServiceType) Number

func (x ServiceType) Number() protoreflect.EnumNumber

func (ServiceType) String

func (x ServiceType) String() string

func (ServiceType) Type

Source Files

  • events.pb.go
  • ext.pb.go
  • services.pb.go

Jump to