metricsv1

package
v1.36.11-2025091615041... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 5 Imported by: 1

Documentation

Index

Constants

This section is empty.

Variables

var (
	MetricRequestStep_name = map[int32]string{
		0: "UNKNOWN_STEP",
		1: "HOURLY",
		2: "DAILY",
		3: "MONTHLY",
		4: "MINUTELY",
	}
	MetricRequestStep_value = map[string]int32{
		"UNKNOWN_STEP": 0,
		"HOURLY":       1,
		"DAILY":        2,
		"MONTHLY":      3,
		"MINUTELY":     4,
	}
)

Enum value maps for MetricRequestStep.

var (
	MetricFilterType_name = map[int32]string{
		0: "UNKNOWN_FILTER_TYPE",
		1: "EQUALS",
		2: "STARTS_WITH",
		3: "ENDS_WITH",
		4: "CONTAINS",
	}
	MetricFilterType_value = map[string]int32{
		"UNKNOWN_FILTER_TYPE": 0,
		"EQUALS":              1,
		"STARTS_WITH":         2,
		"ENDS_WITH":           3,
		"CONTAINS":            4,
	}
)

Enum value maps for MetricFilterType.

var File_simplecloud_metrics_v1_metrics_api_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type GetMetricsPaginatedRequest

type GetMetricsPaginatedRequest struct {

	// The metric types to get, if empty, all metrics will be returned
	MetricTypes []string `protobuf:"bytes,1,rep,name=metric_types,json=metricTypes,proto3" json:"metric_types,omitempty"`
	// The start time of the query, if empty, the start time will be the beginning of time
	From *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=from,proto3" json:"from,omitempty"`
	// The end time of the query, if empty, the end time will be the end of time
	To *timestamppb.Timestamp `protobuf:"bytes,3,opt,name=to,proto3" json:"to,omitempty"`
	// The step of the query, if empty, the step will be HOURLY
	Step MetricRequestStep `protobuf:"varint,4,opt,name=step,proto3,enum=simplecloud.metrics.v1.MetricRequestStep" json:"step,omitempty"`
	// The meta filters to apply to the query, if empty, no filters will be applied
	MetaFilters []*MetricRequestMetaFilter `protobuf:"bytes,5,rep,name=meta_filters,json=metaFilters,proto3" json:"meta_filters,omitempty"`
	// The number of items to return per page
	PageSize int32 `protobuf:"varint,6,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
	// The page token for pagination
	PageToken string `protobuf:"bytes,7,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
	// contains filtered or unexported fields
}

func (*GetMetricsPaginatedRequest) ClearFrom

func (x *GetMetricsPaginatedRequest) ClearFrom()

func (*GetMetricsPaginatedRequest) ClearTo

func (x *GetMetricsPaginatedRequest) ClearTo()

func (*GetMetricsPaginatedRequest) GetFrom

func (*GetMetricsPaginatedRequest) GetMetaFilters

func (x *GetMetricsPaginatedRequest) GetMetaFilters() []*MetricRequestMetaFilter

func (*GetMetricsPaginatedRequest) GetMetricTypes

func (x *GetMetricsPaginatedRequest) GetMetricTypes() []string

func (*GetMetricsPaginatedRequest) GetPageSize

func (x *GetMetricsPaginatedRequest) GetPageSize() int32

func (*GetMetricsPaginatedRequest) GetPageToken

func (x *GetMetricsPaginatedRequest) GetPageToken() string

func (*GetMetricsPaginatedRequest) GetStep

func (*GetMetricsPaginatedRequest) GetTo

func (*GetMetricsPaginatedRequest) HasFrom

func (x *GetMetricsPaginatedRequest) HasFrom() bool

func (*GetMetricsPaginatedRequest) HasTo

func (x *GetMetricsPaginatedRequest) HasTo() bool

func (*GetMetricsPaginatedRequest) ProtoMessage

func (*GetMetricsPaginatedRequest) ProtoMessage()

func (*GetMetricsPaginatedRequest) ProtoReflect

func (*GetMetricsPaginatedRequest) Reset

func (x *GetMetricsPaginatedRequest) Reset()

func (*GetMetricsPaginatedRequest) SetFrom

func (*GetMetricsPaginatedRequest) SetMetaFilters

func (x *GetMetricsPaginatedRequest) SetMetaFilters(v []*MetricRequestMetaFilter)

func (*GetMetricsPaginatedRequest) SetMetricTypes

func (x *GetMetricsPaginatedRequest) SetMetricTypes(v []string)

func (*GetMetricsPaginatedRequest) SetPageSize

func (x *GetMetricsPaginatedRequest) SetPageSize(v int32)

func (*GetMetricsPaginatedRequest) SetPageToken

func (x *GetMetricsPaginatedRequest) SetPageToken(v string)

func (*GetMetricsPaginatedRequest) SetStep

func (*GetMetricsPaginatedRequest) SetTo

func (*GetMetricsPaginatedRequest) String

func (x *GetMetricsPaginatedRequest) String() string

type GetMetricsPaginatedRequest_builder

type GetMetricsPaginatedRequest_builder struct {

	// The metric types to get, if empty, all metrics will be returned
	MetricTypes []string
	// The start time of the query, if empty, the start time will be the beginning of time
	From *timestamppb.Timestamp
	// The end time of the query, if empty, the end time will be the end of time
	To *timestamppb.Timestamp
	// The step of the query, if empty, the step will be HOURLY
	Step MetricRequestStep
	// The meta filters to apply to the query, if empty, no filters will be applied
	MetaFilters []*MetricRequestMetaFilter
	// The number of items to return per page
	PageSize int32
	// The page token for pagination
	PageToken string
	// contains filtered or unexported fields
}

func (GetMetricsPaginatedRequest_builder) Build

type GetMetricsPaginatedResponse

type GetMetricsPaginatedResponse struct {

	// The list of metrics for the current page
	Metrics []*Metric `protobuf:"bytes,1,rep,name=metrics,proto3" json:"metrics,omitempty"`
	// The next page token, empty if there are no more pages
	NextPageToken string `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
	// The total count of metrics matching the query
	TotalCount int64 `protobuf:"varint,3,opt,name=total_count,json=totalCount,proto3" json:"total_count,omitempty"`
	// contains filtered or unexported fields
}

func (*GetMetricsPaginatedResponse) GetMetrics

func (x *GetMetricsPaginatedResponse) GetMetrics() []*Metric

func (*GetMetricsPaginatedResponse) GetNextPageToken

func (x *GetMetricsPaginatedResponse) GetNextPageToken() string

func (*GetMetricsPaginatedResponse) GetTotalCount

func (x *GetMetricsPaginatedResponse) GetTotalCount() int64

func (*GetMetricsPaginatedResponse) ProtoMessage

func (*GetMetricsPaginatedResponse) ProtoMessage()

func (*GetMetricsPaginatedResponse) ProtoReflect

func (*GetMetricsPaginatedResponse) Reset

func (x *GetMetricsPaginatedResponse) Reset()

func (*GetMetricsPaginatedResponse) SetMetrics

func (x *GetMetricsPaginatedResponse) SetMetrics(v []*Metric)

func (*GetMetricsPaginatedResponse) SetNextPageToken

func (x *GetMetricsPaginatedResponse) SetNextPageToken(v string)

func (*GetMetricsPaginatedResponse) SetTotalCount

func (x *GetMetricsPaginatedResponse) SetTotalCount(v int64)

func (*GetMetricsPaginatedResponse) String

func (x *GetMetricsPaginatedResponse) String() string

type GetMetricsPaginatedResponse_builder

type GetMetricsPaginatedResponse_builder struct {

	// The list of metrics for the current page
	Metrics []*Metric
	// The next page token, empty if there are no more pages
	NextPageToken string
	// The total count of metrics matching the query
	TotalCount int64
	// contains filtered or unexported fields
}

func (GetMetricsPaginatedResponse_builder) Build

type GetMetricsRequest

type GetMetricsRequest struct {

	// The metric types to get, if empty, all metrics will be returned
	MetricTypes []string `protobuf:"bytes,1,rep,name=metric_types,json=metricTypes,proto3" json:"metric_types,omitempty"`
	// The start time of the query, if empty, the start time will be the beginning of time
	From *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=from,proto3" json:"from,omitempty"`
	// The end time of the query, if empty, the end time will be the end of time
	To *timestamppb.Timestamp `protobuf:"bytes,3,opt,name=to,proto3" json:"to,omitempty"`
	// The step of the query, if empty, the step will be HOURLY
	Step MetricRequestStep `protobuf:"varint,4,opt,name=step,proto3,enum=simplecloud.metrics.v1.MetricRequestStep" json:"step,omitempty"`
	// The meta filters to apply to the query, if empty, no filters will be applied
	MetaFilters []*MetricRequestMetaFilter `protobuf:"bytes,5,rep,name=meta_filters,json=metaFilters,proto3" json:"meta_filters,omitempty"`
	// contains filtered or unexported fields
}

func (*GetMetricsRequest) ClearFrom

func (x *GetMetricsRequest) ClearFrom()

func (*GetMetricsRequest) ClearTo

func (x *GetMetricsRequest) ClearTo()

func (*GetMetricsRequest) GetFrom

func (x *GetMetricsRequest) GetFrom() *timestamppb.Timestamp

func (*GetMetricsRequest) GetMetaFilters

func (x *GetMetricsRequest) GetMetaFilters() []*MetricRequestMetaFilter

func (*GetMetricsRequest) GetMetricTypes

func (x *GetMetricsRequest) GetMetricTypes() []string

func (*GetMetricsRequest) GetStep

func (x *GetMetricsRequest) GetStep() MetricRequestStep

func (*GetMetricsRequest) GetTo

func (*GetMetricsRequest) HasFrom

func (x *GetMetricsRequest) HasFrom() bool

func (*GetMetricsRequest) HasTo

func (x *GetMetricsRequest) HasTo() bool

func (*GetMetricsRequest) ProtoMessage

func (*GetMetricsRequest) ProtoMessage()

func (*GetMetricsRequest) ProtoReflect

func (x *GetMetricsRequest) ProtoReflect() protoreflect.Message

func (*GetMetricsRequest) Reset

func (x *GetMetricsRequest) Reset()

func (*GetMetricsRequest) SetFrom

func (x *GetMetricsRequest) SetFrom(v *timestamppb.Timestamp)

func (*GetMetricsRequest) SetMetaFilters

func (x *GetMetricsRequest) SetMetaFilters(v []*MetricRequestMetaFilter)

func (*GetMetricsRequest) SetMetricTypes

func (x *GetMetricsRequest) SetMetricTypes(v []string)

func (*GetMetricsRequest) SetStep

func (x *GetMetricsRequest) SetStep(v MetricRequestStep)

func (*GetMetricsRequest) SetTo

func (*GetMetricsRequest) String

func (x *GetMetricsRequest) String() string

type GetMetricsRequest_builder

type GetMetricsRequest_builder struct {

	// The metric types to get, if empty, all metrics will be returned
	MetricTypes []string
	// The start time of the query, if empty, the start time will be the beginning of time
	From *timestamppb.Timestamp
	// The end time of the query, if empty, the end time will be the end of time
	To *timestamppb.Timestamp
	// The step of the query, if empty, the step will be HOURLY
	Step MetricRequestStep
	// The meta filters to apply to the query, if empty, no filters will be applied
	MetaFilters []*MetricRequestMetaFilter
	// contains filtered or unexported fields
}

func (GetMetricsRequest_builder) Build

type GetMetricsResponse

type GetMetricsResponse struct {
	Metrics []*Metric `protobuf:"bytes,1,rep,name=metrics,proto3" json:"metrics,omitempty"`
	// contains filtered or unexported fields
}

func (*GetMetricsResponse) GetMetrics

func (x *GetMetricsResponse) GetMetrics() []*Metric

func (*GetMetricsResponse) ProtoMessage

func (*GetMetricsResponse) ProtoMessage()

func (*GetMetricsResponse) ProtoReflect

func (x *GetMetricsResponse) ProtoReflect() protoreflect.Message

func (*GetMetricsResponse) Reset

func (x *GetMetricsResponse) Reset()

func (*GetMetricsResponse) SetMetrics

func (x *GetMetricsResponse) SetMetrics(v []*Metric)

func (*GetMetricsResponse) String

func (x *GetMetricsResponse) String() string

type GetMetricsResponse_builder

type GetMetricsResponse_builder struct {
	Metrics []*Metric
	// contains filtered or unexported fields
}

func (GetMetricsResponse_builder) Build

type Metric

type Metric struct {
	UniqueId    string                 `protobuf:"bytes,1,opt,name=unique_id,json=uniqueId,proto3" json:"unique_id,omitempty"`
	MetricType  string                 `protobuf:"bytes,2,opt,name=metric_type,json=metricType,proto3" json:"metric_type,omitempty"`
	MetricValue int64                  `protobuf:"varint,3,opt,name=metric_value,json=metricValue,proto3" json:"metric_value,omitempty"`
	Time        *timestamppb.Timestamp `protobuf:"bytes,4,opt,name=time,proto3" json:"time,omitempty"`
	Meta        []*MetricMeta          `protobuf:"bytes,5,rep,name=meta,proto3" json:"meta,omitempty"`
	// contains filtered or unexported fields
}

func (*Metric) ClearTime

func (x *Metric) ClearTime()

func (*Metric) GetMeta

func (x *Metric) GetMeta() []*MetricMeta

func (*Metric) GetMetricType

func (x *Metric) GetMetricType() string

func (*Metric) GetMetricValue

func (x *Metric) GetMetricValue() int64

func (*Metric) GetTime

func (x *Metric) GetTime() *timestamppb.Timestamp

func (*Metric) GetUniqueId

func (x *Metric) GetUniqueId() string

func (*Metric) HasTime

func (x *Metric) HasTime() bool

func (*Metric) ProtoMessage

func (*Metric) ProtoMessage()

func (*Metric) ProtoReflect

func (x *Metric) ProtoReflect() protoreflect.Message

func (*Metric) Reset

func (x *Metric) Reset()

func (*Metric) SetMeta

func (x *Metric) SetMeta(v []*MetricMeta)

func (*Metric) SetMetricType

func (x *Metric) SetMetricType(v string)

func (*Metric) SetMetricValue

func (x *Metric) SetMetricValue(v int64)

func (*Metric) SetTime

func (x *Metric) SetTime(v *timestamppb.Timestamp)

func (*Metric) SetUniqueId

func (x *Metric) SetUniqueId(v string)

func (*Metric) String

func (x *Metric) String() string

type MetricFilterType

type MetricFilterType int32
const (
	MetricFilterType_UNKNOWN_FILTER_TYPE MetricFilterType = 0
	MetricFilterType_EQUALS              MetricFilterType = 1
	MetricFilterType_STARTS_WITH         MetricFilterType = 2
	MetricFilterType_ENDS_WITH           MetricFilterType = 3
	MetricFilterType_CONTAINS            MetricFilterType = 4
)

func (MetricFilterType) Descriptor

func (MetricFilterType) Enum

func (MetricFilterType) Number

func (MetricFilterType) String

func (x MetricFilterType) String() string

func (MetricFilterType) Type

type MetricMeta

type MetricMeta struct {
	MetricUniqueId string `protobuf:"bytes,1,opt,name=metric_unique_id,json=metricUniqueId,proto3" json:"metric_unique_id,omitempty"`
	DataName       string `protobuf:"bytes,2,opt,name=data_name,json=dataName,proto3" json:"data_name,omitempty"`
	DataValue      string `protobuf:"bytes,3,opt,name=data_value,json=dataValue,proto3" json:"data_value,omitempty"`
	// contains filtered or unexported fields
}

func (*MetricMeta) GetDataName

func (x *MetricMeta) GetDataName() string

func (*MetricMeta) GetDataValue

func (x *MetricMeta) GetDataValue() string

func (*MetricMeta) GetMetricUniqueId

func (x *MetricMeta) GetMetricUniqueId() string

func (*MetricMeta) ProtoMessage

func (*MetricMeta) ProtoMessage()

func (*MetricMeta) ProtoReflect

func (x *MetricMeta) ProtoReflect() protoreflect.Message

func (*MetricMeta) Reset

func (x *MetricMeta) Reset()

func (*MetricMeta) SetDataName

func (x *MetricMeta) SetDataName(v string)

func (*MetricMeta) SetDataValue

func (x *MetricMeta) SetDataValue(v string)

func (*MetricMeta) SetMetricUniqueId

func (x *MetricMeta) SetMetricUniqueId(v string)

func (*MetricMeta) String

func (x *MetricMeta) String() string

type MetricMeta_builder

type MetricMeta_builder struct {
	MetricUniqueId string
	DataName       string
	DataValue      string
	// contains filtered or unexported fields
}

func (MetricMeta_builder) Build

func (b0 MetricMeta_builder) Build() *MetricMeta

type MetricRequestMetaFilter

type MetricRequestMetaFilter struct {
	Key        string           `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
	Value      string           `protobuf:"bytes,2,opt,name=value,proto3" json:"value,omitempty"`
	FilterType MetricFilterType `` /* 137-byte string literal not displayed */
	Negate     bool             `protobuf:"varint,4,opt,name=negate,proto3" json:"negate,omitempty"`
	// contains filtered or unexported fields
}

func (*MetricRequestMetaFilter) GetFilterType

func (x *MetricRequestMetaFilter) GetFilterType() MetricFilterType

func (*MetricRequestMetaFilter) GetKey

func (x *MetricRequestMetaFilter) GetKey() string

func (*MetricRequestMetaFilter) GetNegate

func (x *MetricRequestMetaFilter) GetNegate() bool

func (*MetricRequestMetaFilter) GetValue

func (x *MetricRequestMetaFilter) GetValue() string

func (*MetricRequestMetaFilter) ProtoMessage

func (*MetricRequestMetaFilter) ProtoMessage()

func (*MetricRequestMetaFilter) ProtoReflect

func (x *MetricRequestMetaFilter) ProtoReflect() protoreflect.Message

func (*MetricRequestMetaFilter) Reset

func (x *MetricRequestMetaFilter) Reset()

func (*MetricRequestMetaFilter) SetFilterType

func (x *MetricRequestMetaFilter) SetFilterType(v MetricFilterType)

func (*MetricRequestMetaFilter) SetKey

func (x *MetricRequestMetaFilter) SetKey(v string)

func (*MetricRequestMetaFilter) SetNegate

func (x *MetricRequestMetaFilter) SetNegate(v bool)

func (*MetricRequestMetaFilter) SetValue

func (x *MetricRequestMetaFilter) SetValue(v string)

func (*MetricRequestMetaFilter) String

func (x *MetricRequestMetaFilter) String() string

type MetricRequestMetaFilter_builder

type MetricRequestMetaFilter_builder struct {
	Key        string
	Value      string
	FilterType MetricFilterType
	Negate     bool
	// contains filtered or unexported fields
}

func (MetricRequestMetaFilter_builder) Build

type MetricRequestStep

type MetricRequestStep int32
const (
	MetricRequestStep_UNKNOWN_STEP MetricRequestStep = 0
	MetricRequestStep_HOURLY       MetricRequestStep = 1
	MetricRequestStep_DAILY        MetricRequestStep = 2
	MetricRequestStep_MONTHLY      MetricRequestStep = 3
	MetricRequestStep_MINUTELY     MetricRequestStep = 4
)

func (MetricRequestStep) Descriptor

func (MetricRequestStep) Enum

func (MetricRequestStep) Number

func (MetricRequestStep) String

func (x MetricRequestStep) String() string

func (MetricRequestStep) Type

type Metric_builder

type Metric_builder struct {
	UniqueId    string
	MetricType  string
	MetricValue int64
	Time        *timestamppb.Timestamp
	Meta        []*MetricMeta
	// contains filtered or unexported fields
}

func (Metric_builder) Build

func (b0 Metric_builder) Build() *Metric

type RecordMetricRequest

type RecordMetricRequest struct {
	Metric *Metric `protobuf:"bytes,1,opt,name=metric,proto3" json:"metric,omitempty"`
	// contains filtered or unexported fields
}

func (*RecordMetricRequest) ClearMetric

func (x *RecordMetricRequest) ClearMetric()

func (*RecordMetricRequest) GetMetric

func (x *RecordMetricRequest) GetMetric() *Metric

func (*RecordMetricRequest) HasMetric

func (x *RecordMetricRequest) HasMetric() bool

func (*RecordMetricRequest) ProtoMessage

func (*RecordMetricRequest) ProtoMessage()

func (*RecordMetricRequest) ProtoReflect

func (x *RecordMetricRequest) ProtoReflect() protoreflect.Message

func (*RecordMetricRequest) Reset

func (x *RecordMetricRequest) Reset()

func (*RecordMetricRequest) SetMetric

func (x *RecordMetricRequest) SetMetric(v *Metric)

func (*RecordMetricRequest) String

func (x *RecordMetricRequest) String() string

type RecordMetricRequest_builder

type RecordMetricRequest_builder struct {
	Metric *Metric
	// contains filtered or unexported fields
}

func (RecordMetricRequest_builder) Build

type RecordMetricResponse

type RecordMetricResponse struct {
	Metric *Metric `protobuf:"bytes,1,opt,name=metric,proto3" json:"metric,omitempty"`
	// contains filtered or unexported fields
}

func (*RecordMetricResponse) ClearMetric

func (x *RecordMetricResponse) ClearMetric()

func (*RecordMetricResponse) GetMetric

func (x *RecordMetricResponse) GetMetric() *Metric

func (*RecordMetricResponse) HasMetric

func (x *RecordMetricResponse) HasMetric() bool

func (*RecordMetricResponse) ProtoMessage

func (*RecordMetricResponse) ProtoMessage()

func (*RecordMetricResponse) ProtoReflect

func (x *RecordMetricResponse) ProtoReflect() protoreflect.Message

func (*RecordMetricResponse) Reset

func (x *RecordMetricResponse) Reset()

func (*RecordMetricResponse) SetMetric

func (x *RecordMetricResponse) SetMetric(v *Metric)

func (*RecordMetricResponse) String

func (x *RecordMetricResponse) String() string

type RecordMetricResponse_builder

type RecordMetricResponse_builder struct {
	Metric *Metric
	// contains filtered or unexported fields
}

func (RecordMetricResponse_builder) Build

Source Files

  • metrics_api.pb.go

Jump to