Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterArticleServiceServer(s grpc.ServiceRegistrar, srv ArticleServiceServer)
- type ArticleServiceClient
- type ArticleServiceServer
- type UnimplementedArticleServiceServer
- func (UnimplementedArticleServiceServer) BatchGetArticles(context.Context, *v1.BatchGetArticlesRequest) (*v1.BatchGetArticlesResponse, error)
- func (UnimplementedArticleServiceServer) GetArticle(context.Context, *v1.GetArticleRequest) (*v1.Article, error)
- func (UnimplementedArticleServiceServer) ListArticles(context.Context, *v1.ListArticlesRequest) (*v1.ListArticlesResponse, error)
- func (UnimplementedArticleServiceServer) ListSections(context.Context, *emptypb.Empty) (*v1.ListSectionsResponse, error)
- type UnsafeArticleServiceServer
Constants ¶
const ( ArticleService_GetArticle_FullMethodName = "/stroeer.core.v1.ArticleService/GetArticle" ArticleService_BatchGetArticles_FullMethodName = "/stroeer.core.v1.ArticleService/BatchGetArticles" ArticleService_ListArticles_FullMethodName = "/stroeer.core.v1.ArticleService/ListArticles" ArticleService_ListSections_FullMethodName = "/stroeer.core.v1.ArticleService/ListSections" )
Variables ¶
var ArticleService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "stroeer.core.v1.ArticleService", HandlerType: (*ArticleServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "GetArticle", Handler: _ArticleService_GetArticle_Handler, }, { MethodName: "BatchGetArticles", Handler: _ArticleService_BatchGetArticles_Handler, }, { MethodName: "ListArticles", Handler: _ArticleService_ListArticles_Handler, }, { MethodName: "ListSections", Handler: _ArticleService_ListSections_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "stroeer/core/v1/core_article_service.proto", }
ArticleService_ServiceDesc is the grpc.ServiceDesc for ArticleService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterArticleServiceServer ¶
func RegisterArticleServiceServer(s grpc.ServiceRegistrar, srv ArticleServiceServer)
Types ¶
type ArticleServiceClient ¶
type ArticleServiceClient interface {
GetArticle(ctx context.Context, in *v1.GetArticleRequest, opts ...grpc.CallOption) (*v1.Article, error)
BatchGetArticles(ctx context.Context, in *v1.BatchGetArticlesRequest, opts ...grpc.CallOption) (*v1.BatchGetArticlesResponse, error)
ListArticles(ctx context.Context, in *v1.ListArticlesRequest, opts ...grpc.CallOption) (*v1.ListArticlesResponse, error)
// Allow Empty as request param
// buf:lint:ignore RPC_REQUEST_STANDARD_NAME
ListSections(ctx context.Context, in *emptypb.Empty, opts ...grpc.CallOption) (*v1.ListSectionsResponse, error)
}
ArticleServiceClient is the client API for ArticleService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewArticleServiceClient ¶
func NewArticleServiceClient(cc grpc.ClientConnInterface) ArticleServiceClient
type ArticleServiceServer ¶
type ArticleServiceServer interface {
GetArticle(context.Context, *v1.GetArticleRequest) (*v1.Article, error)
BatchGetArticles(context.Context, *v1.BatchGetArticlesRequest) (*v1.BatchGetArticlesResponse, error)
ListArticles(context.Context, *v1.ListArticlesRequest) (*v1.ListArticlesResponse, error)
// Allow Empty as request param
// buf:lint:ignore RPC_REQUEST_STANDARD_NAME
ListSections(context.Context, *emptypb.Empty) (*v1.ListSectionsResponse, error)
}
ArticleServiceServer is the server API for ArticleService service. All implementations should embed UnimplementedArticleServiceServer for forward compatibility.
type UnimplementedArticleServiceServer ¶
type UnimplementedArticleServiceServer struct{}
UnimplementedArticleServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedArticleServiceServer) BatchGetArticles ¶
func (UnimplementedArticleServiceServer) BatchGetArticles(context.Context, *v1.BatchGetArticlesRequest) (*v1.BatchGetArticlesResponse, error)
func (UnimplementedArticleServiceServer) GetArticle ¶
func (UnimplementedArticleServiceServer) GetArticle(context.Context, *v1.GetArticleRequest) (*v1.Article, error)
func (UnimplementedArticleServiceServer) ListArticles ¶
func (UnimplementedArticleServiceServer) ListArticles(context.Context, *v1.ListArticlesRequest) (*v1.ListArticlesResponse, error)
func (UnimplementedArticleServiceServer) ListSections ¶
func (UnimplementedArticleServiceServer) ListSections(context.Context, *emptypb.Empty) (*v1.ListSectionsResponse, error)
type UnsafeArticleServiceServer ¶
type UnsafeArticleServiceServer interface {
// contains filtered or unexported methods
}
UnsafeArticleServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ArticleServiceServer will result in compilation errors.
Source Files
¶
- core_article_service_grpc.pb.go