Documentation
¶
Index ¶
Constants ¶
const ( CurationService_GetCuration_FullMethodName = "/stroeer.curation.v1.CurationService/GetCuration" CurationService_BatchGetCuration_FullMethodName = "/stroeer.curation.v1.CurationService/BatchGetCuration" )
Variables ¶
var CurationService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "stroeer.curation.v1.CurationService", HandlerType: (*CurationServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "GetCuration", Handler: _CurationService_GetCuration_Handler, }, { MethodName: "BatchGetCuration", Handler: _CurationService_BatchGetCuration_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "stroeer/curation/v1/core_curation_service.proto", }
CurationService_ServiceDesc is the grpc.ServiceDesc for CurationService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterCurationServiceServer ¶
func RegisterCurationServiceServer(s grpc.ServiceRegistrar, srv CurationServiceServer)
Types ¶
type CurationServiceClient ¶
type CurationServiceClient interface {
GetCuration(ctx context.Context, in *v1.GetCurationRequest, opts ...grpc.CallOption) (*v1.GetCurationResponse, error)
BatchGetCuration(ctx context.Context, in *v1.BatchGetCurationRequest, opts ...grpc.CallOption) (*v1.BatchGetCurationResponse, error)
}
CurationServiceClient is the client API for CurationService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
* This services allows to query curations within the CMS. In the CMS domain this is implemented as `Lists` which usually contain one ore more `Articles`.
@CodeBlockStart protobuf
func NewCurationServiceClient ¶
func NewCurationServiceClient(cc grpc.ClientConnInterface) CurationServiceClient
type CurationServiceServer ¶
type CurationServiceServer interface {
GetCuration(context.Context, *v1.GetCurationRequest) (*v1.GetCurationResponse, error)
BatchGetCuration(context.Context, *v1.BatchGetCurationRequest) (*v1.BatchGetCurationResponse, error)
}
CurationServiceServer is the server API for CurationService service. All implementations should embed UnimplementedCurationServiceServer for forward compatibility.
* This services allows to query curations within the CMS. In the CMS domain this is implemented as `Lists` which usually contain one ore more `Articles`.
@CodeBlockStart protobuf
type UnimplementedCurationServiceServer ¶
type UnimplementedCurationServiceServer struct{}
UnimplementedCurationServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedCurationServiceServer) BatchGetCuration ¶
func (UnimplementedCurationServiceServer) BatchGetCuration(context.Context, *v1.BatchGetCurationRequest) (*v1.BatchGetCurationResponse, error)
func (UnimplementedCurationServiceServer) GetCuration ¶
func (UnimplementedCurationServiceServer) GetCuration(context.Context, *v1.GetCurationRequest) (*v1.GetCurationResponse, error)
type UnsafeCurationServiceServer ¶
type UnsafeCurationServiceServer interface {
// contains filtered or unexported methods
}
UnsafeCurationServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to CurationServiceServer will result in compilation errors.
Source Files
¶
- core_curation_service_grpc.pb.go