Documentation
¶
Index ¶
Constants ¶
const (
)
Variables ¶
ServiceName: "stroeer.navigation.v1.NavigationService", HandlerType: (*NavigationServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "GetNavigation", Handler: _NavigationService_GetNavigation_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "stroeer/navigation/v1/navigation_service.proto", }
NavigationService_ServiceDesc is the grpc.ServiceDesc for NavigationService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterNavigationServiceServer ¶
func RegisterNavigationServiceServer(s grpc.ServiceRegistrar, srv NavigationServiceServer)
Types ¶
type NavigationServiceClient ¶
type NavigationServiceClient interface {
GetNavigation(ctx context.Context, in *v1.GetNavigationRequest, opts ...grpc.CallOption) (*v1.GetNavigationResponse, error)
}
NavigationServiceClient is the client API for NavigationService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewNavigationServiceClient ¶
func NewNavigationServiceClient(cc grpc.ClientConnInterface) NavigationServiceClient
type NavigationServiceServer ¶
type NavigationServiceServer interface {
GetNavigation(context.Context, *v1.GetNavigationRequest) (*v1.GetNavigationResponse, error)
}
NavigationServiceServer is the server API for NavigationService service. All implementations should embed UnimplementedNavigationServiceServer for forward compatibility.
type UnimplementedNavigationServiceServer ¶
type UnimplementedNavigationServiceServer struct{}
UnimplementedNavigationServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedNavigationServiceServer) GetNavigation ¶
func (UnimplementedNavigationServiceServer) GetNavigation(context.Context, *v1.GetNavigationRequest) (*v1.GetNavigationResponse, error)
type UnsafeNavigationServiceServer ¶
type UnsafeNavigationServiceServer interface {
// contains filtered or unexported methods
}
UnsafeNavigationServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to NavigationServiceServer will result in compilation errors.
Source Files
¶
- navigation_service_grpc.pb.go