curationv1

package
v1.36.11-2026022309590... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 6 Imported by: 2

Documentation

Index

Constants

This section is empty.

Variables

var File_stroeer_curation_v1_core_curation_service_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type BatchGetCurationRequest

type BatchGetCurationRequest struct {
	Ids []int64 `protobuf:"varint,1,rep,packed,name=ids,proto3" json:"ids,omitempty"`
	// contains filtered or unexported fields
}

* # `⚙︎ BatchGetCuration`

Fetch multiple curations by their id and return the [`repeated stroeer.core.v1.Article`](Article.html) those curations contain. The response may be empty in case the curation does not contain any items. The ordering of items will the same ordering as the `ids` requested.

## BatchGetCurationRequest

| Field name | Type | Description | |------------------|-------------------------------------|--------------------------------------| | `ids` | `repeated int64` | the _ids_ of the lists to be fetched |

@CodeBlockStart protobuf

func (*BatchGetCurationRequest) GetIds

func (x *BatchGetCurationRequest) GetIds() []int64

func (*BatchGetCurationRequest) ProtoMessage

func (*BatchGetCurationRequest) ProtoMessage()

func (*BatchGetCurationRequest) ProtoReflect

func (x *BatchGetCurationRequest) ProtoReflect() protoreflect.Message

func (*BatchGetCurationRequest) Reset

func (x *BatchGetCurationRequest) Reset()

func (*BatchGetCurationRequest) SetIds

func (x *BatchGetCurationRequest) SetIds(v []int64)

func (*BatchGetCurationRequest) String

func (x *BatchGetCurationRequest) String() string

type BatchGetCurationRequest_builder

type BatchGetCurationRequest_builder struct {
	Ids []int64
	// contains filtered or unexported fields
}

func (BatchGetCurationRequest_builder) Build

type BatchGetCurationResponse

type BatchGetCurationResponse struct {
	Curations []*GetCurationResponse `protobuf:"bytes,1,rep,name=curations,proto3" json:"curations,omitempty"`
	// contains filtered or unexported fields
}

* ## BatchGetCurationResponse

| Field name | Type | Description | |------------------|-------------------------------------|--------------------------------------------------------------------------------| | `curations` | [`GetCurationResponse`][cr] | a single response item that corresponds to _ids_ this service was called with. |

[cr]: #getcurationresponse

@CodeBlockStart protobuf

func (*BatchGetCurationResponse) GetCurations

func (x *BatchGetCurationResponse) GetCurations() []*GetCurationResponse

func (*BatchGetCurationResponse) ProtoMessage

func (*BatchGetCurationResponse) ProtoMessage()

func (*BatchGetCurationResponse) ProtoReflect

func (x *BatchGetCurationResponse) ProtoReflect() protoreflect.Message

func (*BatchGetCurationResponse) Reset

func (x *BatchGetCurationResponse) Reset()

func (*BatchGetCurationResponse) SetCurations

func (x *BatchGetCurationResponse) SetCurations(v []*GetCurationResponse)

func (*BatchGetCurationResponse) String

func (x *BatchGetCurationResponse) String() string

type BatchGetCurationResponse_builder

type BatchGetCurationResponse_builder struct {
	Curations []*GetCurationResponse
	// contains filtered or unexported fields
}

func (BatchGetCurationResponse_builder) Build

type GetCurationRequest

type GetCurationRequest struct {
	Id int64 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
	// contains filtered or unexported fields
}

* # `⚙︎ GetCuration`

Fetch a curation by its id and return the [`repeated stroeer.core.v1.Article`](Article.html) this curation contains. The response may be empty in case the curation does not contain any items.

a `NOT_FOUND` status code will indicate the curation `id` does not exist.

## GetCurationRequest

| Field name | Type | Description | |------------------|----------|-------------------------------------------------------------| | `id` | `int64` | [required] id of the list to be fetched |

@CodeBlockStart protobuf

func (*GetCurationRequest) GetId

func (x *GetCurationRequest) GetId() int64

func (*GetCurationRequest) ProtoMessage

func (*GetCurationRequest) ProtoMessage()

func (*GetCurationRequest) ProtoReflect

func (x *GetCurationRequest) ProtoReflect() protoreflect.Message

func (*GetCurationRequest) Reset

func (x *GetCurationRequest) Reset()

func (*GetCurationRequest) SetId

func (x *GetCurationRequest) SetId(v int64)

func (*GetCurationRequest) String

func (x *GetCurationRequest) String() string

type GetCurationRequest_builder

type GetCurationRequest_builder struct {
	Id int64
	// contains filtered or unexported fields
}

func (GetCurationRequest_builder) Build

type GetCurationResponse

type GetCurationResponse struct {
	Id         int64                  `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
	Label      string                 `protobuf:"bytes,2,opt,name=label,proto3" json:"label,omitempty"`
	UpdateTime *timestamppb.Timestamp `protobuf:"bytes,3,opt,name=update_time,json=updateTime,proto3" json:"update_time,omitempty"`
	Articles   []*v1.Article          `protobuf:"bytes,4,rep,name=articles,proto3" json:"articles,omitempty"`
	// contains filtered or unexported fields
}

func (*GetCurationResponse) ClearUpdateTime

func (x *GetCurationResponse) ClearUpdateTime()

func (*GetCurationResponse) GetArticles

func (x *GetCurationResponse) GetArticles() []*v1.Article

func (*GetCurationResponse) GetId

func (x *GetCurationResponse) GetId() int64

func (*GetCurationResponse) GetLabel

func (x *GetCurationResponse) GetLabel() string

func (*GetCurationResponse) GetUpdateTime

func (x *GetCurationResponse) GetUpdateTime() *timestamppb.Timestamp

func (*GetCurationResponse) HasUpdateTime

func (x *GetCurationResponse) HasUpdateTime() bool

func (*GetCurationResponse) ProtoMessage

func (*GetCurationResponse) ProtoMessage()

func (*GetCurationResponse) ProtoReflect

func (x *GetCurationResponse) ProtoReflect() protoreflect.Message

func (*GetCurationResponse) Reset

func (x *GetCurationResponse) Reset()

func (*GetCurationResponse) SetArticles

func (x *GetCurationResponse) SetArticles(v []*v1.Article)

func (*GetCurationResponse) SetId

func (x *GetCurationResponse) SetId(v int64)

func (*GetCurationResponse) SetLabel

func (x *GetCurationResponse) SetLabel(v string)

func (*GetCurationResponse) SetUpdateTime

func (x *GetCurationResponse) SetUpdateTime(v *timestamppb.Timestamp)

func (*GetCurationResponse) String

func (x *GetCurationResponse) String() string

type GetCurationResponse_builder

type GetCurationResponse_builder struct {
	Id         int64
	Label      string
	UpdateTime *timestamppb.Timestamp
	Articles   []*v1.Article
	// contains filtered or unexported fields
}

func (GetCurationResponse_builder) Build

Source Files

  • core_curation_service.pb.go

Jump to