sectionv1

package
v1.36.11-2026022309590... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 7 Imported by: 3

Documentation

Index

Constants

This section is empty.

Variables

var (
	GetSectionPageResponse_PaginationType_name = map[int32]string{
		0: "PAGINATION_TYPE_UNSPECIFIED",
		1: "FIXED_BLOCK",
		2: "GHOST_BLOCK",
	}
	GetSectionPageResponse_PaginationType_value = map[string]int32{
		"PAGINATION_TYPE_UNSPECIFIED": 0,
		"FIXED_BLOCK":                 1,
		"GHOST_BLOCK":                 2,
	}
)

Enum value maps for GetSectionPageResponse_PaginationType.

var File_stroeer_page_section_v1_section_page_proto protoreflect.FileDescriptor
var File_stroeer_page_section_v1_section_page_service_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type GetSectionPageRequest

type GetSectionPageRequest struct {

	// valid section_path, with leading and trailing slash
	SectionPath string `protobuf:"bytes,1,opt,name=section_path,json=sectionPath,proto3" json:"section_path,omitempty"`
	// use to page through sections. If unspecified, it will default to `1`.
	// Paging is 1-based (1 is the first page, there is no page `0`)
	//
	// Due to underlying mechanisms and seo requirements, page-size is fixed at 30
	// The service may return fewer than this value.
	Page int32 `protobuf:"varint,2,opt,name=page,proto3" json:"page,omitempty"`
	// contains filtered or unexported fields
}

* Message to provide parameters when requesting data for a section page, currently only the path of the page. Correct paths have a leading and a trailing slash, like `/nachrichten/unterhaltung/` The homepage has the path `/`.

```protobuf

message GetSectionPageRequest {
  // valid section_path, with leading and trailing slash
  string section_path = 1;

  // use to page through sections. If unspecified, it will default to `1`.
  // Paging is 1-based (1 is the first page, there is no page `0`)
  //
  // Due to underlying mechanisms and seo requirements, page-size is fixed at 30
  // The service may return fewer than this value.
  int32 page = 2;
}

```

func (*GetSectionPageRequest) GetPage

func (x *GetSectionPageRequest) GetPage() int32

func (*GetSectionPageRequest) GetSectionPath

func (x *GetSectionPageRequest) GetSectionPath() string

func (*GetSectionPageRequest) ProtoMessage

func (*GetSectionPageRequest) ProtoMessage()

func (*GetSectionPageRequest) ProtoReflect

func (x *GetSectionPageRequest) ProtoReflect() protoreflect.Message

func (*GetSectionPageRequest) Reset

func (x *GetSectionPageRequest) Reset()

func (*GetSectionPageRequest) SetPage

func (x *GetSectionPageRequest) SetPage(v int32)

func (*GetSectionPageRequest) SetSectionPath

func (x *GetSectionPageRequest) SetSectionPath(v string)

func (*GetSectionPageRequest) String

func (x *GetSectionPageRequest) String() string

type GetSectionPageRequest_builder

type GetSectionPageRequest_builder struct {

	// valid section_path, with leading and trailing slash
	SectionPath string
	// use to page through sections. If unspecified, it will default to `1`.
	// Paging is 1-based (1 is the first page, there is no page `0`)
	//
	// Due to underlying mechanisms and seo requirements, page-size is fixed at 30
	// The service may return fewer than this value.
	Page int32
	// contains filtered or unexported fields
}

func (GetSectionPageRequest_builder) Build

type GetSectionPageResponse

type GetSectionPageResponse struct {
	SectionPage *SectionPage `protobuf:"bytes,1,opt,name=section_page,json=sectionPage,proto3" json:"section_page,omitempty"`
	// Total number of pages in this `section_path`
	TotalPages     int32                                 `protobuf:"varint,2,opt,name=total_pages,json=totalPages,proto3" json:"total_pages,omitempty"`
	PaginationType GetSectionPageResponse_PaginationType `` /* 171-byte string literal not displayed */
	// contains filtered or unexported fields
}

* Response message when requesting data for a section page. Responds with `NOT_FOUND` if an unknown path is requested, or the path is incorrect.

```protobuf message GetSectionPageResponse { stroeer.page.section.v1.SectionPage section_page = 1;

// Total number of pages in this `section_path`

int32 total_pages = 2;

PaginationType pagination_type = 3;

 enum PaginationType {
   // Not specified.
   PAGINATION_TYPE_UNSPECIFIED = 0;

   // The default pagination type.
   FIXED_BLOCK = 1;

   // Pagination type for Evergreen-Ressorts.
   GHOST_BLOCK = 2;
 }
}

```

func (*GetSectionPageResponse) ClearSectionPage

func (x *GetSectionPageResponse) ClearSectionPage()

func (*GetSectionPageResponse) GetPaginationType

func (*GetSectionPageResponse) GetSectionPage

func (x *GetSectionPageResponse) GetSectionPage() *SectionPage

func (*GetSectionPageResponse) GetTotalPages

func (x *GetSectionPageResponse) GetTotalPages() int32

func (*GetSectionPageResponse) HasSectionPage

func (x *GetSectionPageResponse) HasSectionPage() bool

func (*GetSectionPageResponse) ProtoMessage

func (*GetSectionPageResponse) ProtoMessage()

func (*GetSectionPageResponse) ProtoReflect

func (x *GetSectionPageResponse) ProtoReflect() protoreflect.Message

func (*GetSectionPageResponse) Reset

func (x *GetSectionPageResponse) Reset()

func (*GetSectionPageResponse) SetPaginationType

func (*GetSectionPageResponse) SetSectionPage

func (x *GetSectionPageResponse) SetSectionPage(v *SectionPage)

func (*GetSectionPageResponse) SetTotalPages

func (x *GetSectionPageResponse) SetTotalPages(v int32)

func (*GetSectionPageResponse) String

func (x *GetSectionPageResponse) String() string

type GetSectionPageResponse_PaginationType

type GetSectionPageResponse_PaginationType int32
const (
	// Not specified.
	GetSectionPageResponse_PAGINATION_TYPE_UNSPECIFIED GetSectionPageResponse_PaginationType = 0
	// The default pagination type.
	GetSectionPageResponse_FIXED_BLOCK GetSectionPageResponse_PaginationType = 1
	// Pagination type for Evergreen-Ressorts.
	GetSectionPageResponse_GHOST_BLOCK GetSectionPageResponse_PaginationType = 2
)

func (GetSectionPageResponse_PaginationType) Descriptor

func (GetSectionPageResponse_PaginationType) Enum

func (GetSectionPageResponse_PaginationType) Number

func (GetSectionPageResponse_PaginationType) String

func (GetSectionPageResponse_PaginationType) Type

type GetSectionPageResponse_builder

type GetSectionPageResponse_builder struct {
	SectionPage *SectionPage
	// Total number of pages in this `section_path`
	TotalPages     int32
	PaginationType GetSectionPageResponse_PaginationType
	// contains filtered or unexported fields
}

func (GetSectionPageResponse_builder) Build

type SectionPage

type SectionPage struct {
	Section *SectionPage_Section `protobuf:"bytes,1,opt,name=section,proto3" json:"section,omitempty"`
	Stages  []*v1.Stage          `protobuf:"bytes,2,rep,name=stages,proto3" json:"stages,omitempty"`
	// Page navigation including internal and external references
	// The root references has nested references
	// root
	//   - menu
	//   - submenu
	//   - menu
	//   - submenu
	//   - external references
	NavigationMenu *v11.Reference `protobuf:"bytes,3,opt,name=navigation_menu,json=navigationMenu,proto3" json:"navigation_menu,omitempty"`
	// contains filtered or unexported fields
}

All data to render a section page like the homepage or "/politik/".

func (*SectionPage) ClearNavigationMenu

func (x *SectionPage) ClearNavigationMenu()

func (*SectionPage) ClearSection

func (x *SectionPage) ClearSection()

func (*SectionPage) GetNavigationMenu

func (x *SectionPage) GetNavigationMenu() *v11.Reference

func (*SectionPage) GetSection

func (x *SectionPage) GetSection() *SectionPage_Section

func (*SectionPage) GetStages

func (x *SectionPage) GetStages() []*v1.Stage

func (*SectionPage) HasNavigationMenu

func (x *SectionPage) HasNavigationMenu() bool

func (*SectionPage) HasSection

func (x *SectionPage) HasSection() bool

func (*SectionPage) ProtoMessage

func (*SectionPage) ProtoMessage()

func (*SectionPage) ProtoReflect

func (x *SectionPage) ProtoReflect() protoreflect.Message

func (*SectionPage) Reset

func (x *SectionPage) Reset()

func (*SectionPage) SetNavigationMenu

func (x *SectionPage) SetNavigationMenu(v *v11.Reference)

func (*SectionPage) SetSection

func (x *SectionPage) SetSection(v *SectionPage_Section)

func (*SectionPage) SetStages

func (x *SectionPage) SetStages(v []*v1.Stage)

func (*SectionPage) String

func (x *SectionPage) String() string

type SectionPage_Section

type SectionPage_Section struct {

	// Generic map containing general content and configuration information of
	// the section (required).
	// The entry set is defined by the content management system and
	// will vary depending on the main type of the article.
	//
	// Clients must be resilient to unknown or missing entry sets.
	Fields map[string]string `` /* 139-byte string literal not displayed */
	// References, e.g. URLs belonging to this section (required).
	// For example:
	// * `internal`: URL path for this section e.g. /section/id_$ID/title.html
	// * `external`: Canonical URL of this section, may differ if external, e.g. https://www.giga.de/tech/
	SectionTree *v11.Reference   `protobuf:"bytes,2,opt,name=section_tree,json=sectionTree,proto3" json:"section_tree,omitempty"`
	References  []*v11.Reference `protobuf:"bytes,3,rep,name=references,proto3" json:"references,omitempty"`
	// contains filtered or unexported fields
}

All meta information to render a section page.

func (*SectionPage_Section) ClearSectionTree

func (x *SectionPage_Section) ClearSectionTree()

func (*SectionPage_Section) GetFields

func (x *SectionPage_Section) GetFields() map[string]string

func (*SectionPage_Section) GetReferences

func (x *SectionPage_Section) GetReferences() []*v11.Reference

func (*SectionPage_Section) GetSectionTree

func (x *SectionPage_Section) GetSectionTree() *v11.Reference

func (*SectionPage_Section) HasSectionTree

func (x *SectionPage_Section) HasSectionTree() bool

func (*SectionPage_Section) ProtoMessage

func (*SectionPage_Section) ProtoMessage()

func (*SectionPage_Section) ProtoReflect

func (x *SectionPage_Section) ProtoReflect() protoreflect.Message

func (*SectionPage_Section) Reset

func (x *SectionPage_Section) Reset()

func (*SectionPage_Section) SetFields

func (x *SectionPage_Section) SetFields(v map[string]string)

func (*SectionPage_Section) SetReferences

func (x *SectionPage_Section) SetReferences(v []*v11.Reference)

func (*SectionPage_Section) SetSectionTree

func (x *SectionPage_Section) SetSectionTree(v *v11.Reference)

func (*SectionPage_Section) String

func (x *SectionPage_Section) String() string

type SectionPage_Section_builder

type SectionPage_Section_builder struct {

	// Generic map containing general content and configuration information of
	// the section (required).
	// The entry set is defined by the content management system and
	// will vary depending on the main type of the article.
	//
	// Clients must be resilient to unknown or missing entry sets.
	Fields map[string]string
	// References, e.g. URLs belonging to this section (required).
	// For example:
	// * `internal`: URL path for this section e.g. /section/id_$ID/title.html
	// * `external`: Canonical URL of this section, may differ if external, e.g. https://www.giga.de/tech/
	SectionTree *v11.Reference
	References  []*v11.Reference
	// contains filtered or unexported fields
}

func (SectionPage_Section_builder) Build

type SectionPage_builder

type SectionPage_builder struct {
	Section *SectionPage_Section
	Stages  []*v1.Stage
	// Page navigation including internal and external references
	// The root references has nested references
	// root
	//   - menu
	//   - submenu
	//   - menu
	//   - submenu
	//   - external references
	NavigationMenu *v11.Reference
	// contains filtered or unexported fields
}

func (SectionPage_builder) Build

func (b0 SectionPage_builder) Build() *SectionPage

Source Files

  • section_page.pb.go
  • section_page_service.pb.go

Jump to