stagev1

package
v1.36.12-2026042909065... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

const Stage_Item_ArticleTeaser_case case_Stage_Item_ItemType = 3
const Stage_Item_Commercial_case case_Stage_Item_ItemType = 4
const Stage_Item_ItemType_not_set_case case_Stage_Item_ItemType = 0
const Stage_Item_Stage_case case_Stage_Item_ItemType = 2

Variables

var File_stroeer_page_stage_v1_stage_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type Stage

type Stage struct {
	Configuration  *Stage_Configuration `protobuf:"bytes,1,opt,name=configuration,proto3" json:"configuration,omitempty"`
	StreamItems    []*Stage_Item        `protobuf:"bytes,2,rep,name=stream_items,json=streamItems,proto3" json:"stream_items,omitempty"`
	CompanionItems []*Stage_Item        `protobuf:"bytes,3,rep,name=companion_items,json=companionItems,proto3" json:"companion_items,omitempty"`
	// contains filtered or unexported fields
}

* A stream stage with companions and the main content area. Embedded items can be editorial articles, advertisement and/or stages (only one level deep). ```protobuf

message Stage {
  Configuration configuration = 1;
  repeated Item stream_items = 2;
  repeated Item companion_items = 3;

```

func (*Stage) ClearConfiguration

func (x *Stage) ClearConfiguration()

func (*Stage) GetCompanionItems

func (x *Stage) GetCompanionItems() []*Stage_Item

func (*Stage) GetConfiguration

func (x *Stage) GetConfiguration() *Stage_Configuration

func (*Stage) GetStreamItems

func (x *Stage) GetStreamItems() []*Stage_Item

func (*Stage) HasConfiguration

func (x *Stage) HasConfiguration() bool

func (*Stage) ProtoMessage

func (*Stage) ProtoMessage()

func (*Stage) ProtoReflect

func (x *Stage) ProtoReflect() protoreflect.Message

func (*Stage) Reset

func (x *Stage) Reset()

func (*Stage) SetCompanionItems

func (x *Stage) SetCompanionItems(v []*Stage_Item)

func (*Stage) SetConfiguration

func (x *Stage) SetConfiguration(v *Stage_Configuration)

func (*Stage) SetStreamItems

func (x *Stage) SetStreamItems(v []*Stage_Item)

func (*Stage) String

func (x *Stage) String() string

type Stage_Configuration

type Stage_Configuration struct {

	// * `stage_layout`: represents a visual layout, which may affect teasers, colors, and other styles.
	// If entry `stage_layout` is missing, use layout `stream`.
	// the stage_layout field can be used to configure full page width commercials (e.g. nativendo, t-online empfiehlt)
	Fields map[string]string `` /* 139-byte string literal not displayed */
	// All kind of references as part of the stage. Filter reference by
	// `Reference.type`:
	// * `ref_stage_title`
	// * `ref_sub_navigation`
	References []*v1.Reference `protobuf:"bytes,2,rep,name=references,proto3" json:"references,omitempty"`
	// contains filtered or unexported fields
}

Stage and companion layouts must be coordinated with UI department, especially the `stream` layout. The stage title is in the `references`, also when not linked.

func (*Stage_Configuration) GetFields

func (x *Stage_Configuration) GetFields() map[string]string

func (*Stage_Configuration) GetReferences

func (x *Stage_Configuration) GetReferences() []*v1.Reference

func (*Stage_Configuration) ProtoMessage

func (*Stage_Configuration) ProtoMessage()

func (*Stage_Configuration) ProtoReflect

func (x *Stage_Configuration) ProtoReflect() protoreflect.Message

func (*Stage_Configuration) Reset

func (x *Stage_Configuration) Reset()

func (*Stage_Configuration) SetFields

func (x *Stage_Configuration) SetFields(v map[string]string)

func (*Stage_Configuration) SetReferences

func (x *Stage_Configuration) SetReferences(v []*v1.Reference)

func (*Stage_Configuration) String

func (x *Stage_Configuration) String() string

type Stage_Configuration_builder

type Stage_Configuration_builder struct {

	// * `stage_layout`: represents a visual layout, which may affect teasers, colors, and other styles.
	// If entry `stage_layout` is missing, use layout `stream`.
	// the stage_layout field can be used to configure full page width commercials (e.g. nativendo, t-online empfiehlt)
	Fields map[string]string
	// All kind of references as part of the stage. Filter reference by
	// `Reference.type`:
	// * `ref_stage_title`
	// * `ref_sub_navigation`
	References []*v1.Reference
	// contains filtered or unexported fields
}

func (Stage_Configuration_builder) Build

type Stage_Item

type Stage_Item struct {

	// Optional flags/hints for customization independent of the `item_type`
	Fields map[string]string `` /* 139-byte string literal not displayed */
	// Types that are valid to be assigned to ItemType:
	//
	//	*Stage_Item_Stage
	//	*Stage_Item_ArticleTeaser_
	//	*Stage_Item_Commercial_
	ItemType isStage_Item_ItemType `protobuf_oneof:"item_type"`
	// contains filtered or unexported fields
}

A generic model to represent what can be part of a stage.

func (*Stage_Item) ClearArticleTeaser

func (x *Stage_Item) ClearArticleTeaser()

func (*Stage_Item) ClearCommercial

func (x *Stage_Item) ClearCommercial()

func (*Stage_Item) ClearItemType

func (x *Stage_Item) ClearItemType()

func (*Stage_Item) ClearStage

func (x *Stage_Item) ClearStage()

func (*Stage_Item) GetArticleTeaser

func (x *Stage_Item) GetArticleTeaser() *Stage_Item_ArticleTeaser

func (*Stage_Item) GetCommercial

func (x *Stage_Item) GetCommercial() *Stage_Item_Commercial

func (*Stage_Item) GetFields

func (x *Stage_Item) GetFields() map[string]string

func (*Stage_Item) GetItemType

func (x *Stage_Item) GetItemType() isStage_Item_ItemType

func (*Stage_Item) GetStage

func (x *Stage_Item) GetStage() *Stage

func (*Stage_Item) HasArticleTeaser

func (x *Stage_Item) HasArticleTeaser() bool

func (*Stage_Item) HasCommercial

func (x *Stage_Item) HasCommercial() bool

func (*Stage_Item) HasItemType

func (x *Stage_Item) HasItemType() bool

func (*Stage_Item) HasStage

func (x *Stage_Item) HasStage() bool

func (*Stage_Item) ProtoMessage

func (*Stage_Item) ProtoMessage()

func (*Stage_Item) ProtoReflect

func (x *Stage_Item) ProtoReflect() protoreflect.Message

func (*Stage_Item) Reset

func (x *Stage_Item) Reset()

func (*Stage_Item) SetArticleTeaser

func (x *Stage_Item) SetArticleTeaser(v *Stage_Item_ArticleTeaser)

func (*Stage_Item) SetCommercial

func (x *Stage_Item) SetCommercial(v *Stage_Item_Commercial)

func (*Stage_Item) SetFields

func (x *Stage_Item) SetFields(v map[string]string)

func (*Stage_Item) SetStage

func (x *Stage_Item) SetStage(v *Stage)

func (*Stage_Item) String

func (x *Stage_Item) String() string

func (*Stage_Item) WhichItemType

func (x *Stage_Item) WhichItemType() case_Stage_Item_ItemType

type Stage_Item_ArticleTeaser

type Stage_Item_ArticleTeaser struct {

	// `fields` may contain additional rendering information.
	// * `teaser_layout`: marker to use a particular layout in the rendering teaser template.
	// * `teaser_variant`: marker to use also a particular variant of the provided `teaser_layout`.
	// If `teaser_layout` entries is missing use layout `stream`.
	Fields map[string]string `` /* 139-byte string literal not displayed */
	// `Article.body` is set to `null` to reduce overhead.
	Article *v1.Article `protobuf:"bytes,2,opt,name=article,proto3" json:"article,omitempty"`
	// contains filtered or unexported fields
}

Bundles the data needed to render a core article as a teaser as part of a stage. Coordinate teaser layouts, especially the `stream` layout with UI department.

func (*Stage_Item_ArticleTeaser) ClearArticle

func (x *Stage_Item_ArticleTeaser) ClearArticle()

func (*Stage_Item_ArticleTeaser) GetArticle

func (x *Stage_Item_ArticleTeaser) GetArticle() *v1.Article

func (*Stage_Item_ArticleTeaser) GetFields

func (x *Stage_Item_ArticleTeaser) GetFields() map[string]string

func (*Stage_Item_ArticleTeaser) HasArticle

func (x *Stage_Item_ArticleTeaser) HasArticle() bool

func (*Stage_Item_ArticleTeaser) ProtoMessage

func (*Stage_Item_ArticleTeaser) ProtoMessage()

func (*Stage_Item_ArticleTeaser) ProtoReflect

func (x *Stage_Item_ArticleTeaser) ProtoReflect() protoreflect.Message

func (*Stage_Item_ArticleTeaser) Reset

func (x *Stage_Item_ArticleTeaser) Reset()

func (*Stage_Item_ArticleTeaser) SetArticle

func (x *Stage_Item_ArticleTeaser) SetArticle(v *v1.Article)

func (*Stage_Item_ArticleTeaser) SetFields

func (x *Stage_Item_ArticleTeaser) SetFields(v map[string]string)

func (*Stage_Item_ArticleTeaser) String

func (x *Stage_Item_ArticleTeaser) String() string

type Stage_Item_ArticleTeaser_

type Stage_Item_ArticleTeaser_ struct {
	ArticleTeaser *Stage_Item_ArticleTeaser `protobuf:"bytes,3,opt,name=article_teaser,json=articleTeaser,proto3,oneof"`
}

type Stage_Item_ArticleTeaser_builder

type Stage_Item_ArticleTeaser_builder struct {

	// `fields` may contain additional rendering information.
	// * `teaser_layout`: marker to use a particular layout in the rendering teaser template.
	// * `teaser_variant`: marker to use also a particular variant of the provided `teaser_layout`.
	// If `teaser_layout` entries is missing use layout `stream`.
	Fields map[string]string
	// `Article.body` is set to `null` to reduce overhead.
	Article *v1.Article
	// contains filtered or unexported fields
}

func (Stage_Item_ArticleTeaser_builder) Build

type Stage_Item_Commercial

type Stage_Item_Commercial struct {

	// e.g. advertisement booking ids. Data may differ between commercial types.
	Fields map[string]string `` /* 139-byte string literal not displayed */
	// contains filtered or unexported fields
}

Bundles the data to render a commercial as part of a stage.

func (*Stage_Item_Commercial) GetFields

func (x *Stage_Item_Commercial) GetFields() map[string]string

func (*Stage_Item_Commercial) ProtoMessage

func (*Stage_Item_Commercial) ProtoMessage()

func (*Stage_Item_Commercial) ProtoReflect

func (x *Stage_Item_Commercial) ProtoReflect() protoreflect.Message

func (*Stage_Item_Commercial) Reset

func (x *Stage_Item_Commercial) Reset()

func (*Stage_Item_Commercial) SetFields

func (x *Stage_Item_Commercial) SetFields(v map[string]string)

func (*Stage_Item_Commercial) String

func (x *Stage_Item_Commercial) String() string

type Stage_Item_Commercial_

type Stage_Item_Commercial_ struct {
	Commercial *Stage_Item_Commercial `protobuf:"bytes,4,opt,name=commercial,proto3,oneof"`
}

type Stage_Item_Commercial_builder

type Stage_Item_Commercial_builder struct {

	// e.g. advertisement booking ids. Data may differ between commercial types.
	Fields map[string]string
	// contains filtered or unexported fields
}

func (Stage_Item_Commercial_builder) Build

type Stage_Item_Stage

type Stage_Item_Stage struct {
	// We don't support recursion and limit the depth at this point to 1 in the services
	Stage *Stage `protobuf:"bytes,2,opt,name=stage,proto3,oneof"`
}

type Stage_Item_builder

type Stage_Item_builder struct {

	// Optional flags/hints for customization independent of the `item_type`
	Fields map[string]string
	// Fields of oneof ItemType:
	// We don't support recursion and limit the depth at this point to 1 in the services
	Stage         *Stage
	ArticleTeaser *Stage_Item_ArticleTeaser
	Commercial    *Stage_Item_Commercial
	// contains filtered or unexported fields
}

func (Stage_Item_builder) Build

func (b0 Stage_Item_builder) Build() *Stage_Item

type Stage_builder

type Stage_builder struct {
	Configuration  *Stage_Configuration
	StreamItems    []*Stage_Item
	CompanionItems []*Stage_Item
	// contains filtered or unexported fields
}

func (Stage_builder) Build

func (b0 Stage_builder) Build() *Stage

Source Files

  • stage.pb.go

Jump to