cloudservicev1grpc

package
v1.6.1-20240614173613-... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	CloudService_GetUsers_FullMethodName                    = "/temporal.api.cloud.cloudservice.v1.CloudService/GetUsers"
	CloudService_GetUser_FullMethodName                     = "/temporal.api.cloud.cloudservice.v1.CloudService/GetUser"
	CloudService_CreateUser_FullMethodName                  = "/temporal.api.cloud.cloudservice.v1.CloudService/CreateUser"
	CloudService_UpdateUser_FullMethodName                  = "/temporal.api.cloud.cloudservice.v1.CloudService/UpdateUser"
	CloudService_DeleteUser_FullMethodName                  = "/temporal.api.cloud.cloudservice.v1.CloudService/DeleteUser"
	CloudService_SetUserNamespaceAccess_FullMethodName      = "/temporal.api.cloud.cloudservice.v1.CloudService/SetUserNamespaceAccess"
	CloudService_GetAsyncOperation_FullMethodName           = "/temporal.api.cloud.cloudservice.v1.CloudService/GetAsyncOperation"
	CloudService_CreateNamespace_FullMethodName             = "/temporal.api.cloud.cloudservice.v1.CloudService/CreateNamespace"
	CloudService_GetNamespaces_FullMethodName               = "/temporal.api.cloud.cloudservice.v1.CloudService/GetNamespaces"
	CloudService_GetNamespace_FullMethodName                = "/temporal.api.cloud.cloudservice.v1.CloudService/GetNamespace"
	CloudService_UpdateNamespace_FullMethodName             = "/temporal.api.cloud.cloudservice.v1.CloudService/UpdateNamespace"
	CloudService_RenameCustomSearchAttribute_FullMethodName = "/temporal.api.cloud.cloudservice.v1.CloudService/RenameCustomSearchAttribute"
	CloudService_DeleteNamespace_FullMethodName             = "/temporal.api.cloud.cloudservice.v1.CloudService/DeleteNamespace"
	CloudService_FailoverNamespaceRegion_FullMethodName     = "/temporal.api.cloud.cloudservice.v1.CloudService/FailoverNamespaceRegion"
	CloudService_AddNamespaceRegion_FullMethodName          = "/temporal.api.cloud.cloudservice.v1.CloudService/AddNamespaceRegion"
	CloudService_GetRegions_FullMethodName                  = "/temporal.api.cloud.cloudservice.v1.CloudService/GetRegions"
	CloudService_GetRegion_FullMethodName                   = "/temporal.api.cloud.cloudservice.v1.CloudService/GetRegion"
	CloudService_GetApiKeys_FullMethodName                  = "/temporal.api.cloud.cloudservice.v1.CloudService/GetApiKeys"
	CloudService_GetApiKey_FullMethodName                   = "/temporal.api.cloud.cloudservice.v1.CloudService/GetApiKey"
	CloudService_CreateApiKey_FullMethodName                = "/temporal.api.cloud.cloudservice.v1.CloudService/CreateApiKey"
	CloudService_UpdateApiKey_FullMethodName                = "/temporal.api.cloud.cloudservice.v1.CloudService/UpdateApiKey"
	CloudService_DeleteApiKey_FullMethodName                = "/temporal.api.cloud.cloudservice.v1.CloudService/DeleteApiKey"
	CloudService_GetUserGroups_FullMethodName               = "/temporal.api.cloud.cloudservice.v1.CloudService/GetUserGroups"
	CloudService_GetUserGroup_FullMethodName                = "/temporal.api.cloud.cloudservice.v1.CloudService/GetUserGroup"
	CloudService_CreateUserGroup_FullMethodName             = "/temporal.api.cloud.cloudservice.v1.CloudService/CreateUserGroup"
	CloudService_UpdateUserGroup_FullMethodName             = "/temporal.api.cloud.cloudservice.v1.CloudService/UpdateUserGroup"
	CloudService_DeleteUserGroup_FullMethodName             = "/temporal.api.cloud.cloudservice.v1.CloudService/DeleteUserGroup"
	CloudService_SetUserGroupNamespaceAccess_FullMethodName = "/temporal.api.cloud.cloudservice.v1.CloudService/SetUserGroupNamespaceAccess"
	CloudService_CreateServiceAccount_FullMethodName        = "/temporal.api.cloud.cloudservice.v1.CloudService/CreateServiceAccount"
	CloudService_GetServiceAccount_FullMethodName           = "/temporal.api.cloud.cloudservice.v1.CloudService/GetServiceAccount"
	CloudService_GetServiceAccounts_FullMethodName          = "/temporal.api.cloud.cloudservice.v1.CloudService/GetServiceAccounts"
	CloudService_UpdateServiceAccount_FullMethodName        = "/temporal.api.cloud.cloudservice.v1.CloudService/UpdateServiceAccount"
	CloudService_DeleteServiceAccount_FullMethodName        = "/temporal.api.cloud.cloudservice.v1.CloudService/DeleteServiceAccount"
)

Variables

var CloudService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "temporal.api.cloud.cloudservice.v1.CloudService",
	HandlerType: (*CloudServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetUsers",
			Handler:    _CloudService_GetUsers_Handler,
		},
		{
			MethodName: "GetUser",
			Handler:    _CloudService_GetUser_Handler,
		},
		{
			MethodName: "CreateUser",
			Handler:    _CloudService_CreateUser_Handler,
		},
		{
			MethodName: "UpdateUser",
			Handler:    _CloudService_UpdateUser_Handler,
		},
		{
			MethodName: "DeleteUser",
			Handler:    _CloudService_DeleteUser_Handler,
		},
		{
			MethodName: "SetUserNamespaceAccess",
			Handler:    _CloudService_SetUserNamespaceAccess_Handler,
		},
		{
			MethodName: "GetAsyncOperation",
			Handler:    _CloudService_GetAsyncOperation_Handler,
		},
		{
			MethodName: "CreateNamespace",
			Handler:    _CloudService_CreateNamespace_Handler,
		},
		{
			MethodName: "GetNamespaces",
			Handler:    _CloudService_GetNamespaces_Handler,
		},
		{
			MethodName: "GetNamespace",
			Handler:    _CloudService_GetNamespace_Handler,
		},
		{
			MethodName: "UpdateNamespace",
			Handler:    _CloudService_UpdateNamespace_Handler,
		},
		{
			MethodName: "RenameCustomSearchAttribute",
			Handler:    _CloudService_RenameCustomSearchAttribute_Handler,
		},
		{
			MethodName: "DeleteNamespace",
			Handler:    _CloudService_DeleteNamespace_Handler,
		},
		{
			MethodName: "FailoverNamespaceRegion",
			Handler:    _CloudService_FailoverNamespaceRegion_Handler,
		},
		{
			MethodName: "AddNamespaceRegion",
			Handler:    _CloudService_AddNamespaceRegion_Handler,
		},
		{
			MethodName: "GetRegions",
			Handler:    _CloudService_GetRegions_Handler,
		},
		{
			MethodName: "GetRegion",
			Handler:    _CloudService_GetRegion_Handler,
		},
		{
			MethodName: "GetApiKeys",
			Handler:    _CloudService_GetApiKeys_Handler,
		},
		{
			MethodName: "GetApiKey",
			Handler:    _CloudService_GetApiKey_Handler,
		},
		{
			MethodName: "CreateApiKey",
			Handler:    _CloudService_CreateApiKey_Handler,
		},
		{
			MethodName: "UpdateApiKey",
			Handler:    _CloudService_UpdateApiKey_Handler,
		},
		{
			MethodName: "DeleteApiKey",
			Handler:    _CloudService_DeleteApiKey_Handler,
		},
		{
			MethodName: "GetUserGroups",
			Handler:    _CloudService_GetUserGroups_Handler,
		},
		{
			MethodName: "GetUserGroup",
			Handler:    _CloudService_GetUserGroup_Handler,
		},
		{
			MethodName: "CreateUserGroup",
			Handler:    _CloudService_CreateUserGroup_Handler,
		},
		{
			MethodName: "UpdateUserGroup",
			Handler:    _CloudService_UpdateUserGroup_Handler,
		},
		{
			MethodName: "DeleteUserGroup",
			Handler:    _CloudService_DeleteUserGroup_Handler,
		},
		{
			MethodName: "SetUserGroupNamespaceAccess",
			Handler:    _CloudService_SetUserGroupNamespaceAccess_Handler,
		},
		{
			MethodName: "CreateServiceAccount",
			Handler:    _CloudService_CreateServiceAccount_Handler,
		},
		{
			MethodName: "GetServiceAccount",
			Handler:    _CloudService_GetServiceAccount_Handler,
		},
		{
			MethodName: "GetServiceAccounts",
			Handler:    _CloudService_GetServiceAccounts_Handler,
		},
		{
			MethodName: "UpdateServiceAccount",
			Handler:    _CloudService_UpdateServiceAccount_Handler,
		},
		{
			MethodName: "DeleteServiceAccount",
			Handler:    _CloudService_DeleteServiceAccount_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "temporal/api/cloud/cloudservice/v1/service.proto",
}

CloudService_ServiceDesc is the grpc.ServiceDesc for CloudService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterCloudServiceServer

func RegisterCloudServiceServer(s grpc.ServiceRegistrar, srv CloudServiceServer)

Types

type CloudServiceClient

type CloudServiceClient interface {
	// Gets all known users
	GetUsers(ctx context.Context, in *v1.GetUsersRequest, opts ...grpc.CallOption) (*v1.GetUsersResponse, error)
	// Get a user
	GetUser(ctx context.Context, in *v1.GetUserRequest, opts ...grpc.CallOption) (*v1.GetUserResponse, error)
	// Create a user
	CreateUser(ctx context.Context, in *v1.CreateUserRequest, opts ...grpc.CallOption) (*v1.CreateUserResponse, error)
	// Update a user
	UpdateUser(ctx context.Context, in *v1.UpdateUserRequest, opts ...grpc.CallOption) (*v1.UpdateUserResponse, error)
	// Delete a user
	DeleteUser(ctx context.Context, in *v1.DeleteUserRequest, opts ...grpc.CallOption) (*v1.DeleteUserResponse, error)
	// Set a user's access to a namespace
	SetUserNamespaceAccess(ctx context.Context, in *v1.SetUserNamespaceAccessRequest, opts ...grpc.CallOption) (*v1.SetUserNamespaceAccessResponse, error)
	// Get the latest information on an async operation
	GetAsyncOperation(ctx context.Context, in *v1.GetAsyncOperationRequest, opts ...grpc.CallOption) (*v1.GetAsyncOperationResponse, error)
	// Create a new namespace
	CreateNamespace(ctx context.Context, in *v1.CreateNamespaceRequest, opts ...grpc.CallOption) (*v1.CreateNamespaceResponse, error)
	// Get all namespaces
	GetNamespaces(ctx context.Context, in *v1.GetNamespacesRequest, opts ...grpc.CallOption) (*v1.GetNamespacesResponse, error)
	// Get a namespace
	GetNamespace(ctx context.Context, in *v1.GetNamespaceRequest, opts ...grpc.CallOption) (*v1.GetNamespaceResponse, error)
	// Update a namespace
	UpdateNamespace(ctx context.Context, in *v1.UpdateNamespaceRequest, opts ...grpc.CallOption) (*v1.UpdateNamespaceResponse, error)
	// Rename an existing customer search attribute
	RenameCustomSearchAttribute(ctx context.Context, in *v1.RenameCustomSearchAttributeRequest, opts ...grpc.CallOption) (*v1.RenameCustomSearchAttributeResponse, error)
	// Delete a namespace
	DeleteNamespace(ctx context.Context, in *v1.DeleteNamespaceRequest, opts ...grpc.CallOption) (*v1.DeleteNamespaceResponse, error)
	// Failover a multi-region namespace
	FailoverNamespaceRegion(ctx context.Context, in *v1.FailoverNamespaceRegionRequest, opts ...grpc.CallOption) (*v1.FailoverNamespaceRegionResponse, error)
	// Add a new region to a namespace
	AddNamespaceRegion(ctx context.Context, in *v1.AddNamespaceRegionRequest, opts ...grpc.CallOption) (*v1.AddNamespaceRegionResponse, error)
	// Get all regions
	GetRegions(ctx context.Context, in *v1.GetRegionsRequest, opts ...grpc.CallOption) (*v1.GetRegionsResponse, error)
	// Get a region
	GetRegion(ctx context.Context, in *v1.GetRegionRequest, opts ...grpc.CallOption) (*v1.GetRegionResponse, error)
	// Get all known API keys
	GetApiKeys(ctx context.Context, in *v1.GetApiKeysRequest, opts ...grpc.CallOption) (*v1.GetApiKeysResponse, error)
	// Get an API key
	GetApiKey(ctx context.Context, in *v1.GetApiKeyRequest, opts ...grpc.CallOption) (*v1.GetApiKeyResponse, error)
	// Create an API key
	CreateApiKey(ctx context.Context, in *v1.CreateApiKeyRequest, opts ...grpc.CallOption) (*v1.CreateApiKeyResponse, error)
	// Update an API key
	UpdateApiKey(ctx context.Context, in *v1.UpdateApiKeyRequest, opts ...grpc.CallOption) (*v1.UpdateApiKeyResponse, error)
	// Delete an API key
	DeleteApiKey(ctx context.Context, in *v1.DeleteApiKeyRequest, opts ...grpc.CallOption) (*v1.DeleteApiKeyResponse, error)
	// Get all user groups
	GetUserGroups(ctx context.Context, in *v1.GetUserGroupsRequest, opts ...grpc.CallOption) (*v1.GetUserGroupsResponse, error)
	// Get a user group
	GetUserGroup(ctx context.Context, in *v1.GetUserGroupRequest, opts ...grpc.CallOption) (*v1.GetUserGroupResponse, error)
	// Create new a user group
	CreateUserGroup(ctx context.Context, in *v1.CreateUserGroupRequest, opts ...grpc.CallOption) (*v1.CreateUserGroupResponse, error)
	// Update a user group
	UpdateUserGroup(ctx context.Context, in *v1.UpdateUserGroupRequest, opts ...grpc.CallOption) (*v1.UpdateUserGroupResponse, error)
	// Delete a user group
	DeleteUserGroup(ctx context.Context, in *v1.DeleteUserGroupRequest, opts ...grpc.CallOption) (*v1.DeleteUserGroupResponse, error)
	// Set a user group's access to a namespace
	SetUserGroupNamespaceAccess(ctx context.Context, in *v1.SetUserGroupNamespaceAccessRequest, opts ...grpc.CallOption) (*v1.SetUserGroupNamespaceAccessResponse, error)
	// Create a service account.
	CreateServiceAccount(ctx context.Context, in *v1.CreateServiceAccountRequest, opts ...grpc.CallOption) (*v1.CreateServiceAccountResponse, error)
	// Get a service account.
	GetServiceAccount(ctx context.Context, in *v1.GetServiceAccountRequest, opts ...grpc.CallOption) (*v1.GetServiceAccountResponse, error)
	// Get service accounts.
	GetServiceAccounts(ctx context.Context, in *v1.GetServiceAccountsRequest, opts ...grpc.CallOption) (*v1.GetServiceAccountsResponse, error)
	// Update a service account.
	UpdateServiceAccount(ctx context.Context, in *v1.UpdateServiceAccountRequest, opts ...grpc.CallOption) (*v1.UpdateServiceAccountResponse, error)
	// Delete a service account.
	DeleteServiceAccount(ctx context.Context, in *v1.DeleteServiceAccountRequest, opts ...grpc.CallOption) (*v1.DeleteServiceAccountResponse, error)
}

CloudServiceClient is the client API for CloudService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

WARNING: This service is currently experimental and may change in incompatible ways.

func NewCloudServiceClient

func NewCloudServiceClient(cc grpc.ClientConnInterface) CloudServiceClient

type CloudServiceServer

type CloudServiceServer interface {
	// Gets all known users
	GetUsers(context.Context, *v1.GetUsersRequest) (*v1.GetUsersResponse, error)
	// Get a user
	GetUser(context.Context, *v1.GetUserRequest) (*v1.GetUserResponse, error)
	// Create a user
	CreateUser(context.Context, *v1.CreateUserRequest) (*v1.CreateUserResponse, error)
	// Update a user
	UpdateUser(context.Context, *v1.UpdateUserRequest) (*v1.UpdateUserResponse, error)
	// Delete a user
	DeleteUser(context.Context, *v1.DeleteUserRequest) (*v1.DeleteUserResponse, error)
	// Set a user's access to a namespace
	SetUserNamespaceAccess(context.Context, *v1.SetUserNamespaceAccessRequest) (*v1.SetUserNamespaceAccessResponse, error)
	// Get the latest information on an async operation
	GetAsyncOperation(context.Context, *v1.GetAsyncOperationRequest) (*v1.GetAsyncOperationResponse, error)
	// Create a new namespace
	CreateNamespace(context.Context, *v1.CreateNamespaceRequest) (*v1.CreateNamespaceResponse, error)
	// Get all namespaces
	GetNamespaces(context.Context, *v1.GetNamespacesRequest) (*v1.GetNamespacesResponse, error)
	// Get a namespace
	GetNamespace(context.Context, *v1.GetNamespaceRequest) (*v1.GetNamespaceResponse, error)
	// Update a namespace
	UpdateNamespace(context.Context, *v1.UpdateNamespaceRequest) (*v1.UpdateNamespaceResponse, error)
	// Rename an existing customer search attribute
	RenameCustomSearchAttribute(context.Context, *v1.RenameCustomSearchAttributeRequest) (*v1.RenameCustomSearchAttributeResponse, error)
	// Delete a namespace
	DeleteNamespace(context.Context, *v1.DeleteNamespaceRequest) (*v1.DeleteNamespaceResponse, error)
	// Failover a multi-region namespace
	FailoverNamespaceRegion(context.Context, *v1.FailoverNamespaceRegionRequest) (*v1.FailoverNamespaceRegionResponse, error)
	// Add a new region to a namespace
	AddNamespaceRegion(context.Context, *v1.AddNamespaceRegionRequest) (*v1.AddNamespaceRegionResponse, error)
	// Get all regions
	GetRegions(context.Context, *v1.GetRegionsRequest) (*v1.GetRegionsResponse, error)
	// Get a region
	GetRegion(context.Context, *v1.GetRegionRequest) (*v1.GetRegionResponse, error)
	// Get all known API keys
	GetApiKeys(context.Context, *v1.GetApiKeysRequest) (*v1.GetApiKeysResponse, error)
	// Get an API key
	GetApiKey(context.Context, *v1.GetApiKeyRequest) (*v1.GetApiKeyResponse, error)
	// Create an API key
	CreateApiKey(context.Context, *v1.CreateApiKeyRequest) (*v1.CreateApiKeyResponse, error)
	// Update an API key
	UpdateApiKey(context.Context, *v1.UpdateApiKeyRequest) (*v1.UpdateApiKeyResponse, error)
	// Delete an API key
	DeleteApiKey(context.Context, *v1.DeleteApiKeyRequest) (*v1.DeleteApiKeyResponse, error)
	// Get all user groups
	GetUserGroups(context.Context, *v1.GetUserGroupsRequest) (*v1.GetUserGroupsResponse, error)
	// Get a user group
	GetUserGroup(context.Context, *v1.GetUserGroupRequest) (*v1.GetUserGroupResponse, error)
	// Create new a user group
	CreateUserGroup(context.Context, *v1.CreateUserGroupRequest) (*v1.CreateUserGroupResponse, error)
	// Update a user group
	UpdateUserGroup(context.Context, *v1.UpdateUserGroupRequest) (*v1.UpdateUserGroupResponse, error)
	// Delete a user group
	DeleteUserGroup(context.Context, *v1.DeleteUserGroupRequest) (*v1.DeleteUserGroupResponse, error)
	// Set a user group's access to a namespace
	SetUserGroupNamespaceAccess(context.Context, *v1.SetUserGroupNamespaceAccessRequest) (*v1.SetUserGroupNamespaceAccessResponse, error)
	// Create a service account.
	CreateServiceAccount(context.Context, *v1.CreateServiceAccountRequest) (*v1.CreateServiceAccountResponse, error)
	// Get a service account.
	GetServiceAccount(context.Context, *v1.GetServiceAccountRequest) (*v1.GetServiceAccountResponse, error)
	// Get service accounts.
	GetServiceAccounts(context.Context, *v1.GetServiceAccountsRequest) (*v1.GetServiceAccountsResponse, error)
	// Update a service account.
	UpdateServiceAccount(context.Context, *v1.UpdateServiceAccountRequest) (*v1.UpdateServiceAccountResponse, error)
	// Delete a service account.
	DeleteServiceAccount(context.Context, *v1.DeleteServiceAccountRequest) (*v1.DeleteServiceAccountResponse, error)
}

CloudServiceServer is the server API for CloudService service. All implementations should embed UnimplementedCloudServiceServer for forward compatibility.

WARNING: This service is currently experimental and may change in incompatible ways.

type UnimplementedCloudServiceServer

type UnimplementedCloudServiceServer struct{}

UnimplementedCloudServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedCloudServiceServer) AddNamespaceRegion

func (UnimplementedCloudServiceServer) CreateApiKey

func (UnimplementedCloudServiceServer) CreateNamespace

func (UnimplementedCloudServiceServer) CreateServiceAccount

func (UnimplementedCloudServiceServer) CreateUser

func (UnimplementedCloudServiceServer) CreateUserGroup

func (UnimplementedCloudServiceServer) DeleteApiKey

func (UnimplementedCloudServiceServer) DeleteNamespace

func (UnimplementedCloudServiceServer) DeleteServiceAccount

func (UnimplementedCloudServiceServer) DeleteUser

func (UnimplementedCloudServiceServer) DeleteUserGroup

func (UnimplementedCloudServiceServer) FailoverNamespaceRegion

func (UnimplementedCloudServiceServer) GetApiKey

func (UnimplementedCloudServiceServer) GetApiKeys

func (UnimplementedCloudServiceServer) GetAsyncOperation

func (UnimplementedCloudServiceServer) GetNamespace

func (UnimplementedCloudServiceServer) GetNamespaces

func (UnimplementedCloudServiceServer) GetRegion

func (UnimplementedCloudServiceServer) GetRegions

func (UnimplementedCloudServiceServer) GetServiceAccount

func (UnimplementedCloudServiceServer) GetServiceAccounts

func (UnimplementedCloudServiceServer) GetUser

func (UnimplementedCloudServiceServer) GetUserGroup

func (UnimplementedCloudServiceServer) GetUserGroups

func (UnimplementedCloudServiceServer) GetUsers

func (UnimplementedCloudServiceServer) RenameCustomSearchAttribute

func (UnimplementedCloudServiceServer) SetUserGroupNamespaceAccess

func (UnimplementedCloudServiceServer) SetUserNamespaceAccess

func (UnimplementedCloudServiceServer) UpdateApiKey

func (UnimplementedCloudServiceServer) UpdateNamespace

func (UnimplementedCloudServiceServer) UpdateServiceAccount

func (UnimplementedCloudServiceServer) UpdateUser

func (UnimplementedCloudServiceServer) UpdateUserGroup

type UnsafeCloudServiceServer

type UnsafeCloudServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeCloudServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to CloudServiceServer will result in compilation errors.

Source Files

  • service_grpc.pb.go

Jump to