Documentation
¶
Index ¶
- Variables
- type AsyncOperation
- func (x *AsyncOperation) ClearCheckDuration()
- func (x *AsyncOperation) ClearFinishedTime()
- func (x *AsyncOperation) ClearOperationInput()
- func (x *AsyncOperation) ClearStartedTime()
- func (x *AsyncOperation) GetCheckDuration() *durationpb.Duration
- func (x *AsyncOperation) GetFailureReason() string
- func (x *AsyncOperation) GetFinishedTime() *timestamppb.Timestamp
- func (x *AsyncOperation) GetId() string
- func (x *AsyncOperation) GetOperationInput() *anypb.Any
- func (x *AsyncOperation) GetOperationType() string
- func (x *AsyncOperation) GetStartedTime() *timestamppb.Timestamp
- func (x *AsyncOperation) GetState() string
- func (x *AsyncOperation) HasCheckDuration() bool
- func (x *AsyncOperation) HasFinishedTime() bool
- func (x *AsyncOperation) HasOperationInput() bool
- func (x *AsyncOperation) HasStartedTime() bool
- func (*AsyncOperation) ProtoMessage()
- func (x *AsyncOperation) ProtoReflect() protoreflect.Message
- func (x *AsyncOperation) Reset()
- func (x *AsyncOperation) SetCheckDuration(v *durationpb.Duration)
- func (x *AsyncOperation) SetFailureReason(v string)
- func (x *AsyncOperation) SetFinishedTime(v *timestamppb.Timestamp)
- func (x *AsyncOperation) SetId(v string)
- func (x *AsyncOperation) SetOperationInput(v *anypb.Any)
- func (x *AsyncOperation) SetOperationType(v string)
- func (x *AsyncOperation) SetStartedTime(v *timestamppb.Timestamp)
- func (x *AsyncOperation) SetState(v string)
- func (x *AsyncOperation) String() string
- type AsyncOperation_builder
Constants ¶
This section is empty.
Variables ¶
var File_temporal_api_cloud_operation_v1_message_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type AsyncOperation ¶
type AsyncOperation struct {
// The operation id
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
// The current state of this operation
// Possible values are: pending, in_progress, failed, cancelled, fulfilled
State string `protobuf:"bytes,2,opt,name=state,proto3" json:"state,omitempty"`
// The recommended duration to check back for an update in the operation's state
CheckDuration *durationpb.Duration `protobuf:"bytes,3,opt,name=check_duration,json=checkDuration,proto3" json:"check_duration,omitempty"`
// The type of operation being performed
OperationType string `protobuf:"bytes,4,opt,name=operation_type,json=operationType,proto3" json:"operation_type,omitempty"`
// The input to the operation being performed
//
// (-- api-linter: core::0146::any=disabled --)
OperationInput *anypb.Any `protobuf:"bytes,5,opt,name=operation_input,json=operationInput,proto3" json:"operation_input,omitempty"`
// If the operation failed, the reason for the failure
FailureReason string `protobuf:"bytes,6,opt,name=failure_reason,json=failureReason,proto3" json:"failure_reason,omitempty"`
// The date and time when the operation initiated
StartedTime *timestamppb.Timestamp `protobuf:"bytes,7,opt,name=started_time,json=startedTime,proto3" json:"started_time,omitempty"`
// The date and time when the operation completed
FinishedTime *timestamppb.Timestamp `protobuf:"bytes,8,opt,name=finished_time,json=finishedTime,proto3" json:"finished_time,omitempty"`
// contains filtered or unexported fields
}
func (*AsyncOperation) ClearCheckDuration ¶
func (x *AsyncOperation) ClearCheckDuration()
func (*AsyncOperation) ClearFinishedTime ¶
func (x *AsyncOperation) ClearFinishedTime()
func (*AsyncOperation) ClearOperationInput ¶
func (x *AsyncOperation) ClearOperationInput()
func (*AsyncOperation) ClearStartedTime ¶
func (x *AsyncOperation) ClearStartedTime()
func (*AsyncOperation) GetCheckDuration ¶
func (x *AsyncOperation) GetCheckDuration() *durationpb.Duration
func (*AsyncOperation) GetFailureReason ¶
func (x *AsyncOperation) GetFailureReason() string
func (*AsyncOperation) GetFinishedTime ¶
func (x *AsyncOperation) GetFinishedTime() *timestamppb.Timestamp
func (*AsyncOperation) GetId ¶
func (x *AsyncOperation) GetId() string
func (*AsyncOperation) GetOperationInput ¶
func (x *AsyncOperation) GetOperationInput() *anypb.Any
func (*AsyncOperation) GetOperationType ¶
func (x *AsyncOperation) GetOperationType() string
func (*AsyncOperation) GetStartedTime ¶
func (x *AsyncOperation) GetStartedTime() *timestamppb.Timestamp
func (*AsyncOperation) GetState ¶
func (x *AsyncOperation) GetState() string
func (*AsyncOperation) HasCheckDuration ¶
func (x *AsyncOperation) HasCheckDuration() bool
func (*AsyncOperation) HasFinishedTime ¶
func (x *AsyncOperation) HasFinishedTime() bool
func (*AsyncOperation) HasOperationInput ¶
func (x *AsyncOperation) HasOperationInput() bool
func (*AsyncOperation) HasStartedTime ¶
func (x *AsyncOperation) HasStartedTime() bool
func (*AsyncOperation) ProtoMessage ¶
func (*AsyncOperation) ProtoMessage()
func (*AsyncOperation) ProtoReflect ¶
func (x *AsyncOperation) ProtoReflect() protoreflect.Message
func (*AsyncOperation) Reset ¶
func (x *AsyncOperation) Reset()
func (*AsyncOperation) SetCheckDuration ¶
func (x *AsyncOperation) SetCheckDuration(v *durationpb.Duration)
func (*AsyncOperation) SetFailureReason ¶
func (x *AsyncOperation) SetFailureReason(v string)
func (*AsyncOperation) SetFinishedTime ¶
func (x *AsyncOperation) SetFinishedTime(v *timestamppb.Timestamp)
func (*AsyncOperation) SetId ¶
func (x *AsyncOperation) SetId(v string)
func (*AsyncOperation) SetOperationInput ¶
func (x *AsyncOperation) SetOperationInput(v *anypb.Any)
func (*AsyncOperation) SetOperationType ¶
func (x *AsyncOperation) SetOperationType(v string)
func (*AsyncOperation) SetStartedTime ¶
func (x *AsyncOperation) SetStartedTime(v *timestamppb.Timestamp)
func (*AsyncOperation) SetState ¶
func (x *AsyncOperation) SetState(v string)
func (*AsyncOperation) String ¶
func (x *AsyncOperation) String() string
type AsyncOperation_builder ¶
type AsyncOperation_builder struct {
// The operation id
Id string
// The current state of this operation
// Possible values are: pending, in_progress, failed, cancelled, fulfilled
State string
// The recommended duration to check back for an update in the operation's state
CheckDuration *durationpb.Duration
// The type of operation being performed
OperationType string
// The input to the operation being performed
//
// (-- api-linter: core::0146::any=disabled --)
OperationInput *anypb.Any
// If the operation failed, the reason for the failure
FailureReason string
// The date and time when the operation initiated
StartedTime *timestamppb.Timestamp
// The date and time when the operation completed
FinishedTime *timestamppb.Timestamp
// contains filtered or unexported fields
}
func (AsyncOperation_builder) Build ¶
func (b0 AsyncOperation_builder) Build() *AsyncOperation
Source Files
¶
- message.pb.go
Click to show internal directories.
Click to hide internal directories.