regionv1

package
v1.36.10-2024061417361... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var File_temporal_api_cloud_region_v1_message_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type Region

type Region struct {

	// The id of the temporal cloud region.
	Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	// The name of the cloud provider that's hosting the region.
	// Currently only "aws" is supported.
	CloudProvider string `protobuf:"bytes,2,opt,name=cloud_provider,json=cloudProvider,proto3" json:"cloud_provider,omitempty"`
	// The region identifier as defined by the cloud provider.
	CloudProviderRegion string `protobuf:"bytes,3,opt,name=cloud_provider_region,json=cloudProviderRegion,proto3" json:"cloud_provider_region,omitempty"`
	// The human readable location of the region.
	Location string `protobuf:"bytes,4,opt,name=location,proto3" json:"location,omitempty"`
	// contains filtered or unexported fields
}

func (*Region) GetCloudProvider

func (x *Region) GetCloudProvider() string

func (*Region) GetCloudProviderRegion

func (x *Region) GetCloudProviderRegion() string

func (*Region) GetId

func (x *Region) GetId() string

func (*Region) GetLocation

func (x *Region) GetLocation() string

func (*Region) ProtoMessage

func (*Region) ProtoMessage()

func (*Region) ProtoReflect

func (x *Region) ProtoReflect() protoreflect.Message

func (*Region) Reset

func (x *Region) Reset()

func (*Region) SetCloudProvider

func (x *Region) SetCloudProvider(v string)

func (*Region) SetCloudProviderRegion

func (x *Region) SetCloudProviderRegion(v string)

func (*Region) SetId

func (x *Region) SetId(v string)

func (*Region) SetLocation

func (x *Region) SetLocation(v string)

func (*Region) String

func (x *Region) String() string

type Region_builder

type Region_builder struct {

	// The id of the temporal cloud region.
	Id string
	// The name of the cloud provider that's hosting the region.
	// Currently only "aws" is supported.
	CloudProvider string
	// The region identifier as defined by the cloud provider.
	CloudProviderRegion string
	// The human readable location of the region.
	Location string
	// contains filtered or unexported fields
}

func (Region_builder) Build

func (b0 Region_builder) Build() *Region

Source Files

  • message.pb.go

Jump to