Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterOperatorServiceServer(s grpc.ServiceRegistrar, srv OperatorServiceServer)
- type OperatorServiceClient
- type OperatorServiceServer
- type UnimplementedOperatorServiceServer
- func (UnimplementedOperatorServiceServer) AddOrUpdateRemoteCluster(context.Context, *v1.AddOrUpdateRemoteClusterRequest) (*v1.AddOrUpdateRemoteClusterResponse, error)
- func (UnimplementedOperatorServiceServer) AddSearchAttributes(context.Context, *v1.AddSearchAttributesRequest) (*v1.AddSearchAttributesResponse, error)
- func (UnimplementedOperatorServiceServer) DeleteNamespace(context.Context, *v1.DeleteNamespaceRequest) (*v1.DeleteNamespaceResponse, error)
- func (UnimplementedOperatorServiceServer) ListClusters(context.Context, *v1.ListClustersRequest) (*v1.ListClustersResponse, error)
- func (UnimplementedOperatorServiceServer) ListSearchAttributes(context.Context, *v1.ListSearchAttributesRequest) (*v1.ListSearchAttributesResponse, error)
- func (UnimplementedOperatorServiceServer) RemoveRemoteCluster(context.Context, *v1.RemoveRemoteClusterRequest) (*v1.RemoveRemoteClusterResponse, error)
- func (UnimplementedOperatorServiceServer) RemoveSearchAttributes(context.Context, *v1.RemoveSearchAttributesRequest) (*v1.RemoveSearchAttributesResponse, error)
- type UnsafeOperatorServiceServer
Constants ¶
const ( OperatorService_AddSearchAttributes_FullMethodName = "/temporal.api.operatorservice.v1.OperatorService/AddSearchAttributes" OperatorService_RemoveSearchAttributes_FullMethodName = "/temporal.api.operatorservice.v1.OperatorService/RemoveSearchAttributes" OperatorService_ListSearchAttributes_FullMethodName = "/temporal.api.operatorservice.v1.OperatorService/ListSearchAttributes" OperatorService_DeleteNamespace_FullMethodName = "/temporal.api.operatorservice.v1.OperatorService/DeleteNamespace" OperatorService_AddOrUpdateRemoteCluster_FullMethodName = "/temporal.api.operatorservice.v1.OperatorService/AddOrUpdateRemoteCluster" OperatorService_RemoveRemoteCluster_FullMethodName = "/temporal.api.operatorservice.v1.OperatorService/RemoveRemoteCluster" OperatorService_ListClusters_FullMethodName = "/temporal.api.operatorservice.v1.OperatorService/ListClusters" )
Variables ¶
var OperatorService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "temporal.api.operatorservice.v1.OperatorService", HandlerType: (*OperatorServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "AddSearchAttributes", Handler: _OperatorService_AddSearchAttributes_Handler, }, { MethodName: "RemoveSearchAttributes", Handler: _OperatorService_RemoveSearchAttributes_Handler, }, { MethodName: "ListSearchAttributes", Handler: _OperatorService_ListSearchAttributes_Handler, }, { MethodName: "DeleteNamespace", Handler: _OperatorService_DeleteNamespace_Handler, }, { MethodName: "AddOrUpdateRemoteCluster", Handler: _OperatorService_AddOrUpdateRemoteCluster_Handler, }, { MethodName: "RemoveRemoteCluster", Handler: _OperatorService_RemoveRemoteCluster_Handler, }, { MethodName: "ListClusters", Handler: _OperatorService_ListClusters_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "temporal/api/operatorservice/v1/service.proto", }
OperatorService_ServiceDesc is the grpc.ServiceDesc for OperatorService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterOperatorServiceServer ¶
func RegisterOperatorServiceServer(s grpc.ServiceRegistrar, srv OperatorServiceServer)
Types ¶
type OperatorServiceClient ¶
type OperatorServiceClient interface {
// AddSearchAttributes add custom search attributes.
//
// Returns ALREADY_EXISTS status code if a Search Attribute with any of the specified names already exists
// Returns INTERNAL status code with temporal.api.errordetails.v1.SystemWorkflowFailure in Error Details if registration process fails,
AddSearchAttributes(ctx context.Context, in *v1.AddSearchAttributesRequest, opts ...grpc.CallOption) (*v1.AddSearchAttributesResponse, error)
// RemoveSearchAttributes removes custom search attributes.
//
// Returns NOT_FOUND status code if a Search Attribute with any of the specified names is not registered
RemoveSearchAttributes(ctx context.Context, in *v1.RemoveSearchAttributesRequest, opts ...grpc.CallOption) (*v1.RemoveSearchAttributesResponse, error)
// ListSearchAttributes returns comprehensive information about search attributes.
ListSearchAttributes(ctx context.Context, in *v1.ListSearchAttributesRequest, opts ...grpc.CallOption) (*v1.ListSearchAttributesResponse, error)
// DeleteNamespace synchronously deletes a namespace and asynchronously reclaims all namespace resources.
// (-- api-linter: core::0135::method-signature=disabled
//
// aip.dev/not-precedent: DeleteNamespace RPC doesn't follow Google API format. --)
//
// (-- api-linter: core::0135::response-message-name=disabled
//
// aip.dev/not-precedent: DeleteNamespace RPC doesn't follow Google API format. --)
DeleteNamespace(ctx context.Context, in *v1.DeleteNamespaceRequest, opts ...grpc.CallOption) (*v1.DeleteNamespaceResponse, error)
// AddOrUpdateRemoteCluster adds or updates remote cluster.
AddOrUpdateRemoteCluster(ctx context.Context, in *v1.AddOrUpdateRemoteClusterRequest, opts ...grpc.CallOption) (*v1.AddOrUpdateRemoteClusterResponse, error)
// RemoveRemoteCluster removes remote cluster.
RemoveRemoteCluster(ctx context.Context, in *v1.RemoveRemoteClusterRequest, opts ...grpc.CallOption) (*v1.RemoveRemoteClusterResponse, error)
// ListClusters returns information about Temporal clusters.
ListClusters(ctx context.Context, in *v1.ListClustersRequest, opts ...grpc.CallOption) (*v1.ListClustersResponse, error)
}
OperatorServiceClient is the client API for OperatorService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewOperatorServiceClient ¶
func NewOperatorServiceClient(cc grpc.ClientConnInterface) OperatorServiceClient
type OperatorServiceServer ¶
type OperatorServiceServer interface {
// AddSearchAttributes add custom search attributes.
//
// Returns ALREADY_EXISTS status code if a Search Attribute with any of the specified names already exists
// Returns INTERNAL status code with temporal.api.errordetails.v1.SystemWorkflowFailure in Error Details if registration process fails,
AddSearchAttributes(context.Context, *v1.AddSearchAttributesRequest) (*v1.AddSearchAttributesResponse, error)
// RemoveSearchAttributes removes custom search attributes.
//
// Returns NOT_FOUND status code if a Search Attribute with any of the specified names is not registered
RemoveSearchAttributes(context.Context, *v1.RemoveSearchAttributesRequest) (*v1.RemoveSearchAttributesResponse, error)
// ListSearchAttributes returns comprehensive information about search attributes.
ListSearchAttributes(context.Context, *v1.ListSearchAttributesRequest) (*v1.ListSearchAttributesResponse, error)
// DeleteNamespace synchronously deletes a namespace and asynchronously reclaims all namespace resources.
// (-- api-linter: core::0135::method-signature=disabled
//
// aip.dev/not-precedent: DeleteNamespace RPC doesn't follow Google API format. --)
//
// (-- api-linter: core::0135::response-message-name=disabled
//
// aip.dev/not-precedent: DeleteNamespace RPC doesn't follow Google API format. --)
DeleteNamespace(context.Context, *v1.DeleteNamespaceRequest) (*v1.DeleteNamespaceResponse, error)
// AddOrUpdateRemoteCluster adds or updates remote cluster.
AddOrUpdateRemoteCluster(context.Context, *v1.AddOrUpdateRemoteClusterRequest) (*v1.AddOrUpdateRemoteClusterResponse, error)
// RemoveRemoteCluster removes remote cluster.
RemoveRemoteCluster(context.Context, *v1.RemoveRemoteClusterRequest) (*v1.RemoveRemoteClusterResponse, error)
// ListClusters returns information about Temporal clusters.
ListClusters(context.Context, *v1.ListClustersRequest) (*v1.ListClustersResponse, error)
}
OperatorServiceServer is the server API for OperatorService service. All implementations should embed UnimplementedOperatorServiceServer for forward compatibility
type UnimplementedOperatorServiceServer ¶
type UnimplementedOperatorServiceServer struct {
}
UnimplementedOperatorServiceServer should be embedded to have forward compatible implementations.
func (UnimplementedOperatorServiceServer) AddOrUpdateRemoteCluster ¶
func (UnimplementedOperatorServiceServer) AddOrUpdateRemoteCluster(context.Context, *v1.AddOrUpdateRemoteClusterRequest) (*v1.AddOrUpdateRemoteClusterResponse, error)
func (UnimplementedOperatorServiceServer) AddSearchAttributes ¶
func (UnimplementedOperatorServiceServer) AddSearchAttributes(context.Context, *v1.AddSearchAttributesRequest) (*v1.AddSearchAttributesResponse, error)
func (UnimplementedOperatorServiceServer) DeleteNamespace ¶
func (UnimplementedOperatorServiceServer) DeleteNamespace(context.Context, *v1.DeleteNamespaceRequest) (*v1.DeleteNamespaceResponse, error)
func (UnimplementedOperatorServiceServer) ListClusters ¶
func (UnimplementedOperatorServiceServer) ListClusters(context.Context, *v1.ListClustersRequest) (*v1.ListClustersResponse, error)
func (UnimplementedOperatorServiceServer) ListSearchAttributes ¶
func (UnimplementedOperatorServiceServer) ListSearchAttributes(context.Context, *v1.ListSearchAttributesRequest) (*v1.ListSearchAttributesResponse, error)
func (UnimplementedOperatorServiceServer) RemoveRemoteCluster ¶
func (UnimplementedOperatorServiceServer) RemoveRemoteCluster(context.Context, *v1.RemoveRemoteClusterRequest) (*v1.RemoveRemoteClusterResponse, error)
func (UnimplementedOperatorServiceServer) RemoveSearchAttributes ¶
func (UnimplementedOperatorServiceServer) RemoveSearchAttributes(context.Context, *v1.RemoveSearchAttributesRequest) (*v1.RemoveSearchAttributesResponse, error)
type UnsafeOperatorServiceServer ¶
type UnsafeOperatorServiceServer interface {
// contains filtered or unexported methods
}
UnsafeOperatorServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to OperatorServiceServer will result in compilation errors.
Source Files
¶
- service_grpc.pb.go