Documentation
¶
Index ¶
- Variables
- type Filter
- func (x *Filter) GetField() string
- func (x *Filter) GetFunction() Filter_Function
- func (x *Filter) GetValues() []string
- func (*Filter) ProtoMessage()
- func (x *Filter) ProtoReflect() protoreflect.Message
- func (x *Filter) Reset()
- func (x *Filter) SetField(v string)
- func (x *Filter) SetFunction(v Filter_Function)
- func (x *Filter) SetValues(v []string)
- func (x *Filter) String() string
- type Filter_Function
- type Filter_builder
- type ListRequest
- func (x *ListRequest) ClearSortBy()
- func (x *ListRequest) GetFilters() []*Filter
- func (x *ListRequest) GetLimit() uint32
- func (x *ListRequest) GetRawFilters() []string
- func (x *ListRequest) GetSortBy() *Sort
- func (x *ListRequest) GetToken() string
- func (x *ListRequest) HasSortBy() bool
- func (*ListRequest) ProtoMessage()
- func (x *ListRequest) ProtoReflect() protoreflect.Message
- func (x *ListRequest) Reset()
- func (x *ListRequest) SetFilters(v []*Filter)
- func (x *ListRequest) SetLimit(v uint32)
- func (x *ListRequest) SetRawFilters(v []string)
- func (x *ListRequest) SetSortBy(v *Sort)
- func (x *ListRequest) SetToken(v string)
- func (x *ListRequest) String() string
- type ListRequest_builder
- type Sort
- type Sort_Direction
- type Sort_builder
Constants ¶
This section is empty.
Variables ¶
var ( Sort_Direction_name = map[int32]string{ 0: "DESCENDING", 1: "ASCENDING", } Sort_Direction_value = map[string]int32{ "DESCENDING": 0, "ASCENDING": 1, } )
Enum value maps for Sort_Direction.
var ( Filter_Function_name = map[int32]string{ 0: "EQUAL", 1: "NOT_EQUAL", 2: "GREATER_THAN", 3: "GREATER_THAN_OR_EQUAL", 4: "LESS_THAN", 5: "LESS_THAN_OR_EQUAL", 6: "CONTAINS", 7: "VALUE_IN", } Filter_Function_value = map[string]int32{ "EQUAL": 0, "NOT_EQUAL": 1, "GREATER_THAN": 2, "GREATER_THAN_OR_EQUAL": 3, "LESS_THAN": 4, "LESS_THAN_OR_EQUAL": 5, "CONTAINS": 6, "VALUE_IN": 7, } )
Enum value maps for Filter_Function.
var File_common_list_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Filter ¶
type Filter struct {
Function Filter_Function `protobuf:"varint,1,opt,name=function,proto3,enum=cloudidl.common.Filter_Function" json:"function,omitempty"`
// e.g. name or version
Field string `protobuf:"bytes,2,opt,name=field,proto3" json:"field,omitempty"`
// Only in the case of a VALUE_IN function, values may contain multiple entries.
Values []string `protobuf:"bytes,3,rep,name=values,proto3" json:"values,omitempty"`
// contains filtered or unexported fields
}
func (*Filter) GetFunction ¶
func (x *Filter) GetFunction() Filter_Function
func (*Filter) ProtoReflect ¶
func (x *Filter) ProtoReflect() protoreflect.Message
func (*Filter) SetFunction ¶
func (x *Filter) SetFunction(v Filter_Function)
type Filter_Function ¶
type Filter_Function int32
const ( Filter_EQUAL Filter_Function = 0 Filter_NOT_EQUAL Filter_Function = 1 Filter_GREATER_THAN Filter_Function = 2 Filter_GREATER_THAN_OR_EQUAL Filter_Function = 3 Filter_LESS_THAN Filter_Function = 4 Filter_LESS_THAN_OR_EQUAL Filter_Function = 5 Filter_CONTAINS Filter_Function = 6 Filter_VALUE_IN Filter_Function = 7 )
func (Filter_Function) Descriptor ¶
func (Filter_Function) Descriptor() protoreflect.EnumDescriptor
func (Filter_Function) Enum ¶
func (x Filter_Function) Enum() *Filter_Function
func (Filter_Function) Number ¶
func (x Filter_Function) Number() protoreflect.EnumNumber
func (Filter_Function) String ¶
func (x Filter_Function) String() string
func (Filter_Function) Type ¶
func (Filter_Function) Type() protoreflect.EnumType
type Filter_builder ¶
type Filter_builder struct {
Function Filter_Function
// e.g. name or version
Field string
// Only in the case of a VALUE_IN function, values may contain multiple entries.
Values []string
// contains filtered or unexported fields
}
func (Filter_builder) Build ¶
func (b0 Filter_builder) Build() *Filter
type ListRequest ¶
type ListRequest struct {
// Indicates the number of resources to be returned.
// +required
Limit uint32 `protobuf:"varint,1,opt,name=limit,proto3" json:"limit,omitempty"`
// In the case of multiple pages of results, the server-provided token can be used to fetch the next page
// in a query.
// +optional
Token string `protobuf:"bytes,2,opt,name=token,proto3" json:"token,omitempty"`
// Specifies how listed entities should be sorted in the response.
// +optional
SortBy *Sort `protobuf:"bytes,3,opt,name=sort_by,json=sortBy,proto3" json:"sort_by,omitempty"`
// Indicates a list of filters. This field is used for grpc get requests.
// +optional
Filters []*Filter `protobuf:"bytes,4,rep,name=filters,proto3" json:"filters,omitempty"`
// Indicates a raw list of filters passed as string.This field is used for REST get requests
// +optional
RawFilters []string `protobuf:"bytes,5,rep,name=raw_filters,json=rawFilters,proto3" json:"raw_filters,omitempty"`
// contains filtered or unexported fields
}
func (*ListRequest) ClearSortBy ¶
func (x *ListRequest) ClearSortBy()
func (*ListRequest) GetFilters ¶
func (x *ListRequest) GetFilters() []*Filter
func (*ListRequest) GetLimit ¶
func (x *ListRequest) GetLimit() uint32
func (*ListRequest) GetRawFilters ¶
func (x *ListRequest) GetRawFilters() []string
func (*ListRequest) GetSortBy ¶
func (x *ListRequest) GetSortBy() *Sort
func (*ListRequest) GetToken ¶
func (x *ListRequest) GetToken() string
func (*ListRequest) HasSortBy ¶
func (x *ListRequest) HasSortBy() bool
func (*ListRequest) ProtoMessage ¶
func (*ListRequest) ProtoMessage()
func (*ListRequest) ProtoReflect ¶
func (x *ListRequest) ProtoReflect() protoreflect.Message
func (*ListRequest) Reset ¶
func (x *ListRequest) Reset()
func (*ListRequest) SetFilters ¶
func (x *ListRequest) SetFilters(v []*Filter)
func (*ListRequest) SetLimit ¶
func (x *ListRequest) SetLimit(v uint32)
func (*ListRequest) SetRawFilters ¶
func (x *ListRequest) SetRawFilters(v []string)
func (*ListRequest) SetSortBy ¶
func (x *ListRequest) SetSortBy(v *Sort)
func (*ListRequest) SetToken ¶
func (x *ListRequest) SetToken(v string)
func (*ListRequest) String ¶
func (x *ListRequest) String() string
type ListRequest_builder ¶
type ListRequest_builder struct {
// Indicates the number of resources to be returned.
// +required
Limit uint32
// In the case of multiple pages of results, the server-provided token can be used to fetch the next page
// in a query.
// +optional
Token string
// Specifies how listed entities should be sorted in the response.
// +optional
SortBy *Sort
// Indicates a list of filters. This field is used for grpc get requests.
// +optional
Filters []*Filter
// Indicates a raw list of filters passed as string.This field is used for REST get requests
// +optional
RawFilters []string
// contains filtered or unexported fields
}
func (ListRequest_builder) Build ¶
func (b0 ListRequest_builder) Build() *ListRequest
type Sort ¶
type Sort struct {
// Indicates an attribute to sort the response values.
// +required
Key string `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
// Indicates the direction to apply sort key for response values.
// +optional
Direction Sort_Direction `protobuf:"varint,2,opt,name=direction,proto3,enum=cloudidl.common.Sort_Direction" json:"direction,omitempty"`
// contains filtered or unexported fields
}
Specifies sort ordering in a list request.
func (*Sort) GetDirection ¶
func (x *Sort) GetDirection() Sort_Direction
func (*Sort) ProtoReflect ¶
func (x *Sort) ProtoReflect() protoreflect.Message
func (*Sort) SetDirection ¶
func (x *Sort) SetDirection(v Sort_Direction)
type Sort_Direction ¶
type Sort_Direction int32
const ( // By default, fields are sorted in descending order. Sort_DESCENDING Sort_Direction = 0 Sort_ASCENDING Sort_Direction = 1 )
func (Sort_Direction) Descriptor ¶
func (Sort_Direction) Descriptor() protoreflect.EnumDescriptor
func (Sort_Direction) Enum ¶
func (x Sort_Direction) Enum() *Sort_Direction
func (Sort_Direction) Number ¶
func (x Sort_Direction) Number() protoreflect.EnumNumber
func (Sort_Direction) String ¶
func (x Sort_Direction) String() string
func (Sort_Direction) Type ¶
func (Sort_Direction) Type() protoreflect.EnumType
type Sort_builder ¶
type Sort_builder struct {
// Indicates an attribute to sort the response values.
// +required
Key string
// Indicates the direction to apply sort key for response values.
// +optional
Direction Sort_Direction
// contains filtered or unexported fields
}
func (Sort_builder) Build ¶
func (b0 Sort_builder) Build() *Sort
Source Files
¶
- list.pb.go
Click to show internal directories.
Click to hide internal directories.