objectstorev1

package
v1.36.10-2023062222351... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 8 Imported by: 1

Documentation

Index

Constants

const TerminateLargeObjectUploadRequest_AbortUpload_case case_TerminateLargeObjectUploadRequest_Request = 4
const TerminateLargeObjectUploadRequest_Request_not_set_case case_TerminateLargeObjectUploadRequest_Request = 0
const TerminateLargeObjectUploadRequest_SuccessfulUpload_case case_TerminateLargeObjectUploadRequest_Request = 3

Variables

var File_objectstore_payload_proto protoreflect.FileDescriptor
var File_objectstore_service_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type AbortUploadRequest

type AbortUploadRequest struct {
	// contains filtered or unexported fields
}

func (*AbortUploadRequest) ProtoMessage

func (*AbortUploadRequest) ProtoMessage()

func (*AbortUploadRequest) ProtoReflect

func (x *AbortUploadRequest) ProtoReflect() protoreflect.Message

func (*AbortUploadRequest) Reset

func (x *AbortUploadRequest) Reset()

func (*AbortUploadRequest) String

func (x *AbortUploadRequest) String() string

type AbortUploadRequest_builder

type AbortUploadRequest_builder struct {
	// contains filtered or unexported fields
}

func (AbortUploadRequest_builder) Build

type CreateLargeObjectDownloadLinkRequest

type CreateLargeObjectDownloadLinkRequest struct {

	// key is the globally unique identifier for the object. union://
	Key string `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
	// ExpiresIn defines a requested expiration duration for the generated url. The request will be rejected if this
	// exceeds the platform allowed max.
	// +optional. The default value comes from a global config.
	ExpiresIn *durationpb.Duration `protobuf:"bytes,2,opt,name=expires_in,json=expiresIn,proto3" json:"expires_in,omitempty"`
	// contains filtered or unexported fields
}

func (*CreateLargeObjectDownloadLinkRequest) ClearExpiresIn

func (x *CreateLargeObjectDownloadLinkRequest) ClearExpiresIn()

func (*CreateLargeObjectDownloadLinkRequest) GetExpiresIn

func (*CreateLargeObjectDownloadLinkRequest) GetKey

func (*CreateLargeObjectDownloadLinkRequest) HasExpiresIn

func (x *CreateLargeObjectDownloadLinkRequest) HasExpiresIn() bool

func (*CreateLargeObjectDownloadLinkRequest) ProtoMessage

func (*CreateLargeObjectDownloadLinkRequest) ProtoMessage()

func (*CreateLargeObjectDownloadLinkRequest) ProtoReflect

func (*CreateLargeObjectDownloadLinkRequest) Reset

func (*CreateLargeObjectDownloadLinkRequest) SetExpiresIn

func (*CreateLargeObjectDownloadLinkRequest) SetKey

func (*CreateLargeObjectDownloadLinkRequest) String

type CreateLargeObjectDownloadLinkRequest_builder

type CreateLargeObjectDownloadLinkRequest_builder struct {

	// key is the globally unique identifier for the object. union://
	Key string
	// ExpiresIn defines a requested expiration duration for the generated url. The request will be rejected if this
	// exceeds the platform allowed max.
	// +optional. The default value comes from a global config.
	ExpiresIn *durationpb.Duration
	// contains filtered or unexported fields
}

func (CreateLargeObjectDownloadLinkRequest_builder) Build

type CreateLargeObjectDownloadLinkResponse

type CreateLargeObjectDownloadLinkResponse struct {

	// SignedUrl specifies the url to use to download content from (e.g. https://my-bucket.s3.amazonaws.com/randomstring/suffix.tar?X-...)
	SignedUrl string `protobuf:"bytes,1,opt,name=signed_url,json=signedUrl,proto3" json:"signed_url,omitempty"`
	// ExpiresAt defines when will the signed URL expires.
	ExpiresAt *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=expires_at,json=expiresAt,proto3" json:"expires_at,omitempty"`
	// contains filtered or unexported fields
}

func (*CreateLargeObjectDownloadLinkResponse) ClearExpiresAt

func (x *CreateLargeObjectDownloadLinkResponse) ClearExpiresAt()

func (*CreateLargeObjectDownloadLinkResponse) GetExpiresAt

func (*CreateLargeObjectDownloadLinkResponse) GetSignedUrl

func (*CreateLargeObjectDownloadLinkResponse) HasExpiresAt

func (x *CreateLargeObjectDownloadLinkResponse) HasExpiresAt() bool

func (*CreateLargeObjectDownloadLinkResponse) ProtoMessage

func (*CreateLargeObjectDownloadLinkResponse) ProtoMessage()

func (*CreateLargeObjectDownloadLinkResponse) ProtoReflect

func (*CreateLargeObjectDownloadLinkResponse) Reset

func (*CreateLargeObjectDownloadLinkResponse) SetExpiresAt

func (*CreateLargeObjectDownloadLinkResponse) SetSignedUrl

func (x *CreateLargeObjectDownloadLinkResponse) SetSignedUrl(v string)

func (*CreateLargeObjectDownloadLinkResponse) String

type CreateLargeObjectDownloadLinkResponse_builder

type CreateLargeObjectDownloadLinkResponse_builder struct {

	// SignedUrl specifies the url to use to download content from (e.g. https://my-bucket.s3.amazonaws.com/randomstring/suffix.tar?X-...)
	SignedUrl string
	// ExpiresAt defines when will the signed URL expires.
	ExpiresAt *timestamppb.Timestamp
	// contains filtered or unexported fields
}

func (CreateLargeObjectDownloadLinkResponse_builder) Build

type CreateLargeObjectUploadLocationRequest

type CreateLargeObjectUploadLocationRequest struct {
	Key       string `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
	SizeBytes uint64 `protobuf:"varint,2,opt,name=size_bytes,json=sizeBytes,proto3" json:"size_bytes,omitempty"`
	// ExpiresIn defines a requested expiration duration for the generated url. The request will be rejected if this
	// exceeds the platform allowed max.
	// +optional. The default value comes from a global config.
	ExpiresIn *durationpb.Duration `protobuf:"bytes,3,opt,name=expires_in,json=expiresIn,proto3" json:"expires_in,omitempty"`
	// contains filtered or unexported fields
}

func (*CreateLargeObjectUploadLocationRequest) ClearExpiresIn

func (x *CreateLargeObjectUploadLocationRequest) ClearExpiresIn()

func (*CreateLargeObjectUploadLocationRequest) GetExpiresIn

func (*CreateLargeObjectUploadLocationRequest) GetKey

func (*CreateLargeObjectUploadLocationRequest) GetSizeBytes

func (*CreateLargeObjectUploadLocationRequest) HasExpiresIn

func (x *CreateLargeObjectUploadLocationRequest) HasExpiresIn() bool

func (*CreateLargeObjectUploadLocationRequest) ProtoMessage

func (*CreateLargeObjectUploadLocationRequest) ProtoReflect

func (*CreateLargeObjectUploadLocationRequest) Reset

func (*CreateLargeObjectUploadLocationRequest) SetExpiresIn

func (*CreateLargeObjectUploadLocationRequest) SetKey

func (*CreateLargeObjectUploadLocationRequest) SetSizeBytes

func (*CreateLargeObjectUploadLocationRequest) String

type CreateLargeObjectUploadLocationRequest_builder

type CreateLargeObjectUploadLocationRequest_builder struct {
	Key       string
	SizeBytes uint64
	// ExpiresIn defines a requested expiration duration for the generated url. The request will be rejected if this
	// exceeds the platform allowed max.
	// +optional. The default value comes from a global config.
	ExpiresIn *durationpb.Duration
	// contains filtered or unexported fields
}

func (CreateLargeObjectUploadLocationRequest_builder) Build

type CreateLargeObjectUploadLocationResponse

type CreateLargeObjectUploadLocationResponse struct {
	OperationId string `protobuf:"bytes,1,opt,name=operation_id,json=operationId,proto3" json:"operation_id,omitempty"`
	// SignedPartRequest specifies the url to use to upload content to (
	// e.g. https://my-bucket.s3.amazonaws.com/randomstring/suffix.tar?X-...)
	SignedPartRequests []*SignedPartRequest `protobuf:"bytes,2,rep,name=signed_part_requests,json=signedPartRequests,proto3" json:"signed_part_requests,omitempty"`
	// NativeUrl specifies the url in the format of (e.g. union://<key>)
	NativeUrl string `protobuf:"bytes,3,opt,name=native_url,json=nativeUrl,proto3" json:"native_url,omitempty"`
	// contains filtered or unexported fields
}

func (*CreateLargeObjectUploadLocationResponse) GetNativeUrl

func (*CreateLargeObjectUploadLocationResponse) GetOperationId

func (x *CreateLargeObjectUploadLocationResponse) GetOperationId() string

func (*CreateLargeObjectUploadLocationResponse) GetSignedPartRequests

func (x *CreateLargeObjectUploadLocationResponse) GetSignedPartRequests() []*SignedPartRequest

func (*CreateLargeObjectUploadLocationResponse) ProtoMessage

func (*CreateLargeObjectUploadLocationResponse) ProtoReflect

func (*CreateLargeObjectUploadLocationResponse) Reset

func (*CreateLargeObjectUploadLocationResponse) SetNativeUrl

func (*CreateLargeObjectUploadLocationResponse) SetOperationId

func (x *CreateLargeObjectUploadLocationResponse) SetOperationId(v string)

func (*CreateLargeObjectUploadLocationResponse) SetSignedPartRequests

func (x *CreateLargeObjectUploadLocationResponse) SetSignedPartRequests(v []*SignedPartRequest)

func (*CreateLargeObjectUploadLocationResponse) String

type CreateLargeObjectUploadLocationResponse_builder

type CreateLargeObjectUploadLocationResponse_builder struct {
	OperationId string
	// SignedPartRequest specifies the url to use to upload content to (
	// e.g. https://my-bucket.s3.amazonaws.com/randomstring/suffix.tar?X-...)
	SignedPartRequests []*SignedPartRequest
	// NativeUrl specifies the url in the format of (e.g. union://<key>)
	NativeUrl string
	// contains filtered or unexported fields
}

func (CreateLargeObjectUploadLocationResponse_builder) Build

type DeleteRequest

type DeleteRequest struct {
	Key string `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
	// contains filtered or unexported fields
}

func (*DeleteRequest) GetKey

func (x *DeleteRequest) GetKey() string

func (*DeleteRequest) ProtoMessage

func (*DeleteRequest) ProtoMessage()

func (*DeleteRequest) ProtoReflect

func (x *DeleteRequest) ProtoReflect() protoreflect.Message

func (*DeleteRequest) Reset

func (x *DeleteRequest) Reset()

func (*DeleteRequest) SetKey

func (x *DeleteRequest) SetKey(v string)

func (*DeleteRequest) String

func (x *DeleteRequest) String() string

type DeleteRequest_builder

type DeleteRequest_builder struct {
	Key string
	// contains filtered or unexported fields
}

func (DeleteRequest_builder) Build

type DeleteResponse

type DeleteResponse struct {
	// contains filtered or unexported fields
}

func (*DeleteResponse) ProtoMessage

func (*DeleteResponse) ProtoMessage()

func (*DeleteResponse) ProtoReflect

func (x *DeleteResponse) ProtoReflect() protoreflect.Message

func (*DeleteResponse) Reset

func (x *DeleteResponse) Reset()

func (*DeleteResponse) String

func (x *DeleteResponse) String() string

type DeleteResponse_builder

type DeleteResponse_builder struct {
	// contains filtered or unexported fields
}

func (DeleteResponse_builder) Build

type DownloadPartRequest

type DownloadPartRequest struct {

	// key is the globally unique identifier for the object. union://
	Key string `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
	// StartPos is the start position of the object to be downloaded.
	StartPos int64 `protobuf:"varint,2,opt,name=start_pos,json=startPos,proto3" json:"start_pos,omitempty"`
	// SizeBytes is the length of the object to be downloaded.
	SizeBytes int64 `protobuf:"varint,3,opt,name=size_bytes,json=sizeBytes,proto3" json:"size_bytes,omitempty"`
	// contains filtered or unexported fields
}

func (*DownloadPartRequest) GetKey

func (x *DownloadPartRequest) GetKey() string

func (*DownloadPartRequest) GetSizeBytes

func (x *DownloadPartRequest) GetSizeBytes() int64

func (*DownloadPartRequest) GetStartPos

func (x *DownloadPartRequest) GetStartPos() int64

func (*DownloadPartRequest) ProtoMessage

func (*DownloadPartRequest) ProtoMessage()

func (*DownloadPartRequest) ProtoReflect

func (x *DownloadPartRequest) ProtoReflect() protoreflect.Message

func (*DownloadPartRequest) Reset

func (x *DownloadPartRequest) Reset()

func (*DownloadPartRequest) SetKey

func (x *DownloadPartRequest) SetKey(v string)

func (*DownloadPartRequest) SetSizeBytes

func (x *DownloadPartRequest) SetSizeBytes(v int64)

func (*DownloadPartRequest) SetStartPos

func (x *DownloadPartRequest) SetStartPos(v int64)

func (*DownloadPartRequest) String

func (x *DownloadPartRequest) String() string

type DownloadPartRequest_builder

type DownloadPartRequest_builder struct {

	// key is the globally unique identifier for the object. union://
	Key string
	// StartPos is the start position of the object to be downloaded.
	StartPos int64
	// SizeBytes is the length of the object to be downloaded.
	SizeBytes int64
	// contains filtered or unexported fields
}

func (DownloadPartRequest_builder) Build

type DownloadPartResponse

type DownloadPartResponse struct {

	// object contains the actual bytes to be stored.
	Object *Object `protobuf:"bytes,1,opt,name=object,proto3" json:"object,omitempty"`
	// contains filtered or unexported fields
}

func (*DownloadPartResponse) ClearObject

func (x *DownloadPartResponse) ClearObject()

func (*DownloadPartResponse) GetObject

func (x *DownloadPartResponse) GetObject() *Object

func (*DownloadPartResponse) HasObject

func (x *DownloadPartResponse) HasObject() bool

func (*DownloadPartResponse) ProtoMessage

func (*DownloadPartResponse) ProtoMessage()

func (*DownloadPartResponse) ProtoReflect

func (x *DownloadPartResponse) ProtoReflect() protoreflect.Message

func (*DownloadPartResponse) Reset

func (x *DownloadPartResponse) Reset()

func (*DownloadPartResponse) SetObject

func (x *DownloadPartResponse) SetObject(v *Object)

func (*DownloadPartResponse) String

func (x *DownloadPartResponse) String() string

type DownloadPartResponse_builder

type DownloadPartResponse_builder struct {

	// object contains the actual bytes to be stored.
	Object *Object
	// contains filtered or unexported fields
}

func (DownloadPartResponse_builder) Build

type GetRequest

type GetRequest struct {
	Key string `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
	// contains filtered or unexported fields
}

func (*GetRequest) GetKey

func (x *GetRequest) GetKey() string

func (*GetRequest) ProtoMessage

func (*GetRequest) ProtoMessage()

func (*GetRequest) ProtoReflect

func (x *GetRequest) ProtoReflect() protoreflect.Message

func (*GetRequest) Reset

func (x *GetRequest) Reset()

func (*GetRequest) SetKey

func (x *GetRequest) SetKey(v string)

func (*GetRequest) String

func (x *GetRequest) String() string

type GetRequest_builder

type GetRequest_builder struct {
	Key string
	// contains filtered or unexported fields
}

func (GetRequest_builder) Build

func (b0 GetRequest_builder) Build() *GetRequest

type GetResponse

type GetResponse struct {
	Object    *Object   `protobuf:"bytes,1,opt,name=object,proto3" json:"object,omitempty"`
	Metadata  *Metadata `protobuf:"bytes,2,opt,name=metadata,proto3" json:"metadata,omitempty"`
	SizeBytes uint64    `protobuf:"varint,3,opt,name=size_bytes,json=sizeBytes,proto3" json:"size_bytes,omitempty"`
	Etag      string    `protobuf:"bytes,4,opt,name=etag,proto3" json:"etag,omitempty"`
	// contains filtered or unexported fields
}

func (*GetResponse) ClearMetadata

func (x *GetResponse) ClearMetadata()

func (*GetResponse) ClearObject

func (x *GetResponse) ClearObject()

func (*GetResponse) GetEtag

func (x *GetResponse) GetEtag() string

func (*GetResponse) GetMetadata

func (x *GetResponse) GetMetadata() *Metadata

func (*GetResponse) GetObject

func (x *GetResponse) GetObject() *Object

func (*GetResponse) GetSizeBytes

func (x *GetResponse) GetSizeBytes() uint64

func (*GetResponse) HasMetadata

func (x *GetResponse) HasMetadata() bool

func (*GetResponse) HasObject

func (x *GetResponse) HasObject() bool

func (*GetResponse) ProtoMessage

func (*GetResponse) ProtoMessage()

func (*GetResponse) ProtoReflect

func (x *GetResponse) ProtoReflect() protoreflect.Message

func (*GetResponse) Reset

func (x *GetResponse) Reset()

func (*GetResponse) SetEtag

func (x *GetResponse) SetEtag(v string)

func (*GetResponse) SetMetadata

func (x *GetResponse) SetMetadata(v *Metadata)

func (*GetResponse) SetObject

func (x *GetResponse) SetObject(v *Object)

func (*GetResponse) SetSizeBytes

func (x *GetResponse) SetSizeBytes(v uint64)

func (*GetResponse) String

func (x *GetResponse) String() string

type GetResponse_builder

type GetResponse_builder struct {
	Object    *Object
	Metadata  *Metadata
	SizeBytes uint64
	Etag      string
	// contains filtered or unexported fields
}

func (GetResponse_builder) Build

func (b0 GetResponse_builder) Build() *GetResponse

type HeadRequest

type HeadRequest struct {
	Key string `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
	// contains filtered or unexported fields
}

func (*HeadRequest) GetKey

func (x *HeadRequest) GetKey() string

func (*HeadRequest) ProtoMessage

func (*HeadRequest) ProtoMessage()

func (*HeadRequest) ProtoReflect

func (x *HeadRequest) ProtoReflect() protoreflect.Message

func (*HeadRequest) Reset

func (x *HeadRequest) Reset()

func (*HeadRequest) SetKey

func (x *HeadRequest) SetKey(v string)

func (*HeadRequest) String

func (x *HeadRequest) String() string

type HeadRequest_builder

type HeadRequest_builder struct {
	Key string
	// contains filtered or unexported fields
}

func (HeadRequest_builder) Build

func (b0 HeadRequest_builder) Build() *HeadRequest

type HeadResponse

type HeadResponse struct {
	Metadata  *Metadata `protobuf:"bytes,1,opt,name=metadata,proto3" json:"metadata,omitempty"`
	Etag      string    `protobuf:"bytes,2,opt,name=etag,proto3" json:"etag,omitempty"`
	SizeBytes uint64    `protobuf:"varint,3,opt,name=size_bytes,json=sizeBytes,proto3" json:"size_bytes,omitempty"`
	// contains filtered or unexported fields
}

func (*HeadResponse) ClearMetadata

func (x *HeadResponse) ClearMetadata()

func (*HeadResponse) GetEtag

func (x *HeadResponse) GetEtag() string

func (*HeadResponse) GetMetadata

func (x *HeadResponse) GetMetadata() *Metadata

func (*HeadResponse) GetSizeBytes

func (x *HeadResponse) GetSizeBytes() uint64

func (*HeadResponse) HasMetadata

func (x *HeadResponse) HasMetadata() bool

func (*HeadResponse) ProtoMessage

func (*HeadResponse) ProtoMessage()

func (*HeadResponse) ProtoReflect

func (x *HeadResponse) ProtoReflect() protoreflect.Message

func (*HeadResponse) Reset

func (x *HeadResponse) Reset()

func (*HeadResponse) SetEtag

func (x *HeadResponse) SetEtag(v string)

func (*HeadResponse) SetMetadata

func (x *HeadResponse) SetMetadata(v *Metadata)

func (*HeadResponse) SetSizeBytes

func (x *HeadResponse) SetSizeBytes(v uint64)

func (*HeadResponse) String

func (x *HeadResponse) String() string

type HeadResponse_builder

type HeadResponse_builder struct {
	Metadata  *Metadata
	Etag      string
	SizeBytes uint64
	// contains filtered or unexported fields
}

func (HeadResponse_builder) Build

func (b0 HeadResponse_builder) Build() *HeadResponse

type HttpHeaderValues

type HttpHeaderValues struct {
	Values []string `protobuf:"bytes,1,rep,name=values,proto3" json:"values,omitempty"`
	// contains filtered or unexported fields
}

func (*HttpHeaderValues) GetValues

func (x *HttpHeaderValues) GetValues() []string

func (*HttpHeaderValues) ProtoMessage

func (*HttpHeaderValues) ProtoMessage()

func (*HttpHeaderValues) ProtoReflect

func (x *HttpHeaderValues) ProtoReflect() protoreflect.Message

func (*HttpHeaderValues) Reset

func (x *HttpHeaderValues) Reset()

func (*HttpHeaderValues) SetValues

func (x *HttpHeaderValues) SetValues(v []string)

func (*HttpHeaderValues) String

func (x *HttpHeaderValues) String() string

type HttpHeaderValues_builder

type HttpHeaderValues_builder struct {
	Values []string
	// contains filtered or unexported fields
}

func (HttpHeaderValues_builder) Build

type LargeObjectUpload

type LargeObjectUpload struct {
	OperationId string `protobuf:"bytes,1,opt,name=operation_id,json=operationId,proto3" json:"operation_id,omitempty"`
	Key         string `protobuf:"bytes,2,opt,name=key,proto3" json:"key,omitempty"`
	// contains filtered or unexported fields
}

func (*LargeObjectUpload) GetKey

func (x *LargeObjectUpload) GetKey() string

func (*LargeObjectUpload) GetOperationId

func (x *LargeObjectUpload) GetOperationId() string

func (*LargeObjectUpload) ProtoMessage

func (*LargeObjectUpload) ProtoMessage()

func (*LargeObjectUpload) ProtoReflect

func (x *LargeObjectUpload) ProtoReflect() protoreflect.Message

func (*LargeObjectUpload) Reset

func (x *LargeObjectUpload) Reset()

func (*LargeObjectUpload) SetKey

func (x *LargeObjectUpload) SetKey(v string)

func (*LargeObjectUpload) SetOperationId

func (x *LargeObjectUpload) SetOperationId(v string)

func (*LargeObjectUpload) String

func (x *LargeObjectUpload) String() string

type LargeObjectUpload_builder

type LargeObjectUpload_builder struct {
	OperationId string
	Key         string
	// contains filtered or unexported fields
}

func (LargeObjectUpload_builder) Build

type ListInProgressLargeObjectUploadsRequest

type ListInProgressLargeObjectUploadsRequest struct {
	Request *common.ListRequest `protobuf:"bytes,1,opt,name=request,proto3" json:"request,omitempty"`
	// contains filtered or unexported fields
}

func (*ListInProgressLargeObjectUploadsRequest) ClearRequest

func (x *ListInProgressLargeObjectUploadsRequest) ClearRequest()

func (*ListInProgressLargeObjectUploadsRequest) GetRequest

func (*ListInProgressLargeObjectUploadsRequest) HasRequest

func (*ListInProgressLargeObjectUploadsRequest) ProtoMessage

func (*ListInProgressLargeObjectUploadsRequest) ProtoReflect

func (*ListInProgressLargeObjectUploadsRequest) Reset

func (*ListInProgressLargeObjectUploadsRequest) SetRequest

func (*ListInProgressLargeObjectUploadsRequest) String

type ListInProgressLargeObjectUploadsRequest_builder

type ListInProgressLargeObjectUploadsRequest_builder struct {
	Request *common.ListRequest
	// contains filtered or unexported fields
}

func (ListInProgressLargeObjectUploadsRequest_builder) Build

type ListInProgressLargeObjectUploadsResponse

type ListInProgressLargeObjectUploadsResponse struct {
	Operations []*LargeObjectUpload `protobuf:"bytes,1,rep,name=operations,proto3" json:"operations,omitempty"`
	// contains filtered or unexported fields
}

func (*ListInProgressLargeObjectUploadsResponse) GetOperations

func (*ListInProgressLargeObjectUploadsResponse) ProtoMessage

func (*ListInProgressLargeObjectUploadsResponse) ProtoReflect

func (*ListInProgressLargeObjectUploadsResponse) Reset

func (*ListInProgressLargeObjectUploadsResponse) SetOperations

func (*ListInProgressLargeObjectUploadsResponse) String

type ListInProgressLargeObjectUploadsResponse_builder

type ListInProgressLargeObjectUploadsResponse_builder struct {
	Operations []*LargeObjectUpload
	// contains filtered or unexported fields
}

func (ListInProgressLargeObjectUploadsResponse_builder) Build

type ListRequest

type ListRequest struct {
	Request *common.ListRequest `protobuf:"bytes,1,opt,name=request,proto3" json:"request,omitempty"`
	// contains filtered or unexported fields
}

func (*ListRequest) ClearRequest

func (x *ListRequest) ClearRequest()

func (*ListRequest) GetRequest

func (x *ListRequest) GetRequest() *common.ListRequest

func (*ListRequest) HasRequest

func (x *ListRequest) HasRequest() bool

func (*ListRequest) ProtoMessage

func (*ListRequest) ProtoMessage()

func (*ListRequest) ProtoReflect

func (x *ListRequest) ProtoReflect() protoreflect.Message

func (*ListRequest) Reset

func (x *ListRequest) Reset()

func (*ListRequest) SetRequest

func (x *ListRequest) SetRequest(v *common.ListRequest)

func (*ListRequest) String

func (x *ListRequest) String() string

type ListRequest_builder

type ListRequest_builder struct {
	Request *common.ListRequest
	// contains filtered or unexported fields
}

func (ListRequest_builder) Build

func (b0 ListRequest_builder) Build() *ListRequest

type ListResponse

type ListResponse struct {
	Keys []string `protobuf:"bytes,1,rep,name=keys,proto3" json:"keys,omitempty"`
	// contains filtered or unexported fields
}

func (*ListResponse) GetKeys

func (x *ListResponse) GetKeys() []string

func (*ListResponse) ProtoMessage

func (*ListResponse) ProtoMessage()

func (*ListResponse) ProtoReflect

func (x *ListResponse) ProtoReflect() protoreflect.Message

func (*ListResponse) Reset

func (x *ListResponse) Reset()

func (*ListResponse) SetKeys

func (x *ListResponse) SetKeys(v []string)

func (*ListResponse) String

func (x *ListResponse) String() string

type ListResponse_builder

type ListResponse_builder struct {
	Keys []string
	// contains filtered or unexported fields
}

func (ListResponse_builder) Build

func (b0 ListResponse_builder) Build() *ListResponse

type Metadata

type Metadata struct {

	// tag is a free form string that can be associated with an object.
	Tag map[string]string `` /* 133-byte string literal not displayed */
	// contains filtered or unexported fields
}

Metadata about the objects

func (*Metadata) GetTag

func (x *Metadata) GetTag() map[string]string

func (*Metadata) ProtoMessage

func (*Metadata) ProtoMessage()

func (*Metadata) ProtoReflect

func (x *Metadata) ProtoReflect() protoreflect.Message

func (*Metadata) Reset

func (x *Metadata) Reset()

func (*Metadata) SetTag

func (x *Metadata) SetTag(v map[string]string)

func (*Metadata) String

func (x *Metadata) String() string

type MetadataRequest

type MetadataRequest struct {
	// contains filtered or unexported fields
}

func (*MetadataRequest) ProtoMessage

func (*MetadataRequest) ProtoMessage()

func (*MetadataRequest) ProtoReflect

func (x *MetadataRequest) ProtoReflect() protoreflect.Message

func (*MetadataRequest) Reset

func (x *MetadataRequest) Reset()

func (*MetadataRequest) String

func (x *MetadataRequest) String() string

type MetadataRequest_builder

type MetadataRequest_builder struct {
	// contains filtered or unexported fields
}

func (MetadataRequest_builder) Build

type MetadataResponse

type MetadataResponse struct {

	// max_object_size_bytes is the maximum size of each object. Beyond which the object must be uploaded in parts.
	MaxObjectSizeBytes uint64 `protobuf:"varint,1,opt,name=max_object_size_bytes,json=maxObjectSizeBytes,proto3" json:"max_object_size_bytes,omitempty"`
	// min_part_size_bytes is the minimum size of each part in a multipart upload.
	MinPartSizeBytes uint64 `protobuf:"varint,2,opt,name=min_part_size_bytes,json=minPartSizeBytes,proto3" json:"min_part_size_bytes,omitempty"`
	// max_part_size_bytes is the maximum size of each part in a multipart upload.
	MaxPartSizeBytes uint64 `protobuf:"varint,3,opt,name=max_part_size_bytes,json=maxPartSizeBytes,proto3" json:"max_part_size_bytes,omitempty"`
	// contains filtered or unexported fields
}

func (*MetadataResponse) GetMaxObjectSizeBytes

func (x *MetadataResponse) GetMaxObjectSizeBytes() uint64

func (*MetadataResponse) GetMaxPartSizeBytes

func (x *MetadataResponse) GetMaxPartSizeBytes() uint64

func (*MetadataResponse) GetMinPartSizeBytes

func (x *MetadataResponse) GetMinPartSizeBytes() uint64

func (*MetadataResponse) ProtoMessage

func (*MetadataResponse) ProtoMessage()

func (*MetadataResponse) ProtoReflect

func (x *MetadataResponse) ProtoReflect() protoreflect.Message

func (*MetadataResponse) Reset

func (x *MetadataResponse) Reset()

func (*MetadataResponse) SetMaxObjectSizeBytes

func (x *MetadataResponse) SetMaxObjectSizeBytes(v uint64)

func (*MetadataResponse) SetMaxPartSizeBytes

func (x *MetadataResponse) SetMaxPartSizeBytes(v uint64)

func (*MetadataResponse) SetMinPartSizeBytes

func (x *MetadataResponse) SetMinPartSizeBytes(v uint64)

func (*MetadataResponse) String

func (x *MetadataResponse) String() string

type MetadataResponse_builder

type MetadataResponse_builder struct {

	// max_object_size_bytes is the maximum size of each object. Beyond which the object must be uploaded in parts.
	MaxObjectSizeBytes uint64
	// min_part_size_bytes is the minimum size of each part in a multipart upload.
	MinPartSizeBytes uint64
	// max_part_size_bytes is the maximum size of each part in a multipart upload.
	MaxPartSizeBytes uint64
	// contains filtered or unexported fields
}

func (MetadataResponse_builder) Build

type Metadata_builder

type Metadata_builder struct {

	// tag is a free form string that can be associated with an object.
	Tag map[string]string
	// contains filtered or unexported fields
}

func (Metadata_builder) Build

func (b0 Metadata_builder) Build() *Metadata

type Object

type Object struct {

	// Contents field contains the actual bytes of the object.
	Contents []byte `protobuf:"bytes,1,opt,name=contents,proto3" json:"contents,omitempty"`
	// contains filtered or unexported fields
}

Object represents the actual contents of the object stored/retrieved

func (*Object) GetContents

func (x *Object) GetContents() []byte

func (*Object) ProtoMessage

func (*Object) ProtoMessage()

func (*Object) ProtoReflect

func (x *Object) ProtoReflect() protoreflect.Message

func (*Object) Reset

func (x *Object) Reset()

func (*Object) SetContents

func (x *Object) SetContents(v []byte)

func (*Object) String

func (x *Object) String() string

type Object_builder

type Object_builder struct {

	// Contents field contains the actual bytes of the object.
	Contents []byte
	// contains filtered or unexported fields
}

func (Object_builder) Build

func (b0 Object_builder) Build() *Object

type PutRequest

type PutRequest struct {

	// key is the globally unique identifier for the object. unionmeta://
	Key string `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
	// metadata about the object.
	Metadata *Metadata `protobuf:"bytes,2,opt,name=metadata,proto3" json:"metadata,omitempty"`
	// object contains the actual bytes to be stored.
	Object *Object `protobuf:"bytes,3,opt,name=object,proto3" json:"object,omitempty"`
	// contains filtered or unexported fields
}

PutRequest represents a put request.

func (*PutRequest) ClearMetadata

func (x *PutRequest) ClearMetadata()

func (*PutRequest) ClearObject

func (x *PutRequest) ClearObject()

func (*PutRequest) GetKey

func (x *PutRequest) GetKey() string

func (*PutRequest) GetMetadata

func (x *PutRequest) GetMetadata() *Metadata

func (*PutRequest) GetObject

func (x *PutRequest) GetObject() *Object

func (*PutRequest) HasMetadata

func (x *PutRequest) HasMetadata() bool

func (*PutRequest) HasObject

func (x *PutRequest) HasObject() bool

func (*PutRequest) ProtoMessage

func (*PutRequest) ProtoMessage()

func (*PutRequest) ProtoReflect

func (x *PutRequest) ProtoReflect() protoreflect.Message

func (*PutRequest) Reset

func (x *PutRequest) Reset()

func (*PutRequest) SetKey

func (x *PutRequest) SetKey(v string)

func (*PutRequest) SetMetadata

func (x *PutRequest) SetMetadata(v *Metadata)

func (*PutRequest) SetObject

func (x *PutRequest) SetObject(v *Object)

func (*PutRequest) String

func (x *PutRequest) String() string

type PutRequest_builder

type PutRequest_builder struct {

	// key is the globally unique identifier for the object. unionmeta://
	Key string
	// metadata about the object.
	Metadata *Metadata
	// object contains the actual bytes to be stored.
	Object *Object
	// contains filtered or unexported fields
}

func (PutRequest_builder) Build

func (b0 PutRequest_builder) Build() *PutRequest

type PutResponse

type PutResponse struct {
	SizeBytes uint64 `protobuf:"varint,1,opt,name=size_bytes,json=sizeBytes,proto3" json:"size_bytes,omitempty"`
	Etag      string `protobuf:"bytes,2,opt,name=etag,proto3" json:"etag,omitempty"`
	// contains filtered or unexported fields
}

func (*PutResponse) GetEtag

func (x *PutResponse) GetEtag() string

func (*PutResponse) GetSizeBytes

func (x *PutResponse) GetSizeBytes() uint64

func (*PutResponse) ProtoMessage

func (*PutResponse) ProtoMessage()

func (*PutResponse) ProtoReflect

func (x *PutResponse) ProtoReflect() protoreflect.Message

func (*PutResponse) Reset

func (x *PutResponse) Reset()

func (*PutResponse) SetEtag

func (x *PutResponse) SetEtag(v string)

func (*PutResponse) SetSizeBytes

func (x *PutResponse) SetSizeBytes(v uint64)

func (*PutResponse) String

func (x *PutResponse) String() string

type PutResponse_builder

type PutResponse_builder struct {
	SizeBytes uint64
	Etag      string
	// contains filtered or unexported fields
}

func (PutResponse_builder) Build

func (b0 PutResponse_builder) Build() *PutResponse

type SignedPartRequest

type SignedPartRequest struct {

	// PartNumber is the part number of the part.
	PartNumber int32 `protobuf:"varint,1,opt,name=part_number,json=partNumber,proto3" json:"part_number,omitempty"`
	// ExpiresAt defines when will the signed URL expires.
	ExpiresAt *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=expires_at,json=expiresAt,proto3" json:"expires_at,omitempty"`
	// SignedUrl specifies the url to use to upload content to (e.g. https://my-bucket.s3.amazonaws.com/randomstring/suffix.tar?X-...)
	Url     string                       `protobuf:"bytes,3,opt,name=url,proto3" json:"url,omitempty"`
	Method  string                       `protobuf:"bytes,4,opt,name=method,proto3" json:"method,omitempty"`
	Headers map[string]*HttpHeaderValues `` /* 141-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*SignedPartRequest) ClearExpiresAt

func (x *SignedPartRequest) ClearExpiresAt()

func (*SignedPartRequest) GetExpiresAt

func (x *SignedPartRequest) GetExpiresAt() *timestamppb.Timestamp

func (*SignedPartRequest) GetHeaders

func (x *SignedPartRequest) GetHeaders() map[string]*HttpHeaderValues

func (*SignedPartRequest) GetMethod

func (x *SignedPartRequest) GetMethod() string

func (*SignedPartRequest) GetPartNumber

func (x *SignedPartRequest) GetPartNumber() int32

func (*SignedPartRequest) GetUrl

func (x *SignedPartRequest) GetUrl() string

func (*SignedPartRequest) HasExpiresAt

func (x *SignedPartRequest) HasExpiresAt() bool

func (*SignedPartRequest) ProtoMessage

func (*SignedPartRequest) ProtoMessage()

func (*SignedPartRequest) ProtoReflect

func (x *SignedPartRequest) ProtoReflect() protoreflect.Message

func (*SignedPartRequest) Reset

func (x *SignedPartRequest) Reset()

func (*SignedPartRequest) SetExpiresAt

func (x *SignedPartRequest) SetExpiresAt(v *timestamppb.Timestamp)

func (*SignedPartRequest) SetHeaders

func (x *SignedPartRequest) SetHeaders(v map[string]*HttpHeaderValues)

func (*SignedPartRequest) SetMethod

func (x *SignedPartRequest) SetMethod(v string)

func (*SignedPartRequest) SetPartNumber

func (x *SignedPartRequest) SetPartNumber(v int32)

func (*SignedPartRequest) SetUrl

func (x *SignedPartRequest) SetUrl(v string)

func (*SignedPartRequest) String

func (x *SignedPartRequest) String() string

type SignedPartRequest_builder

type SignedPartRequest_builder struct {

	// PartNumber is the part number of the part.
	PartNumber int32
	// ExpiresAt defines when will the signed URL expires.
	ExpiresAt *timestamppb.Timestamp
	// SignedUrl specifies the url to use to upload content to (e.g. https://my-bucket.s3.amazonaws.com/randomstring/suffix.tar?X-...)
	Url     string
	Method  string
	Headers map[string]*HttpHeaderValues
	// contains filtered or unexported fields
}

func (SignedPartRequest_builder) Build

type StartLargeObjectUploadRequest

type StartLargeObjectUploadRequest struct {

	// key is the globally unique identifier for the object. union://
	Key string `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
	// size_bytes is the size of the object to be uploaded.
	SizeBytes uint64 `protobuf:"varint,2,opt,name=size_bytes,json=sizeBytes,proto3" json:"size_bytes,omitempty"` // 1GB
	// metadata about the object.
	Metadata *Metadata `protobuf:"bytes,3,opt,name=metadata,proto3" json:"metadata,omitempty"`
	// contains filtered or unexported fields
}

func (*StartLargeObjectUploadRequest) ClearMetadata

func (x *StartLargeObjectUploadRequest) ClearMetadata()

func (*StartLargeObjectUploadRequest) GetKey

func (*StartLargeObjectUploadRequest) GetMetadata

func (x *StartLargeObjectUploadRequest) GetMetadata() *Metadata

func (*StartLargeObjectUploadRequest) GetSizeBytes

func (x *StartLargeObjectUploadRequest) GetSizeBytes() uint64

func (*StartLargeObjectUploadRequest) HasMetadata

func (x *StartLargeObjectUploadRequest) HasMetadata() bool

func (*StartLargeObjectUploadRequest) ProtoMessage

func (*StartLargeObjectUploadRequest) ProtoMessage()

func (*StartLargeObjectUploadRequest) ProtoReflect

func (*StartLargeObjectUploadRequest) Reset

func (x *StartLargeObjectUploadRequest) Reset()

func (*StartLargeObjectUploadRequest) SetKey

func (*StartLargeObjectUploadRequest) SetMetadata

func (x *StartLargeObjectUploadRequest) SetMetadata(v *Metadata)

func (*StartLargeObjectUploadRequest) SetSizeBytes

func (x *StartLargeObjectUploadRequest) SetSizeBytes(v uint64)

func (*StartLargeObjectUploadRequest) String

type StartLargeObjectUploadRequest_builder

type StartLargeObjectUploadRequest_builder struct {

	// key is the globally unique identifier for the object. union://
	Key string
	// size_bytes is the size of the object to be uploaded.
	SizeBytes uint64
	// metadata about the object.
	Metadata *Metadata
	// contains filtered or unexported fields
}

func (StartLargeObjectUploadRequest_builder) Build

type StartLargeObjectUploadResponse

type StartLargeObjectUploadResponse struct {

	// operation_id is the id of the operation.
	OperationId string `protobuf:"bytes,1,opt,name=operation_id,json=operationId,proto3" json:"operation_id,omitempty"`
	// ExpiresAt defines when will the upload expires. If upload isn't successfully completed by then, it'll be aborted.
	ExpiresAt *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=expires_at,json=expiresAt,proto3" json:"expires_at,omitempty"`
	// contains filtered or unexported fields
}

func (*StartLargeObjectUploadResponse) ClearExpiresAt

func (x *StartLargeObjectUploadResponse) ClearExpiresAt()

func (*StartLargeObjectUploadResponse) GetExpiresAt

func (*StartLargeObjectUploadResponse) GetOperationId

func (x *StartLargeObjectUploadResponse) GetOperationId() string

func (*StartLargeObjectUploadResponse) HasExpiresAt

func (x *StartLargeObjectUploadResponse) HasExpiresAt() bool

func (*StartLargeObjectUploadResponse) ProtoMessage

func (*StartLargeObjectUploadResponse) ProtoMessage()

func (*StartLargeObjectUploadResponse) ProtoReflect

func (*StartLargeObjectUploadResponse) Reset

func (x *StartLargeObjectUploadResponse) Reset()

func (*StartLargeObjectUploadResponse) SetExpiresAt

func (*StartLargeObjectUploadResponse) SetOperationId

func (x *StartLargeObjectUploadResponse) SetOperationId(v string)

func (*StartLargeObjectUploadResponse) String

type StartLargeObjectUploadResponse_builder

type StartLargeObjectUploadResponse_builder struct {

	// operation_id is the id of the operation.
	OperationId string
	// ExpiresAt defines when will the upload expires. If upload isn't successfully completed by then, it'll be aborted.
	ExpiresAt *timestamppb.Timestamp
	// contains filtered or unexported fields
}

func (StartLargeObjectUploadResponse_builder) Build

type SuccessfulUploadRequest

type SuccessfulUploadRequest struct {
	EtagsParts map[string]int32 `` /* 166-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*SuccessfulUploadRequest) GetEtagsParts

func (x *SuccessfulUploadRequest) GetEtagsParts() map[string]int32

func (*SuccessfulUploadRequest) ProtoMessage

func (*SuccessfulUploadRequest) ProtoMessage()

func (*SuccessfulUploadRequest) ProtoReflect

func (x *SuccessfulUploadRequest) ProtoReflect() protoreflect.Message

func (*SuccessfulUploadRequest) Reset

func (x *SuccessfulUploadRequest) Reset()

func (*SuccessfulUploadRequest) SetEtagsParts

func (x *SuccessfulUploadRequest) SetEtagsParts(v map[string]int32)

func (*SuccessfulUploadRequest) String

func (x *SuccessfulUploadRequest) String() string

type SuccessfulUploadRequest_builder

type SuccessfulUploadRequest_builder struct {
	EtagsParts map[string]int32
	// contains filtered or unexported fields
}

func (SuccessfulUploadRequest_builder) Build

type TerminateLargeObjectUploadRequest

type TerminateLargeObjectUploadRequest struct {
	OperationId string `protobuf:"bytes,1,opt,name=operation_id,json=operationId,proto3" json:"operation_id,omitempty"`
	Key         string `protobuf:"bytes,2,opt,name=key,proto3" json:"key,omitempty"`
	// Types that are valid to be assigned to Request:
	//
	//	*TerminateLargeObjectUploadRequest_SuccessfulUpload
	//	*TerminateLargeObjectUploadRequest_AbortUpload
	Request isTerminateLargeObjectUploadRequest_Request `protobuf_oneof:"request"`
	// contains filtered or unexported fields
}

func (*TerminateLargeObjectUploadRequest) ClearAbortUpload

func (x *TerminateLargeObjectUploadRequest) ClearAbortUpload()

func (*TerminateLargeObjectUploadRequest) ClearRequest

func (x *TerminateLargeObjectUploadRequest) ClearRequest()

func (*TerminateLargeObjectUploadRequest) ClearSuccessfulUpload

func (x *TerminateLargeObjectUploadRequest) ClearSuccessfulUpload()

func (*TerminateLargeObjectUploadRequest) GetAbortUpload

func (*TerminateLargeObjectUploadRequest) GetKey

func (*TerminateLargeObjectUploadRequest) GetOperationId

func (x *TerminateLargeObjectUploadRequest) GetOperationId() string

func (*TerminateLargeObjectUploadRequest) GetRequest

func (x *TerminateLargeObjectUploadRequest) GetRequest() isTerminateLargeObjectUploadRequest_Request

func (*TerminateLargeObjectUploadRequest) GetSuccessfulUpload

func (*TerminateLargeObjectUploadRequest) HasAbortUpload

func (x *TerminateLargeObjectUploadRequest) HasAbortUpload() bool

func (*TerminateLargeObjectUploadRequest) HasRequest

func (x *TerminateLargeObjectUploadRequest) HasRequest() bool

func (*TerminateLargeObjectUploadRequest) HasSuccessfulUpload

func (x *TerminateLargeObjectUploadRequest) HasSuccessfulUpload() bool

func (*TerminateLargeObjectUploadRequest) ProtoMessage

func (*TerminateLargeObjectUploadRequest) ProtoMessage()

func (*TerminateLargeObjectUploadRequest) ProtoReflect

func (*TerminateLargeObjectUploadRequest) Reset

func (*TerminateLargeObjectUploadRequest) SetAbortUpload

func (*TerminateLargeObjectUploadRequest) SetKey

func (*TerminateLargeObjectUploadRequest) SetOperationId

func (x *TerminateLargeObjectUploadRequest) SetOperationId(v string)

func (*TerminateLargeObjectUploadRequest) SetSuccessfulUpload

func (*TerminateLargeObjectUploadRequest) String

func (*TerminateLargeObjectUploadRequest) WhichRequest

func (x *TerminateLargeObjectUploadRequest) WhichRequest() case_TerminateLargeObjectUploadRequest_Request

type TerminateLargeObjectUploadRequest_AbortUpload

type TerminateLargeObjectUploadRequest_AbortUpload struct {
	AbortUpload *AbortUploadRequest `protobuf:"bytes,4,opt,name=abort_upload,json=abortUpload,proto3,oneof"`
}

type TerminateLargeObjectUploadRequest_SuccessfulUpload

type TerminateLargeObjectUploadRequest_SuccessfulUpload struct {
	SuccessfulUpload *SuccessfulUploadRequest `protobuf:"bytes,3,opt,name=successful_upload,json=successfulUpload,proto3,oneof"`
}

type TerminateLargeObjectUploadRequest_builder

type TerminateLargeObjectUploadRequest_builder struct {
	OperationId string
	Key         string
	// Fields of oneof Request:
	SuccessfulUpload *SuccessfulUploadRequest
	AbortUpload      *AbortUploadRequest
	// contains filtered or unexported fields
}

func (TerminateLargeObjectUploadRequest_builder) Build

type TerminateLargeObjectUploadResponse

type TerminateLargeObjectUploadResponse struct {

	// key is the globally unique identifier for the object. union://
	Key string `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
	// etag is the etag of the object.
	Etag string `protobuf:"bytes,2,opt,name=etag,proto3" json:"etag,omitempty"`
	// contains filtered or unexported fields
}

func (*TerminateLargeObjectUploadResponse) GetEtag

func (*TerminateLargeObjectUploadResponse) GetKey

func (*TerminateLargeObjectUploadResponse) ProtoMessage

func (*TerminateLargeObjectUploadResponse) ProtoMessage()

func (*TerminateLargeObjectUploadResponse) ProtoReflect

func (*TerminateLargeObjectUploadResponse) Reset

func (*TerminateLargeObjectUploadResponse) SetEtag

func (*TerminateLargeObjectUploadResponse) SetKey

func (*TerminateLargeObjectUploadResponse) String

type TerminateLargeObjectUploadResponse_builder

type TerminateLargeObjectUploadResponse_builder struct {

	// key is the globally unique identifier for the object. union://
	Key string
	// etag is the etag of the object.
	Etag string
	// contains filtered or unexported fields
}

func (TerminateLargeObjectUploadResponse_builder) Build

type UploadPartRequest

type UploadPartRequest struct {

	// operation_id is the id of the operation.
	OperationId string `protobuf:"bytes,1,opt,name=operation_id,json=operationId,proto3" json:"operation_id,omitempty"`
	// key is the globally unique identifier for the object. union://
	Key string `protobuf:"bytes,2,opt,name=key,proto3" json:"key,omitempty"`
	// PartNumber is the part number of the part.
	PartNumber int32 `protobuf:"varint,3,opt,name=part_number,json=partNumber,proto3" json:"part_number,omitempty"`
	// object contains the actual bytes to be stored.
	Object *Object `protobuf:"bytes,4,opt,name=object,proto3" json:"object,omitempty"`
	// content_length is the full size of the object to be uploaded.
	ContentLength int64 `protobuf:"varint,5,opt,name=content_length,json=contentLength,proto3" json:"content_length,omitempty"`
	// contains filtered or unexported fields
}

func (*UploadPartRequest) ClearObject

func (x *UploadPartRequest) ClearObject()

func (*UploadPartRequest) GetContentLength

func (x *UploadPartRequest) GetContentLength() int64

func (*UploadPartRequest) GetKey

func (x *UploadPartRequest) GetKey() string

func (*UploadPartRequest) GetObject

func (x *UploadPartRequest) GetObject() *Object

func (*UploadPartRequest) GetOperationId

func (x *UploadPartRequest) GetOperationId() string

func (*UploadPartRequest) GetPartNumber

func (x *UploadPartRequest) GetPartNumber() int32

func (*UploadPartRequest) HasObject

func (x *UploadPartRequest) HasObject() bool

func (*UploadPartRequest) ProtoMessage

func (*UploadPartRequest) ProtoMessage()

func (*UploadPartRequest) ProtoReflect

func (x *UploadPartRequest) ProtoReflect() protoreflect.Message

func (*UploadPartRequest) Reset

func (x *UploadPartRequest) Reset()

func (*UploadPartRequest) SetContentLength

func (x *UploadPartRequest) SetContentLength(v int64)

func (*UploadPartRequest) SetKey

func (x *UploadPartRequest) SetKey(v string)

func (*UploadPartRequest) SetObject

func (x *UploadPartRequest) SetObject(v *Object)

func (*UploadPartRequest) SetOperationId

func (x *UploadPartRequest) SetOperationId(v string)

func (*UploadPartRequest) SetPartNumber

func (x *UploadPartRequest) SetPartNumber(v int32)

func (*UploadPartRequest) String

func (x *UploadPartRequest) String() string

type UploadPartRequest_builder

type UploadPartRequest_builder struct {

	// operation_id is the id of the operation.
	OperationId string
	// key is the globally unique identifier for the object. union://
	Key string
	// PartNumber is the part number of the part.
	PartNumber int32
	// object contains the actual bytes to be stored.
	Object *Object
	// content_length is the full size of the object to be uploaded.
	ContentLength int64
	// contains filtered or unexported fields
}

func (UploadPartRequest_builder) Build

type UploadPartResponse

type UploadPartResponse struct {

	// etag is the etag of the object.
	Etag string `protobuf:"bytes,1,opt,name=etag,proto3" json:"etag,omitempty"`
	// contains filtered or unexported fields
}

func (*UploadPartResponse) GetEtag

func (x *UploadPartResponse) GetEtag() string

func (*UploadPartResponse) ProtoMessage

func (*UploadPartResponse) ProtoMessage()

func (*UploadPartResponse) ProtoReflect

func (x *UploadPartResponse) ProtoReflect() protoreflect.Message

func (*UploadPartResponse) Reset

func (x *UploadPartResponse) Reset()

func (*UploadPartResponse) SetEtag

func (x *UploadPartResponse) SetEtag(v string)

func (*UploadPartResponse) String

func (x *UploadPartResponse) String() string

type UploadPartResponse_builder

type UploadPartResponse_builder struct {

	// etag is the etag of the object.
	Etag string
	// contains filtered or unexported fields
}

func (UploadPartResponse_builder) Build

Source Files

  • payload.pb.go
  • service.pb.go

Jump to