apigatewayv1

package
v1.36.10-2024050211440... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	Api_State_name = map[int32]string{
		0: "STATE_UNSPECIFIED",
		1: "CREATING",
		2: "ACTIVE",
		3: "FAILED",
		4: "DELETING",
		5: "UPDATING",
	}
	Api_State_value = map[string]int32{
		"STATE_UNSPECIFIED": 0,
		"CREATING":          1,
		"ACTIVE":            2,
		"FAILED":            3,
		"DELETING":          4,
		"UPDATING":          5,
	}
)

Enum value maps for Api_State.

var (
	ApiConfig_State_name = map[int32]string{
		0: "STATE_UNSPECIFIED",
		1: "CREATING",
		2: "ACTIVE",
		3: "FAILED",
		4: "DELETING",
		5: "UPDATING",
		6: "ACTIVATING",
	}
	ApiConfig_State_value = map[string]int32{
		"STATE_UNSPECIFIED": 0,
		"CREATING":          1,
		"ACTIVE":            2,
		"FAILED":            3,
		"DELETING":          4,
		"UPDATING":          5,
		"ACTIVATING":        6,
	}
)

Enum value maps for ApiConfig_State.

var (
	Gateway_State_name = map[int32]string{
		0: "STATE_UNSPECIFIED",
		1: "CREATING",
		2: "ACTIVE",
		3: "FAILED",
		4: "DELETING",
		5: "UPDATING",
	}
	Gateway_State_value = map[string]int32{
		"STATE_UNSPECIFIED": 0,
		"CREATING":          1,
		"ACTIVE":            2,
		"FAILED":            3,
		"DELETING":          4,
		"UPDATING":          5,
	}
)

Enum value maps for Gateway_State.

var File_google_events_cloud_apigateway_v1_data_proto protoreflect.FileDescriptor
var File_google_events_cloud_apigateway_v1_events_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type Api

type Api struct {

	// Output only. Resource name of the API.
	// Format: projects/{project}/locations/global/apis/{api}
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Output only. Created time.
	CreateTime *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
	// Output only. Updated time.
	UpdateTime *timestamppb.Timestamp `protobuf:"bytes,3,opt,name=update_time,json=updateTime,proto3" json:"update_time,omitempty"`
	// Optional. Resource labels to represent user-provided metadata.
	// Refer to cloud documentation on labels for more details.
	// https://cloud.google.com/compute/docs/labeling-resources
	Labels map[string]string `` /* 139-byte string literal not displayed */
	// Optional. Display name.
	DisplayName string `protobuf:"bytes,5,opt,name=display_name,json=displayName,proto3" json:"display_name,omitempty"`
	// Optional. Immutable. The name of a Google Managed Service (
	// https://cloud.google.com/service-infrastructure/docs/glossary#managed).
	// If not specified, a new Service will automatically be created in the same
	// project as this API.
	ManagedService string `protobuf:"bytes,7,opt,name=managed_service,json=managedService,proto3" json:"managed_service,omitempty"`
	// Output only. State of the API.
	State Api_State `protobuf:"varint,12,opt,name=state,proto3,enum=google.events.cloud.apigateway.v1.Api_State" json:"state,omitempty"`
	// contains filtered or unexported fields
}

An API that can be served by one or more Gateways.

func (*Api) ClearCreateTime

func (x *Api) ClearCreateTime()

func (*Api) ClearUpdateTime

func (x *Api) ClearUpdateTime()

func (*Api) GetCreateTime

func (x *Api) GetCreateTime() *timestamppb.Timestamp

func (*Api) GetDisplayName

func (x *Api) GetDisplayName() string

func (*Api) GetLabels

func (x *Api) GetLabels() map[string]string

func (*Api) GetManagedService

func (x *Api) GetManagedService() string

func (*Api) GetName

func (x *Api) GetName() string

func (*Api) GetState

func (x *Api) GetState() Api_State

func (*Api) GetUpdateTime

func (x *Api) GetUpdateTime() *timestamppb.Timestamp

func (*Api) HasCreateTime

func (x *Api) HasCreateTime() bool

func (*Api) HasUpdateTime

func (x *Api) HasUpdateTime() bool

func (*Api) ProtoMessage

func (*Api) ProtoMessage()

func (*Api) ProtoReflect

func (x *Api) ProtoReflect() protoreflect.Message

func (*Api) Reset

func (x *Api) Reset()

func (*Api) SetCreateTime

func (x *Api) SetCreateTime(v *timestamppb.Timestamp)

func (*Api) SetDisplayName

func (x *Api) SetDisplayName(v string)

func (*Api) SetLabels

func (x *Api) SetLabels(v map[string]string)

func (*Api) SetManagedService

func (x *Api) SetManagedService(v string)

func (*Api) SetName

func (x *Api) SetName(v string)

func (*Api) SetState

func (x *Api) SetState(v Api_State)

func (*Api) SetUpdateTime

func (x *Api) SetUpdateTime(v *timestamppb.Timestamp)

func (*Api) String

func (x *Api) String() string

type ApiConfig

type ApiConfig struct {

	// Output only. Resource name of the API Config.
	// Format: projects/{project}/locations/global/apis/{api}/configs/{api_config}
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Output only. Created time.
	CreateTime *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
	// Output only. Updated time.
	UpdateTime *timestamppb.Timestamp `protobuf:"bytes,3,opt,name=update_time,json=updateTime,proto3" json:"update_time,omitempty"`
	// Optional. Resource labels to represent user-provided metadata.
	// Refer to cloud documentation on labels for more details.
	// https://cloud.google.com/compute/docs/labeling-resources
	Labels map[string]string `` /* 139-byte string literal not displayed */
	// Optional. Display name.
	DisplayName string `protobuf:"bytes,5,opt,name=display_name,json=displayName,proto3" json:"display_name,omitempty"`
	// Immutable. The Google Cloud IAM Service Account that Gateways serving this
	// config should use to authenticate to other services. This may either be the
	// Service Account's email
	// (`{ACCOUNT_ID}@{PROJECT}.iam.gserviceaccount.com`) or its full resource
	// name (`projects/{PROJECT}/accounts/{UNIQUE_ID}`). This is most often used
	// when the service is a GCP resource such as a Cloud Run Service or an
	// IAP-secured service.
	GatewayServiceAccount string `` /* 127-byte string literal not displayed */
	// Output only. The ID of the associated Service Config (
	// https://cloud.google.com/service-infrastructure/docs/glossary#config).
	ServiceConfigId string `protobuf:"bytes,12,opt,name=service_config_id,json=serviceConfigId,proto3" json:"service_config_id,omitempty"`
	// Output only. State of the API Config.
	State ApiConfig_State `protobuf:"varint,8,opt,name=state,proto3,enum=google.events.cloud.apigateway.v1.ApiConfig_State" json:"state,omitempty"`
	// Optional. OpenAPI specification documents. If specified, grpc_services and
	// managed_service_configs must not be included.
	OpenapiDocuments []*ApiConfig_OpenApiDocument `protobuf:"bytes,9,rep,name=openapi_documents,json=openapiDocuments,proto3" json:"openapi_documents,omitempty"`
	// Optional. gRPC service definition files. If specified, openapi_documents
	// must not be included.
	GrpcServices []*ApiConfig_GrpcServiceDefinition `protobuf:"bytes,10,rep,name=grpc_services,json=grpcServices,proto3" json:"grpc_services,omitempty"`
	// Optional. Service Configuration files. At least one must be included when
	// using gRPC service definitions. See
	// https://cloud.google.com/endpoints/docs/grpc/grpc-service-config#service_configuration_overview
	// for the expected file contents.
	//
	// If multiple files are specified, the files are merged with the following
	// rules:
	// * All singular scalar fields are merged using "last one wins" semantics in
	// the order of the files uploaded.
	// * Repeated fields are concatenated.
	// * Singular embedded messages are merged using these rules for nested
	// fields.
	ManagedServiceConfigs []*ApiConfig_File `` /* 127-byte string literal not displayed */
	// contains filtered or unexported fields
}

An API Configuration is a combination of settings for both the Managed Service and Gateways serving this API Config.

func (*ApiConfig) ClearCreateTime

func (x *ApiConfig) ClearCreateTime()

func (*ApiConfig) ClearUpdateTime

func (x *ApiConfig) ClearUpdateTime()

func (*ApiConfig) GetCreateTime

func (x *ApiConfig) GetCreateTime() *timestamppb.Timestamp

func (*ApiConfig) GetDisplayName

func (x *ApiConfig) GetDisplayName() string

func (*ApiConfig) GetGatewayServiceAccount

func (x *ApiConfig) GetGatewayServiceAccount() string

func (*ApiConfig) GetGrpcServices

func (x *ApiConfig) GetGrpcServices() []*ApiConfig_GrpcServiceDefinition

func (*ApiConfig) GetLabels

func (x *ApiConfig) GetLabels() map[string]string

func (*ApiConfig) GetManagedServiceConfigs

func (x *ApiConfig) GetManagedServiceConfigs() []*ApiConfig_File

func (*ApiConfig) GetName

func (x *ApiConfig) GetName() string

func (*ApiConfig) GetOpenapiDocuments

func (x *ApiConfig) GetOpenapiDocuments() []*ApiConfig_OpenApiDocument

func (*ApiConfig) GetServiceConfigId

func (x *ApiConfig) GetServiceConfigId() string

func (*ApiConfig) GetState

func (x *ApiConfig) GetState() ApiConfig_State

func (*ApiConfig) GetUpdateTime

func (x *ApiConfig) GetUpdateTime() *timestamppb.Timestamp

func (*ApiConfig) HasCreateTime

func (x *ApiConfig) HasCreateTime() bool

func (*ApiConfig) HasUpdateTime

func (x *ApiConfig) HasUpdateTime() bool

func (*ApiConfig) ProtoMessage

func (*ApiConfig) ProtoMessage()

func (*ApiConfig) ProtoReflect

func (x *ApiConfig) ProtoReflect() protoreflect.Message

func (*ApiConfig) Reset

func (x *ApiConfig) Reset()

func (*ApiConfig) SetCreateTime

func (x *ApiConfig) SetCreateTime(v *timestamppb.Timestamp)

func (*ApiConfig) SetDisplayName

func (x *ApiConfig) SetDisplayName(v string)

func (*ApiConfig) SetGatewayServiceAccount

func (x *ApiConfig) SetGatewayServiceAccount(v string)

func (*ApiConfig) SetGrpcServices

func (x *ApiConfig) SetGrpcServices(v []*ApiConfig_GrpcServiceDefinition)

func (*ApiConfig) SetLabels

func (x *ApiConfig) SetLabels(v map[string]string)

func (*ApiConfig) SetManagedServiceConfigs

func (x *ApiConfig) SetManagedServiceConfigs(v []*ApiConfig_File)

func (*ApiConfig) SetName

func (x *ApiConfig) SetName(v string)

func (*ApiConfig) SetOpenapiDocuments

func (x *ApiConfig) SetOpenapiDocuments(v []*ApiConfig_OpenApiDocument)

func (*ApiConfig) SetServiceConfigId

func (x *ApiConfig) SetServiceConfigId(v string)

func (*ApiConfig) SetState

func (x *ApiConfig) SetState(v ApiConfig_State)

func (*ApiConfig) SetUpdateTime

func (x *ApiConfig) SetUpdateTime(v *timestamppb.Timestamp)

func (*ApiConfig) String

func (x *ApiConfig) String() string

type ApiConfigCreatedEvent

type ApiConfigCreatedEvent struct {

	// The data associated with the event.
	Data *ApiConfigEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

The CloudEvent raised when an ApiConfig is created.

func (*ApiConfigCreatedEvent) ClearData

func (x *ApiConfigCreatedEvent) ClearData()

func (*ApiConfigCreatedEvent) GetData

func (*ApiConfigCreatedEvent) HasData

func (x *ApiConfigCreatedEvent) HasData() bool

func (*ApiConfigCreatedEvent) ProtoMessage

func (*ApiConfigCreatedEvent) ProtoMessage()

func (*ApiConfigCreatedEvent) ProtoReflect

func (x *ApiConfigCreatedEvent) ProtoReflect() protoreflect.Message

func (*ApiConfigCreatedEvent) Reset

func (x *ApiConfigCreatedEvent) Reset()

func (*ApiConfigCreatedEvent) SetData

func (*ApiConfigCreatedEvent) String

func (x *ApiConfigCreatedEvent) String() string

type ApiConfigCreatedEvent_builder

type ApiConfigCreatedEvent_builder struct {

	// The data associated with the event.
	Data *ApiConfigEventData
	// contains filtered or unexported fields
}

func (ApiConfigCreatedEvent_builder) Build

type ApiConfigDeletedEvent

type ApiConfigDeletedEvent struct {

	// The data associated with the event.
	Data *ApiConfigEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

The CloudEvent raised when an ApiConfig is deleted.

func (*ApiConfigDeletedEvent) ClearData

func (x *ApiConfigDeletedEvent) ClearData()

func (*ApiConfigDeletedEvent) GetData

func (*ApiConfigDeletedEvent) HasData

func (x *ApiConfigDeletedEvent) HasData() bool

func (*ApiConfigDeletedEvent) ProtoMessage

func (*ApiConfigDeletedEvent) ProtoMessage()

func (*ApiConfigDeletedEvent) ProtoReflect

func (x *ApiConfigDeletedEvent) ProtoReflect() protoreflect.Message

func (*ApiConfigDeletedEvent) Reset

func (x *ApiConfigDeletedEvent) Reset()

func (*ApiConfigDeletedEvent) SetData

func (*ApiConfigDeletedEvent) String

func (x *ApiConfigDeletedEvent) String() string

type ApiConfigDeletedEvent_builder

type ApiConfigDeletedEvent_builder struct {

	// The data associated with the event.
	Data *ApiConfigEventData
	// contains filtered or unexported fields
}

func (ApiConfigDeletedEvent_builder) Build

type ApiConfigEventData

type ApiConfigEventData struct {

	// Optional. The ApiConfig event payload. Unset for deletion events.
	Payload *ApiConfig `protobuf:"bytes,1,opt,name=payload,proto3,oneof" json:"payload,omitempty"`
	// contains filtered or unexported fields
}

The data within all ApiConfig events.

func (*ApiConfigEventData) ClearPayload

func (x *ApiConfigEventData) ClearPayload()

func (*ApiConfigEventData) GetPayload

func (x *ApiConfigEventData) GetPayload() *ApiConfig

func (*ApiConfigEventData) HasPayload

func (x *ApiConfigEventData) HasPayload() bool

func (*ApiConfigEventData) ProtoMessage

func (*ApiConfigEventData) ProtoMessage()

func (*ApiConfigEventData) ProtoReflect

func (x *ApiConfigEventData) ProtoReflect() protoreflect.Message

func (*ApiConfigEventData) Reset

func (x *ApiConfigEventData) Reset()

func (*ApiConfigEventData) SetPayload

func (x *ApiConfigEventData) SetPayload(v *ApiConfig)

func (*ApiConfigEventData) String

func (x *ApiConfigEventData) String() string

type ApiConfigEventData_builder

type ApiConfigEventData_builder struct {

	// Optional. The ApiConfig event payload. Unset for deletion events.
	Payload *ApiConfig
	// contains filtered or unexported fields
}

func (ApiConfigEventData_builder) Build

type ApiConfigUpdatedEvent

type ApiConfigUpdatedEvent struct {

	// The data associated with the event.
	Data *ApiConfigEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

The CloudEvent raised when an ApiConfig is updated.

func (*ApiConfigUpdatedEvent) ClearData

func (x *ApiConfigUpdatedEvent) ClearData()

func (*ApiConfigUpdatedEvent) GetData

func (*ApiConfigUpdatedEvent) HasData

func (x *ApiConfigUpdatedEvent) HasData() bool

func (*ApiConfigUpdatedEvent) ProtoMessage

func (*ApiConfigUpdatedEvent) ProtoMessage()

func (*ApiConfigUpdatedEvent) ProtoReflect

func (x *ApiConfigUpdatedEvent) ProtoReflect() protoreflect.Message

func (*ApiConfigUpdatedEvent) Reset

func (x *ApiConfigUpdatedEvent) Reset()

func (*ApiConfigUpdatedEvent) SetData

func (*ApiConfigUpdatedEvent) String

func (x *ApiConfigUpdatedEvent) String() string

type ApiConfigUpdatedEvent_builder

type ApiConfigUpdatedEvent_builder struct {

	// The data associated with the event.
	Data *ApiConfigEventData
	// contains filtered or unexported fields
}

func (ApiConfigUpdatedEvent_builder) Build

type ApiConfig_File

type ApiConfig_File struct {

	// The file path (full or relative path). This is typically the path of the
	// file when it is uploaded.
	Path string `protobuf:"bytes,1,opt,name=path,proto3" json:"path,omitempty"`
	// The bytes that constitute the file.
	Contents []byte `protobuf:"bytes,2,opt,name=contents,proto3" json:"contents,omitempty"`
	// contains filtered or unexported fields
}

A lightweight description of a file.

func (*ApiConfig_File) GetContents

func (x *ApiConfig_File) GetContents() []byte

func (*ApiConfig_File) GetPath

func (x *ApiConfig_File) GetPath() string

func (*ApiConfig_File) ProtoMessage

func (*ApiConfig_File) ProtoMessage()

func (*ApiConfig_File) ProtoReflect

func (x *ApiConfig_File) ProtoReflect() protoreflect.Message

func (*ApiConfig_File) Reset

func (x *ApiConfig_File) Reset()

func (*ApiConfig_File) SetContents

func (x *ApiConfig_File) SetContents(v []byte)

func (*ApiConfig_File) SetPath

func (x *ApiConfig_File) SetPath(v string)

func (*ApiConfig_File) String

func (x *ApiConfig_File) String() string

type ApiConfig_File_builder

type ApiConfig_File_builder struct {

	// The file path (full or relative path). This is typically the path of the
	// file when it is uploaded.
	Path string
	// The bytes that constitute the file.
	Contents []byte
	// contains filtered or unexported fields
}

func (ApiConfig_File_builder) Build

type ApiConfig_GrpcServiceDefinition

type ApiConfig_GrpcServiceDefinition struct {

	// Optional. Uncompiled proto files associated with the descriptor set, used
	// for display purposes (server-side compilation is not supported). These
	// should match the inputs to 'protoc' command used to generate
	// file_descriptor_set.
	Source []*ApiConfig_File `protobuf:"bytes,2,rep,name=source,proto3" json:"source,omitempty"`
	// contains filtered or unexported fields
}

A gRPC service definition.

func (*ApiConfig_GrpcServiceDefinition) GetSource

func (*ApiConfig_GrpcServiceDefinition) ProtoMessage

func (*ApiConfig_GrpcServiceDefinition) ProtoMessage()

func (*ApiConfig_GrpcServiceDefinition) ProtoReflect

func (*ApiConfig_GrpcServiceDefinition) Reset

func (*ApiConfig_GrpcServiceDefinition) SetSource

func (*ApiConfig_GrpcServiceDefinition) String

type ApiConfig_GrpcServiceDefinition_builder

type ApiConfig_GrpcServiceDefinition_builder struct {

	// Optional. Uncompiled proto files associated with the descriptor set, used
	// for display purposes (server-side compilation is not supported). These
	// should match the inputs to 'protoc' command used to generate
	// file_descriptor_set.
	Source []*ApiConfig_File
	// contains filtered or unexported fields
}

func (ApiConfig_GrpcServiceDefinition_builder) Build

type ApiConfig_OpenApiDocument

type ApiConfig_OpenApiDocument struct {

	// The OpenAPI Specification document file.
	Document *ApiConfig_File `protobuf:"bytes,1,opt,name=document,proto3" json:"document,omitempty"`
	// contains filtered or unexported fields
}

An OpenAPI Specification Document describing an API.

func (*ApiConfig_OpenApiDocument) ClearDocument

func (x *ApiConfig_OpenApiDocument) ClearDocument()

func (*ApiConfig_OpenApiDocument) GetDocument

func (x *ApiConfig_OpenApiDocument) GetDocument() *ApiConfig_File

func (*ApiConfig_OpenApiDocument) HasDocument

func (x *ApiConfig_OpenApiDocument) HasDocument() bool

func (*ApiConfig_OpenApiDocument) ProtoMessage

func (*ApiConfig_OpenApiDocument) ProtoMessage()

func (*ApiConfig_OpenApiDocument) ProtoReflect

func (*ApiConfig_OpenApiDocument) Reset

func (x *ApiConfig_OpenApiDocument) Reset()

func (*ApiConfig_OpenApiDocument) SetDocument

func (x *ApiConfig_OpenApiDocument) SetDocument(v *ApiConfig_File)

func (*ApiConfig_OpenApiDocument) String

func (x *ApiConfig_OpenApiDocument) String() string

type ApiConfig_OpenApiDocument_builder

type ApiConfig_OpenApiDocument_builder struct {

	// The OpenAPI Specification document file.
	Document *ApiConfig_File
	// contains filtered or unexported fields
}

func (ApiConfig_OpenApiDocument_builder) Build

type ApiConfig_State

type ApiConfig_State int32

All the possible API Config states.

const (
	// API Config does not have a state yet.
	ApiConfig_STATE_UNSPECIFIED ApiConfig_State = 0
	// API Config is being created and deployed to the API Controller.
	ApiConfig_CREATING ApiConfig_State = 1
	// API Config is ready for use by Gateways.
	ApiConfig_ACTIVE ApiConfig_State = 2
	// API Config creation failed.
	ApiConfig_FAILED ApiConfig_State = 3
	// API Config is being deleted.
	ApiConfig_DELETING ApiConfig_State = 4
	// API Config is being updated.
	ApiConfig_UPDATING ApiConfig_State = 5
	// API Config settings are being activated in downstream systems.
	// API Configs in this state cannot be used by Gateways.
	ApiConfig_ACTIVATING ApiConfig_State = 6
)

func (ApiConfig_State) Descriptor

func (ApiConfig_State) Enum

func (x ApiConfig_State) Enum() *ApiConfig_State

func (ApiConfig_State) Number

func (ApiConfig_State) String

func (x ApiConfig_State) String() string

func (ApiConfig_State) Type

type ApiConfig_builder

type ApiConfig_builder struct {

	// Output only. Resource name of the API Config.
	// Format: projects/{project}/locations/global/apis/{api}/configs/{api_config}
	Name string
	// Output only. Created time.
	CreateTime *timestamppb.Timestamp
	// Output only. Updated time.
	UpdateTime *timestamppb.Timestamp
	// Optional. Resource labels to represent user-provided metadata.
	// Refer to cloud documentation on labels for more details.
	// https://cloud.google.com/compute/docs/labeling-resources
	Labels map[string]string
	// Optional. Display name.
	DisplayName string
	// Immutable. The Google Cloud IAM Service Account that Gateways serving this
	// config should use to authenticate to other services. This may either be the
	// Service Account's email
	// (`{ACCOUNT_ID}@{PROJECT}.iam.gserviceaccount.com`) or its full resource
	// name (`projects/{PROJECT}/accounts/{UNIQUE_ID}`). This is most often used
	// when the service is a GCP resource such as a Cloud Run Service or an
	// IAP-secured service.
	GatewayServiceAccount string
	// Output only. The ID of the associated Service Config (
	// https://cloud.google.com/service-infrastructure/docs/glossary#config).
	ServiceConfigId string
	// Output only. State of the API Config.
	State ApiConfig_State
	// Optional. OpenAPI specification documents. If specified, grpc_services and
	// managed_service_configs must not be included.
	OpenapiDocuments []*ApiConfig_OpenApiDocument
	// Optional. gRPC service definition files. If specified, openapi_documents
	// must not be included.
	GrpcServices []*ApiConfig_GrpcServiceDefinition
	// Optional. Service Configuration files. At least one must be included when
	// using gRPC service definitions. See
	// https://cloud.google.com/endpoints/docs/grpc/grpc-service-config#service_configuration_overview
	// for the expected file contents.
	//
	// If multiple files are specified, the files are merged with the following
	// rules:
	// * All singular scalar fields are merged using "last one wins" semantics in
	// the order of the files uploaded.
	// * Repeated fields are concatenated.
	// * Singular embedded messages are merged using these rules for nested
	// fields.
	ManagedServiceConfigs []*ApiConfig_File
	// contains filtered or unexported fields
}

func (ApiConfig_builder) Build

func (b0 ApiConfig_builder) Build() *ApiConfig

type ApiCreatedEvent

type ApiCreatedEvent struct {

	// The data associated with the event.
	Data *ApiEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

The CloudEvent raised when an Api is created.

func (*ApiCreatedEvent) ClearData

func (x *ApiCreatedEvent) ClearData()

func (*ApiCreatedEvent) GetData

func (x *ApiCreatedEvent) GetData() *ApiEventData

func (*ApiCreatedEvent) HasData

func (x *ApiCreatedEvent) HasData() bool

func (*ApiCreatedEvent) ProtoMessage

func (*ApiCreatedEvent) ProtoMessage()

func (*ApiCreatedEvent) ProtoReflect

func (x *ApiCreatedEvent) ProtoReflect() protoreflect.Message

func (*ApiCreatedEvent) Reset

func (x *ApiCreatedEvent) Reset()

func (*ApiCreatedEvent) SetData

func (x *ApiCreatedEvent) SetData(v *ApiEventData)

func (*ApiCreatedEvent) String

func (x *ApiCreatedEvent) String() string

type ApiCreatedEvent_builder

type ApiCreatedEvent_builder struct {

	// The data associated with the event.
	Data *ApiEventData
	// contains filtered or unexported fields
}

func (ApiCreatedEvent_builder) Build

type ApiDeletedEvent

type ApiDeletedEvent struct {

	// The data associated with the event.
	Data *ApiEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

The CloudEvent raised when an Api is deleted.

func (*ApiDeletedEvent) ClearData

func (x *ApiDeletedEvent) ClearData()

func (*ApiDeletedEvent) GetData

func (x *ApiDeletedEvent) GetData() *ApiEventData

func (*ApiDeletedEvent) HasData

func (x *ApiDeletedEvent) HasData() bool

func (*ApiDeletedEvent) ProtoMessage

func (*ApiDeletedEvent) ProtoMessage()

func (*ApiDeletedEvent) ProtoReflect

func (x *ApiDeletedEvent) ProtoReflect() protoreflect.Message

func (*ApiDeletedEvent) Reset

func (x *ApiDeletedEvent) Reset()

func (*ApiDeletedEvent) SetData

func (x *ApiDeletedEvent) SetData(v *ApiEventData)

func (*ApiDeletedEvent) String

func (x *ApiDeletedEvent) String() string

type ApiDeletedEvent_builder

type ApiDeletedEvent_builder struct {

	// The data associated with the event.
	Data *ApiEventData
	// contains filtered or unexported fields
}

func (ApiDeletedEvent_builder) Build

type ApiEventData

type ApiEventData struct {

	// Optional. The Api event payload. Unset for deletion events.
	Payload *Api `protobuf:"bytes,1,opt,name=payload,proto3,oneof" json:"payload,omitempty"`
	// contains filtered or unexported fields
}

The data within all Api events.

func (*ApiEventData) ClearPayload

func (x *ApiEventData) ClearPayload()

func (*ApiEventData) GetPayload

func (x *ApiEventData) GetPayload() *Api

func (*ApiEventData) HasPayload

func (x *ApiEventData) HasPayload() bool

func (*ApiEventData) ProtoMessage

func (*ApiEventData) ProtoMessage()

func (*ApiEventData) ProtoReflect

func (x *ApiEventData) ProtoReflect() protoreflect.Message

func (*ApiEventData) Reset

func (x *ApiEventData) Reset()

func (*ApiEventData) SetPayload

func (x *ApiEventData) SetPayload(v *Api)

func (*ApiEventData) String

func (x *ApiEventData) String() string

type ApiEventData_builder

type ApiEventData_builder struct {

	// Optional. The Api event payload. Unset for deletion events.
	Payload *Api
	// contains filtered or unexported fields
}

func (ApiEventData_builder) Build

func (b0 ApiEventData_builder) Build() *ApiEventData

type ApiUpdatedEvent

type ApiUpdatedEvent struct {

	// The data associated with the event.
	Data *ApiEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

The CloudEvent raised when an Api is updated.

func (*ApiUpdatedEvent) ClearData

func (x *ApiUpdatedEvent) ClearData()

func (*ApiUpdatedEvent) GetData

func (x *ApiUpdatedEvent) GetData() *ApiEventData

func (*ApiUpdatedEvent) HasData

func (x *ApiUpdatedEvent) HasData() bool

func (*ApiUpdatedEvent) ProtoMessage

func (*ApiUpdatedEvent) ProtoMessage()

func (*ApiUpdatedEvent) ProtoReflect

func (x *ApiUpdatedEvent) ProtoReflect() protoreflect.Message

func (*ApiUpdatedEvent) Reset

func (x *ApiUpdatedEvent) Reset()

func (*ApiUpdatedEvent) SetData

func (x *ApiUpdatedEvent) SetData(v *ApiEventData)

func (*ApiUpdatedEvent) String

func (x *ApiUpdatedEvent) String() string

type ApiUpdatedEvent_builder

type ApiUpdatedEvent_builder struct {

	// The data associated with the event.
	Data *ApiEventData
	// contains filtered or unexported fields
}

func (ApiUpdatedEvent_builder) Build

type Api_State

type Api_State int32

All the possible API states.

const (
	// API does not have a state yet.
	Api_STATE_UNSPECIFIED Api_State = 0
	// API is being created.
	Api_CREATING Api_State = 1
	// API is active.
	Api_ACTIVE Api_State = 2
	// API creation failed.
	Api_FAILED Api_State = 3
	// API is being deleted.
	Api_DELETING Api_State = 4
	// API is being updated.
	Api_UPDATING Api_State = 5
)

func (Api_State) Descriptor

func (Api_State) Descriptor() protoreflect.EnumDescriptor

func (Api_State) Enum

func (x Api_State) Enum() *Api_State

func (Api_State) Number

func (x Api_State) Number() protoreflect.EnumNumber

func (Api_State) String

func (x Api_State) String() string

func (Api_State) Type

type Api_builder

type Api_builder struct {

	// Output only. Resource name of the API.
	// Format: projects/{project}/locations/global/apis/{api}
	Name string
	// Output only. Created time.
	CreateTime *timestamppb.Timestamp
	// Output only. Updated time.
	UpdateTime *timestamppb.Timestamp
	// Optional. Resource labels to represent user-provided metadata.
	// Refer to cloud documentation on labels for more details.
	// https://cloud.google.com/compute/docs/labeling-resources
	Labels map[string]string
	// Optional. Display name.
	DisplayName string
	// Optional. Immutable. The name of a Google Managed Service (
	// https://cloud.google.com/service-infrastructure/docs/glossary#managed).
	// If not specified, a new Service will automatically be created in the same
	// project as this API.
	ManagedService string
	// Output only. State of the API.
	State Api_State
	// contains filtered or unexported fields
}

func (Api_builder) Build

func (b0 Api_builder) Build() *Api

type Gateway

type Gateway struct {

	// Output only. Resource name of the Gateway.
	// Format: projects/{project}/locations/{location}/gateways/{gateway}
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Output only. Created time.
	CreateTime *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
	// Output only. Updated time.
	UpdateTime *timestamppb.Timestamp `protobuf:"bytes,3,opt,name=update_time,json=updateTime,proto3" json:"update_time,omitempty"`
	// Optional. Resource labels to represent user-provided metadata.
	// Refer to cloud documentation on labels for more details.
	// https://cloud.google.com/compute/docs/labeling-resources
	Labels map[string]string `` /* 139-byte string literal not displayed */
	// Optional. Display name.
	DisplayName string `protobuf:"bytes,5,opt,name=display_name,json=displayName,proto3" json:"display_name,omitempty"`
	// Required. Resource name of the API Config for this Gateway.
	// Format: projects/{project}/locations/global/apis/{api}/configs/{apiConfig}
	ApiConfig string `protobuf:"bytes,6,opt,name=api_config,json=apiConfig,proto3" json:"api_config,omitempty"`
	// Output only. The current state of the Gateway.
	State Gateway_State `protobuf:"varint,7,opt,name=state,proto3,enum=google.events.cloud.apigateway.v1.Gateway_State" json:"state,omitempty"`
	// Output only. The default API Gateway host name of the form
	// `{gateway_id}-{hash}.{region_code}.gateway.dev`.
	DefaultHostname string `protobuf:"bytes,9,opt,name=default_hostname,json=defaultHostname,proto3" json:"default_hostname,omitempty"`
	// contains filtered or unexported fields
}

A Gateway is an API-aware HTTP proxy. It performs API-Method and/or API-Consumer specific actions based on an API Config such as authentication, policy enforcement, and backend selection.

func (*Gateway) ClearCreateTime

func (x *Gateway) ClearCreateTime()

func (*Gateway) ClearUpdateTime

func (x *Gateway) ClearUpdateTime()

func (*Gateway) GetApiConfig

func (x *Gateway) GetApiConfig() string

func (*Gateway) GetCreateTime

func (x *Gateway) GetCreateTime() *timestamppb.Timestamp

func (*Gateway) GetDefaultHostname

func (x *Gateway) GetDefaultHostname() string

func (*Gateway) GetDisplayName

func (x *Gateway) GetDisplayName() string

func (*Gateway) GetLabels

func (x *Gateway) GetLabels() map[string]string

func (*Gateway) GetName

func (x *Gateway) GetName() string

func (*Gateway) GetState

func (x *Gateway) GetState() Gateway_State

func (*Gateway) GetUpdateTime

func (x *Gateway) GetUpdateTime() *timestamppb.Timestamp

func (*Gateway) HasCreateTime

func (x *Gateway) HasCreateTime() bool

func (*Gateway) HasUpdateTime

func (x *Gateway) HasUpdateTime() bool

func (*Gateway) ProtoMessage

func (*Gateway) ProtoMessage()

func (*Gateway) ProtoReflect

func (x *Gateway) ProtoReflect() protoreflect.Message

func (*Gateway) Reset

func (x *Gateway) Reset()

func (*Gateway) SetApiConfig

func (x *Gateway) SetApiConfig(v string)

func (*Gateway) SetCreateTime

func (x *Gateway) SetCreateTime(v *timestamppb.Timestamp)

func (*Gateway) SetDefaultHostname

func (x *Gateway) SetDefaultHostname(v string)

func (*Gateway) SetDisplayName

func (x *Gateway) SetDisplayName(v string)

func (*Gateway) SetLabels

func (x *Gateway) SetLabels(v map[string]string)

func (*Gateway) SetName

func (x *Gateway) SetName(v string)

func (*Gateway) SetState

func (x *Gateway) SetState(v Gateway_State)

func (*Gateway) SetUpdateTime

func (x *Gateway) SetUpdateTime(v *timestamppb.Timestamp)

func (*Gateway) String

func (x *Gateway) String() string

type GatewayCreatedEvent

type GatewayCreatedEvent struct {

	// The data associated with the event.
	Data *GatewayEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

The CloudEvent raised when a Gateway is created.

func (*GatewayCreatedEvent) ClearData

func (x *GatewayCreatedEvent) ClearData()

func (*GatewayCreatedEvent) GetData

func (x *GatewayCreatedEvent) GetData() *GatewayEventData

func (*GatewayCreatedEvent) HasData

func (x *GatewayCreatedEvent) HasData() bool

func (*GatewayCreatedEvent) ProtoMessage

func (*GatewayCreatedEvent) ProtoMessage()

func (*GatewayCreatedEvent) ProtoReflect

func (x *GatewayCreatedEvent) ProtoReflect() protoreflect.Message

func (*GatewayCreatedEvent) Reset

func (x *GatewayCreatedEvent) Reset()

func (*GatewayCreatedEvent) SetData

func (x *GatewayCreatedEvent) SetData(v *GatewayEventData)

func (*GatewayCreatedEvent) String

func (x *GatewayCreatedEvent) String() string

type GatewayCreatedEvent_builder

type GatewayCreatedEvent_builder struct {

	// The data associated with the event.
	Data *GatewayEventData
	// contains filtered or unexported fields
}

func (GatewayCreatedEvent_builder) Build

type GatewayDeletedEvent

type GatewayDeletedEvent struct {

	// The data associated with the event.
	Data *GatewayEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

The CloudEvent raised when a Gateway is deleted.

func (*GatewayDeletedEvent) ClearData

func (x *GatewayDeletedEvent) ClearData()

func (*GatewayDeletedEvent) GetData

func (x *GatewayDeletedEvent) GetData() *GatewayEventData

func (*GatewayDeletedEvent) HasData

func (x *GatewayDeletedEvent) HasData() bool

func (*GatewayDeletedEvent) ProtoMessage

func (*GatewayDeletedEvent) ProtoMessage()

func (*GatewayDeletedEvent) ProtoReflect

func (x *GatewayDeletedEvent) ProtoReflect() protoreflect.Message

func (*GatewayDeletedEvent) Reset

func (x *GatewayDeletedEvent) Reset()

func (*GatewayDeletedEvent) SetData

func (x *GatewayDeletedEvent) SetData(v *GatewayEventData)

func (*GatewayDeletedEvent) String

func (x *GatewayDeletedEvent) String() string

type GatewayDeletedEvent_builder

type GatewayDeletedEvent_builder struct {

	// The data associated with the event.
	Data *GatewayEventData
	// contains filtered or unexported fields
}

func (GatewayDeletedEvent_builder) Build

type GatewayEventData

type GatewayEventData struct {

	// Optional. The Gateway event payload. Unset for deletion events.
	Payload *Gateway `protobuf:"bytes,1,opt,name=payload,proto3,oneof" json:"payload,omitempty"`
	// contains filtered or unexported fields
}

The data within all Gateway events.

func (*GatewayEventData) ClearPayload

func (x *GatewayEventData) ClearPayload()

func (*GatewayEventData) GetPayload

func (x *GatewayEventData) GetPayload() *Gateway

func (*GatewayEventData) HasPayload

func (x *GatewayEventData) HasPayload() bool

func (*GatewayEventData) ProtoMessage

func (*GatewayEventData) ProtoMessage()

func (*GatewayEventData) ProtoReflect

func (x *GatewayEventData) ProtoReflect() protoreflect.Message

func (*GatewayEventData) Reset

func (x *GatewayEventData) Reset()

func (*GatewayEventData) SetPayload

func (x *GatewayEventData) SetPayload(v *Gateway)

func (*GatewayEventData) String

func (x *GatewayEventData) String() string

type GatewayEventData_builder

type GatewayEventData_builder struct {

	// Optional. The Gateway event payload. Unset for deletion events.
	Payload *Gateway
	// contains filtered or unexported fields
}

func (GatewayEventData_builder) Build

type GatewayUpdatedEvent

type GatewayUpdatedEvent struct {

	// The data associated with the event.
	Data *GatewayEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

The CloudEvent raised when a Gateway is updated.

func (*GatewayUpdatedEvent) ClearData

func (x *GatewayUpdatedEvent) ClearData()

func (*GatewayUpdatedEvent) GetData

func (x *GatewayUpdatedEvent) GetData() *GatewayEventData

func (*GatewayUpdatedEvent) HasData

func (x *GatewayUpdatedEvent) HasData() bool

func (*GatewayUpdatedEvent) ProtoMessage

func (*GatewayUpdatedEvent) ProtoMessage()

func (*GatewayUpdatedEvent) ProtoReflect

func (x *GatewayUpdatedEvent) ProtoReflect() protoreflect.Message

func (*GatewayUpdatedEvent) Reset

func (x *GatewayUpdatedEvent) Reset()

func (*GatewayUpdatedEvent) SetData

func (x *GatewayUpdatedEvent) SetData(v *GatewayEventData)

func (*GatewayUpdatedEvent) String

func (x *GatewayUpdatedEvent) String() string

type GatewayUpdatedEvent_builder

type GatewayUpdatedEvent_builder struct {

	// The data associated with the event.
	Data *GatewayEventData
	// contains filtered or unexported fields
}

func (GatewayUpdatedEvent_builder) Build

type Gateway_State

type Gateway_State int32

All the possible Gateway states.

const (
	// Gateway does not have a state yet.
	Gateway_STATE_UNSPECIFIED Gateway_State = 0
	// Gateway is being created.
	Gateway_CREATING Gateway_State = 1
	// Gateway is running and ready for requests.
	Gateway_ACTIVE Gateway_State = 2
	// Gateway creation failed.
	Gateway_FAILED Gateway_State = 3
	// Gateway is being deleted.
	Gateway_DELETING Gateway_State = 4
	// Gateway is being updated.
	Gateway_UPDATING Gateway_State = 5
)

func (Gateway_State) Descriptor

func (Gateway_State) Enum

func (x Gateway_State) Enum() *Gateway_State

func (Gateway_State) Number

func (Gateway_State) String

func (x Gateway_State) String() string

func (Gateway_State) Type

type Gateway_builder

type Gateway_builder struct {

	// Output only. Resource name of the Gateway.
	// Format: projects/{project}/locations/{location}/gateways/{gateway}
	Name string
	// Output only. Created time.
	CreateTime *timestamppb.Timestamp
	// Output only. Updated time.
	UpdateTime *timestamppb.Timestamp
	// Optional. Resource labels to represent user-provided metadata.
	// Refer to cloud documentation on labels for more details.
	// https://cloud.google.com/compute/docs/labeling-resources
	Labels map[string]string
	// Optional. Display name.
	DisplayName string
	// Required. Resource name of the API Config for this Gateway.
	// Format: projects/{project}/locations/global/apis/{api}/configs/{apiConfig}
	ApiConfig string
	// Output only. The current state of the Gateway.
	State Gateway_State
	// Output only. The default API Gateway host name of the form
	// `{gateway_id}-{hash}.{region_code}.gateway.dev`.
	DefaultHostname string
	// contains filtered or unexported fields
}

func (Gateway_builder) Build

func (b0 Gateway_builder) Build() *Gateway

Source Files

  • data.pb.go
  • events.pb.go

Jump to