auditv1

package
v1.36.11-2024050211440... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 10 Imported by: 0

Documentation

Index

Constants

const ServiceAccountDelegationInfo_Authority_not_set_case case_ServiceAccountDelegationInfo_Authority = 0
const ServiceAccountDelegationInfo_FirstPartyPrincipal_case case_ServiceAccountDelegationInfo_Authority = 1
const ServiceAccountDelegationInfo_ThirdPartyPrincipal_case case_ServiceAccountDelegationInfo_Authority = 2

Variables

var (
	LogSeverity_name = map[int32]string{
		0:   "DEFAULT",
		100: "DEBUG",
		200: "INFO",
		300: "NOTICE",
		400: "WARNING",
		500: "ERROR",
		600: "CRITICAL",
		700: "ALERT",
		800: "EMERGENCY",
	}
	LogSeverity_value = map[string]int32{
		"DEFAULT":   0,
		"DEBUG":     100,
		"INFO":      200,
		"NOTICE":    300,
		"WARNING":   400,
		"ERROR":     500,
		"CRITICAL":  600,
		"ALERT":     700,
		"EMERGENCY": 800,
	}
)

Enum value maps for LogSeverity.

var File_google_events_cloud_audit_v1_data_proto protoreflect.FileDescriptor
var File_google_events_cloud_audit_v1_events_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type AuditLog

type AuditLog struct {

	// The name of the API service performing the operation. For example,
	// `"datastore.googleapis.com"`.
	ServiceName string `protobuf:"bytes,7,opt,name=service_name,json=serviceName,proto3" json:"service_name,omitempty"`
	// The name of the service method or operation.
	// For API calls, this should be the name of the API method.
	// For example,
	//
	//	"google.datastore.v1.Datastore.RunQuery"
	//	"google.logging.v1.LoggingService.DeleteLog"
	MethodName string `protobuf:"bytes,8,opt,name=method_name,json=methodName,proto3" json:"method_name,omitempty"`
	// The resource or collection that is the target of the operation.
	// The name is a scheme-less URI, not including the API service name.
	// For example:
	//
	//	"shelves/SHELF_ID/books"
	//	"shelves/SHELF_ID/books/BOOK_ID"
	ResourceName string `protobuf:"bytes,11,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	// The resource location information.
	ResourceLocation *ResourceLocation `protobuf:"bytes,20,opt,name=resource_location,json=resourceLocation,proto3" json:"resource_location,omitempty"`
	// The resource's original state before mutation. Present only for
	// operations which have successfully modified the targeted resource(s).
	// In general, this field should contain all changed fields, except those
	// that are already been included in `request`, `response`, `metadata` or
	// `service_data` fields.
	// When the JSON object represented here has a proto equivalent,
	// the proto name will be indicated in the `@type` property.
	ResourceOriginalState *structpb.Struct `` /* 127-byte string literal not displayed */
	// The number of items returned from a List or Query API method,
	// if applicable.
	NumResponseItems int64 `protobuf:"varint,12,opt,name=num_response_items,json=numResponseItems,proto3" json:"num_response_items,omitempty"`
	// The status of the overall operation.
	Status *status.Status `protobuf:"bytes,2,opt,name=status,proto3" json:"status,omitempty"`
	// Authentication information.
	AuthenticationInfo *AuthenticationInfo `protobuf:"bytes,3,opt,name=authentication_info,json=authenticationInfo,proto3" json:"authentication_info,omitempty"`
	// Authorization information. If there are multiple
	// resources or permissions involved, then there is
	// one AuthorizationInfo element for each {resource, permission} tuple.
	AuthorizationInfo []*AuthorizationInfo `protobuf:"bytes,9,rep,name=authorization_info,json=authorizationInfo,proto3" json:"authorization_info,omitempty"`
	// Metadata about the operation.
	RequestMetadata *RequestMetadata `protobuf:"bytes,4,opt,name=request_metadata,json=requestMetadata,proto3" json:"request_metadata,omitempty"`
	// The operation request. This may not include all request parameters,
	// such as those that are too large, privacy-sensitive, or duplicated
	// elsewhere in the log record.
	// It should never include user-generated data, such as file contents.
	// When the JSON object represented here has a proto equivalent, the proto
	// name will be indicated in the `@type` property.
	Request *structpb.Struct `protobuf:"bytes,16,opt,name=request,proto3" json:"request,omitempty"`
	// The operation response. This may not include all response elements,
	// such as those that are too large, privacy-sensitive, or duplicated
	// elsewhere in the log record.
	// It should never include user-generated data, such as file contents.
	// When the JSON object represented here has a proto equivalent, the proto
	// name will be indicated in the `@type` property.
	Response *structpb.Struct `protobuf:"bytes,17,opt,name=response,proto3" json:"response,omitempty"`
	// Other service-specific data about the request, response, and other
	// information associated with the current audited event.
	Metadata *structpb.Struct `protobuf:"bytes,18,opt,name=metadata,proto3" json:"metadata,omitempty"`
	// Deprecated: Use `metadata` field instead.
	// Other service-specific data about the request, response, and other
	// activities.
	// When the JSON object represented here has a proto equivalent, the proto
	// name will be indicated in the `@type` property.
	ServiceData *structpb.Struct `protobuf:"bytes,15,opt,name=service_data,json=serviceData,proto3" json:"service_data,omitempty"`
	// contains filtered or unexported fields
}

Common audit log format for Google Cloud Platform API operations. Copied from https://github.com/googleapis/googleapis/blob/master/google/cloud/audit/audit_log.proto, but changing service_data from Any to Struct.

func (*AuditLog) ClearAuthenticationInfo

func (x *AuditLog) ClearAuthenticationInfo()

func (*AuditLog) ClearMetadata

func (x *AuditLog) ClearMetadata()

func (*AuditLog) ClearRequest

func (x *AuditLog) ClearRequest()

func (*AuditLog) ClearRequestMetadata

func (x *AuditLog) ClearRequestMetadata()

func (*AuditLog) ClearResourceLocation

func (x *AuditLog) ClearResourceLocation()

func (*AuditLog) ClearResourceOriginalState

func (x *AuditLog) ClearResourceOriginalState()

func (*AuditLog) ClearResponse

func (x *AuditLog) ClearResponse()

func (*AuditLog) ClearServiceData

func (x *AuditLog) ClearServiceData()

func (*AuditLog) ClearStatus

func (x *AuditLog) ClearStatus()

func (*AuditLog) GetAuthenticationInfo

func (x *AuditLog) GetAuthenticationInfo() *AuthenticationInfo

func (*AuditLog) GetAuthorizationInfo

func (x *AuditLog) GetAuthorizationInfo() []*AuthorizationInfo

func (*AuditLog) GetMetadata

func (x *AuditLog) GetMetadata() *structpb.Struct

func (*AuditLog) GetMethodName

func (x *AuditLog) GetMethodName() string

func (*AuditLog) GetNumResponseItems

func (x *AuditLog) GetNumResponseItems() int64

func (*AuditLog) GetRequest

func (x *AuditLog) GetRequest() *structpb.Struct

func (*AuditLog) GetRequestMetadata

func (x *AuditLog) GetRequestMetadata() *RequestMetadata

func (*AuditLog) GetResourceLocation

func (x *AuditLog) GetResourceLocation() *ResourceLocation

func (*AuditLog) GetResourceName

func (x *AuditLog) GetResourceName() string

func (*AuditLog) GetResourceOriginalState

func (x *AuditLog) GetResourceOriginalState() *structpb.Struct

func (*AuditLog) GetResponse

func (x *AuditLog) GetResponse() *structpb.Struct

func (*AuditLog) GetServiceData

func (x *AuditLog) GetServiceData() *structpb.Struct

func (*AuditLog) GetServiceName

func (x *AuditLog) GetServiceName() string

func (*AuditLog) GetStatus

func (x *AuditLog) GetStatus() *status.Status

func (*AuditLog) HasAuthenticationInfo

func (x *AuditLog) HasAuthenticationInfo() bool

func (*AuditLog) HasMetadata

func (x *AuditLog) HasMetadata() bool

func (*AuditLog) HasRequest

func (x *AuditLog) HasRequest() bool

func (*AuditLog) HasRequestMetadata

func (x *AuditLog) HasRequestMetadata() bool

func (*AuditLog) HasResourceLocation

func (x *AuditLog) HasResourceLocation() bool

func (*AuditLog) HasResourceOriginalState

func (x *AuditLog) HasResourceOriginalState() bool

func (*AuditLog) HasResponse

func (x *AuditLog) HasResponse() bool

func (*AuditLog) HasServiceData

func (x *AuditLog) HasServiceData() bool

func (*AuditLog) HasStatus

func (x *AuditLog) HasStatus() bool

func (*AuditLog) ProtoMessage

func (*AuditLog) ProtoMessage()

func (*AuditLog) ProtoReflect

func (x *AuditLog) ProtoReflect() protoreflect.Message

func (*AuditLog) Reset

func (x *AuditLog) Reset()

func (*AuditLog) SetAuthenticationInfo

func (x *AuditLog) SetAuthenticationInfo(v *AuthenticationInfo)

func (*AuditLog) SetAuthorizationInfo

func (x *AuditLog) SetAuthorizationInfo(v []*AuthorizationInfo)

func (*AuditLog) SetMetadata

func (x *AuditLog) SetMetadata(v *structpb.Struct)

func (*AuditLog) SetMethodName

func (x *AuditLog) SetMethodName(v string)

func (*AuditLog) SetNumResponseItems

func (x *AuditLog) SetNumResponseItems(v int64)

func (*AuditLog) SetRequest

func (x *AuditLog) SetRequest(v *structpb.Struct)

func (*AuditLog) SetRequestMetadata

func (x *AuditLog) SetRequestMetadata(v *RequestMetadata)

func (*AuditLog) SetResourceLocation

func (x *AuditLog) SetResourceLocation(v *ResourceLocation)

func (*AuditLog) SetResourceName

func (x *AuditLog) SetResourceName(v string)

func (*AuditLog) SetResourceOriginalState

func (x *AuditLog) SetResourceOriginalState(v *structpb.Struct)

func (*AuditLog) SetResponse

func (x *AuditLog) SetResponse(v *structpb.Struct)

func (*AuditLog) SetServiceData

func (x *AuditLog) SetServiceData(v *structpb.Struct)

func (*AuditLog) SetServiceName

func (x *AuditLog) SetServiceName(v string)

func (*AuditLog) SetStatus

func (x *AuditLog) SetStatus(v *status.Status)

func (*AuditLog) String

func (x *AuditLog) String() string

type AuditLogWrittenEvent

type AuditLogWrittenEvent struct {

	// The data associated with the event.
	Data *LogEntryData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

The CloudEvent raised when an audit log entry is written.

func (*AuditLogWrittenEvent) ClearData

func (x *AuditLogWrittenEvent) ClearData()

func (*AuditLogWrittenEvent) GetData

func (x *AuditLogWrittenEvent) GetData() *LogEntryData

func (*AuditLogWrittenEvent) HasData

func (x *AuditLogWrittenEvent) HasData() bool

func (*AuditLogWrittenEvent) ProtoMessage

func (*AuditLogWrittenEvent) ProtoMessage()

func (*AuditLogWrittenEvent) ProtoReflect

func (x *AuditLogWrittenEvent) ProtoReflect() protoreflect.Message

func (*AuditLogWrittenEvent) Reset

func (x *AuditLogWrittenEvent) Reset()

func (*AuditLogWrittenEvent) SetData

func (x *AuditLogWrittenEvent) SetData(v *LogEntryData)

func (*AuditLogWrittenEvent) String

func (x *AuditLogWrittenEvent) String() string

type AuditLogWrittenEvent_builder

type AuditLogWrittenEvent_builder struct {

	// The data associated with the event.
	Data *LogEntryData
	// contains filtered or unexported fields
}

func (AuditLogWrittenEvent_builder) Build

type AuditLog_builder

type AuditLog_builder struct {

	// The name of the API service performing the operation. For example,
	// `"datastore.googleapis.com"`.
	ServiceName string
	// The name of the service method or operation.
	// For API calls, this should be the name of the API method.
	// For example,
	//
	//	"google.datastore.v1.Datastore.RunQuery"
	//	"google.logging.v1.LoggingService.DeleteLog"
	MethodName string
	// The resource or collection that is the target of the operation.
	// The name is a scheme-less URI, not including the API service name.
	// For example:
	//
	//	"shelves/SHELF_ID/books"
	//	"shelves/SHELF_ID/books/BOOK_ID"
	ResourceName string
	// The resource location information.
	ResourceLocation *ResourceLocation
	// The resource's original state before mutation. Present only for
	// operations which have successfully modified the targeted resource(s).
	// In general, this field should contain all changed fields, except those
	// that are already been included in `request`, `response`, `metadata` or
	// `service_data` fields.
	// When the JSON object represented here has a proto equivalent,
	// the proto name will be indicated in the `@type` property.
	ResourceOriginalState *structpb.Struct
	// The number of items returned from a List or Query API method,
	// if applicable.
	NumResponseItems int64
	// The status of the overall operation.
	Status *status.Status
	// Authentication information.
	AuthenticationInfo *AuthenticationInfo
	// Authorization information. If there are multiple
	// resources or permissions involved, then there is
	// one AuthorizationInfo element for each {resource, permission} tuple.
	AuthorizationInfo []*AuthorizationInfo
	// Metadata about the operation.
	RequestMetadata *RequestMetadata
	// The operation request. This may not include all request parameters,
	// such as those that are too large, privacy-sensitive, or duplicated
	// elsewhere in the log record.
	// It should never include user-generated data, such as file contents.
	// When the JSON object represented here has a proto equivalent, the proto
	// name will be indicated in the `@type` property.
	Request *structpb.Struct
	// The operation response. This may not include all response elements,
	// such as those that are too large, privacy-sensitive, or duplicated
	// elsewhere in the log record.
	// It should never include user-generated data, such as file contents.
	// When the JSON object represented here has a proto equivalent, the proto
	// name will be indicated in the `@type` property.
	Response *structpb.Struct
	// Other service-specific data about the request, response, and other
	// information associated with the current audited event.
	Metadata *structpb.Struct
	// Deprecated: Use `metadata` field instead.
	// Other service-specific data about the request, response, and other
	// activities.
	// When the JSON object represented here has a proto equivalent, the proto
	// name will be indicated in the `@type` property.
	ServiceData *structpb.Struct
	// contains filtered or unexported fields
}

func (AuditLog_builder) Build

func (b0 AuditLog_builder) Build() *AuditLog

type AuthenticationInfo

type AuthenticationInfo struct {

	// The email address of the authenticated user (or service account on behalf
	// of third party principal) making the request. For third party identity
	// callers, the `principal_subject` field is populated instead of this field.
	// For privacy reasons, the principal email address is sometimes redacted.
	// For more information, see [Caller identities in audit
	// logs](https://cloud.google.com/logging/docs/audit#user-id).
	PrincipalEmail string `protobuf:"bytes,1,opt,name=principal_email,json=principalEmail,proto3" json:"principal_email,omitempty"`
	// The authority selector specified by the requestor, if any.
	// It is not guaranteed that the principal was allowed to use this authority.
	AuthoritySelector string `protobuf:"bytes,2,opt,name=authority_selector,json=authoritySelector,proto3" json:"authority_selector,omitempty"`
	// The third party identification (if any) of the authenticated user making
	// the request.
	// When the JSON object represented here has a proto equivalent, the proto
	// name will be indicated in the `@type` property.
	ThirdPartyPrincipal *structpb.Struct `protobuf:"bytes,4,opt,name=third_party_principal,json=thirdPartyPrincipal,proto3" json:"third_party_principal,omitempty"`
	// The name of the service account key used to create or exchange
	// credentials for authenticating the service account making the request.
	// This is a scheme-less URI full resource name. For example:
	//
	// "//iam.googleapis.com/projects/{PROJECT_ID}/serviceAccounts/{ACCOUNT}/keys/{key}"
	ServiceAccountKeyName string `` /* 128-byte string literal not displayed */
	// Identity delegation history of an authenticated service account that makes
	// the request. It contains information on the real authorities that try to
	// access GCP resources by delegating on a service account. When multiple
	// authorities present, they are guaranteed to be sorted based on the original
	// ordering of the identity delegation events.
	ServiceAccountDelegationInfo []*ServiceAccountDelegationInfo `` /* 149-byte string literal not displayed */
	// String representation of identity of requesting party.
	// Populated for both first and third party identities.
	PrincipalSubject string `protobuf:"bytes,8,opt,name=principal_subject,json=principalSubject,proto3" json:"principal_subject,omitempty"`
	// contains filtered or unexported fields
}

Authentication information for the operation.

func (*AuthenticationInfo) ClearThirdPartyPrincipal

func (x *AuthenticationInfo) ClearThirdPartyPrincipal()

func (*AuthenticationInfo) GetAuthoritySelector

func (x *AuthenticationInfo) GetAuthoritySelector() string

func (*AuthenticationInfo) GetPrincipalEmail

func (x *AuthenticationInfo) GetPrincipalEmail() string

func (*AuthenticationInfo) GetPrincipalSubject

func (x *AuthenticationInfo) GetPrincipalSubject() string

func (*AuthenticationInfo) GetServiceAccountDelegationInfo

func (x *AuthenticationInfo) GetServiceAccountDelegationInfo() []*ServiceAccountDelegationInfo

func (*AuthenticationInfo) GetServiceAccountKeyName

func (x *AuthenticationInfo) GetServiceAccountKeyName() string

func (*AuthenticationInfo) GetThirdPartyPrincipal

func (x *AuthenticationInfo) GetThirdPartyPrincipal() *structpb.Struct

func (*AuthenticationInfo) HasThirdPartyPrincipal

func (x *AuthenticationInfo) HasThirdPartyPrincipal() bool

func (*AuthenticationInfo) ProtoMessage

func (*AuthenticationInfo) ProtoMessage()

func (*AuthenticationInfo) ProtoReflect

func (x *AuthenticationInfo) ProtoReflect() protoreflect.Message

func (*AuthenticationInfo) Reset

func (x *AuthenticationInfo) Reset()

func (*AuthenticationInfo) SetAuthoritySelector

func (x *AuthenticationInfo) SetAuthoritySelector(v string)

func (*AuthenticationInfo) SetPrincipalEmail

func (x *AuthenticationInfo) SetPrincipalEmail(v string)

func (*AuthenticationInfo) SetPrincipalSubject

func (x *AuthenticationInfo) SetPrincipalSubject(v string)

func (*AuthenticationInfo) SetServiceAccountDelegationInfo

func (x *AuthenticationInfo) SetServiceAccountDelegationInfo(v []*ServiceAccountDelegationInfo)

func (*AuthenticationInfo) SetServiceAccountKeyName

func (x *AuthenticationInfo) SetServiceAccountKeyName(v string)

func (*AuthenticationInfo) SetThirdPartyPrincipal

func (x *AuthenticationInfo) SetThirdPartyPrincipal(v *structpb.Struct)

func (*AuthenticationInfo) String

func (x *AuthenticationInfo) String() string

type AuthenticationInfo_builder

type AuthenticationInfo_builder struct {

	// The email address of the authenticated user (or service account on behalf
	// of third party principal) making the request. For third party identity
	// callers, the `principal_subject` field is populated instead of this field.
	// For privacy reasons, the principal email address is sometimes redacted.
	// For more information, see [Caller identities in audit
	// logs](https://cloud.google.com/logging/docs/audit#user-id).
	PrincipalEmail string
	// The authority selector specified by the requestor, if any.
	// It is not guaranteed that the principal was allowed to use this authority.
	AuthoritySelector string
	// The third party identification (if any) of the authenticated user making
	// the request.
	// When the JSON object represented here has a proto equivalent, the proto
	// name will be indicated in the `@type` property.
	ThirdPartyPrincipal *structpb.Struct
	// The name of the service account key used to create or exchange
	// credentials for authenticating the service account making the request.
	// This is a scheme-less URI full resource name. For example:
	//
	// "//iam.googleapis.com/projects/{PROJECT_ID}/serviceAccounts/{ACCOUNT}/keys/{key}"
	ServiceAccountKeyName string
	// Identity delegation history of an authenticated service account that makes
	// the request. It contains information on the real authorities that try to
	// access GCP resources by delegating on a service account. When multiple
	// authorities present, they are guaranteed to be sorted based on the original
	// ordering of the identity delegation events.
	ServiceAccountDelegationInfo []*ServiceAccountDelegationInfo
	// String representation of identity of requesting party.
	// Populated for both first and third party identities.
	PrincipalSubject string
	// contains filtered or unexported fields
}

func (AuthenticationInfo_builder) Build

type AuthorizationInfo

type AuthorizationInfo struct {

	// The resource being accessed, as a REST-style string. For example:
	//
	//	bigquery.googleapis.com/projects/PROJECTID/datasets/DATASETID
	Resource string `protobuf:"bytes,1,opt,name=resource,proto3" json:"resource,omitempty"`
	// The required IAM permission.
	Permission string `protobuf:"bytes,2,opt,name=permission,proto3" json:"permission,omitempty"`
	// Whether or not authorization for `resource` and `permission`
	// was granted.
	Granted bool `protobuf:"varint,3,opt,name=granted,proto3" json:"granted,omitempty"`
	// Resource attributes used in IAM condition evaluation. This field contains
	// resource attributes like resource type and resource name.
	//
	// To get the whole view of the attributes used in IAM
	// condition evaluation, the user must also look into
	// `AuditLogData.request_metadata.request_attributes`.
	ResourceAttributes *attribute_context.AttributeContext_Resource `protobuf:"bytes,5,opt,name=resource_attributes,json=resourceAttributes,proto3" json:"resource_attributes,omitempty"`
	// contains filtered or unexported fields
}

Authorization information for the operation.

func (*AuthorizationInfo) ClearResourceAttributes

func (x *AuthorizationInfo) ClearResourceAttributes()

func (*AuthorizationInfo) GetGranted

func (x *AuthorizationInfo) GetGranted() bool

func (*AuthorizationInfo) GetPermission

func (x *AuthorizationInfo) GetPermission() string

func (*AuthorizationInfo) GetResource

func (x *AuthorizationInfo) GetResource() string

func (*AuthorizationInfo) GetResourceAttributes

func (*AuthorizationInfo) HasResourceAttributes

func (x *AuthorizationInfo) HasResourceAttributes() bool

func (*AuthorizationInfo) ProtoMessage

func (*AuthorizationInfo) ProtoMessage()

func (*AuthorizationInfo) ProtoReflect

func (x *AuthorizationInfo) ProtoReflect() protoreflect.Message

func (*AuthorizationInfo) Reset

func (x *AuthorizationInfo) Reset()

func (*AuthorizationInfo) SetGranted

func (x *AuthorizationInfo) SetGranted(v bool)

func (*AuthorizationInfo) SetPermission

func (x *AuthorizationInfo) SetPermission(v string)

func (*AuthorizationInfo) SetResource

func (x *AuthorizationInfo) SetResource(v string)

func (*AuthorizationInfo) SetResourceAttributes

func (x *AuthorizationInfo) SetResourceAttributes(v *attribute_context.AttributeContext_Resource)

func (*AuthorizationInfo) String

func (x *AuthorizationInfo) String() string

type AuthorizationInfo_builder

type AuthorizationInfo_builder struct {

	// The resource being accessed, as a REST-style string. For example:
	//
	//	bigquery.googleapis.com/projects/PROJECTID/datasets/DATASETID
	Resource string
	// The required IAM permission.
	Permission string
	// Whether or not authorization for `resource` and `permission`
	// was granted.
	Granted bool
	// Resource attributes used in IAM condition evaluation. This field contains
	// resource attributes like resource type and resource name.
	//
	// To get the whole view of the attributes used in IAM
	// condition evaluation, the user must also look into
	// `AuditLogData.request_metadata.request_attributes`.
	ResourceAttributes *attribute_context.AttributeContext_Resource
	// contains filtered or unexported fields
}

func (AuthorizationInfo_builder) Build

type LogEntryData

type LogEntryData struct {

	// The resource name of the log to which this log entry belongs.
	LogName string `protobuf:"bytes,12,opt,name=log_name,json=logName,proto3" json:"log_name,omitempty"`
	// The monitored resource that produced this log entry.
	//
	// Example: a log entry that reports a database error would be associated with
	// the monitored resource designating the particular database that reported
	// the error.
	Resource *api.MonitoredResource `protobuf:"bytes,8,opt,name=resource,proto3" json:"resource,omitempty"`
	// The log entry payload, which is always an AuditLog for Cloud Audit Log
	// events.
	ProtoPayload *AuditLog `protobuf:"bytes,2,opt,name=proto_payload,json=protoPayload,proto3" json:"proto_payload,omitempty"`
	// A unique identifier for the log entry.
	InsertId string `protobuf:"bytes,4,opt,name=insert_id,json=insertId,proto3" json:"insert_id,omitempty"`
	// A set of user-defined (key, value) data that provides additional
	// information about the log entry.
	Labels map[string]string `` /* 140-byte string literal not displayed */
	// Information about an operation associated with the log entry, if
	// applicable.
	Operation *LogEntryOperation `protobuf:"bytes,15,opt,name=operation,proto3" json:"operation,omitempty"`
	// The time the event described by the log entry occurred.
	Timestamp *timestamppb.Timestamp `protobuf:"bytes,9,opt,name=timestamp,proto3" json:"timestamp,omitempty"`
	// The time the log entry was received by Logging.
	ReceiveTimestamp *timestamppb.Timestamp `protobuf:"bytes,24,opt,name=receive_timestamp,json=receiveTimestamp,proto3" json:"receive_timestamp,omitempty"`
	// The severity of the log entry.
	Severity LogSeverity `protobuf:"varint,10,opt,name=severity,proto3,enum=google.events.cloud.audit.v1.LogSeverity" json:"severity,omitempty"`
	// Resource name of the trace associated with the log entry, if any. If it
	// contains a relative resource name, the name is assumed to be relative to
	// `//tracing.googleapis.com`. Example:
	// `projects/my-projectid/traces/06796866738c859f2f19b7cfb3214824`
	Trace string `protobuf:"bytes,22,opt,name=trace,proto3" json:"trace,omitempty"`
	// The span ID within the trace associated with the log entry, if any.
	//
	// For Trace spans, this is the same format that the Trace API v2 uses: a
	// 16-character hexadecimal encoding of an 8-byte array, such as
	// `000000000000004a`.
	SpanId string `protobuf:"bytes,27,opt,name=span_id,json=spanId,proto3" json:"span_id,omitempty"`
	// Information indicating this LogEntry is part of a sequence of multiple logs
	// split from a single LogEntry.
	Split *LogSplit `protobuf:"bytes,35,opt,name=split,proto3" json:"split,omitempty"`
	// contains filtered or unexported fields
}

The data within all Cloud Audit Logs log entry events.

func (*LogEntryData) ClearOperation

func (x *LogEntryData) ClearOperation()

func (*LogEntryData) ClearProtoPayload

func (x *LogEntryData) ClearProtoPayload()

func (*LogEntryData) ClearReceiveTimestamp

func (x *LogEntryData) ClearReceiveTimestamp()

func (*LogEntryData) ClearResource

func (x *LogEntryData) ClearResource()

func (*LogEntryData) ClearSplit

func (x *LogEntryData) ClearSplit()

func (*LogEntryData) ClearTimestamp

func (x *LogEntryData) ClearTimestamp()

func (*LogEntryData) GetInsertId

func (x *LogEntryData) GetInsertId() string

func (*LogEntryData) GetLabels

func (x *LogEntryData) GetLabels() map[string]string

func (*LogEntryData) GetLogName

func (x *LogEntryData) GetLogName() string

func (*LogEntryData) GetOperation

func (x *LogEntryData) GetOperation() *LogEntryOperation

func (*LogEntryData) GetProtoPayload

func (x *LogEntryData) GetProtoPayload() *AuditLog

func (*LogEntryData) GetReceiveTimestamp

func (x *LogEntryData) GetReceiveTimestamp() *timestamppb.Timestamp

func (*LogEntryData) GetResource

func (x *LogEntryData) GetResource() *api.MonitoredResource

func (*LogEntryData) GetSeverity

func (x *LogEntryData) GetSeverity() LogSeverity

func (*LogEntryData) GetSpanId

func (x *LogEntryData) GetSpanId() string

func (*LogEntryData) GetSplit

func (x *LogEntryData) GetSplit() *LogSplit

func (*LogEntryData) GetTimestamp

func (x *LogEntryData) GetTimestamp() *timestamppb.Timestamp

func (*LogEntryData) GetTrace

func (x *LogEntryData) GetTrace() string

func (*LogEntryData) HasOperation

func (x *LogEntryData) HasOperation() bool

func (*LogEntryData) HasProtoPayload

func (x *LogEntryData) HasProtoPayload() bool

func (*LogEntryData) HasReceiveTimestamp

func (x *LogEntryData) HasReceiveTimestamp() bool

func (*LogEntryData) HasResource

func (x *LogEntryData) HasResource() bool

func (*LogEntryData) HasSplit

func (x *LogEntryData) HasSplit() bool

func (*LogEntryData) HasTimestamp

func (x *LogEntryData) HasTimestamp() bool

func (*LogEntryData) ProtoMessage

func (*LogEntryData) ProtoMessage()

func (*LogEntryData) ProtoReflect

func (x *LogEntryData) ProtoReflect() protoreflect.Message

func (*LogEntryData) Reset

func (x *LogEntryData) Reset()

func (*LogEntryData) SetInsertId

func (x *LogEntryData) SetInsertId(v string)

func (*LogEntryData) SetLabels

func (x *LogEntryData) SetLabels(v map[string]string)

func (*LogEntryData) SetLogName

func (x *LogEntryData) SetLogName(v string)

func (*LogEntryData) SetOperation

func (x *LogEntryData) SetOperation(v *LogEntryOperation)

func (*LogEntryData) SetProtoPayload

func (x *LogEntryData) SetProtoPayload(v *AuditLog)

func (*LogEntryData) SetReceiveTimestamp

func (x *LogEntryData) SetReceiveTimestamp(v *timestamppb.Timestamp)

func (*LogEntryData) SetResource

func (x *LogEntryData) SetResource(v *api.MonitoredResource)

func (*LogEntryData) SetSeverity

func (x *LogEntryData) SetSeverity(v LogSeverity)

func (*LogEntryData) SetSpanId

func (x *LogEntryData) SetSpanId(v string)

func (*LogEntryData) SetSplit

func (x *LogEntryData) SetSplit(v *LogSplit)

func (*LogEntryData) SetTimestamp

func (x *LogEntryData) SetTimestamp(v *timestamppb.Timestamp)

func (*LogEntryData) SetTrace

func (x *LogEntryData) SetTrace(v string)

func (*LogEntryData) String

func (x *LogEntryData) String() string

type LogEntryData_builder

type LogEntryData_builder struct {

	// The resource name of the log to which this log entry belongs.
	LogName string
	// The monitored resource that produced this log entry.
	//
	// Example: a log entry that reports a database error would be associated with
	// the monitored resource designating the particular database that reported
	// the error.
	Resource *api.MonitoredResource
	// The log entry payload, which is always an AuditLog for Cloud Audit Log
	// events.
	ProtoPayload *AuditLog
	// A unique identifier for the log entry.
	InsertId string
	// A set of user-defined (key, value) data that provides additional
	// information about the log entry.
	Labels map[string]string
	// Information about an operation associated with the log entry, if
	// applicable.
	Operation *LogEntryOperation
	// The time the event described by the log entry occurred.
	Timestamp *timestamppb.Timestamp
	// The time the log entry was received by Logging.
	ReceiveTimestamp *timestamppb.Timestamp
	// The severity of the log entry.
	Severity LogSeverity
	// Resource name of the trace associated with the log entry, if any. If it
	// contains a relative resource name, the name is assumed to be relative to
	// `//tracing.googleapis.com`. Example:
	// `projects/my-projectid/traces/06796866738c859f2f19b7cfb3214824`
	Trace string
	// The span ID within the trace associated with the log entry, if any.
	//
	// For Trace spans, this is the same format that the Trace API v2 uses: a
	// 16-character hexadecimal encoding of an 8-byte array, such as
	// `000000000000004a`.
	SpanId string
	// Information indicating this LogEntry is part of a sequence of multiple logs
	// split from a single LogEntry.
	Split *LogSplit
	// contains filtered or unexported fields
}

func (LogEntryData_builder) Build

func (b0 LogEntryData_builder) Build() *LogEntryData

type LogEntryOperation

type LogEntryOperation struct {

	// An arbitrary operation identifier. Log entries with the same
	// identifier are assumed to be part of the same operation.
	Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	// An arbitrary producer identifier. The combination of `id` and
	// `producer` must be globally unique. Examples for `producer`:
	// `"MyDivision.MyBigCompany.com"`, `"github.com/MyProject/MyApplication"`.
	Producer string `protobuf:"bytes,2,opt,name=producer,proto3" json:"producer,omitempty"`
	// True if this is the first log entry in the operation.
	First bool `protobuf:"varint,3,opt,name=first,proto3" json:"first,omitempty"`
	// True if this is the last log entry in the operation.
	Last bool `protobuf:"varint,4,opt,name=last,proto3" json:"last,omitempty"`
	// contains filtered or unexported fields
}

Additional information about a potentially long-running operation with which a log entry is associated.

func (*LogEntryOperation) GetFirst

func (x *LogEntryOperation) GetFirst() bool

func (*LogEntryOperation) GetId

func (x *LogEntryOperation) GetId() string

func (*LogEntryOperation) GetLast

func (x *LogEntryOperation) GetLast() bool

func (*LogEntryOperation) GetProducer

func (x *LogEntryOperation) GetProducer() string

func (*LogEntryOperation) ProtoMessage

func (*LogEntryOperation) ProtoMessage()

func (*LogEntryOperation) ProtoReflect

func (x *LogEntryOperation) ProtoReflect() protoreflect.Message

func (*LogEntryOperation) Reset

func (x *LogEntryOperation) Reset()

func (*LogEntryOperation) SetFirst

func (x *LogEntryOperation) SetFirst(v bool)

func (*LogEntryOperation) SetId

func (x *LogEntryOperation) SetId(v string)

func (*LogEntryOperation) SetLast

func (x *LogEntryOperation) SetLast(v bool)

func (*LogEntryOperation) SetProducer

func (x *LogEntryOperation) SetProducer(v string)

func (*LogEntryOperation) String

func (x *LogEntryOperation) String() string

type LogEntryOperation_builder

type LogEntryOperation_builder struct {

	// An arbitrary operation identifier. Log entries with the same
	// identifier are assumed to be part of the same operation.
	Id string
	// An arbitrary producer identifier. The combination of `id` and
	// `producer` must be globally unique. Examples for `producer`:
	// `"MyDivision.MyBigCompany.com"`, `"github.com/MyProject/MyApplication"`.
	Producer string
	// True if this is the first log entry in the operation.
	First bool
	// True if this is the last log entry in the operation.
	Last bool
	// contains filtered or unexported fields
}

func (LogEntryOperation_builder) Build

type LogSeverity

type LogSeverity int32

The severity of the event described in a log entry, expressed as one of the standard severity levels listed below. For your reference, the levels are assigned the listed numeric values. The effect of using numeric values other than those listed is undefined. Copied from https://github.com/googleapis/googleapis/blob/master/google/logging/type/log_severity.proto

const (
	// (0) The log entry has no assigned severity level.
	LogSeverity_DEFAULT LogSeverity = 0
	// (100) Debug or trace information.
	LogSeverity_DEBUG LogSeverity = 100
	// (200) Routine information, such as ongoing status or performance.
	LogSeverity_INFO LogSeverity = 200
	// (300) Normal but significant events, such as start up, shut down, or
	// a configuration change.
	LogSeverity_NOTICE LogSeverity = 300
	// (400) Warning events might cause problems.
	LogSeverity_WARNING LogSeverity = 400
	// (500) Error events are likely to cause problems.
	LogSeverity_ERROR LogSeverity = 500
	// (600) Critical events cause more severe problems or outages.
	LogSeverity_CRITICAL LogSeverity = 600
	// (700) A person must take an action immediately.
	LogSeverity_ALERT LogSeverity = 700
	// (800) One or more systems are unusable.
	LogSeverity_EMERGENCY LogSeverity = 800
)

func (LogSeverity) Descriptor

func (LogSeverity) Enum

func (x LogSeverity) Enum() *LogSeverity

func (LogSeverity) Number

func (x LogSeverity) Number() protoreflect.EnumNumber

func (LogSeverity) String

func (x LogSeverity) String() string

func (LogSeverity) Type

type LogSplit

type LogSplit struct {

	// A globally unique identifier for all LogEntries in a sequence of split
	// logs. All LogEntries with the same |LogSplit.uid| are assumed to be part of
	// the same sequence of split logs.
	Uid string `protobuf:"bytes,1,opt,name=uid,proto3" json:"uid,omitempty"`
	// The index of this LogEntry in the sequence of split logs. LogEntries are
	// given |index| values 0, 1, ..., n-1 for a sequence of n entries.
	Index int32 `protobuf:"varint,2,opt,name=index,proto3" json:"index,omitempty"`
	// The total number of logs that the original LogEntry was split into.
	TotalSplits int32 `protobuf:"varint,3,opt,name=total_splits,json=totalSplits,proto3" json:"total_splits,omitempty"`
	// contains filtered or unexported fields
}

Additional information used to correlate multiple LogEntries. Used when a single LogEntry would exceed the Google Cloud Logging size limit and is split across multiple entries.

func (*LogSplit) GetIndex

func (x *LogSplit) GetIndex() int32

func (*LogSplit) GetTotalSplits

func (x *LogSplit) GetTotalSplits() int32

func (*LogSplit) GetUid

func (x *LogSplit) GetUid() string

func (*LogSplit) ProtoMessage

func (*LogSplit) ProtoMessage()

func (*LogSplit) ProtoReflect

func (x *LogSplit) ProtoReflect() protoreflect.Message

func (*LogSplit) Reset

func (x *LogSplit) Reset()

func (*LogSplit) SetIndex

func (x *LogSplit) SetIndex(v int32)

func (*LogSplit) SetTotalSplits

func (x *LogSplit) SetTotalSplits(v int32)

func (*LogSplit) SetUid

func (x *LogSplit) SetUid(v string)

func (*LogSplit) String

func (x *LogSplit) String() string

type LogSplit_builder

type LogSplit_builder struct {

	// A globally unique identifier for all LogEntries in a sequence of split
	// logs. All LogEntries with the same |LogSplit.uid| are assumed to be part of
	// the same sequence of split logs.
	Uid string
	// The index of this LogEntry in the sequence of split logs. LogEntries are
	// given |index| values 0, 1, ..., n-1 for a sequence of n entries.
	Index int32
	// The total number of logs that the original LogEntry was split into.
	TotalSplits int32
	// contains filtered or unexported fields
}

func (LogSplit_builder) Build

func (b0 LogSplit_builder) Build() *LogSplit

type RequestMetadata

type RequestMetadata struct {

	// The IP address of the caller.
	// For caller from internet, this will be public IPv4 or IPv6 address.
	// For caller from a Compute Engine VM with external IP address, this
	// will be the VM's external IP address. For caller from a Compute
	// Engine VM without external IP address, if the VM is in the same
	// organization (or project) as the accessed resource, `caller_ip` will
	// be the VM's internal IPv4 address, otherwise the `caller_ip` will be
	// redacted to "gce-internal-ip".
	// See https://cloud.google.com/compute/docs/vpc/ for more information.
	CallerIp string `protobuf:"bytes,1,opt,name=caller_ip,json=callerIp,proto3" json:"caller_ip,omitempty"`
	// The user agent of the caller.
	// This information is not authenticated and should be treated accordingly.
	// For example:
	//
	//   - `google-api-python-client/1.4.0`:
	//     The request was made by the Google API client for Python.
	//   - `Cloud SDK Command Line Tool apitools-client/1.0 gcloud/0.9.62`:
	//     The request was made by the Google Cloud SDK CLI (gcloud).
	//   - `AppEngine-Google; (+http://code.google.com/appengine; appid:
	//
	// s~my-project`:
	//
	//	The request was made from the `my-project` App Engine app.
	CallerSuppliedUserAgent string `` /* 134-byte string literal not displayed */
	// The network of the caller.
	// Set only if the network host project is part of the same GCP organization
	// (or project) as the accessed resource.
	// See https://cloud.google.com/compute/docs/vpc/ for more information.
	// This is a scheme-less URI full resource name. For example:
	//
	//	"//compute.googleapis.com/projects/PROJECT_ID/global/networks/NETWORK_ID"
	CallerNetwork string `protobuf:"bytes,3,opt,name=caller_network,json=callerNetwork,proto3" json:"caller_network,omitempty"`
	// Request attributes used in IAM condition evaluation. This field contains
	// request attributes like request time and access levels associated with
	// the request.
	//
	// To get the whole view of the attributes used in IAM
	// condition evaluation, the user must also look into
	// `AuditLog.authentication_info.resource_attributes`.
	RequestAttributes *attribute_context.AttributeContext_Request `protobuf:"bytes,7,opt,name=request_attributes,json=requestAttributes,proto3" json:"request_attributes,omitempty"`
	// The destination of a network activity, such as accepting a TCP connection.
	// In a multi hop network activity, the destination represents the receiver of
	// the last hop. Only two fields are used in this message, Peer.port and
	// Peer.ip. These fields are optionally populated by those services utilizing
	// the IAM condition feature.
	DestinationAttributes *attribute_context.AttributeContext_Peer `protobuf:"bytes,8,opt,name=destination_attributes,json=destinationAttributes,proto3" json:"destination_attributes,omitempty"`
	// contains filtered or unexported fields
}

Metadata about the request.

func (*RequestMetadata) ClearDestinationAttributes

func (x *RequestMetadata) ClearDestinationAttributes()

func (*RequestMetadata) ClearRequestAttributes

func (x *RequestMetadata) ClearRequestAttributes()

func (*RequestMetadata) GetCallerIp

func (x *RequestMetadata) GetCallerIp() string

func (*RequestMetadata) GetCallerNetwork

func (x *RequestMetadata) GetCallerNetwork() string

func (*RequestMetadata) GetCallerSuppliedUserAgent

func (x *RequestMetadata) GetCallerSuppliedUserAgent() string

func (*RequestMetadata) GetDestinationAttributes

func (x *RequestMetadata) GetDestinationAttributes() *attribute_context.AttributeContext_Peer

func (*RequestMetadata) GetRequestAttributes

func (x *RequestMetadata) GetRequestAttributes() *attribute_context.AttributeContext_Request

func (*RequestMetadata) HasDestinationAttributes

func (x *RequestMetadata) HasDestinationAttributes() bool

func (*RequestMetadata) HasRequestAttributes

func (x *RequestMetadata) HasRequestAttributes() bool

func (*RequestMetadata) ProtoMessage

func (*RequestMetadata) ProtoMessage()

func (*RequestMetadata) ProtoReflect

func (x *RequestMetadata) ProtoReflect() protoreflect.Message

func (*RequestMetadata) Reset

func (x *RequestMetadata) Reset()

func (*RequestMetadata) SetCallerIp

func (x *RequestMetadata) SetCallerIp(v string)

func (*RequestMetadata) SetCallerNetwork

func (x *RequestMetadata) SetCallerNetwork(v string)

func (*RequestMetadata) SetCallerSuppliedUserAgent

func (x *RequestMetadata) SetCallerSuppliedUserAgent(v string)

func (*RequestMetadata) SetDestinationAttributes

func (x *RequestMetadata) SetDestinationAttributes(v *attribute_context.AttributeContext_Peer)

func (*RequestMetadata) SetRequestAttributes

func (x *RequestMetadata) SetRequestAttributes(v *attribute_context.AttributeContext_Request)

func (*RequestMetadata) String

func (x *RequestMetadata) String() string

type RequestMetadata_builder

type RequestMetadata_builder struct {

	// The IP address of the caller.
	// For caller from internet, this will be public IPv4 or IPv6 address.
	// For caller from a Compute Engine VM with external IP address, this
	// will be the VM's external IP address. For caller from a Compute
	// Engine VM without external IP address, if the VM is in the same
	// organization (or project) as the accessed resource, `caller_ip` will
	// be the VM's internal IPv4 address, otherwise the `caller_ip` will be
	// redacted to "gce-internal-ip".
	// See https://cloud.google.com/compute/docs/vpc/ for more information.
	CallerIp string
	// The user agent of the caller.
	// This information is not authenticated and should be treated accordingly.
	// For example:
	//
	//   - `google-api-python-client/1.4.0`:
	//     The request was made by the Google API client for Python.
	//   - `Cloud SDK Command Line Tool apitools-client/1.0 gcloud/0.9.62`:
	//     The request was made by the Google Cloud SDK CLI (gcloud).
	//   - `AppEngine-Google; (+http://code.google.com/appengine; appid:
	//
	// s~my-project`:
	//
	//	The request was made from the `my-project` App Engine app.
	CallerSuppliedUserAgent string
	// The network of the caller.
	// Set only if the network host project is part of the same GCP organization
	// (or project) as the accessed resource.
	// See https://cloud.google.com/compute/docs/vpc/ for more information.
	// This is a scheme-less URI full resource name. For example:
	//
	//	"//compute.googleapis.com/projects/PROJECT_ID/global/networks/NETWORK_ID"
	CallerNetwork string
	// Request attributes used in IAM condition evaluation. This field contains
	// request attributes like request time and access levels associated with
	// the request.
	//
	// To get the whole view of the attributes used in IAM
	// condition evaluation, the user must also look into
	// `AuditLog.authentication_info.resource_attributes`.
	RequestAttributes *attribute_context.AttributeContext_Request
	// The destination of a network activity, such as accepting a TCP connection.
	// In a multi hop network activity, the destination represents the receiver of
	// the last hop. Only two fields are used in this message, Peer.port and
	// Peer.ip. These fields are optionally populated by those services utilizing
	// the IAM condition feature.
	DestinationAttributes *attribute_context.AttributeContext_Peer
	// contains filtered or unexported fields
}

func (RequestMetadata_builder) Build

type ResourceLocation

type ResourceLocation struct {

	// The locations of a resource after the execution of the operation.
	// Requests to create or delete a location based resource must populate
	// the 'current_locations' field and not the 'original_locations' field.
	// For example:
	//
	//	"europe-west1-a"
	//	"us-east1"
	//	"nam3"
	CurrentLocations []string `protobuf:"bytes,1,rep,name=current_locations,json=currentLocations,proto3" json:"current_locations,omitempty"`
	// The locations of a resource prior to the execution of the operation.
	// Requests that mutate the resource's location must populate both the
	// 'original_locations' as well as the 'current_locations' fields.
	// For example:
	//
	//	"europe-west1-a"
	//	"us-east1"
	//	"nam3"
	OriginalLocations []string `protobuf:"bytes,2,rep,name=original_locations,json=originalLocations,proto3" json:"original_locations,omitempty"`
	// contains filtered or unexported fields
}

Location information about a resource.

func (*ResourceLocation) GetCurrentLocations

func (x *ResourceLocation) GetCurrentLocations() []string

func (*ResourceLocation) GetOriginalLocations

func (x *ResourceLocation) GetOriginalLocations() []string

func (*ResourceLocation) ProtoMessage

func (*ResourceLocation) ProtoMessage()

func (*ResourceLocation) ProtoReflect

func (x *ResourceLocation) ProtoReflect() protoreflect.Message

func (*ResourceLocation) Reset

func (x *ResourceLocation) Reset()

func (*ResourceLocation) SetCurrentLocations

func (x *ResourceLocation) SetCurrentLocations(v []string)

func (*ResourceLocation) SetOriginalLocations

func (x *ResourceLocation) SetOriginalLocations(v []string)

func (*ResourceLocation) String

func (x *ResourceLocation) String() string

type ResourceLocation_builder

type ResourceLocation_builder struct {

	// The locations of a resource after the execution of the operation.
	// Requests to create or delete a location based resource must populate
	// the 'current_locations' field and not the 'original_locations' field.
	// For example:
	//
	//	"europe-west1-a"
	//	"us-east1"
	//	"nam3"
	CurrentLocations []string
	// The locations of a resource prior to the execution of the operation.
	// Requests that mutate the resource's location must populate both the
	// 'original_locations' as well as the 'current_locations' fields.
	// For example:
	//
	//	"europe-west1-a"
	//	"us-east1"
	//	"nam3"
	OriginalLocations []string
	// contains filtered or unexported fields
}

func (ResourceLocation_builder) Build

type ServiceAccountDelegationInfo

type ServiceAccountDelegationInfo struct {

	// Entity that creates credentials for service account and assumes its
	// identity for authentication.
	//
	// Types that are valid to be assigned to Authority:
	//
	//	*ServiceAccountDelegationInfo_FirstPartyPrincipal_
	//	*ServiceAccountDelegationInfo_ThirdPartyPrincipal_
	Authority isServiceAccountDelegationInfo_Authority `protobuf_oneof:"Authority"`
	// contains filtered or unexported fields
}

Identity delegation history of an authenticated service account.

func (*ServiceAccountDelegationInfo) ClearAuthority

func (x *ServiceAccountDelegationInfo) ClearAuthority()

func (*ServiceAccountDelegationInfo) ClearFirstPartyPrincipal

func (x *ServiceAccountDelegationInfo) ClearFirstPartyPrincipal()

func (*ServiceAccountDelegationInfo) ClearThirdPartyPrincipal

func (x *ServiceAccountDelegationInfo) ClearThirdPartyPrincipal()

func (*ServiceAccountDelegationInfo) GetAuthority

func (x *ServiceAccountDelegationInfo) GetAuthority() isServiceAccountDelegationInfo_Authority

func (*ServiceAccountDelegationInfo) GetFirstPartyPrincipal

func (*ServiceAccountDelegationInfo) GetThirdPartyPrincipal

func (*ServiceAccountDelegationInfo) HasAuthority

func (x *ServiceAccountDelegationInfo) HasAuthority() bool

func (*ServiceAccountDelegationInfo) HasFirstPartyPrincipal

func (x *ServiceAccountDelegationInfo) HasFirstPartyPrincipal() bool

func (*ServiceAccountDelegationInfo) HasThirdPartyPrincipal

func (x *ServiceAccountDelegationInfo) HasThirdPartyPrincipal() bool

func (*ServiceAccountDelegationInfo) ProtoMessage

func (*ServiceAccountDelegationInfo) ProtoMessage()

func (*ServiceAccountDelegationInfo) ProtoReflect

func (*ServiceAccountDelegationInfo) Reset

func (x *ServiceAccountDelegationInfo) Reset()

func (*ServiceAccountDelegationInfo) SetFirstPartyPrincipal

func (*ServiceAccountDelegationInfo) SetThirdPartyPrincipal

func (*ServiceAccountDelegationInfo) String

func (*ServiceAccountDelegationInfo) WhichAuthority

func (x *ServiceAccountDelegationInfo) WhichAuthority() case_ServiceAccountDelegationInfo_Authority

type ServiceAccountDelegationInfo_FirstPartyPrincipal

type ServiceAccountDelegationInfo_FirstPartyPrincipal struct {

	// The email address of a Google account.
	PrincipalEmail string `protobuf:"bytes,1,opt,name=principal_email,json=principalEmail,proto3" json:"principal_email,omitempty"`
	// Metadata about the service that uses the service account.
	ServiceMetadata *structpb.Struct `protobuf:"bytes,2,opt,name=service_metadata,json=serviceMetadata,proto3" json:"service_metadata,omitempty"`
	// contains filtered or unexported fields
}

First party identity principal.

func (*ServiceAccountDelegationInfo_FirstPartyPrincipal) ClearServiceMetadata

func (x *ServiceAccountDelegationInfo_FirstPartyPrincipal) ClearServiceMetadata()

func (*ServiceAccountDelegationInfo_FirstPartyPrincipal) GetPrincipalEmail

func (*ServiceAccountDelegationInfo_FirstPartyPrincipal) GetServiceMetadata

func (*ServiceAccountDelegationInfo_FirstPartyPrincipal) HasServiceMetadata

func (*ServiceAccountDelegationInfo_FirstPartyPrincipal) ProtoMessage

func (*ServiceAccountDelegationInfo_FirstPartyPrincipal) ProtoReflect

func (*ServiceAccountDelegationInfo_FirstPartyPrincipal) Reset

func (*ServiceAccountDelegationInfo_FirstPartyPrincipal) SetPrincipalEmail

func (*ServiceAccountDelegationInfo_FirstPartyPrincipal) SetServiceMetadata

func (*ServiceAccountDelegationInfo_FirstPartyPrincipal) String

type ServiceAccountDelegationInfo_FirstPartyPrincipal_

type ServiceAccountDelegationInfo_FirstPartyPrincipal_ struct {
	// First party (Google) identity as the real authority.
	FirstPartyPrincipal *ServiceAccountDelegationInfo_FirstPartyPrincipal `protobuf:"bytes,1,opt,name=first_party_principal,json=firstPartyPrincipal,proto3,oneof"`
}

type ServiceAccountDelegationInfo_FirstPartyPrincipal_builder

type ServiceAccountDelegationInfo_FirstPartyPrincipal_builder struct {

	// The email address of a Google account.
	PrincipalEmail string
	// Metadata about the service that uses the service account.
	ServiceMetadata *structpb.Struct
	// contains filtered or unexported fields
}

func (ServiceAccountDelegationInfo_FirstPartyPrincipal_builder) Build

type ServiceAccountDelegationInfo_ThirdPartyPrincipal

type ServiceAccountDelegationInfo_ThirdPartyPrincipal struct {

	// Metadata about third party identity.
	ThirdPartyClaims *structpb.Struct `protobuf:"bytes,1,opt,name=third_party_claims,json=thirdPartyClaims,proto3" json:"third_party_claims,omitempty"`
	// contains filtered or unexported fields
}

Third party identity principal.

func (*ServiceAccountDelegationInfo_ThirdPartyPrincipal) ClearThirdPartyClaims

func (x *ServiceAccountDelegationInfo_ThirdPartyPrincipal) ClearThirdPartyClaims()

func (*ServiceAccountDelegationInfo_ThirdPartyPrincipal) GetThirdPartyClaims

func (*ServiceAccountDelegationInfo_ThirdPartyPrincipal) HasThirdPartyClaims

func (x *ServiceAccountDelegationInfo_ThirdPartyPrincipal) HasThirdPartyClaims() bool

func (*ServiceAccountDelegationInfo_ThirdPartyPrincipal) ProtoMessage

func (*ServiceAccountDelegationInfo_ThirdPartyPrincipal) ProtoReflect

func (*ServiceAccountDelegationInfo_ThirdPartyPrincipal) Reset

func (*ServiceAccountDelegationInfo_ThirdPartyPrincipal) SetThirdPartyClaims

func (*ServiceAccountDelegationInfo_ThirdPartyPrincipal) String

type ServiceAccountDelegationInfo_ThirdPartyPrincipal_

type ServiceAccountDelegationInfo_ThirdPartyPrincipal_ struct {
	// Third party identity as the real authority.
	ThirdPartyPrincipal *ServiceAccountDelegationInfo_ThirdPartyPrincipal `protobuf:"bytes,2,opt,name=third_party_principal,json=thirdPartyPrincipal,proto3,oneof"`
}

type ServiceAccountDelegationInfo_ThirdPartyPrincipal_builder

type ServiceAccountDelegationInfo_ThirdPartyPrincipal_builder struct {

	// Metadata about third party identity.
	ThirdPartyClaims *structpb.Struct
	// contains filtered or unexported fields
}

func (ServiceAccountDelegationInfo_ThirdPartyPrincipal_builder) Build

type ServiceAccountDelegationInfo_builder

type ServiceAccountDelegationInfo_builder struct {

	// Fields of oneof Authority:
	// First party (Google) identity as the real authority.
	FirstPartyPrincipal *ServiceAccountDelegationInfo_FirstPartyPrincipal
	// Third party identity as the real authority.
	ThirdPartyPrincipal *ServiceAccountDelegationInfo_ThirdPartyPrincipal
	// contains filtered or unexported fields
}

func (ServiceAccountDelegationInfo_builder) Build

Source Files

  • data.pb.go
  • events.pb.go

Jump to