Documentation
¶
Index ¶
- Variables
- type AppConnection
- func (x *AppConnection) ClearApplicationEndpoint()
- func (x *AppConnection) ClearCreateTime()
- func (x *AppConnection) ClearGateway()
- func (x *AppConnection) ClearUpdateTime()
- func (x *AppConnection) GetApplicationEndpoint() *AppConnection_ApplicationEndpoint
- func (x *AppConnection) GetConnectors() []string
- func (x *AppConnection) GetCreateTime() *timestamppb.Timestamp
- func (x *AppConnection) GetDisplayName() string
- func (x *AppConnection) GetGateway() *AppConnection_Gateway
- func (x *AppConnection) GetLabels() map[string]string
- func (x *AppConnection) GetName() string
- func (x *AppConnection) GetState() AppConnection_State
- func (x *AppConnection) GetType() AppConnection_Type
- func (x *AppConnection) GetUid() string
- func (x *AppConnection) GetUpdateTime() *timestamppb.Timestamp
- func (x *AppConnection) HasApplicationEndpoint() bool
- func (x *AppConnection) HasCreateTime() bool
- func (x *AppConnection) HasGateway() bool
- func (x *AppConnection) HasUpdateTime() bool
- func (*AppConnection) ProtoMessage()
- func (x *AppConnection) ProtoReflect() protoreflect.Message
- func (x *AppConnection) Reset()
- func (x *AppConnection) SetApplicationEndpoint(v *AppConnection_ApplicationEndpoint)
- func (x *AppConnection) SetConnectors(v []string)
- func (x *AppConnection) SetCreateTime(v *timestamppb.Timestamp)
- func (x *AppConnection) SetDisplayName(v string)
- func (x *AppConnection) SetGateway(v *AppConnection_Gateway)
- func (x *AppConnection) SetLabels(v map[string]string)
- func (x *AppConnection) SetName(v string)
- func (x *AppConnection) SetState(v AppConnection_State)
- func (x *AppConnection) SetType(v AppConnection_Type)
- func (x *AppConnection) SetUid(v string)
- func (x *AppConnection) SetUpdateTime(v *timestamppb.Timestamp)
- func (x *AppConnection) String() string
- type AppConnectionCreatedEvent
- func (x *AppConnectionCreatedEvent) ClearData()
- func (x *AppConnectionCreatedEvent) GetData() *AppConnectionEventData
- func (x *AppConnectionCreatedEvent) HasData() bool
- func (*AppConnectionCreatedEvent) ProtoMessage()
- func (x *AppConnectionCreatedEvent) ProtoReflect() protoreflect.Message
- func (x *AppConnectionCreatedEvent) Reset()
- func (x *AppConnectionCreatedEvent) SetData(v *AppConnectionEventData)
- func (x *AppConnectionCreatedEvent) String() string
- type AppConnectionCreatedEvent_builder
- type AppConnectionDeletedEvent
- func (x *AppConnectionDeletedEvent) ClearData()
- func (x *AppConnectionDeletedEvent) GetData() *AppConnectionEventData
- func (x *AppConnectionDeletedEvent) HasData() bool
- func (*AppConnectionDeletedEvent) ProtoMessage()
- func (x *AppConnectionDeletedEvent) ProtoReflect() protoreflect.Message
- func (x *AppConnectionDeletedEvent) Reset()
- func (x *AppConnectionDeletedEvent) SetData(v *AppConnectionEventData)
- func (x *AppConnectionDeletedEvent) String() string
- type AppConnectionDeletedEvent_builder
- type AppConnectionEventData
- func (x *AppConnectionEventData) ClearPayload()
- func (x *AppConnectionEventData) GetPayload() *AppConnection
- func (x *AppConnectionEventData) HasPayload() bool
- func (*AppConnectionEventData) ProtoMessage()
- func (x *AppConnectionEventData) ProtoReflect() protoreflect.Message
- func (x *AppConnectionEventData) Reset()
- func (x *AppConnectionEventData) SetPayload(v *AppConnection)
- func (x *AppConnectionEventData) String() string
- type AppConnectionEventData_builder
- type AppConnectionUpdatedEvent
- func (x *AppConnectionUpdatedEvent) ClearData()
- func (x *AppConnectionUpdatedEvent) GetData() *AppConnectionEventData
- func (x *AppConnectionUpdatedEvent) HasData() bool
- func (*AppConnectionUpdatedEvent) ProtoMessage()
- func (x *AppConnectionUpdatedEvent) ProtoReflect() protoreflect.Message
- func (x *AppConnectionUpdatedEvent) Reset()
- func (x *AppConnectionUpdatedEvent) SetData(v *AppConnectionEventData)
- func (x *AppConnectionUpdatedEvent) String() string
- type AppConnectionUpdatedEvent_builder
- type AppConnection_ApplicationEndpoint
- func (x *AppConnection_ApplicationEndpoint) GetHost() string
- func (x *AppConnection_ApplicationEndpoint) GetPort() int32
- func (*AppConnection_ApplicationEndpoint) ProtoMessage()
- func (x *AppConnection_ApplicationEndpoint) ProtoReflect() protoreflect.Message
- func (x *AppConnection_ApplicationEndpoint) Reset()
- func (x *AppConnection_ApplicationEndpoint) SetHost(v string)
- func (x *AppConnection_ApplicationEndpoint) SetPort(v int32)
- func (x *AppConnection_ApplicationEndpoint) String() string
- type AppConnection_ApplicationEndpoint_builder
- type AppConnection_Gateway
- func (x *AppConnection_Gateway) GetAppGateway() string
- func (x *AppConnection_Gateway) GetIngressPort() int32
- func (x *AppConnection_Gateway) GetL7Psc() string
- func (x *AppConnection_Gateway) GetType() AppConnection_Gateway_Type
- func (x *AppConnection_Gateway) GetUri() string
- func (*AppConnection_Gateway) ProtoMessage()
- func (x *AppConnection_Gateway) ProtoReflect() protoreflect.Message
- func (x *AppConnection_Gateway) Reset()
- func (x *AppConnection_Gateway) SetAppGateway(v string)
- func (x *AppConnection_Gateway) SetIngressPort(v int32)
- func (x *AppConnection_Gateway) SetL7Psc(v string)
- func (x *AppConnection_Gateway) SetType(v AppConnection_Gateway_Type)
- func (x *AppConnection_Gateway) SetUri(v string)
- func (x *AppConnection_Gateway) String() string
- type AppConnection_Gateway_Type
- func (AppConnection_Gateway_Type) Descriptor() protoreflect.EnumDescriptor
- func (x AppConnection_Gateway_Type) Enum() *AppConnection_Gateway_Type
- func (x AppConnection_Gateway_Type) Number() protoreflect.EnumNumber
- func (x AppConnection_Gateway_Type) String() string
- func (AppConnection_Gateway_Type) Type() protoreflect.EnumType
- type AppConnection_Gateway_builder
- type AppConnection_State
- type AppConnection_Type
- type AppConnection_builder
Constants ¶
This section is empty.
Variables ¶
var ( AppConnection_Type_name = map[int32]string{ 0: "TYPE_UNSPECIFIED", 1: "TCP_PROXY", } AppConnection_Type_value = map[string]int32{ "TYPE_UNSPECIFIED": 0, "TCP_PROXY": 1, } )
Enum value maps for AppConnection_Type.
var ( AppConnection_State_name = map[int32]string{ 0: "STATE_UNSPECIFIED", 1: "CREATING", 2: "CREATED", 3: "UPDATING", 4: "DELETING", 5: "DOWN", } AppConnection_State_value = map[string]int32{ "STATE_UNSPECIFIED": 0, "CREATING": 1, "CREATED": 2, "UPDATING": 3, "DELETING": 4, "DOWN": 5, } )
Enum value maps for AppConnection_State.
var ( AppConnection_Gateway_Type_name = map[int32]string{ 0: "TYPE_UNSPECIFIED", 1: "GCP_REGIONAL_MIG", } AppConnection_Gateway_Type_value = map[string]int32{ "TYPE_UNSPECIFIED": 0, "GCP_REGIONAL_MIG": 1, } )
Enum value maps for AppConnection_Gateway_Type.
var File_google_events_cloud_beyondcorp_appconnections_v1_data_proto protoreflect.FileDescriptor
var File_google_events_cloud_beyondcorp_appconnections_v1_events_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type AppConnection ¶
type AppConnection struct {
// Required. Unique resource name of the AppConnection.
// The name is ignored when creating a AppConnection.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// Output only. Timestamp when the resource was created.
CreateTime *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
// Output only. Timestamp when the resource was last modified.
UpdateTime *timestamppb.Timestamp `protobuf:"bytes,3,opt,name=update_time,json=updateTime,proto3" json:"update_time,omitempty"`
// Optional. Resource labels to represent user provided metadata.
Labels map[string]string `` /* 139-byte string literal not displayed */
// Optional. An arbitrary user-provided name for the AppConnection. Cannot
// exceed 64 characters.
DisplayName string `protobuf:"bytes,5,opt,name=display_name,json=displayName,proto3" json:"display_name,omitempty"`
// Output only. A unique identifier for the instance generated by the
// system.
Uid string `protobuf:"bytes,6,opt,name=uid,proto3" json:"uid,omitempty"`
// Required. The type of network connectivity used by the AppConnection.
Type AppConnection_Type `` /* 135-byte string literal not displayed */
// Required. Address of the remote application endpoint for the BeyondCorp
// AppConnection.
ApplicationEndpoint *AppConnection_ApplicationEndpoint `protobuf:"bytes,8,opt,name=application_endpoint,json=applicationEndpoint,proto3" json:"application_endpoint,omitempty"`
// Optional. List of [google.cloud.beyondcorp.v1main.Connector.name] that are
// authorised to be associated with this AppConnection.
Connectors []string `protobuf:"bytes,9,rep,name=connectors,proto3" json:"connectors,omitempty"`
// Output only. The current state of the AppConnection.
State AppConnection_State `` /* 139-byte string literal not displayed */
// Optional. Gateway used by the AppConnection.
Gateway *AppConnection_Gateway `protobuf:"bytes,11,opt,name=gateway,proto3" json:"gateway,omitempty"`
// contains filtered or unexported fields
}
A BeyondCorp AppConnection resource represents a BeyondCorp protected AppConnection to a remote application. It creates all the necessary GCP components needed for creating a BeyondCorp protected AppConnection. Multiple connectors can be authorised for a single AppConnection.
func (*AppConnection) ClearApplicationEndpoint ¶
func (x *AppConnection) ClearApplicationEndpoint()
func (*AppConnection) ClearCreateTime ¶
func (x *AppConnection) ClearCreateTime()
func (*AppConnection) ClearGateway ¶
func (x *AppConnection) ClearGateway()
func (*AppConnection) ClearUpdateTime ¶
func (x *AppConnection) ClearUpdateTime()
func (*AppConnection) GetApplicationEndpoint ¶
func (x *AppConnection) GetApplicationEndpoint() *AppConnection_ApplicationEndpoint
func (*AppConnection) GetConnectors ¶
func (x *AppConnection) GetConnectors() []string
func (*AppConnection) GetCreateTime ¶
func (x *AppConnection) GetCreateTime() *timestamppb.Timestamp
func (*AppConnection) GetDisplayName ¶
func (x *AppConnection) GetDisplayName() string
func (*AppConnection) GetGateway ¶
func (x *AppConnection) GetGateway() *AppConnection_Gateway
func (*AppConnection) GetLabels ¶
func (x *AppConnection) GetLabels() map[string]string
func (*AppConnection) GetName ¶
func (x *AppConnection) GetName() string
func (*AppConnection) GetState ¶
func (x *AppConnection) GetState() AppConnection_State
func (*AppConnection) GetType ¶
func (x *AppConnection) GetType() AppConnection_Type
func (*AppConnection) GetUid ¶
func (x *AppConnection) GetUid() string
func (*AppConnection) GetUpdateTime ¶
func (x *AppConnection) GetUpdateTime() *timestamppb.Timestamp
func (*AppConnection) HasApplicationEndpoint ¶
func (x *AppConnection) HasApplicationEndpoint() bool
func (*AppConnection) HasCreateTime ¶
func (x *AppConnection) HasCreateTime() bool
func (*AppConnection) HasGateway ¶
func (x *AppConnection) HasGateway() bool
func (*AppConnection) HasUpdateTime ¶
func (x *AppConnection) HasUpdateTime() bool
func (*AppConnection) ProtoMessage ¶
func (*AppConnection) ProtoMessage()
func (*AppConnection) ProtoReflect ¶
func (x *AppConnection) ProtoReflect() protoreflect.Message
func (*AppConnection) Reset ¶
func (x *AppConnection) Reset()
func (*AppConnection) SetApplicationEndpoint ¶
func (x *AppConnection) SetApplicationEndpoint(v *AppConnection_ApplicationEndpoint)
func (*AppConnection) SetConnectors ¶
func (x *AppConnection) SetConnectors(v []string)
func (*AppConnection) SetCreateTime ¶
func (x *AppConnection) SetCreateTime(v *timestamppb.Timestamp)
func (*AppConnection) SetDisplayName ¶
func (x *AppConnection) SetDisplayName(v string)
func (*AppConnection) SetGateway ¶
func (x *AppConnection) SetGateway(v *AppConnection_Gateway)
func (*AppConnection) SetLabels ¶
func (x *AppConnection) SetLabels(v map[string]string)
func (*AppConnection) SetName ¶
func (x *AppConnection) SetName(v string)
func (*AppConnection) SetState ¶
func (x *AppConnection) SetState(v AppConnection_State)
func (*AppConnection) SetType ¶
func (x *AppConnection) SetType(v AppConnection_Type)
func (*AppConnection) SetUid ¶
func (x *AppConnection) SetUid(v string)
func (*AppConnection) SetUpdateTime ¶
func (x *AppConnection) SetUpdateTime(v *timestamppb.Timestamp)
func (*AppConnection) String ¶
func (x *AppConnection) String() string
type AppConnectionCreatedEvent ¶
type AppConnectionCreatedEvent struct {
// The data associated with the event.
Data *AppConnectionEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
// contains filtered or unexported fields
}
The CloudEvent raised when an AppConnection is created.
func (*AppConnectionCreatedEvent) ClearData ¶
func (x *AppConnectionCreatedEvent) ClearData()
func (*AppConnectionCreatedEvent) GetData ¶
func (x *AppConnectionCreatedEvent) GetData() *AppConnectionEventData
func (*AppConnectionCreatedEvent) HasData ¶
func (x *AppConnectionCreatedEvent) HasData() bool
func (*AppConnectionCreatedEvent) ProtoMessage ¶
func (*AppConnectionCreatedEvent) ProtoMessage()
func (*AppConnectionCreatedEvent) ProtoReflect ¶
func (x *AppConnectionCreatedEvent) ProtoReflect() protoreflect.Message
func (*AppConnectionCreatedEvent) Reset ¶
func (x *AppConnectionCreatedEvent) Reset()
func (*AppConnectionCreatedEvent) SetData ¶
func (x *AppConnectionCreatedEvent) SetData(v *AppConnectionEventData)
func (*AppConnectionCreatedEvent) String ¶
func (x *AppConnectionCreatedEvent) String() string
type AppConnectionCreatedEvent_builder ¶
type AppConnectionCreatedEvent_builder struct {
// The data associated with the event.
Data *AppConnectionEventData
// contains filtered or unexported fields
}
func (AppConnectionCreatedEvent_builder) Build ¶
func (b0 AppConnectionCreatedEvent_builder) Build() *AppConnectionCreatedEvent
type AppConnectionDeletedEvent ¶
type AppConnectionDeletedEvent struct {
// The data associated with the event.
Data *AppConnectionEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
// contains filtered or unexported fields
}
The CloudEvent raised when an AppConnection is deleted.
func (*AppConnectionDeletedEvent) ClearData ¶
func (x *AppConnectionDeletedEvent) ClearData()
func (*AppConnectionDeletedEvent) GetData ¶
func (x *AppConnectionDeletedEvent) GetData() *AppConnectionEventData
func (*AppConnectionDeletedEvent) HasData ¶
func (x *AppConnectionDeletedEvent) HasData() bool
func (*AppConnectionDeletedEvent) ProtoMessage ¶
func (*AppConnectionDeletedEvent) ProtoMessage()
func (*AppConnectionDeletedEvent) ProtoReflect ¶
func (x *AppConnectionDeletedEvent) ProtoReflect() protoreflect.Message
func (*AppConnectionDeletedEvent) Reset ¶
func (x *AppConnectionDeletedEvent) Reset()
func (*AppConnectionDeletedEvent) SetData ¶
func (x *AppConnectionDeletedEvent) SetData(v *AppConnectionEventData)
func (*AppConnectionDeletedEvent) String ¶
func (x *AppConnectionDeletedEvent) String() string
type AppConnectionDeletedEvent_builder ¶
type AppConnectionDeletedEvent_builder struct {
// The data associated with the event.
Data *AppConnectionEventData
// contains filtered or unexported fields
}
func (AppConnectionDeletedEvent_builder) Build ¶
func (b0 AppConnectionDeletedEvent_builder) Build() *AppConnectionDeletedEvent
type AppConnectionEventData ¶
type AppConnectionEventData struct {
// Optional. The AppConnection event payload. Unset for deletion events.
Payload *AppConnection `protobuf:"bytes,1,opt,name=payload,proto3,oneof" json:"payload,omitempty"`
// contains filtered or unexported fields
}
The data within all AppConnection events.
func (*AppConnectionEventData) ClearPayload ¶
func (x *AppConnectionEventData) ClearPayload()
func (*AppConnectionEventData) GetPayload ¶
func (x *AppConnectionEventData) GetPayload() *AppConnection
func (*AppConnectionEventData) HasPayload ¶
func (x *AppConnectionEventData) HasPayload() bool
func (*AppConnectionEventData) ProtoMessage ¶
func (*AppConnectionEventData) ProtoMessage()
func (*AppConnectionEventData) ProtoReflect ¶
func (x *AppConnectionEventData) ProtoReflect() protoreflect.Message
func (*AppConnectionEventData) Reset ¶
func (x *AppConnectionEventData) Reset()
func (*AppConnectionEventData) SetPayload ¶
func (x *AppConnectionEventData) SetPayload(v *AppConnection)
func (*AppConnectionEventData) String ¶
func (x *AppConnectionEventData) String() string
type AppConnectionEventData_builder ¶
type AppConnectionEventData_builder struct {
// Optional. The AppConnection event payload. Unset for deletion events.
Payload *AppConnection
// contains filtered or unexported fields
}
func (AppConnectionEventData_builder) Build ¶
func (b0 AppConnectionEventData_builder) Build() *AppConnectionEventData
type AppConnectionUpdatedEvent ¶
type AppConnectionUpdatedEvent struct {
// The data associated with the event.
Data *AppConnectionEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
// contains filtered or unexported fields
}
The CloudEvent raised when an AppConnection is updated.
func (*AppConnectionUpdatedEvent) ClearData ¶
func (x *AppConnectionUpdatedEvent) ClearData()
func (*AppConnectionUpdatedEvent) GetData ¶
func (x *AppConnectionUpdatedEvent) GetData() *AppConnectionEventData
func (*AppConnectionUpdatedEvent) HasData ¶
func (x *AppConnectionUpdatedEvent) HasData() bool
func (*AppConnectionUpdatedEvent) ProtoMessage ¶
func (*AppConnectionUpdatedEvent) ProtoMessage()
func (*AppConnectionUpdatedEvent) ProtoReflect ¶
func (x *AppConnectionUpdatedEvent) ProtoReflect() protoreflect.Message
func (*AppConnectionUpdatedEvent) Reset ¶
func (x *AppConnectionUpdatedEvent) Reset()
func (*AppConnectionUpdatedEvent) SetData ¶
func (x *AppConnectionUpdatedEvent) SetData(v *AppConnectionEventData)
func (*AppConnectionUpdatedEvent) String ¶
func (x *AppConnectionUpdatedEvent) String() string
type AppConnectionUpdatedEvent_builder ¶
type AppConnectionUpdatedEvent_builder struct {
// The data associated with the event.
Data *AppConnectionEventData
// contains filtered or unexported fields
}
func (AppConnectionUpdatedEvent_builder) Build ¶
func (b0 AppConnectionUpdatedEvent_builder) Build() *AppConnectionUpdatedEvent
type AppConnection_ApplicationEndpoint ¶
type AppConnection_ApplicationEndpoint struct {
// Required. Hostname or IP address of the remote application endpoint.
Host string `protobuf:"bytes,1,opt,name=host,proto3" json:"host,omitempty"`
// Required. Port of the remote application endpoint.
Port int32 `protobuf:"varint,2,opt,name=port,proto3" json:"port,omitempty"`
// contains filtered or unexported fields
}
ApplicationEndpoint represents a remote application endpoint.
func (*AppConnection_ApplicationEndpoint) GetHost ¶
func (x *AppConnection_ApplicationEndpoint) GetHost() string
func (*AppConnection_ApplicationEndpoint) GetPort ¶
func (x *AppConnection_ApplicationEndpoint) GetPort() int32
func (*AppConnection_ApplicationEndpoint) ProtoMessage ¶
func (*AppConnection_ApplicationEndpoint) ProtoMessage()
func (*AppConnection_ApplicationEndpoint) ProtoReflect ¶
func (x *AppConnection_ApplicationEndpoint) ProtoReflect() protoreflect.Message
func (*AppConnection_ApplicationEndpoint) Reset ¶
func (x *AppConnection_ApplicationEndpoint) Reset()
func (*AppConnection_ApplicationEndpoint) SetHost ¶
func (x *AppConnection_ApplicationEndpoint) SetHost(v string)
func (*AppConnection_ApplicationEndpoint) SetPort ¶
func (x *AppConnection_ApplicationEndpoint) SetPort(v int32)
func (*AppConnection_ApplicationEndpoint) String ¶
func (x *AppConnection_ApplicationEndpoint) String() string
type AppConnection_ApplicationEndpoint_builder ¶
type AppConnection_ApplicationEndpoint_builder struct {
// Required. Hostname or IP address of the remote application endpoint.
Host string
// Required. Port of the remote application endpoint.
Port int32
// contains filtered or unexported fields
}
func (AppConnection_ApplicationEndpoint_builder) Build ¶
func (b0 AppConnection_ApplicationEndpoint_builder) Build() *AppConnection_ApplicationEndpoint
type AppConnection_Gateway ¶
type AppConnection_Gateway struct {
// Required. The type of hosting used by the gateway.
Type AppConnection_Gateway_Type `` /* 143-byte string literal not displayed */
// Output only. Server-defined URI for this resource.
Uri string `protobuf:"bytes,3,opt,name=uri,proto3" json:"uri,omitempty"`
// Output only. Ingress port reserved on the gateways for this
// AppConnection, if not specified or zero, the default port is 19443.
IngressPort int32 `protobuf:"varint,4,opt,name=ingress_port,json=ingressPort,proto3" json:"ingress_port,omitempty"`
// Required. AppGateway name in following format:
// `projects/{project_id}/locations/{location_id}/appgateways/{gateway_id}`
AppGateway string `protobuf:"bytes,5,opt,name=app_gateway,json=appGateway,proto3" json:"app_gateway,omitempty"`
// Output only. L7 private service connection for this resource.
L7Psc string `protobuf:"bytes,6,opt,name=l7psc,proto3" json:"l7psc,omitempty"`
// contains filtered or unexported fields
}
Gateway represents a user facing component that serves as an entrance to enable connectivity.
func (*AppConnection_Gateway) GetAppGateway ¶
func (x *AppConnection_Gateway) GetAppGateway() string
func (*AppConnection_Gateway) GetIngressPort ¶
func (x *AppConnection_Gateway) GetIngressPort() int32
func (*AppConnection_Gateway) GetL7Psc ¶
func (x *AppConnection_Gateway) GetL7Psc() string
func (*AppConnection_Gateway) GetType ¶
func (x *AppConnection_Gateway) GetType() AppConnection_Gateway_Type
func (*AppConnection_Gateway) GetUri ¶
func (x *AppConnection_Gateway) GetUri() string
func (*AppConnection_Gateway) ProtoMessage ¶
func (*AppConnection_Gateway) ProtoMessage()
func (*AppConnection_Gateway) ProtoReflect ¶
func (x *AppConnection_Gateway) ProtoReflect() protoreflect.Message
func (*AppConnection_Gateway) Reset ¶
func (x *AppConnection_Gateway) Reset()
func (*AppConnection_Gateway) SetAppGateway ¶
func (x *AppConnection_Gateway) SetAppGateway(v string)
func (*AppConnection_Gateway) SetIngressPort ¶
func (x *AppConnection_Gateway) SetIngressPort(v int32)
func (*AppConnection_Gateway) SetL7Psc ¶
func (x *AppConnection_Gateway) SetL7Psc(v string)
func (*AppConnection_Gateway) SetType ¶
func (x *AppConnection_Gateway) SetType(v AppConnection_Gateway_Type)
func (*AppConnection_Gateway) SetUri ¶
func (x *AppConnection_Gateway) SetUri(v string)
func (*AppConnection_Gateway) String ¶
func (x *AppConnection_Gateway) String() string
type AppConnection_Gateway_Type ¶
type AppConnection_Gateway_Type int32
Enum listing possible gateway hosting options.
const ( // Default value. This value is unused. AppConnection_Gateway_TYPE_UNSPECIFIED AppConnection_Gateway_Type = 0 // Gateway hosted in a GCP regional managed instance group. AppConnection_Gateway_GCP_REGIONAL_MIG AppConnection_Gateway_Type = 1 )
func (AppConnection_Gateway_Type) Descriptor ¶
func (AppConnection_Gateway_Type) Descriptor() protoreflect.EnumDescriptor
func (AppConnection_Gateway_Type) Enum ¶
func (x AppConnection_Gateway_Type) Enum() *AppConnection_Gateway_Type
func (AppConnection_Gateway_Type) Number ¶
func (x AppConnection_Gateway_Type) Number() protoreflect.EnumNumber
func (AppConnection_Gateway_Type) String ¶
func (x AppConnection_Gateway_Type) String() string
func (AppConnection_Gateway_Type) Type ¶
func (AppConnection_Gateway_Type) Type() protoreflect.EnumType
type AppConnection_Gateway_builder ¶
type AppConnection_Gateway_builder struct {
// Required. The type of hosting used by the gateway.
Type AppConnection_Gateway_Type
// Output only. Server-defined URI for this resource.
Uri string
// Output only. Ingress port reserved on the gateways for this
// AppConnection, if not specified or zero, the default port is 19443.
IngressPort int32
// Required. AppGateway name in following format:
// `projects/{project_id}/locations/{location_id}/appgateways/{gateway_id}`
AppGateway string
// Output only. L7 private service connection for this resource.
L7Psc string
// contains filtered or unexported fields
}
func (AppConnection_Gateway_builder) Build ¶
func (b0 AppConnection_Gateway_builder) Build() *AppConnection_Gateway
type AppConnection_State ¶
type AppConnection_State int32
Represents the different states of a AppConnection.
const ( // Default value. This value is unused. AppConnection_STATE_UNSPECIFIED AppConnection_State = 0 // AppConnection is being created. AppConnection_CREATING AppConnection_State = 1 // AppConnection has been created. AppConnection_CREATED AppConnection_State = 2 // AppConnection's configuration is being updated. AppConnection_UPDATING AppConnection_State = 3 // AppConnection is being deleted. AppConnection_DELETING AppConnection_State = 4 // AppConnection is down and may be restored in the future. // This happens when CCFE sends ProjectState = OFF. AppConnection_DOWN AppConnection_State = 5 )
func (AppConnection_State) Descriptor ¶
func (AppConnection_State) Descriptor() protoreflect.EnumDescriptor
func (AppConnection_State) Enum ¶
func (x AppConnection_State) Enum() *AppConnection_State
func (AppConnection_State) Number ¶
func (x AppConnection_State) Number() protoreflect.EnumNumber
func (AppConnection_State) String ¶
func (x AppConnection_State) String() string
func (AppConnection_State) Type ¶
func (AppConnection_State) Type() protoreflect.EnumType
type AppConnection_Type ¶
type AppConnection_Type int32
Enum containing list of all possible network connectivity options supported by BeyondCorp AppConnection.
const ( // Default value. This value is unused. AppConnection_TYPE_UNSPECIFIED AppConnection_Type = 0 // TCP Proxy based BeyondCorp AppConnection. API will default to this if // unset. AppConnection_TCP_PROXY AppConnection_Type = 1 )
func (AppConnection_Type) Descriptor ¶
func (AppConnection_Type) Descriptor() protoreflect.EnumDescriptor
func (AppConnection_Type) Enum ¶
func (x AppConnection_Type) Enum() *AppConnection_Type
func (AppConnection_Type) Number ¶
func (x AppConnection_Type) Number() protoreflect.EnumNumber
func (AppConnection_Type) String ¶
func (x AppConnection_Type) String() string
func (AppConnection_Type) Type ¶
func (AppConnection_Type) Type() protoreflect.EnumType
type AppConnection_builder ¶
type AppConnection_builder struct {
// Required. Unique resource name of the AppConnection.
// The name is ignored when creating a AppConnection.
Name string
// Output only. Timestamp when the resource was created.
CreateTime *timestamppb.Timestamp
// Output only. Timestamp when the resource was last modified.
UpdateTime *timestamppb.Timestamp
// Optional. Resource labels to represent user provided metadata.
Labels map[string]string
// Optional. An arbitrary user-provided name for the AppConnection. Cannot
// exceed 64 characters.
DisplayName string
// Output only. A unique identifier for the instance generated by the
// system.
Uid string
// Required. The type of network connectivity used by the AppConnection.
Type AppConnection_Type
// Required. Address of the remote application endpoint for the BeyondCorp
// AppConnection.
ApplicationEndpoint *AppConnection_ApplicationEndpoint
// Optional. List of [google.cloud.beyondcorp.v1main.Connector.name] that are
// authorised to be associated with this AppConnection.
Connectors []string
// Output only. The current state of the AppConnection.
State AppConnection_State
// Optional. Gateway used by the AppConnection.
Gateway *AppConnection_Gateway
// contains filtered or unexported fields
}
func (AppConnection_builder) Build ¶
func (b0 AppConnection_builder) Build() *AppConnection
Source Files
¶
- data.pb.go
- events.pb.go