appconnectorsv1

package
v1.36.11-2024050211440... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

const AppConnector_PrincipalInfo_ServiceAccount_case case_AppConnector_PrincipalInfo_Type = 1
const AppConnector_PrincipalInfo_Type_not_set_case case_AppConnector_PrincipalInfo_Type = 0

Variables

var (
	HealthStatus_name = map[int32]string{
		0: "HEALTH_STATUS_UNSPECIFIED",
		1: "HEALTHY",
		2: "UNHEALTHY",
		3: "UNRESPONSIVE",
		4: "DEGRADED",
	}
	HealthStatus_value = map[string]int32{
		"HEALTH_STATUS_UNSPECIFIED": 0,
		"HEALTHY":                   1,
		"UNHEALTHY":                 2,
		"UNRESPONSIVE":              3,
		"DEGRADED":                  4,
	}
)

Enum value maps for HealthStatus.

var (
	AppConnector_State_name = map[int32]string{
		0: "STATE_UNSPECIFIED",
		1: "CREATING",
		2: "CREATED",
		3: "UPDATING",
		4: "DELETING",
		5: "DOWN",
	}
	AppConnector_State_value = map[string]int32{
		"STATE_UNSPECIFIED": 0,
		"CREATING":          1,
		"CREATED":           2,
		"UPDATING":          3,
		"DELETING":          4,
		"DOWN":              5,
	}
)

Enum value maps for AppConnector_State.

var File_google_events_cloud_beyondcorp_appconnectors_v1_data_proto protoreflect.FileDescriptor
var File_google_events_cloud_beyondcorp_appconnectors_v1_events_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type AppConnector

type AppConnector struct {

	// Required. Unique resource name of the AppConnector.
	// The name is ignored when creating a AppConnector.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Output only. Timestamp when the resource was created.
	CreateTime *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
	// Output only. Timestamp when the resource was last modified.
	UpdateTime *timestamppb.Timestamp `protobuf:"bytes,3,opt,name=update_time,json=updateTime,proto3" json:"update_time,omitempty"`
	// Optional. Resource labels to represent user provided metadata.
	Labels map[string]string `` /* 139-byte string literal not displayed */
	// Optional. An arbitrary user-provided name for the AppConnector. Cannot
	// exceed 64 characters.
	DisplayName string `protobuf:"bytes,5,opt,name=display_name,json=displayName,proto3" json:"display_name,omitempty"`
	// Output only. A unique identifier for the instance generated by the
	// system.
	Uid string `protobuf:"bytes,6,opt,name=uid,proto3" json:"uid,omitempty"`
	// Output only. The current state of the AppConnector.
	State AppConnector_State `` /* 136-byte string literal not displayed */
	// Required. Principal information about the Identity of the AppConnector.
	PrincipalInfo *AppConnector_PrincipalInfo `protobuf:"bytes,8,opt,name=principal_info,json=principalInfo,proto3" json:"principal_info,omitempty"`
	// Optional. Resource info of the connector.
	ResourceInfo *ResourceInfo `protobuf:"bytes,11,opt,name=resource_info,json=resourceInfo,proto3" json:"resource_info,omitempty"`
	// contains filtered or unexported fields
}

A BeyondCorp connector resource that represents an application facing component deployed proximal to and with direct access to the application instances. It is used to establish connectivity between the remote enterprise environment and GCP. It initiates connections to the applications and can proxy the data from users over the connection.

func (*AppConnector) ClearCreateTime

func (x *AppConnector) ClearCreateTime()

func (*AppConnector) ClearPrincipalInfo

func (x *AppConnector) ClearPrincipalInfo()

func (*AppConnector) ClearResourceInfo

func (x *AppConnector) ClearResourceInfo()

func (*AppConnector) ClearUpdateTime

func (x *AppConnector) ClearUpdateTime()

func (*AppConnector) GetCreateTime

func (x *AppConnector) GetCreateTime() *timestamppb.Timestamp

func (*AppConnector) GetDisplayName

func (x *AppConnector) GetDisplayName() string

func (*AppConnector) GetLabels

func (x *AppConnector) GetLabels() map[string]string

func (*AppConnector) GetName

func (x *AppConnector) GetName() string

func (*AppConnector) GetPrincipalInfo

func (x *AppConnector) GetPrincipalInfo() *AppConnector_PrincipalInfo

func (*AppConnector) GetResourceInfo

func (x *AppConnector) GetResourceInfo() *ResourceInfo

func (*AppConnector) GetState

func (x *AppConnector) GetState() AppConnector_State

func (*AppConnector) GetUid

func (x *AppConnector) GetUid() string

func (*AppConnector) GetUpdateTime

func (x *AppConnector) GetUpdateTime() *timestamppb.Timestamp

func (*AppConnector) HasCreateTime

func (x *AppConnector) HasCreateTime() bool

func (*AppConnector) HasPrincipalInfo

func (x *AppConnector) HasPrincipalInfo() bool

func (*AppConnector) HasResourceInfo

func (x *AppConnector) HasResourceInfo() bool

func (*AppConnector) HasUpdateTime

func (x *AppConnector) HasUpdateTime() bool

func (*AppConnector) ProtoMessage

func (*AppConnector) ProtoMessage()

func (*AppConnector) ProtoReflect

func (x *AppConnector) ProtoReflect() protoreflect.Message

func (*AppConnector) Reset

func (x *AppConnector) Reset()

func (*AppConnector) SetCreateTime

func (x *AppConnector) SetCreateTime(v *timestamppb.Timestamp)

func (*AppConnector) SetDisplayName

func (x *AppConnector) SetDisplayName(v string)

func (*AppConnector) SetLabels

func (x *AppConnector) SetLabels(v map[string]string)

func (*AppConnector) SetName

func (x *AppConnector) SetName(v string)

func (*AppConnector) SetPrincipalInfo

func (x *AppConnector) SetPrincipalInfo(v *AppConnector_PrincipalInfo)

func (*AppConnector) SetResourceInfo

func (x *AppConnector) SetResourceInfo(v *ResourceInfo)

func (*AppConnector) SetState

func (x *AppConnector) SetState(v AppConnector_State)

func (*AppConnector) SetUid

func (x *AppConnector) SetUid(v string)

func (*AppConnector) SetUpdateTime

func (x *AppConnector) SetUpdateTime(v *timestamppb.Timestamp)

func (*AppConnector) String

func (x *AppConnector) String() string

type AppConnectorCreatedEvent

type AppConnectorCreatedEvent struct {

	// The data associated with the event.
	Data *AppConnectorEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

The CloudEvent raised when an AppConnector is created.

func (*AppConnectorCreatedEvent) ClearData

func (x *AppConnectorCreatedEvent) ClearData()

func (*AppConnectorCreatedEvent) GetData

func (*AppConnectorCreatedEvent) HasData

func (x *AppConnectorCreatedEvent) HasData() bool

func (*AppConnectorCreatedEvent) ProtoMessage

func (*AppConnectorCreatedEvent) ProtoMessage()

func (*AppConnectorCreatedEvent) ProtoReflect

func (x *AppConnectorCreatedEvent) ProtoReflect() protoreflect.Message

func (*AppConnectorCreatedEvent) Reset

func (x *AppConnectorCreatedEvent) Reset()

func (*AppConnectorCreatedEvent) SetData

func (*AppConnectorCreatedEvent) String

func (x *AppConnectorCreatedEvent) String() string

type AppConnectorCreatedEvent_builder

type AppConnectorCreatedEvent_builder struct {

	// The data associated with the event.
	Data *AppConnectorEventData
	// contains filtered or unexported fields
}

func (AppConnectorCreatedEvent_builder) Build

type AppConnectorDeletedEvent

type AppConnectorDeletedEvent struct {

	// The data associated with the event.
	Data *AppConnectorEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

The CloudEvent raised when an AppConnector is deleted.

func (*AppConnectorDeletedEvent) ClearData

func (x *AppConnectorDeletedEvent) ClearData()

func (*AppConnectorDeletedEvent) GetData

func (*AppConnectorDeletedEvent) HasData

func (x *AppConnectorDeletedEvent) HasData() bool

func (*AppConnectorDeletedEvent) ProtoMessage

func (*AppConnectorDeletedEvent) ProtoMessage()

func (*AppConnectorDeletedEvent) ProtoReflect

func (x *AppConnectorDeletedEvent) ProtoReflect() protoreflect.Message

func (*AppConnectorDeletedEvent) Reset

func (x *AppConnectorDeletedEvent) Reset()

func (*AppConnectorDeletedEvent) SetData

func (*AppConnectorDeletedEvent) String

func (x *AppConnectorDeletedEvent) String() string

type AppConnectorDeletedEvent_builder

type AppConnectorDeletedEvent_builder struct {

	// The data associated with the event.
	Data *AppConnectorEventData
	// contains filtered or unexported fields
}

func (AppConnectorDeletedEvent_builder) Build

type AppConnectorEventData

type AppConnectorEventData struct {

	// Optional. The AppConnector event payload. Unset for deletion events.
	Payload *AppConnector `protobuf:"bytes,1,opt,name=payload,proto3,oneof" json:"payload,omitempty"`
	// contains filtered or unexported fields
}

The data within all AppConnector events.

func (*AppConnectorEventData) ClearPayload

func (x *AppConnectorEventData) ClearPayload()

func (*AppConnectorEventData) GetPayload

func (x *AppConnectorEventData) GetPayload() *AppConnector

func (*AppConnectorEventData) HasPayload

func (x *AppConnectorEventData) HasPayload() bool

func (*AppConnectorEventData) ProtoMessage

func (*AppConnectorEventData) ProtoMessage()

func (*AppConnectorEventData) ProtoReflect

func (x *AppConnectorEventData) ProtoReflect() protoreflect.Message

func (*AppConnectorEventData) Reset

func (x *AppConnectorEventData) Reset()

func (*AppConnectorEventData) SetPayload

func (x *AppConnectorEventData) SetPayload(v *AppConnector)

func (*AppConnectorEventData) String

func (x *AppConnectorEventData) String() string

type AppConnectorEventData_builder

type AppConnectorEventData_builder struct {

	// Optional. The AppConnector event payload. Unset for deletion events.
	Payload *AppConnector
	// contains filtered or unexported fields
}

func (AppConnectorEventData_builder) Build

type AppConnectorUpdatedEvent

type AppConnectorUpdatedEvent struct {

	// The data associated with the event.
	Data *AppConnectorEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

The CloudEvent raised when an AppConnector is updated.

func (*AppConnectorUpdatedEvent) ClearData

func (x *AppConnectorUpdatedEvent) ClearData()

func (*AppConnectorUpdatedEvent) GetData

func (*AppConnectorUpdatedEvent) HasData

func (x *AppConnectorUpdatedEvent) HasData() bool

func (*AppConnectorUpdatedEvent) ProtoMessage

func (*AppConnectorUpdatedEvent) ProtoMessage()

func (*AppConnectorUpdatedEvent) ProtoReflect

func (x *AppConnectorUpdatedEvent) ProtoReflect() protoreflect.Message

func (*AppConnectorUpdatedEvent) Reset

func (x *AppConnectorUpdatedEvent) Reset()

func (*AppConnectorUpdatedEvent) SetData

func (*AppConnectorUpdatedEvent) String

func (x *AppConnectorUpdatedEvent) String() string

type AppConnectorUpdatedEvent_builder

type AppConnectorUpdatedEvent_builder struct {

	// The data associated with the event.
	Data *AppConnectorEventData
	// contains filtered or unexported fields
}

func (AppConnectorUpdatedEvent_builder) Build

type AppConnector_PrincipalInfo

type AppConnector_PrincipalInfo struct {

	// Types that are valid to be assigned to Type:
	//
	//	*AppConnector_PrincipalInfo_ServiceAccount_
	Type isAppConnector_PrincipalInfo_Type `protobuf_oneof:"type"`
	// contains filtered or unexported fields
}

PrincipalInfo represents an Identity oneof.

func (*AppConnector_PrincipalInfo) ClearServiceAccount

func (x *AppConnector_PrincipalInfo) ClearServiceAccount()

func (*AppConnector_PrincipalInfo) ClearType

func (x *AppConnector_PrincipalInfo) ClearType()

func (*AppConnector_PrincipalInfo) GetServiceAccount

func (*AppConnector_PrincipalInfo) GetType

func (x *AppConnector_PrincipalInfo) GetType() isAppConnector_PrincipalInfo_Type

func (*AppConnector_PrincipalInfo) HasServiceAccount

func (x *AppConnector_PrincipalInfo) HasServiceAccount() bool

func (*AppConnector_PrincipalInfo) HasType

func (x *AppConnector_PrincipalInfo) HasType() bool

func (*AppConnector_PrincipalInfo) ProtoMessage

func (*AppConnector_PrincipalInfo) ProtoMessage()

func (*AppConnector_PrincipalInfo) ProtoReflect

func (*AppConnector_PrincipalInfo) Reset

func (x *AppConnector_PrincipalInfo) Reset()

func (*AppConnector_PrincipalInfo) SetServiceAccount

func (*AppConnector_PrincipalInfo) String

func (x *AppConnector_PrincipalInfo) String() string

func (*AppConnector_PrincipalInfo) WhichType

func (x *AppConnector_PrincipalInfo) WhichType() case_AppConnector_PrincipalInfo_Type

type AppConnector_PrincipalInfo_ServiceAccount

type AppConnector_PrincipalInfo_ServiceAccount struct {

	// Email address of the service account.
	Email string `protobuf:"bytes,1,opt,name=email,proto3" json:"email,omitempty"`
	// contains filtered or unexported fields
}

ServiceAccount represents a GCP service account.

func (*AppConnector_PrincipalInfo_ServiceAccount) GetEmail

func (*AppConnector_PrincipalInfo_ServiceAccount) ProtoMessage

func (*AppConnector_PrincipalInfo_ServiceAccount) ProtoReflect

func (*AppConnector_PrincipalInfo_ServiceAccount) Reset

func (*AppConnector_PrincipalInfo_ServiceAccount) SetEmail

func (*AppConnector_PrincipalInfo_ServiceAccount) String

type AppConnector_PrincipalInfo_ServiceAccount_

type AppConnector_PrincipalInfo_ServiceAccount_ struct {
	// A GCP service account.
	ServiceAccount *AppConnector_PrincipalInfo_ServiceAccount `protobuf:"bytes,1,opt,name=service_account,json=serviceAccount,proto3,oneof"`
}

type AppConnector_PrincipalInfo_ServiceAccount_builder

type AppConnector_PrincipalInfo_ServiceAccount_builder struct {

	// Email address of the service account.
	Email string
	// contains filtered or unexported fields
}

func (AppConnector_PrincipalInfo_ServiceAccount_builder) Build

type AppConnector_PrincipalInfo_builder

type AppConnector_PrincipalInfo_builder struct {

	// Fields of oneof Type:
	// A GCP service account.
	ServiceAccount *AppConnector_PrincipalInfo_ServiceAccount
	// contains filtered or unexported fields
}

func (AppConnector_PrincipalInfo_builder) Build

type AppConnector_State

type AppConnector_State int32

Represents the different states of a AppConnector.

const (
	// Default value. This value is unused.
	AppConnector_STATE_UNSPECIFIED AppConnector_State = 0
	// AppConnector is being created.
	AppConnector_CREATING AppConnector_State = 1
	// AppConnector has been created.
	AppConnector_CREATED AppConnector_State = 2
	// AppConnector's configuration is being updated.
	AppConnector_UPDATING AppConnector_State = 3
	// AppConnector is being deleted.
	AppConnector_DELETING AppConnector_State = 4
	// AppConnector is down and may be restored in the future.
	// This happens when CCFE sends ProjectState = OFF.
	AppConnector_DOWN AppConnector_State = 5
)

func (AppConnector_State) Descriptor

func (AppConnector_State) Enum

func (AppConnector_State) Number

func (AppConnector_State) String

func (x AppConnector_State) String() string

func (AppConnector_State) Type

type AppConnector_builder

type AppConnector_builder struct {

	// Required. Unique resource name of the AppConnector.
	// The name is ignored when creating a AppConnector.
	Name string
	// Output only. Timestamp when the resource was created.
	CreateTime *timestamppb.Timestamp
	// Output only. Timestamp when the resource was last modified.
	UpdateTime *timestamppb.Timestamp
	// Optional. Resource labels to represent user provided metadata.
	Labels map[string]string
	// Optional. An arbitrary user-provided name for the AppConnector. Cannot
	// exceed 64 characters.
	DisplayName string
	// Output only. A unique identifier for the instance generated by the
	// system.
	Uid string
	// Output only. The current state of the AppConnector.
	State AppConnector_State
	// Required. Principal information about the Identity of the AppConnector.
	PrincipalInfo *AppConnector_PrincipalInfo
	// Optional. Resource info of the connector.
	ResourceInfo *ResourceInfo
	// contains filtered or unexported fields
}

func (AppConnector_builder) Build

func (b0 AppConnector_builder) Build() *AppConnector

type HealthStatus

type HealthStatus int32

HealthStatus represents the health status.

const (
	// Health status is unknown: not initialized or failed to retrieve.
	HealthStatus_HEALTH_STATUS_UNSPECIFIED HealthStatus = 0
	// The resource is healthy.
	HealthStatus_HEALTHY HealthStatus = 1
	// The resource is unhealthy.
	HealthStatus_UNHEALTHY HealthStatus = 2
	// The resource is unresponsive.
	HealthStatus_UNRESPONSIVE HealthStatus = 3
	// Some sub-resources are UNHEALTHY.
	HealthStatus_DEGRADED HealthStatus = 4
)

func (HealthStatus) Descriptor

func (HealthStatus) Enum

func (x HealthStatus) Enum() *HealthStatus

func (HealthStatus) Number

func (HealthStatus) String

func (x HealthStatus) String() string

func (HealthStatus) Type

type ResourceInfo

type ResourceInfo struct {

	// Required. Unique Id for the resource.
	Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	// Overall health status. Overall status is derived based on the status of
	// each sub level resources.
	Status HealthStatus `` /* 132-byte string literal not displayed */
	// The timestamp to collect the info. It is suggested to be set by
	// the topmost level resource only.
	Time *timestamppb.Timestamp `protobuf:"bytes,4,opt,name=time,proto3" json:"time,omitempty"`
	// List of Info for the sub level resources.
	Sub []*ResourceInfo `protobuf:"bytes,5,rep,name=sub,proto3" json:"sub,omitempty"`
	// contains filtered or unexported fields
}

ResourceInfo represents the information/status of an app connector resource. Such as: - remote_agent

  • container
  • runtime
  • appgateway
  • appconnector
  • appconnection
  • tunnel
  • logagent

func (*ResourceInfo) ClearTime

func (x *ResourceInfo) ClearTime()

func (*ResourceInfo) GetId

func (x *ResourceInfo) GetId() string

func (*ResourceInfo) GetStatus

func (x *ResourceInfo) GetStatus() HealthStatus

func (*ResourceInfo) GetSub

func (x *ResourceInfo) GetSub() []*ResourceInfo

func (*ResourceInfo) GetTime

func (x *ResourceInfo) GetTime() *timestamppb.Timestamp

func (*ResourceInfo) HasTime

func (x *ResourceInfo) HasTime() bool

func (*ResourceInfo) ProtoMessage

func (*ResourceInfo) ProtoMessage()

func (*ResourceInfo) ProtoReflect

func (x *ResourceInfo) ProtoReflect() protoreflect.Message

func (*ResourceInfo) Reset

func (x *ResourceInfo) Reset()

func (*ResourceInfo) SetId

func (x *ResourceInfo) SetId(v string)

func (*ResourceInfo) SetStatus

func (x *ResourceInfo) SetStatus(v HealthStatus)

func (*ResourceInfo) SetSub

func (x *ResourceInfo) SetSub(v []*ResourceInfo)

func (*ResourceInfo) SetTime

func (x *ResourceInfo) SetTime(v *timestamppb.Timestamp)

func (*ResourceInfo) String

func (x *ResourceInfo) String() string

type ResourceInfo_builder

type ResourceInfo_builder struct {

	// Required. Unique Id for the resource.
	Id string
	// Overall health status. Overall status is derived based on the status of
	// each sub level resources.
	Status HealthStatus
	// The timestamp to collect the info. It is suggested to be set by
	// the topmost level resource only.
	Time *timestamppb.Timestamp
	// List of Info for the sub level resources.
	Sub []*ResourceInfo
	// contains filtered or unexported fields
}

func (ResourceInfo_builder) Build

func (b0 ResourceInfo_builder) Build() *ResourceInfo

Source Files

  • data.pb.go
  • events.pb.go

Jump to