clientconnectorservicesv1

package
v1.36.11-2024050211440... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

const ClientConnectorService_Egress_DestinationType_not_set_case case_ClientConnectorService_Egress_DestinationType = 0
const ClientConnectorService_Egress_PeeredVpc_case case_ClientConnectorService_Egress_DestinationType = 1
const ClientConnectorService_Ingress_Config_case case_ClientConnectorService_Ingress_IngressConfig = 1
const ClientConnectorService_Ingress_IngressConfig_not_set_case case_ClientConnectorService_Ingress_IngressConfig = 0

Variables

var (
	ClientConnectorService_State_name = map[int32]string{
		0: "STATE_UNSPECIFIED",
		1: "CREATING",
		2: "UPDATING",
		3: "DELETING",
		4: "RUNNING",
		5: "DOWN",
		6: "ERROR",
	}
	ClientConnectorService_State_value = map[string]int32{
		"STATE_UNSPECIFIED": 0,
		"CREATING":          1,
		"UPDATING":          2,
		"DELETING":          3,
		"RUNNING":           4,
		"DOWN":              5,
		"ERROR":             6,
	}
)

Enum value maps for ClientConnectorService_State.

var (
	ClientConnectorService_Ingress_Config_TransportProtocol_name = map[int32]string{
		0: "TRANSPORT_PROTOCOL_UNSPECIFIED",
		1: "TCP",
	}
	ClientConnectorService_Ingress_Config_TransportProtocol_value = map[string]int32{
		"TRANSPORT_PROTOCOL_UNSPECIFIED": 0,
		"TCP":                            1,
	}
)

Enum value maps for ClientConnectorService_Ingress_Config_TransportProtocol.

var File_google_events_cloud_beyondcorp_clientconnectorservices_v1_data_proto protoreflect.FileDescriptor
var File_google_events_cloud_beyondcorp_clientconnectorservices_v1_events_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type ClientConnectorService

type ClientConnectorService struct {

	// Required. Name of resource. The name is ignored during creation.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Output only. [Output only] Create time stamp.
	CreateTime *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
	// Output only. [Output only] Update time stamp.
	UpdateTime *timestamppb.Timestamp `protobuf:"bytes,3,opt,name=update_time,json=updateTime,proto3" json:"update_time,omitempty"`
	// Optional. User-provided name.
	// The display name should follow certain format.
	// * Must be 6 to 30 characters in length.
	// * Can only contain lowercase letters, numbers, and hyphens.
	// * Must start with a letter.
	DisplayName string `protobuf:"bytes,4,opt,name=display_name,json=displayName,proto3" json:"display_name,omitempty"`
	// Required. The details of the ingress settings.
	Ingress *ClientConnectorService_Ingress `protobuf:"bytes,6,opt,name=ingress,proto3" json:"ingress,omitempty"`
	// Required. The details of the egress settings.
	Egress *ClientConnectorService_Egress `protobuf:"bytes,7,opt,name=egress,proto3" json:"egress,omitempty"`
	// Output only. The operational state of the ClientConnectorService.
	State ClientConnectorService_State `` /* 156-byte string literal not displayed */
	// contains filtered or unexported fields
}

Message describing ClientConnectorService object.

func (*ClientConnectorService) ClearCreateTime

func (x *ClientConnectorService) ClearCreateTime()

func (*ClientConnectorService) ClearEgress

func (x *ClientConnectorService) ClearEgress()

func (*ClientConnectorService) ClearIngress

func (x *ClientConnectorService) ClearIngress()

func (*ClientConnectorService) ClearUpdateTime

func (x *ClientConnectorService) ClearUpdateTime()

func (*ClientConnectorService) GetCreateTime

func (x *ClientConnectorService) GetCreateTime() *timestamppb.Timestamp

func (*ClientConnectorService) GetDisplayName

func (x *ClientConnectorService) GetDisplayName() string

func (*ClientConnectorService) GetEgress

func (*ClientConnectorService) GetIngress

func (*ClientConnectorService) GetName

func (x *ClientConnectorService) GetName() string

func (*ClientConnectorService) GetState

func (*ClientConnectorService) GetUpdateTime

func (x *ClientConnectorService) GetUpdateTime() *timestamppb.Timestamp

func (*ClientConnectorService) HasCreateTime

func (x *ClientConnectorService) HasCreateTime() bool

func (*ClientConnectorService) HasEgress

func (x *ClientConnectorService) HasEgress() bool

func (*ClientConnectorService) HasIngress

func (x *ClientConnectorService) HasIngress() bool

func (*ClientConnectorService) HasUpdateTime

func (x *ClientConnectorService) HasUpdateTime() bool

func (*ClientConnectorService) ProtoMessage

func (*ClientConnectorService) ProtoMessage()

func (*ClientConnectorService) ProtoReflect

func (x *ClientConnectorService) ProtoReflect() protoreflect.Message

func (*ClientConnectorService) Reset

func (x *ClientConnectorService) Reset()

func (*ClientConnectorService) SetCreateTime

func (x *ClientConnectorService) SetCreateTime(v *timestamppb.Timestamp)

func (*ClientConnectorService) SetDisplayName

func (x *ClientConnectorService) SetDisplayName(v string)

func (*ClientConnectorService) SetEgress

func (*ClientConnectorService) SetIngress

func (*ClientConnectorService) SetName

func (x *ClientConnectorService) SetName(v string)

func (*ClientConnectorService) SetState

func (*ClientConnectorService) SetUpdateTime

func (x *ClientConnectorService) SetUpdateTime(v *timestamppb.Timestamp)

func (*ClientConnectorService) String

func (x *ClientConnectorService) String() string

type ClientConnectorServiceCreatedEvent

type ClientConnectorServiceCreatedEvent struct {

	// The data associated with the event.
	Data *ClientConnectorServiceEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

The CloudEvent raised when a ClientConnectorService is created.

func (*ClientConnectorServiceCreatedEvent) ClearData

func (x *ClientConnectorServiceCreatedEvent) ClearData()

func (*ClientConnectorServiceCreatedEvent) GetData

func (*ClientConnectorServiceCreatedEvent) HasData

func (*ClientConnectorServiceCreatedEvent) ProtoMessage

func (*ClientConnectorServiceCreatedEvent) ProtoMessage()

func (*ClientConnectorServiceCreatedEvent) ProtoReflect

func (*ClientConnectorServiceCreatedEvent) Reset

func (*ClientConnectorServiceCreatedEvent) SetData

func (*ClientConnectorServiceCreatedEvent) String

type ClientConnectorServiceCreatedEvent_builder

type ClientConnectorServiceCreatedEvent_builder struct {

	// The data associated with the event.
	Data *ClientConnectorServiceEventData
	// contains filtered or unexported fields
}

func (ClientConnectorServiceCreatedEvent_builder) Build

type ClientConnectorServiceDeletedEvent

type ClientConnectorServiceDeletedEvent struct {

	// The data associated with the event.
	Data *ClientConnectorServiceEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

The CloudEvent raised when a ClientConnectorService is deleted.

func (*ClientConnectorServiceDeletedEvent) ClearData

func (x *ClientConnectorServiceDeletedEvent) ClearData()

func (*ClientConnectorServiceDeletedEvent) GetData

func (*ClientConnectorServiceDeletedEvent) HasData

func (*ClientConnectorServiceDeletedEvent) ProtoMessage

func (*ClientConnectorServiceDeletedEvent) ProtoMessage()

func (*ClientConnectorServiceDeletedEvent) ProtoReflect

func (*ClientConnectorServiceDeletedEvent) Reset

func (*ClientConnectorServiceDeletedEvent) SetData

func (*ClientConnectorServiceDeletedEvent) String

type ClientConnectorServiceDeletedEvent_builder

type ClientConnectorServiceDeletedEvent_builder struct {

	// The data associated with the event.
	Data *ClientConnectorServiceEventData
	// contains filtered or unexported fields
}

func (ClientConnectorServiceDeletedEvent_builder) Build

type ClientConnectorServiceEventData

type ClientConnectorServiceEventData struct {

	// Optional. The ClientConnectorService event payload. Unset for deletion
	// events.
	Payload *ClientConnectorService `protobuf:"bytes,1,opt,name=payload,proto3,oneof" json:"payload,omitempty"`
	// contains filtered or unexported fields
}

The data within all ClientConnectorService events.

func (*ClientConnectorServiceEventData) ClearPayload

func (x *ClientConnectorServiceEventData) ClearPayload()

func (*ClientConnectorServiceEventData) GetPayload

func (*ClientConnectorServiceEventData) HasPayload

func (x *ClientConnectorServiceEventData) HasPayload() bool

func (*ClientConnectorServiceEventData) ProtoMessage

func (*ClientConnectorServiceEventData) ProtoMessage()

func (*ClientConnectorServiceEventData) ProtoReflect

func (*ClientConnectorServiceEventData) Reset

func (*ClientConnectorServiceEventData) SetPayload

func (*ClientConnectorServiceEventData) String

type ClientConnectorServiceEventData_builder

type ClientConnectorServiceEventData_builder struct {

	// Optional. The ClientConnectorService event payload. Unset for deletion
	// events.
	Payload *ClientConnectorService
	// contains filtered or unexported fields
}

func (ClientConnectorServiceEventData_builder) Build

type ClientConnectorServiceUpdatedEvent

type ClientConnectorServiceUpdatedEvent struct {

	// The data associated with the event.
	Data *ClientConnectorServiceEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

The CloudEvent raised when a ClientConnectorService is updated.

func (*ClientConnectorServiceUpdatedEvent) ClearData

func (x *ClientConnectorServiceUpdatedEvent) ClearData()

func (*ClientConnectorServiceUpdatedEvent) GetData

func (*ClientConnectorServiceUpdatedEvent) HasData

func (*ClientConnectorServiceUpdatedEvent) ProtoMessage

func (*ClientConnectorServiceUpdatedEvent) ProtoMessage()

func (*ClientConnectorServiceUpdatedEvent) ProtoReflect

func (*ClientConnectorServiceUpdatedEvent) Reset

func (*ClientConnectorServiceUpdatedEvent) SetData

func (*ClientConnectorServiceUpdatedEvent) String

type ClientConnectorServiceUpdatedEvent_builder

type ClientConnectorServiceUpdatedEvent_builder struct {

	// The data associated with the event.
	Data *ClientConnectorServiceEventData
	// contains filtered or unexported fields
}

func (ClientConnectorServiceUpdatedEvent_builder) Build

type ClientConnectorService_Egress

type ClientConnectorService_Egress struct {

	// Types that are valid to be assigned to DestinationType:
	//
	//	*ClientConnectorService_Egress_PeeredVpc_
	DestinationType isClientConnectorService_Egress_DestinationType `protobuf_oneof:"destination_type"`
	// contains filtered or unexported fields
}

The details of the egress info. One of the following options should be set.

func (*ClientConnectorService_Egress) ClearDestinationType

func (x *ClientConnectorService_Egress) ClearDestinationType()

func (*ClientConnectorService_Egress) ClearPeeredVpc

func (x *ClientConnectorService_Egress) ClearPeeredVpc()

func (*ClientConnectorService_Egress) GetDestinationType

func (x *ClientConnectorService_Egress) GetDestinationType() isClientConnectorService_Egress_DestinationType

func (*ClientConnectorService_Egress) GetPeeredVpc

func (*ClientConnectorService_Egress) HasDestinationType

func (x *ClientConnectorService_Egress) HasDestinationType() bool

func (*ClientConnectorService_Egress) HasPeeredVpc

func (x *ClientConnectorService_Egress) HasPeeredVpc() bool

func (*ClientConnectorService_Egress) ProtoMessage

func (*ClientConnectorService_Egress) ProtoMessage()

func (*ClientConnectorService_Egress) ProtoReflect

func (*ClientConnectorService_Egress) Reset

func (x *ClientConnectorService_Egress) Reset()

func (*ClientConnectorService_Egress) SetPeeredVpc

func (*ClientConnectorService_Egress) String

func (*ClientConnectorService_Egress) WhichDestinationType

func (x *ClientConnectorService_Egress) WhichDestinationType() case_ClientConnectorService_Egress_DestinationType

type ClientConnectorService_Egress_PeeredVpc

type ClientConnectorService_Egress_PeeredVpc struct {

	// Required. The name of the peered VPC owned by the consumer project.
	NetworkVpc string `protobuf:"bytes,1,opt,name=network_vpc,json=networkVpc,proto3" json:"network_vpc,omitempty"`
	// contains filtered or unexported fields
}

The peered VPC owned by the consumer project.

func (*ClientConnectorService_Egress_PeeredVpc) GetNetworkVpc

func (*ClientConnectorService_Egress_PeeredVpc) ProtoMessage

func (*ClientConnectorService_Egress_PeeredVpc) ProtoReflect

func (*ClientConnectorService_Egress_PeeredVpc) Reset

func (*ClientConnectorService_Egress_PeeredVpc) SetNetworkVpc

func (x *ClientConnectorService_Egress_PeeredVpc) SetNetworkVpc(v string)

func (*ClientConnectorService_Egress_PeeredVpc) String

type ClientConnectorService_Egress_PeeredVpc_

type ClientConnectorService_Egress_PeeredVpc_ struct {
	// A VPC from the consumer project.
	PeeredVpc *ClientConnectorService_Egress_PeeredVpc `protobuf:"bytes,1,opt,name=peered_vpc,json=peeredVpc,proto3,oneof"`
}

type ClientConnectorService_Egress_PeeredVpc_builder

type ClientConnectorService_Egress_PeeredVpc_builder struct {

	// Required. The name of the peered VPC owned by the consumer project.
	NetworkVpc string
	// contains filtered or unexported fields
}

func (ClientConnectorService_Egress_PeeredVpc_builder) Build

type ClientConnectorService_Egress_builder

type ClientConnectorService_Egress_builder struct {

	// Fields of oneof DestinationType:
	// A VPC from the consumer project.
	PeeredVpc *ClientConnectorService_Egress_PeeredVpc
	// contains filtered or unexported fields
}

func (ClientConnectorService_Egress_builder) Build

type ClientConnectorService_Ingress

type ClientConnectorService_Ingress struct {

	// Types that are valid to be assigned to IngressConfig:
	//
	//	*ClientConnectorService_Ingress_Config_
	IngressConfig isClientConnectorService_Ingress_IngressConfig `protobuf_oneof:"ingress_config"`
	// contains filtered or unexported fields
}

Settings of how to connect to the ClientGateway. One of the following options should be set.

func (*ClientConnectorService_Ingress) ClearConfig

func (x *ClientConnectorService_Ingress) ClearConfig()

func (*ClientConnectorService_Ingress) ClearIngressConfig

func (x *ClientConnectorService_Ingress) ClearIngressConfig()

func (*ClientConnectorService_Ingress) GetConfig

func (*ClientConnectorService_Ingress) GetIngressConfig

func (x *ClientConnectorService_Ingress) GetIngressConfig() isClientConnectorService_Ingress_IngressConfig

func (*ClientConnectorService_Ingress) HasConfig

func (x *ClientConnectorService_Ingress) HasConfig() bool

func (*ClientConnectorService_Ingress) HasIngressConfig

func (x *ClientConnectorService_Ingress) HasIngressConfig() bool

func (*ClientConnectorService_Ingress) ProtoMessage

func (*ClientConnectorService_Ingress) ProtoMessage()

func (*ClientConnectorService_Ingress) ProtoReflect

func (*ClientConnectorService_Ingress) Reset

func (x *ClientConnectorService_Ingress) Reset()

func (*ClientConnectorService_Ingress) SetConfig

func (*ClientConnectorService_Ingress) String

func (*ClientConnectorService_Ingress) WhichIngressConfig

func (x *ClientConnectorService_Ingress) WhichIngressConfig() case_ClientConnectorService_Ingress_IngressConfig

type ClientConnectorService_Ingress_Config

type ClientConnectorService_Ingress_Config struct {

	// Required. Immutable. The transport protocol used between the client and
	// the server.
	TransportProtocol ClientConnectorService_Ingress_Config_TransportProtocol `` /* 232-byte string literal not displayed */
	// Required. The settings used to configure basic ClientGateways.
	DestinationRoutes []*ClientConnectorService_Ingress_Config_DestinationRoute `protobuf:"bytes,2,rep,name=destination_routes,json=destinationRoutes,proto3" json:"destination_routes,omitempty"`
	// contains filtered or unexported fields
}

The basic ingress config for ClientGateways.

func (*ClientConnectorService_Ingress_Config) GetDestinationRoutes

func (*ClientConnectorService_Ingress_Config) GetTransportProtocol

func (*ClientConnectorService_Ingress_Config) ProtoMessage

func (*ClientConnectorService_Ingress_Config) ProtoMessage()

func (*ClientConnectorService_Ingress_Config) ProtoReflect

func (*ClientConnectorService_Ingress_Config) Reset

func (*ClientConnectorService_Ingress_Config) SetDestinationRoutes

func (*ClientConnectorService_Ingress_Config) SetTransportProtocol

func (*ClientConnectorService_Ingress_Config) String

type ClientConnectorService_Ingress_Config_

type ClientConnectorService_Ingress_Config_ struct {
	// The basic ingress config for ClientGateways.
	Config *ClientConnectorService_Ingress_Config `protobuf:"bytes,1,opt,name=config,proto3,oneof"`
}

type ClientConnectorService_Ingress_Config_DestinationRoute

type ClientConnectorService_Ingress_Config_DestinationRoute struct {

	// Required. The network address of the subnet
	// for which the packet is routed to the ClientGateway.
	Address string `protobuf:"bytes,1,opt,name=address,proto3" json:"address,omitempty"`
	// Required. The network mask of the subnet
	// for which the packet is routed to the ClientGateway.
	Netmask string `protobuf:"bytes,2,opt,name=netmask,proto3" json:"netmask,omitempty"`
	// contains filtered or unexported fields
}

The setting used to configure ClientGateways. It is adding routes to the client's routing table after the connection is established.

func (*ClientConnectorService_Ingress_Config_DestinationRoute) GetAddress

func (*ClientConnectorService_Ingress_Config_DestinationRoute) GetNetmask

func (*ClientConnectorService_Ingress_Config_DestinationRoute) ProtoMessage

func (*ClientConnectorService_Ingress_Config_DestinationRoute) ProtoReflect

func (*ClientConnectorService_Ingress_Config_DestinationRoute) Reset

func (*ClientConnectorService_Ingress_Config_DestinationRoute) SetAddress

func (*ClientConnectorService_Ingress_Config_DestinationRoute) SetNetmask

func (*ClientConnectorService_Ingress_Config_DestinationRoute) String

type ClientConnectorService_Ingress_Config_DestinationRoute_builder

type ClientConnectorService_Ingress_Config_DestinationRoute_builder struct {

	// Required. The network address of the subnet
	// for which the packet is routed to the ClientGateway.
	Address string
	// Required. The network mask of the subnet
	// for which the packet is routed to the ClientGateway.
	Netmask string
	// contains filtered or unexported fields
}

func (ClientConnectorService_Ingress_Config_DestinationRoute_builder) Build

type ClientConnectorService_Ingress_Config_TransportProtocol

type ClientConnectorService_Ingress_Config_TransportProtocol int32

The protocol used to connect to the server.

const (
	// Default value. This value is unused.
	ClientConnectorService_Ingress_Config_TRANSPORT_PROTOCOL_UNSPECIFIED ClientConnectorService_Ingress_Config_TransportProtocol = 0
	// TCP protocol.
	ClientConnectorService_Ingress_Config_TCP ClientConnectorService_Ingress_Config_TransportProtocol = 1
)

func (ClientConnectorService_Ingress_Config_TransportProtocol) Descriptor

func (ClientConnectorService_Ingress_Config_TransportProtocol) Enum

func (ClientConnectorService_Ingress_Config_TransportProtocol) Number

func (ClientConnectorService_Ingress_Config_TransportProtocol) String

func (ClientConnectorService_Ingress_Config_TransportProtocol) Type

type ClientConnectorService_Ingress_Config_builder

type ClientConnectorService_Ingress_Config_builder struct {

	// Required. Immutable. The transport protocol used between the client and
	// the server.
	TransportProtocol ClientConnectorService_Ingress_Config_TransportProtocol
	// Required. The settings used to configure basic ClientGateways.
	DestinationRoutes []*ClientConnectorService_Ingress_Config_DestinationRoute
	// contains filtered or unexported fields
}

func (ClientConnectorService_Ingress_Config_builder) Build

type ClientConnectorService_Ingress_builder

type ClientConnectorService_Ingress_builder struct {

	// Fields of oneof IngressConfig:
	// The basic ingress config for ClientGateways.
	Config *ClientConnectorService_Ingress_Config
	// contains filtered or unexported fields
}

func (ClientConnectorService_Ingress_builder) Build

type ClientConnectorService_State

type ClientConnectorService_State int32

Represents the different states of a ClientConnectorService.

const (
	// Default value. This value is unused.
	ClientConnectorService_STATE_UNSPECIFIED ClientConnectorService_State = 0
	// ClientConnectorService is being created.
	ClientConnectorService_CREATING ClientConnectorService_State = 1
	// ClientConnectorService is being updated.
	ClientConnectorService_UPDATING ClientConnectorService_State = 2
	// ClientConnectorService is being deleted.
	ClientConnectorService_DELETING ClientConnectorService_State = 3
	// ClientConnectorService is running.
	ClientConnectorService_RUNNING ClientConnectorService_State = 4
	// ClientConnectorService is down and may be restored in the future.
	// This happens when CCFE sends ProjectState = OFF.
	ClientConnectorService_DOWN ClientConnectorService_State = 5
	// ClientConnectorService encountered an error and is in an indeterministic
	// state.
	ClientConnectorService_ERROR ClientConnectorService_State = 6
)

func (ClientConnectorService_State) Descriptor

func (ClientConnectorService_State) Enum

func (ClientConnectorService_State) Number

func (ClientConnectorService_State) String

func (ClientConnectorService_State) Type

type ClientConnectorService_builder

type ClientConnectorService_builder struct {

	// Required. Name of resource. The name is ignored during creation.
	Name string
	// Output only. [Output only] Create time stamp.
	CreateTime *timestamppb.Timestamp
	// Output only. [Output only] Update time stamp.
	UpdateTime *timestamppb.Timestamp
	// Optional. User-provided name.
	// The display name should follow certain format.
	// * Must be 6 to 30 characters in length.
	// * Can only contain lowercase letters, numbers, and hyphens.
	// * Must start with a letter.
	DisplayName string
	// Required. The details of the ingress settings.
	Ingress *ClientConnectorService_Ingress
	// Required. The details of the egress settings.
	Egress *ClientConnectorService_Egress
	// Output only. The operational state of the ClientConnectorService.
	State ClientConnectorService_State
	// contains filtered or unexported fields
}

func (ClientConnectorService_builder) Build

Source Files

  • data.pb.go
  • events.pb.go

Jump to