eventarcv1

package
v1.36.11-2024050211440... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

const Channel_PubsubTopic_case case_Channel_Transport = 8
const Channel_Transport_not_set_case case_Channel_Transport = 0
const Destination_CloudFunction_case case_Destination_Descriptor_ = 2
const Destination_CloudRun_case case_Destination_Descriptor_ = 1
const Destination_Descriptor__not_set_case case_Destination_Descriptor_ = 0
const Destination_Gke_case case_Destination_Descriptor_ = 3
const Destination_Workflow_case case_Destination_Descriptor_ = 4
const Transport_Intermediary_not_set_case case_Transport_Intermediary = 0
const Transport_Pubsub_case case_Transport_Intermediary = 1

Variables

var (
	Channel_State_name = map[int32]string{
		0: "STATE_UNSPECIFIED",
		1: "PENDING",
		2: "ACTIVE",
		3: "INACTIVE",
	}
	Channel_State_value = map[string]int32{
		"STATE_UNSPECIFIED": 0,
		"PENDING":           1,
		"ACTIVE":            2,
		"INACTIVE":          3,
	}
)

Enum value maps for Channel_State.

var File_google_events_cloud_eventarc_v1_data_proto protoreflect.FileDescriptor
var File_google_events_cloud_eventarc_v1_events_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type Channel

type Channel struct {

	// Required. The resource name of the channel. Must be unique within the
	// location on the project and must be in
	// `projects/{project}/locations/{location}/channels/{channel_id}` format.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Output only. Server assigned unique identifier for the channel. The value
	// is a UUID4 string and guaranteed to remain unchanged until the resource is
	// deleted.
	Uid string `protobuf:"bytes,2,opt,name=uid,proto3" json:"uid,omitempty"`
	// Output only. The creation time.
	CreateTime *timestamppb.Timestamp `protobuf:"bytes,5,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
	// Output only. The last-modified time.
	UpdateTime *timestamppb.Timestamp `protobuf:"bytes,6,opt,name=update_time,json=updateTime,proto3" json:"update_time,omitempty"`
	// The name of the event provider (e.g. Eventarc SaaS partner) associated
	// with the channel. This provider will be granted permissions to publish
	// events to the channel. Format:
	// `projects/{project}/locations/{location}/providers/{provider_id}`.
	Provider string `protobuf:"bytes,7,opt,name=provider,proto3" json:"provider,omitempty"`
	// Types that are valid to be assigned to Transport:
	//
	//	*Channel_PubsubTopic
	Transport isChannel_Transport `protobuf_oneof:"transport"`
	// Output only. The state of a Channel.
	State Channel_State `protobuf:"varint,9,opt,name=state,proto3,enum=google.events.cloud.eventarc.v1.Channel_State" json:"state,omitempty"`
	// Output only. The activation token for the channel. The token must be used
	// by the provider to register the channel for publishing.
	ActivationToken string `protobuf:"bytes,10,opt,name=activation_token,json=activationToken,proto3" json:"activation_token,omitempty"`
	// Resource name of a KMS crypto key (managed by the user) used to
	// encrypt/decrypt their event data.
	//
	// It must match the pattern
	// `projects/*/locations/*/keyRings/*/cryptoKeys/*`.
	CryptoKeyName string `protobuf:"bytes,11,opt,name=crypto_key_name,json=cryptoKeyName,proto3" json:"crypto_key_name,omitempty"`
	// contains filtered or unexported fields
}

A representation of the Channel resource. A Channel is a resource on which event providers publish their events. The published events are delivered through the transport associated with the channel. Note that a channel is associated with exactly one event provider.

func (*Channel) ClearCreateTime

func (x *Channel) ClearCreateTime()

func (*Channel) ClearPubsubTopic

func (x *Channel) ClearPubsubTopic()

func (*Channel) ClearTransport

func (x *Channel) ClearTransport()

func (*Channel) ClearUpdateTime

func (x *Channel) ClearUpdateTime()

func (*Channel) GetActivationToken

func (x *Channel) GetActivationToken() string

func (*Channel) GetCreateTime

func (x *Channel) GetCreateTime() *timestamppb.Timestamp

func (*Channel) GetCryptoKeyName

func (x *Channel) GetCryptoKeyName() string

func (*Channel) GetName

func (x *Channel) GetName() string

func (*Channel) GetProvider

func (x *Channel) GetProvider() string

func (*Channel) GetPubsubTopic

func (x *Channel) GetPubsubTopic() string

func (*Channel) GetState

func (x *Channel) GetState() Channel_State

func (*Channel) GetTransport

func (x *Channel) GetTransport() isChannel_Transport

func (*Channel) GetUid

func (x *Channel) GetUid() string

func (*Channel) GetUpdateTime

func (x *Channel) GetUpdateTime() *timestamppb.Timestamp

func (*Channel) HasCreateTime

func (x *Channel) HasCreateTime() bool

func (*Channel) HasPubsubTopic

func (x *Channel) HasPubsubTopic() bool

func (*Channel) HasTransport

func (x *Channel) HasTransport() bool

func (*Channel) HasUpdateTime

func (x *Channel) HasUpdateTime() bool

func (*Channel) ProtoMessage

func (*Channel) ProtoMessage()

func (*Channel) ProtoReflect

func (x *Channel) ProtoReflect() protoreflect.Message

func (*Channel) Reset

func (x *Channel) Reset()

func (*Channel) SetActivationToken

func (x *Channel) SetActivationToken(v string)

func (*Channel) SetCreateTime

func (x *Channel) SetCreateTime(v *timestamppb.Timestamp)

func (*Channel) SetCryptoKeyName

func (x *Channel) SetCryptoKeyName(v string)

func (*Channel) SetName

func (x *Channel) SetName(v string)

func (*Channel) SetProvider

func (x *Channel) SetProvider(v string)

func (*Channel) SetPubsubTopic

func (x *Channel) SetPubsubTopic(v string)

func (*Channel) SetState

func (x *Channel) SetState(v Channel_State)

func (*Channel) SetUid

func (x *Channel) SetUid(v string)

func (*Channel) SetUpdateTime

func (x *Channel) SetUpdateTime(v *timestamppb.Timestamp)

func (*Channel) String

func (x *Channel) String() string

func (*Channel) WhichTransport

func (x *Channel) WhichTransport() case_Channel_Transport

type ChannelConnection

type ChannelConnection struct {

	// Required. The name of the connection.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Output only. Server assigned ID of the resource.
	// The server guarantees uniqueness and immutability until deleted.
	Uid string `protobuf:"bytes,2,opt,name=uid,proto3" json:"uid,omitempty"`
	// Required. The name of the connected subscriber Channel.
	// This is a weak reference to avoid cross project and cross accounts
	// references. This must be in
	// `projects/{project}/location/{location}/channels/{channel_id}` format.
	Channel string `protobuf:"bytes,5,opt,name=channel,proto3" json:"channel,omitempty"`
	// Output only. The creation time.
	CreateTime *timestamppb.Timestamp `protobuf:"bytes,6,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
	// Output only. The last-modified time.
	UpdateTime *timestamppb.Timestamp `protobuf:"bytes,7,opt,name=update_time,json=updateTime,proto3" json:"update_time,omitempty"`
	// contains filtered or unexported fields
}

A representation of the ChannelConnection resource. A ChannelConnection is a resource which event providers create during the activation process to establish a connection between the provider and the subscriber channel.

func (*ChannelConnection) ClearCreateTime

func (x *ChannelConnection) ClearCreateTime()

func (*ChannelConnection) ClearUpdateTime

func (x *ChannelConnection) ClearUpdateTime()

func (*ChannelConnection) GetChannel

func (x *ChannelConnection) GetChannel() string

func (*ChannelConnection) GetCreateTime

func (x *ChannelConnection) GetCreateTime() *timestamppb.Timestamp

func (*ChannelConnection) GetName

func (x *ChannelConnection) GetName() string

func (*ChannelConnection) GetUid

func (x *ChannelConnection) GetUid() string

func (*ChannelConnection) GetUpdateTime

func (x *ChannelConnection) GetUpdateTime() *timestamppb.Timestamp

func (*ChannelConnection) HasCreateTime

func (x *ChannelConnection) HasCreateTime() bool

func (*ChannelConnection) HasUpdateTime

func (x *ChannelConnection) HasUpdateTime() bool

func (*ChannelConnection) ProtoMessage

func (*ChannelConnection) ProtoMessage()

func (*ChannelConnection) ProtoReflect

func (x *ChannelConnection) ProtoReflect() protoreflect.Message

func (*ChannelConnection) Reset

func (x *ChannelConnection) Reset()

func (*ChannelConnection) SetChannel

func (x *ChannelConnection) SetChannel(v string)

func (*ChannelConnection) SetCreateTime

func (x *ChannelConnection) SetCreateTime(v *timestamppb.Timestamp)

func (*ChannelConnection) SetName

func (x *ChannelConnection) SetName(v string)

func (*ChannelConnection) SetUid

func (x *ChannelConnection) SetUid(v string)

func (*ChannelConnection) SetUpdateTime

func (x *ChannelConnection) SetUpdateTime(v *timestamppb.Timestamp)

func (*ChannelConnection) String

func (x *ChannelConnection) String() string

type ChannelConnectionCreatedEvent

type ChannelConnectionCreatedEvent struct {

	// The data associated with the event.
	Data *ChannelConnectionEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

The CloudEvent raised when a ChannelConnection is created.

func (*ChannelConnectionCreatedEvent) ClearData

func (x *ChannelConnectionCreatedEvent) ClearData()

func (*ChannelConnectionCreatedEvent) GetData

func (*ChannelConnectionCreatedEvent) HasData

func (x *ChannelConnectionCreatedEvent) HasData() bool

func (*ChannelConnectionCreatedEvent) ProtoMessage

func (*ChannelConnectionCreatedEvent) ProtoMessage()

func (*ChannelConnectionCreatedEvent) ProtoReflect

func (*ChannelConnectionCreatedEvent) Reset

func (x *ChannelConnectionCreatedEvent) Reset()

func (*ChannelConnectionCreatedEvent) SetData

func (*ChannelConnectionCreatedEvent) String

type ChannelConnectionCreatedEvent_builder

type ChannelConnectionCreatedEvent_builder struct {

	// The data associated with the event.
	Data *ChannelConnectionEventData
	// contains filtered or unexported fields
}

func (ChannelConnectionCreatedEvent_builder) Build

type ChannelConnectionDeletedEvent

type ChannelConnectionDeletedEvent struct {

	// The data associated with the event.
	Data *ChannelConnectionEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

The CloudEvent raised when a ChannelConnection is deleted.

func (*ChannelConnectionDeletedEvent) ClearData

func (x *ChannelConnectionDeletedEvent) ClearData()

func (*ChannelConnectionDeletedEvent) GetData

func (*ChannelConnectionDeletedEvent) HasData

func (x *ChannelConnectionDeletedEvent) HasData() bool

func (*ChannelConnectionDeletedEvent) ProtoMessage

func (*ChannelConnectionDeletedEvent) ProtoMessage()

func (*ChannelConnectionDeletedEvent) ProtoReflect

func (*ChannelConnectionDeletedEvent) Reset

func (x *ChannelConnectionDeletedEvent) Reset()

func (*ChannelConnectionDeletedEvent) SetData

func (*ChannelConnectionDeletedEvent) String

type ChannelConnectionDeletedEvent_builder

type ChannelConnectionDeletedEvent_builder struct {

	// The data associated with the event.
	Data *ChannelConnectionEventData
	// contains filtered or unexported fields
}

func (ChannelConnectionDeletedEvent_builder) Build

type ChannelConnectionEventData

type ChannelConnectionEventData struct {

	// The ChannelConnection event payload.
	Payload *ChannelConnection `protobuf:"bytes,1,opt,name=payload,proto3" json:"payload,omitempty"`
	// contains filtered or unexported fields
}

The data within all ChannelConnection events.

func (*ChannelConnectionEventData) ClearPayload

func (x *ChannelConnectionEventData) ClearPayload()

func (*ChannelConnectionEventData) GetPayload

func (*ChannelConnectionEventData) HasPayload

func (x *ChannelConnectionEventData) HasPayload() bool

func (*ChannelConnectionEventData) ProtoMessage

func (*ChannelConnectionEventData) ProtoMessage()

func (*ChannelConnectionEventData) ProtoReflect

func (*ChannelConnectionEventData) Reset

func (x *ChannelConnectionEventData) Reset()

func (*ChannelConnectionEventData) SetPayload

func (*ChannelConnectionEventData) String

func (x *ChannelConnectionEventData) String() string

type ChannelConnectionEventData_builder

type ChannelConnectionEventData_builder struct {

	// The ChannelConnection event payload.
	Payload *ChannelConnection
	// contains filtered or unexported fields
}

func (ChannelConnectionEventData_builder) Build

type ChannelConnection_builder

type ChannelConnection_builder struct {

	// Required. The name of the connection.
	Name string
	// Output only. Server assigned ID of the resource.
	// The server guarantees uniqueness and immutability until deleted.
	Uid string
	// Required. The name of the connected subscriber Channel.
	// This is a weak reference to avoid cross project and cross accounts
	// references. This must be in
	// `projects/{project}/location/{location}/channels/{channel_id}` format.
	Channel string
	// Output only. The creation time.
	CreateTime *timestamppb.Timestamp
	// Output only. The last-modified time.
	UpdateTime *timestamppb.Timestamp
	// contains filtered or unexported fields
}

func (ChannelConnection_builder) Build

type ChannelCreatedEvent

type ChannelCreatedEvent struct {

	// The data associated with the event.
	Data *ChannelEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

The CloudEvent raised when a Channel is created.

func (*ChannelCreatedEvent) ClearData

func (x *ChannelCreatedEvent) ClearData()

func (*ChannelCreatedEvent) GetData

func (x *ChannelCreatedEvent) GetData() *ChannelEventData

func (*ChannelCreatedEvent) HasData

func (x *ChannelCreatedEvent) HasData() bool

func (*ChannelCreatedEvent) ProtoMessage

func (*ChannelCreatedEvent) ProtoMessage()

func (*ChannelCreatedEvent) ProtoReflect

func (x *ChannelCreatedEvent) ProtoReflect() protoreflect.Message

func (*ChannelCreatedEvent) Reset

func (x *ChannelCreatedEvent) Reset()

func (*ChannelCreatedEvent) SetData

func (x *ChannelCreatedEvent) SetData(v *ChannelEventData)

func (*ChannelCreatedEvent) String

func (x *ChannelCreatedEvent) String() string

type ChannelCreatedEvent_builder

type ChannelCreatedEvent_builder struct {

	// The data associated with the event.
	Data *ChannelEventData
	// contains filtered or unexported fields
}

func (ChannelCreatedEvent_builder) Build

type ChannelDeletedEvent

type ChannelDeletedEvent struct {

	// The data associated with the event.
	Data *ChannelEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

The CloudEvent raised when a Channel is deleted.

func (*ChannelDeletedEvent) ClearData

func (x *ChannelDeletedEvent) ClearData()

func (*ChannelDeletedEvent) GetData

func (x *ChannelDeletedEvent) GetData() *ChannelEventData

func (*ChannelDeletedEvent) HasData

func (x *ChannelDeletedEvent) HasData() bool

func (*ChannelDeletedEvent) ProtoMessage

func (*ChannelDeletedEvent) ProtoMessage()

func (*ChannelDeletedEvent) ProtoReflect

func (x *ChannelDeletedEvent) ProtoReflect() protoreflect.Message

func (*ChannelDeletedEvent) Reset

func (x *ChannelDeletedEvent) Reset()

func (*ChannelDeletedEvent) SetData

func (x *ChannelDeletedEvent) SetData(v *ChannelEventData)

func (*ChannelDeletedEvent) String

func (x *ChannelDeletedEvent) String() string

type ChannelDeletedEvent_builder

type ChannelDeletedEvent_builder struct {

	// The data associated with the event.
	Data *ChannelEventData
	// contains filtered or unexported fields
}

func (ChannelDeletedEvent_builder) Build

type ChannelEventData

type ChannelEventData struct {

	// The Channel event payload.
	Payload *Channel `protobuf:"bytes,1,opt,name=payload,proto3" json:"payload,omitempty"`
	// contains filtered or unexported fields
}

The data within all Channel events.

func (*ChannelEventData) ClearPayload

func (x *ChannelEventData) ClearPayload()

func (*ChannelEventData) GetPayload

func (x *ChannelEventData) GetPayload() *Channel

func (*ChannelEventData) HasPayload

func (x *ChannelEventData) HasPayload() bool

func (*ChannelEventData) ProtoMessage

func (*ChannelEventData) ProtoMessage()

func (*ChannelEventData) ProtoReflect

func (x *ChannelEventData) ProtoReflect() protoreflect.Message

func (*ChannelEventData) Reset

func (x *ChannelEventData) Reset()

func (*ChannelEventData) SetPayload

func (x *ChannelEventData) SetPayload(v *Channel)

func (*ChannelEventData) String

func (x *ChannelEventData) String() string

type ChannelEventData_builder

type ChannelEventData_builder struct {

	// The Channel event payload.
	Payload *Channel
	// contains filtered or unexported fields
}

func (ChannelEventData_builder) Build

type ChannelUpdatedEvent

type ChannelUpdatedEvent struct {

	// The data associated with the event.
	Data *ChannelEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

The CloudEvent raised when a Channel is updated.

func (*ChannelUpdatedEvent) ClearData

func (x *ChannelUpdatedEvent) ClearData()

func (*ChannelUpdatedEvent) GetData

func (x *ChannelUpdatedEvent) GetData() *ChannelEventData

func (*ChannelUpdatedEvent) HasData

func (x *ChannelUpdatedEvent) HasData() bool

func (*ChannelUpdatedEvent) ProtoMessage

func (*ChannelUpdatedEvent) ProtoMessage()

func (*ChannelUpdatedEvent) ProtoReflect

func (x *ChannelUpdatedEvent) ProtoReflect() protoreflect.Message

func (*ChannelUpdatedEvent) Reset

func (x *ChannelUpdatedEvent) Reset()

func (*ChannelUpdatedEvent) SetData

func (x *ChannelUpdatedEvent) SetData(v *ChannelEventData)

func (*ChannelUpdatedEvent) String

func (x *ChannelUpdatedEvent) String() string

type ChannelUpdatedEvent_builder

type ChannelUpdatedEvent_builder struct {

	// The data associated with the event.
	Data *ChannelEventData
	// contains filtered or unexported fields
}

func (ChannelUpdatedEvent_builder) Build

type Channel_PubsubTopic

type Channel_PubsubTopic struct {
	// Output only. The name of the Pub/Sub topic created and managed by
	// Eventarc system as a transport for the event delivery. Format:
	// `projects/{project}/topics/{topic_id}`.
	PubsubTopic string `protobuf:"bytes,8,opt,name=pubsub_topic,json=pubsubTopic,proto3,oneof"`
}

type Channel_State

type Channel_State int32

State lists all the possible states of a Channel

const (
	// Default value. This value is unused.
	Channel_STATE_UNSPECIFIED Channel_State = 0
	// The PENDING state indicates that a Channel has been created successfully
	// and there is a new activation token available for the subscriber to use
	// to convey the Channel to the provider in order to create a Connection.
	Channel_PENDING Channel_State = 1
	// The ACTIVE state indicates that a Channel has been successfully
	// connected with the event provider.
	// An ACTIVE Channel is ready to receive and route events from the
	// event provider.
	Channel_ACTIVE Channel_State = 2
	// The INACTIVE state indicates that the Channel cannot receive events
	// permanently. There are two possible cases this state can happen:
	//
	//  1. The SaaS provider disconnected from this Channel.
	//  2. The Channel activation token has expired but the SaaS provider
	//     wasn't connected.
	//
	// To re-establish a Connection with a provider, the subscriber
	// should create a new Channel and give it to the provider.
	Channel_INACTIVE Channel_State = 3
)

func (Channel_State) Descriptor

func (Channel_State) Enum

func (x Channel_State) Enum() *Channel_State

func (Channel_State) Number

func (Channel_State) String

func (x Channel_State) String() string

func (Channel_State) Type

type Channel_builder

type Channel_builder struct {

	// Required. The resource name of the channel. Must be unique within the
	// location on the project and must be in
	// `projects/{project}/locations/{location}/channels/{channel_id}` format.
	Name string
	// Output only. Server assigned unique identifier for the channel. The value
	// is a UUID4 string and guaranteed to remain unchanged until the resource is
	// deleted.
	Uid string
	// Output only. The creation time.
	CreateTime *timestamppb.Timestamp
	// Output only. The last-modified time.
	UpdateTime *timestamppb.Timestamp
	// The name of the event provider (e.g. Eventarc SaaS partner) associated
	// with the channel. This provider will be granted permissions to publish
	// events to the channel. Format:
	// `projects/{project}/locations/{location}/providers/{provider_id}`.
	Provider string
	// Fields of oneof Transport:
	// Output only. The name of the Pub/Sub topic created and managed by
	// Eventarc system as a transport for the event delivery. Format:
	// `projects/{project}/topics/{topic_id}`.
	PubsubTopic *string
	// -- end of Transport
	// Output only. The state of a Channel.
	State Channel_State
	// Output only. The activation token for the channel. The token must be used
	// by the provider to register the channel for publishing.
	ActivationToken string
	// Resource name of a KMS crypto key (managed by the user) used to
	// encrypt/decrypt their event data.
	//
	// It must match the pattern
	// `projects/*/locations/*/keyRings/*/cryptoKeys/*`.
	CryptoKeyName string
	// contains filtered or unexported fields
}

func (Channel_builder) Build

func (b0 Channel_builder) Build() *Channel

type CloudRun

type CloudRun struct {

	// Required. The name of the Cloud Run service being addressed. See
	// https://cloud.google.com/run/docs/reference/rest/v1/namespaces.services.
	//
	// Only services located in the same project as the trigger object
	// can be addressed.
	Service string `protobuf:"bytes,1,opt,name=service,proto3" json:"service,omitempty"`
	// Optional. The relative path on the Cloud Run service the events should be
	// sent to.
	//
	// The value must conform to the definition of a URI path segment (section 3.3
	// of RFC2396). Examples: "/route", "route", "route/subroute".
	Path string `protobuf:"bytes,2,opt,name=path,proto3" json:"path,omitempty"`
	// Required. The region the Cloud Run service is deployed in.
	Region string `protobuf:"bytes,3,opt,name=region,proto3" json:"region,omitempty"`
	// contains filtered or unexported fields
}

Represents a Cloud Run destination.

func (*CloudRun) GetPath

func (x *CloudRun) GetPath() string

func (*CloudRun) GetRegion

func (x *CloudRun) GetRegion() string

func (*CloudRun) GetService

func (x *CloudRun) GetService() string

func (*CloudRun) ProtoMessage

func (*CloudRun) ProtoMessage()

func (*CloudRun) ProtoReflect

func (x *CloudRun) ProtoReflect() protoreflect.Message

func (*CloudRun) Reset

func (x *CloudRun) Reset()

func (*CloudRun) SetPath

func (x *CloudRun) SetPath(v string)

func (*CloudRun) SetRegion

func (x *CloudRun) SetRegion(v string)

func (*CloudRun) SetService

func (x *CloudRun) SetService(v string)

func (*CloudRun) String

func (x *CloudRun) String() string

type CloudRun_builder

type CloudRun_builder struct {

	// Required. The name of the Cloud Run service being addressed. See
	// https://cloud.google.com/run/docs/reference/rest/v1/namespaces.services.
	//
	// Only services located in the same project as the trigger object
	// can be addressed.
	Service string
	// Optional. The relative path on the Cloud Run service the events should be
	// sent to.
	//
	// The value must conform to the definition of a URI path segment (section 3.3
	// of RFC2396). Examples: "/route", "route", "route/subroute".
	Path string
	// Required. The region the Cloud Run service is deployed in.
	Region string
	// contains filtered or unexported fields
}

func (CloudRun_builder) Build

func (b0 CloudRun_builder) Build() *CloudRun

type Destination

type Destination struct {

	// Types that are valid to be assigned to Descriptor_:
	//
	//	*Destination_CloudRun
	//	*Destination_CloudFunction
	//	*Destination_Gke
	//	*Destination_Workflow
	Descriptor_ isDestination_Descriptor_ `protobuf_oneof:"descriptor"`
	// contains filtered or unexported fields
}

Represents a target of an invocation over HTTP.

func (*Destination) ClearCloudFunction

func (x *Destination) ClearCloudFunction()

func (*Destination) ClearCloudRun

func (x *Destination) ClearCloudRun()

func (*Destination) ClearDescriptor

func (x *Destination) ClearDescriptor()

func (*Destination) ClearGke

func (x *Destination) ClearGke()

func (*Destination) ClearWorkflow

func (x *Destination) ClearWorkflow()

func (*Destination) GetCloudFunction

func (x *Destination) GetCloudFunction() string

func (*Destination) GetCloudRun

func (x *Destination) GetCloudRun() *CloudRun

func (*Destination) GetDescriptor_

func (x *Destination) GetDescriptor_() isDestination_Descriptor_

func (*Destination) GetGke

func (x *Destination) GetGke() *GKE

func (*Destination) GetWorkflow

func (x *Destination) GetWorkflow() string

func (*Destination) HasCloudFunction

func (x *Destination) HasCloudFunction() bool

func (*Destination) HasCloudRun

func (x *Destination) HasCloudRun() bool

func (*Destination) HasDescriptor

func (x *Destination) HasDescriptor() bool

func (*Destination) HasGke

func (x *Destination) HasGke() bool

func (*Destination) HasWorkflow

func (x *Destination) HasWorkflow() bool

func (*Destination) ProtoMessage

func (*Destination) ProtoMessage()

func (*Destination) ProtoReflect

func (x *Destination) ProtoReflect() protoreflect.Message

func (*Destination) Reset

func (x *Destination) Reset()

func (*Destination) SetCloudFunction

func (x *Destination) SetCloudFunction(v string)

func (*Destination) SetCloudRun

func (x *Destination) SetCloudRun(v *CloudRun)

func (*Destination) SetGke

func (x *Destination) SetGke(v *GKE)

func (*Destination) SetWorkflow

func (x *Destination) SetWorkflow(v string)

func (*Destination) String

func (x *Destination) String() string

func (*Destination) WhichDescriptor

func (x *Destination) WhichDescriptor() case_Destination_Descriptor_

type Destination_CloudFunction

type Destination_CloudFunction struct {
	// The Cloud Function resource name. Only Cloud Functions V2 is supported.
	// Format: `projects/{project}/locations/{location}/functions/{function}`
	//
	// This is a read-only field. Creating Cloud Functions V2 triggers is only
	// supported via the Cloud Functions product. An error will be returned if
	// the user sets this value.
	CloudFunction string `protobuf:"bytes,2,opt,name=cloud_function,json=cloudFunction,proto3,oneof"`
}

type Destination_CloudRun

type Destination_CloudRun struct {
	// Cloud Run fully-managed resource that receives the events. The resource
	// should be in the same project as the trigger.
	CloudRun *CloudRun `protobuf:"bytes,1,opt,name=cloud_run,json=cloudRun,proto3,oneof"`
}

type Destination_Gke

type Destination_Gke struct {
	// A GKE service capable of receiving events. The service should be running
	// in the same project as the trigger.
	Gke *GKE `protobuf:"bytes,3,opt,name=gke,proto3,oneof"`
}

type Destination_Workflow

type Destination_Workflow struct {
	// The resource name of the Workflow whose Executions are triggered by
	// the events. The Workflow resource should be deployed in the same project
	// as the trigger.
	// Format: `projects/{project}/locations/{location}/workflows/{workflow}`
	Workflow string `protobuf:"bytes,4,opt,name=workflow,proto3,oneof"`
}

type Destination_builder

type Destination_builder struct {

	// Fields of oneof Descriptor_:
	// Cloud Run fully-managed resource that receives the events. The resource
	// should be in the same project as the trigger.
	CloudRun *CloudRun
	// The Cloud Function resource name. Only Cloud Functions V2 is supported.
	// Format: `projects/{project}/locations/{location}/functions/{function}`
	//
	// This is a read-only field. Creating Cloud Functions V2 triggers is only
	// supported via the Cloud Functions product. An error will be returned if
	// the user sets this value.
	CloudFunction *string
	// A GKE service capable of receiving events. The service should be running
	// in the same project as the trigger.
	Gke *GKE
	// The resource name of the Workflow whose Executions are triggered by
	// the events. The Workflow resource should be deployed in the same project
	// as the trigger.
	// Format: `projects/{project}/locations/{location}/workflows/{workflow}`
	Workflow *string
	// contains filtered or unexported fields
}

func (Destination_builder) Build

func (b0 Destination_builder) Build() *Destination

type EventFilter

type EventFilter struct {

	// Required. The name of a CloudEvents attribute. Currently, only a subset of
	// attributes are supported for filtering.
	//
	// All triggers MUST provide a filter for the 'type' attribute.
	Attribute string `protobuf:"bytes,1,opt,name=attribute,proto3" json:"attribute,omitempty"`
	// Required. The value for the attribute.
	Value string `protobuf:"bytes,2,opt,name=value,proto3" json:"value,omitempty"`
	// Optional. The operator used for matching the events with the value of the
	// filter. If not specified, only events that have an exact key-value pair
	// specified in the filter are matched. The only allowed value is
	// `match-path-pattern`.
	Operator string `protobuf:"bytes,3,opt,name=operator,proto3" json:"operator,omitempty"`
	// contains filtered or unexported fields
}

Filters events based on exact matches on the CloudEvents attributes.

func (*EventFilter) GetAttribute

func (x *EventFilter) GetAttribute() string

func (*EventFilter) GetOperator

func (x *EventFilter) GetOperator() string

func (*EventFilter) GetValue

func (x *EventFilter) GetValue() string

func (*EventFilter) ProtoMessage

func (*EventFilter) ProtoMessage()

func (*EventFilter) ProtoReflect

func (x *EventFilter) ProtoReflect() protoreflect.Message

func (*EventFilter) Reset

func (x *EventFilter) Reset()

func (*EventFilter) SetAttribute

func (x *EventFilter) SetAttribute(v string)

func (*EventFilter) SetOperator

func (x *EventFilter) SetOperator(v string)

func (*EventFilter) SetValue

func (x *EventFilter) SetValue(v string)

func (*EventFilter) String

func (x *EventFilter) String() string

type EventFilter_builder

type EventFilter_builder struct {

	// Required. The name of a CloudEvents attribute. Currently, only a subset of
	// attributes are supported for filtering.
	//
	// All triggers MUST provide a filter for the 'type' attribute.
	Attribute string
	// Required. The value for the attribute.
	Value string
	// Optional. The operator used for matching the events with the value of the
	// filter. If not specified, only events that have an exact key-value pair
	// specified in the filter are matched. The only allowed value is
	// `match-path-pattern`.
	Operator string
	// contains filtered or unexported fields
}

func (EventFilter_builder) Build

func (b0 EventFilter_builder) Build() *EventFilter

type GKE

type GKE struct {

	// Required. The name of the cluster the GKE service is running in. The
	// cluster must be running in the same project as the trigger being created.
	Cluster string `protobuf:"bytes,1,opt,name=cluster,proto3" json:"cluster,omitempty"`
	// Required. The name of the Google Compute Engine in which the cluster
	// resides, which can either be compute zone (for example, us-central1-a) for
	// the zonal clusters or region (for example, us-central1) for regional
	// clusters.
	Location string `protobuf:"bytes,2,opt,name=location,proto3" json:"location,omitempty"`
	// Required. The namespace the GKE service is running in.
	Namespace string `protobuf:"bytes,3,opt,name=namespace,proto3" json:"namespace,omitempty"`
	// Required. Name of the GKE service.
	Service string `protobuf:"bytes,4,opt,name=service,proto3" json:"service,omitempty"`
	// Optional. The relative path on the GKE service the events should be sent
	// to.
	//
	// The value must conform to the definition of a URI path segment (section 3.3
	// of RFC2396). Examples: "/route", "route", "route/subroute".
	Path string `protobuf:"bytes,5,opt,name=path,proto3" json:"path,omitempty"`
	// contains filtered or unexported fields
}

Represents a GKE destination.

func (*GKE) GetCluster

func (x *GKE) GetCluster() string

func (*GKE) GetLocation

func (x *GKE) GetLocation() string

func (*GKE) GetNamespace

func (x *GKE) GetNamespace() string

func (*GKE) GetPath

func (x *GKE) GetPath() string

func (*GKE) GetService

func (x *GKE) GetService() string

func (*GKE) ProtoMessage

func (*GKE) ProtoMessage()

func (*GKE) ProtoReflect

func (x *GKE) ProtoReflect() protoreflect.Message

func (*GKE) Reset

func (x *GKE) Reset()

func (*GKE) SetCluster

func (x *GKE) SetCluster(v string)

func (*GKE) SetLocation

func (x *GKE) SetLocation(v string)

func (*GKE) SetNamespace

func (x *GKE) SetNamespace(v string)

func (*GKE) SetPath

func (x *GKE) SetPath(v string)

func (*GKE) SetService

func (x *GKE) SetService(v string)

func (*GKE) String

func (x *GKE) String() string

type GKE_builder

type GKE_builder struct {

	// Required. The name of the cluster the GKE service is running in. The
	// cluster must be running in the same project as the trigger being created.
	Cluster string
	// Required. The name of the Google Compute Engine in which the cluster
	// resides, which can either be compute zone (for example, us-central1-a) for
	// the zonal clusters or region (for example, us-central1) for regional
	// clusters.
	Location string
	// Required. The namespace the GKE service is running in.
	Namespace string
	// Required. Name of the GKE service.
	Service string
	// Optional. The relative path on the GKE service the events should be sent
	// to.
	//
	// The value must conform to the definition of a URI path segment (section 3.3
	// of RFC2396). Examples: "/route", "route", "route/subroute".
	Path string
	// contains filtered or unexported fields
}

func (GKE_builder) Build

func (b0 GKE_builder) Build() *GKE

type Pubsub

type Pubsub struct {

	// Optional. The name of the Pub/Sub topic created and managed by Eventarc as
	// a transport for the event delivery. Format:
	// `projects/{PROJECT_ID}/topics/{TOPIC_NAME}`.
	//
	// You can set an existing topic for triggers of the type
	// `google.cloud.pubsub.topic.v1.messagePublished`. The topic you provide
	// here is not deleted by Eventarc at trigger deletion.
	Topic string `protobuf:"bytes,1,opt,name=topic,proto3" json:"topic,omitempty"`
	// Output only. The name of the Pub/Sub subscription created and managed by
	// Eventarc as a transport for the event delivery. Format:
	// `projects/{PROJECT_ID}/subscriptions/{SUBSCRIPTION_NAME}`.
	Subscription string `protobuf:"bytes,2,opt,name=subscription,proto3" json:"subscription,omitempty"`
	// contains filtered or unexported fields
}

Represents a Pub/Sub transport.

func (*Pubsub) GetSubscription

func (x *Pubsub) GetSubscription() string

func (*Pubsub) GetTopic

func (x *Pubsub) GetTopic() string

func (*Pubsub) ProtoMessage

func (*Pubsub) ProtoMessage()

func (*Pubsub) ProtoReflect

func (x *Pubsub) ProtoReflect() protoreflect.Message

func (*Pubsub) Reset

func (x *Pubsub) Reset()

func (*Pubsub) SetSubscription

func (x *Pubsub) SetSubscription(v string)

func (*Pubsub) SetTopic

func (x *Pubsub) SetTopic(v string)

func (*Pubsub) String

func (x *Pubsub) String() string

type Pubsub_builder

type Pubsub_builder struct {

	// Optional. The name of the Pub/Sub topic created and managed by Eventarc as
	// a transport for the event delivery. Format:
	// `projects/{PROJECT_ID}/topics/{TOPIC_NAME}`.
	//
	// You can set an existing topic for triggers of the type
	// `google.cloud.pubsub.topic.v1.messagePublished`. The topic you provide
	// here is not deleted by Eventarc at trigger deletion.
	Topic string
	// Output only. The name of the Pub/Sub subscription created and managed by
	// Eventarc as a transport for the event delivery. Format:
	// `projects/{PROJECT_ID}/subscriptions/{SUBSCRIPTION_NAME}`.
	Subscription string
	// contains filtered or unexported fields
}

func (Pubsub_builder) Build

func (b0 Pubsub_builder) Build() *Pubsub

type StateCondition

type StateCondition struct {

	// The canonical code of the condition.
	Code code.Code `protobuf:"varint,1,opt,name=code,proto3,enum=google.rpc.Code" json:"code,omitempty"`
	// Human-readable message.
	Message string `protobuf:"bytes,2,opt,name=message,proto3" json:"message,omitempty"`
	// contains filtered or unexported fields
}

A condition that is part of the trigger state computation.

func (*StateCondition) GetCode

func (x *StateCondition) GetCode() code.Code

func (*StateCondition) GetMessage

func (x *StateCondition) GetMessage() string

func (*StateCondition) ProtoMessage

func (*StateCondition) ProtoMessage()

func (*StateCondition) ProtoReflect

func (x *StateCondition) ProtoReflect() protoreflect.Message

func (*StateCondition) Reset

func (x *StateCondition) Reset()

func (*StateCondition) SetCode

func (x *StateCondition) SetCode(v code.Code)

func (*StateCondition) SetMessage

func (x *StateCondition) SetMessage(v string)

func (*StateCondition) String

func (x *StateCondition) String() string

type StateCondition_builder

type StateCondition_builder struct {

	// The canonical code of the condition.
	Code code.Code
	// Human-readable message.
	Message string
	// contains filtered or unexported fields
}

func (StateCondition_builder) Build

type Transport

type Transport struct {

	// Types that are valid to be assigned to Intermediary:
	//
	//	*Transport_Pubsub
	Intermediary isTransport_Intermediary `protobuf_oneof:"intermediary"`
	// contains filtered or unexported fields
}

Represents the transport intermediaries created for the trigger to deliver events.

func (*Transport) ClearIntermediary

func (x *Transport) ClearIntermediary()

func (*Transport) ClearPubsub

func (x *Transport) ClearPubsub()

func (*Transport) GetIntermediary

func (x *Transport) GetIntermediary() isTransport_Intermediary

func (*Transport) GetPubsub

func (x *Transport) GetPubsub() *Pubsub

func (*Transport) HasIntermediary

func (x *Transport) HasIntermediary() bool

func (*Transport) HasPubsub

func (x *Transport) HasPubsub() bool

func (*Transport) ProtoMessage

func (*Transport) ProtoMessage()

func (*Transport) ProtoReflect

func (x *Transport) ProtoReflect() protoreflect.Message

func (*Transport) Reset

func (x *Transport) Reset()

func (*Transport) SetPubsub

func (x *Transport) SetPubsub(v *Pubsub)

func (*Transport) String

func (x *Transport) String() string

func (*Transport) WhichIntermediary

func (x *Transport) WhichIntermediary() case_Transport_Intermediary

type Transport_Pubsub

type Transport_Pubsub struct {
	// The Pub/Sub topic and subscription used by Eventarc as a transport
	// intermediary.
	Pubsub *Pubsub `protobuf:"bytes,1,opt,name=pubsub,proto3,oneof"`
}

type Transport_builder

type Transport_builder struct {

	// Fields of oneof Intermediary:
	// The Pub/Sub topic and subscription used by Eventarc as a transport
	// intermediary.
	Pubsub *Pubsub
	// contains filtered or unexported fields
}

func (Transport_builder) Build

func (b0 Transport_builder) Build() *Transport

type Trigger

type Trigger struct {

	// Required. The resource name of the trigger. Must be unique within the
	// location of the project and must be in
	// `projects/{project}/locations/{location}/triggers/{trigger}` format.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Output only. Server-assigned unique identifier for the trigger. The value
	// is a UUID4 string and guaranteed to remain unchanged until the resource is
	// deleted.
	Uid string `protobuf:"bytes,2,opt,name=uid,proto3" json:"uid,omitempty"`
	// Output only. The creation time.
	CreateTime *timestamppb.Timestamp `protobuf:"bytes,5,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
	// Output only. The last-modified time.
	UpdateTime *timestamppb.Timestamp `protobuf:"bytes,6,opt,name=update_time,json=updateTime,proto3" json:"update_time,omitempty"`
	// Required. Unordered list. The list of filters that applies to event
	// attributes. Only events that match all the provided filters are sent to the
	// destination.
	EventFilters []*EventFilter `protobuf:"bytes,8,rep,name=event_filters,json=eventFilters,proto3" json:"event_filters,omitempty"`
	// Optional. The IAM service account email associated with the trigger. The
	// service account represents the identity of the trigger.
	//
	// The principal who calls this API must have the `iam.serviceAccounts.actAs`
	// permission in the service account. See
	// https://cloud.google.com/iam/docs/understanding-service-accounts?hl=en#sa_common
	// for more information.
	//
	// For Cloud Run destinations, this service account is used to generate
	// identity tokens when invoking the service. See
	// https://cloud.google.com/run/docs/triggering/pubsub-push#create-service-account
	// for information on how to invoke authenticated Cloud Run services.
	// To create Audit Log triggers, the service account should also
	// have the `roles/eventarc.eventReceiver` IAM role.
	ServiceAccount string `protobuf:"bytes,9,opt,name=service_account,json=serviceAccount,proto3" json:"service_account,omitempty"`
	// Required. Destination specifies where the events should be sent to.
	Destination *Destination `protobuf:"bytes,10,opt,name=destination,proto3" json:"destination,omitempty"`
	// Optional. To deliver messages, Eventarc might use other Google Cloud
	// products as a transport intermediary. This field contains a reference to
	// that transport intermediary. This information can be used for debugging
	// purposes.
	Transport *Transport `protobuf:"bytes,11,opt,name=transport,proto3" json:"transport,omitempty"`
	// Optional. User labels attached to the triggers that can be used to group
	// resources.
	Labels map[string]string `` /* 140-byte string literal not displayed */
	// Optional. The name of the channel associated with the trigger in
	// `projects/{project}/locations/{location}/channels/{channel}` format.
	// You must provide a channel to receive events from Eventarc SaaS partners.
	Channel string `protobuf:"bytes,13,opt,name=channel,proto3" json:"channel,omitempty"`
	// Output only. The reason(s) why a trigger is in FAILED state.
	Conditions map[string]*StateCondition `` /* 148-byte string literal not displayed */
	// Optional. EventDataContentType specifies the type of payload in MIME
	// format that is expected from the CloudEvent data field. This is set to
	// `application/json` if the value is not defined.
	EventDataContentType string `` /* 126-byte string literal not displayed */
	// Output only. This checksum is computed by the server based on the value of
	// other fields, and might be sent only on create requests to ensure that the
	// client has an up-to-date value before proceeding.
	Etag string `protobuf:"bytes,99,opt,name=etag,proto3" json:"etag,omitempty"`
	// contains filtered or unexported fields
}

A representation of the trigger resource.

func (*Trigger) ClearCreateTime

func (x *Trigger) ClearCreateTime()

func (*Trigger) ClearDestination

func (x *Trigger) ClearDestination()

func (*Trigger) ClearTransport

func (x *Trigger) ClearTransport()

func (*Trigger) ClearUpdateTime

func (x *Trigger) ClearUpdateTime()

func (*Trigger) GetChannel

func (x *Trigger) GetChannel() string

func (*Trigger) GetConditions

func (x *Trigger) GetConditions() map[string]*StateCondition

func (*Trigger) GetCreateTime

func (x *Trigger) GetCreateTime() *timestamppb.Timestamp

func (*Trigger) GetDestination

func (x *Trigger) GetDestination() *Destination

func (*Trigger) GetEtag

func (x *Trigger) GetEtag() string

func (*Trigger) GetEventDataContentType

func (x *Trigger) GetEventDataContentType() string

func (*Trigger) GetEventFilters

func (x *Trigger) GetEventFilters() []*EventFilter

func (*Trigger) GetLabels

func (x *Trigger) GetLabels() map[string]string

func (*Trigger) GetName

func (x *Trigger) GetName() string

func (*Trigger) GetServiceAccount

func (x *Trigger) GetServiceAccount() string

func (*Trigger) GetTransport

func (x *Trigger) GetTransport() *Transport

func (*Trigger) GetUid

func (x *Trigger) GetUid() string

func (*Trigger) GetUpdateTime

func (x *Trigger) GetUpdateTime() *timestamppb.Timestamp

func (*Trigger) HasCreateTime

func (x *Trigger) HasCreateTime() bool

func (*Trigger) HasDestination

func (x *Trigger) HasDestination() bool

func (*Trigger) HasTransport

func (x *Trigger) HasTransport() bool

func (*Trigger) HasUpdateTime

func (x *Trigger) HasUpdateTime() bool

func (*Trigger) ProtoMessage

func (*Trigger) ProtoMessage()

func (*Trigger) ProtoReflect

func (x *Trigger) ProtoReflect() protoreflect.Message

func (*Trigger) Reset

func (x *Trigger) Reset()

func (*Trigger) SetChannel

func (x *Trigger) SetChannel(v string)

func (*Trigger) SetConditions

func (x *Trigger) SetConditions(v map[string]*StateCondition)

func (*Trigger) SetCreateTime

func (x *Trigger) SetCreateTime(v *timestamppb.Timestamp)

func (*Trigger) SetDestination

func (x *Trigger) SetDestination(v *Destination)

func (*Trigger) SetEtag

func (x *Trigger) SetEtag(v string)

func (*Trigger) SetEventDataContentType

func (x *Trigger) SetEventDataContentType(v string)

func (*Trigger) SetEventFilters

func (x *Trigger) SetEventFilters(v []*EventFilter)

func (*Trigger) SetLabels

func (x *Trigger) SetLabels(v map[string]string)

func (*Trigger) SetName

func (x *Trigger) SetName(v string)

func (*Trigger) SetServiceAccount

func (x *Trigger) SetServiceAccount(v string)

func (*Trigger) SetTransport

func (x *Trigger) SetTransport(v *Transport)

func (*Trigger) SetUid

func (x *Trigger) SetUid(v string)

func (*Trigger) SetUpdateTime

func (x *Trigger) SetUpdateTime(v *timestamppb.Timestamp)

func (*Trigger) String

func (x *Trigger) String() string

type TriggerCreatedEvent

type TriggerCreatedEvent struct {

	// The data associated with the event.
	Data *TriggerEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

The CloudEvent raised when a Trigger is created.

func (*TriggerCreatedEvent) ClearData

func (x *TriggerCreatedEvent) ClearData()

func (*TriggerCreatedEvent) GetData

func (x *TriggerCreatedEvent) GetData() *TriggerEventData

func (*TriggerCreatedEvent) HasData

func (x *TriggerCreatedEvent) HasData() bool

func (*TriggerCreatedEvent) ProtoMessage

func (*TriggerCreatedEvent) ProtoMessage()

func (*TriggerCreatedEvent) ProtoReflect

func (x *TriggerCreatedEvent) ProtoReflect() protoreflect.Message

func (*TriggerCreatedEvent) Reset

func (x *TriggerCreatedEvent) Reset()

func (*TriggerCreatedEvent) SetData

func (x *TriggerCreatedEvent) SetData(v *TriggerEventData)

func (*TriggerCreatedEvent) String

func (x *TriggerCreatedEvent) String() string

type TriggerCreatedEvent_builder

type TriggerCreatedEvent_builder struct {

	// The data associated with the event.
	Data *TriggerEventData
	// contains filtered or unexported fields
}

func (TriggerCreatedEvent_builder) Build

type TriggerDeletedEvent

type TriggerDeletedEvent struct {

	// The data associated with the event.
	Data *TriggerEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

The CloudEvent raised when a Trigger is deleted.

func (*TriggerDeletedEvent) ClearData

func (x *TriggerDeletedEvent) ClearData()

func (*TriggerDeletedEvent) GetData

func (x *TriggerDeletedEvent) GetData() *TriggerEventData

func (*TriggerDeletedEvent) HasData

func (x *TriggerDeletedEvent) HasData() bool

func (*TriggerDeletedEvent) ProtoMessage

func (*TriggerDeletedEvent) ProtoMessage()

func (*TriggerDeletedEvent) ProtoReflect

func (x *TriggerDeletedEvent) ProtoReflect() protoreflect.Message

func (*TriggerDeletedEvent) Reset

func (x *TriggerDeletedEvent) Reset()

func (*TriggerDeletedEvent) SetData

func (x *TriggerDeletedEvent) SetData(v *TriggerEventData)

func (*TriggerDeletedEvent) String

func (x *TriggerDeletedEvent) String() string

type TriggerDeletedEvent_builder

type TriggerDeletedEvent_builder struct {

	// The data associated with the event.
	Data *TriggerEventData
	// contains filtered or unexported fields
}

func (TriggerDeletedEvent_builder) Build

type TriggerEventData

type TriggerEventData struct {

	// The Trigger event payload.
	Payload *Trigger `protobuf:"bytes,1,opt,name=payload,proto3" json:"payload,omitempty"`
	// contains filtered or unexported fields
}

The data within all Trigger events.

func (*TriggerEventData) ClearPayload

func (x *TriggerEventData) ClearPayload()

func (*TriggerEventData) GetPayload

func (x *TriggerEventData) GetPayload() *Trigger

func (*TriggerEventData) HasPayload

func (x *TriggerEventData) HasPayload() bool

func (*TriggerEventData) ProtoMessage

func (*TriggerEventData) ProtoMessage()

func (*TriggerEventData) ProtoReflect

func (x *TriggerEventData) ProtoReflect() protoreflect.Message

func (*TriggerEventData) Reset

func (x *TriggerEventData) Reset()

func (*TriggerEventData) SetPayload

func (x *TriggerEventData) SetPayload(v *Trigger)

func (*TriggerEventData) String

func (x *TriggerEventData) String() string

type TriggerEventData_builder

type TriggerEventData_builder struct {

	// The Trigger event payload.
	Payload *Trigger
	// contains filtered or unexported fields
}

func (TriggerEventData_builder) Build

type TriggerUpdatedEvent

type TriggerUpdatedEvent struct {

	// The data associated with the event.
	Data *TriggerEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

The CloudEvent raised when a Trigger is updated.

func (*TriggerUpdatedEvent) ClearData

func (x *TriggerUpdatedEvent) ClearData()

func (*TriggerUpdatedEvent) GetData

func (x *TriggerUpdatedEvent) GetData() *TriggerEventData

func (*TriggerUpdatedEvent) HasData

func (x *TriggerUpdatedEvent) HasData() bool

func (*TriggerUpdatedEvent) ProtoMessage

func (*TriggerUpdatedEvent) ProtoMessage()

func (*TriggerUpdatedEvent) ProtoReflect

func (x *TriggerUpdatedEvent) ProtoReflect() protoreflect.Message

func (*TriggerUpdatedEvent) Reset

func (x *TriggerUpdatedEvent) Reset()

func (*TriggerUpdatedEvent) SetData

func (x *TriggerUpdatedEvent) SetData(v *TriggerEventData)

func (*TriggerUpdatedEvent) String

func (x *TriggerUpdatedEvent) String() string

type TriggerUpdatedEvent_builder

type TriggerUpdatedEvent_builder struct {

	// The data associated with the event.
	Data *TriggerEventData
	// contains filtered or unexported fields
}

func (TriggerUpdatedEvent_builder) Build

type Trigger_builder

type Trigger_builder struct {

	// Required. The resource name of the trigger. Must be unique within the
	// location of the project and must be in
	// `projects/{project}/locations/{location}/triggers/{trigger}` format.
	Name string
	// Output only. Server-assigned unique identifier for the trigger. The value
	// is a UUID4 string and guaranteed to remain unchanged until the resource is
	// deleted.
	Uid string
	// Output only. The creation time.
	CreateTime *timestamppb.Timestamp
	// Output only. The last-modified time.
	UpdateTime *timestamppb.Timestamp
	// Required. Unordered list. The list of filters that applies to event
	// attributes. Only events that match all the provided filters are sent to the
	// destination.
	EventFilters []*EventFilter
	// Optional. The IAM service account email associated with the trigger. The
	// service account represents the identity of the trigger.
	//
	// The principal who calls this API must have the `iam.serviceAccounts.actAs`
	// permission in the service account. See
	// https://cloud.google.com/iam/docs/understanding-service-accounts?hl=en#sa_common
	// for more information.
	//
	// For Cloud Run destinations, this service account is used to generate
	// identity tokens when invoking the service. See
	// https://cloud.google.com/run/docs/triggering/pubsub-push#create-service-account
	// for information on how to invoke authenticated Cloud Run services.
	// To create Audit Log triggers, the service account should also
	// have the `roles/eventarc.eventReceiver` IAM role.
	ServiceAccount string
	// Required. Destination specifies where the events should be sent to.
	Destination *Destination
	// Optional. To deliver messages, Eventarc might use other Google Cloud
	// products as a transport intermediary. This field contains a reference to
	// that transport intermediary. This information can be used for debugging
	// purposes.
	Transport *Transport
	// Optional. User labels attached to the triggers that can be used to group
	// resources.
	Labels map[string]string
	// Optional. The name of the channel associated with the trigger in
	// `projects/{project}/locations/{location}/channels/{channel}` format.
	// You must provide a channel to receive events from Eventarc SaaS partners.
	Channel string
	// Output only. The reason(s) why a trigger is in FAILED state.
	Conditions map[string]*StateCondition
	// Optional. EventDataContentType specifies the type of payload in MIME
	// format that is expected from the CloudEvent data field. This is set to
	// `application/json` if the value is not defined.
	EventDataContentType string
	// Output only. This checksum is computed by the server based on the value of
	// other fields, and might be sent only on create requests to ensure that the
	// client has an up-to-date value before proceeding.
	Etag string
	// contains filtered or unexported fields
}

func (Trigger_builder) Build

func (b0 Trigger_builder) Build() *Trigger

Source Files

  • data.pb.go
  • events.pb.go

Jump to