firestorev1

package
v1.36.11-2024050211440... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

const Value_ArrayValue_case case_Value_ValueType = 9
const Value_BooleanValue_case case_Value_ValueType = 1
const Value_BytesValue_case case_Value_ValueType = 18
const Value_DoubleValue_case case_Value_ValueType = 3
const Value_GeoPointValue_case case_Value_ValueType = 8
const Value_IntegerValue_case case_Value_ValueType = 2
const Value_MapValue_case case_Value_ValueType = 6
const Value_NullValue_case case_Value_ValueType = 11
const Value_ReferenceValue_case case_Value_ValueType = 5
const Value_StringValue_case case_Value_ValueType = 17
const Value_TimestampValue_case case_Value_ValueType = 10
const Value_ValueType_not_set_case case_Value_ValueType = 0

Variables

var File_google_events_cloud_firestore_v1_data_proto protoreflect.FileDescriptor
var File_google_events_cloud_firestore_v1_events_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type ArrayValue

type ArrayValue struct {

	// Values in the array.
	Values []*Value `protobuf:"bytes,1,rep,name=values,proto3" json:"values,omitempty"`
	// contains filtered or unexported fields
}

An array value.

func (*ArrayValue) GetValues

func (x *ArrayValue) GetValues() []*Value

func (*ArrayValue) ProtoMessage

func (*ArrayValue) ProtoMessage()

func (*ArrayValue) ProtoReflect

func (x *ArrayValue) ProtoReflect() protoreflect.Message

func (*ArrayValue) Reset

func (x *ArrayValue) Reset()

func (*ArrayValue) SetValues

func (x *ArrayValue) SetValues(v []*Value)

func (*ArrayValue) String

func (x *ArrayValue) String() string

type ArrayValue_builder

type ArrayValue_builder struct {

	// Values in the array.
	Values []*Value
	// contains filtered or unexported fields
}

func (ArrayValue_builder) Build

func (b0 ArrayValue_builder) Build() *ArrayValue

type Document

type Document struct {

	// The resource name of the document. For example:
	// `projects/{project_id}/databases/{database_id}/documents/{document_path}`
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// The document's fields.
	//
	// The map keys represent field names.
	//
	// A simple field name contains only characters `a` to `z`, `A` to `Z`,
	// `0` to `9`, or `_`, and must not start with `0` to `9`. For example,
	// `foo_bar_17`.
	//
	// Field names matching the regular expression `__.*__` are reserved. Reserved
	// field names are forbidden except in certain documented contexts. The map
	// keys, represented as UTF-8, must not exceed 1,500 bytes and cannot be
	// empty.
	//
	// Field paths may be used in other contexts to refer to structured fields
	// defined here. For `map_value`, the field path is represented by the simple
	// or quoted field names of the containing fields, delimited by `.`. For
	// example, the structured field
	// `"foo" : { map_value: { "x&y" : { string_value: "hello" }}}` would be
	// represented by the field path `foo.x&y`.
	//
	// Within a field path, a quoted field name starts and ends with “ ` “ and
	// may contain any character. Some characters, including “ ` “, must be
	// escaped using a `\`. For example, “ `x&y` “ represents `x&y` and
	// “ `bak\`tik` “ represents “ bak`tik “.
	Fields map[string]*Value `` /* 139-byte string literal not displayed */
	// The time at which the document was created.
	//
	// This value increases monotonically when a document is deleted then
	// recreated. It can also be compared to values from other documents and
	// the `read_time` of a query.
	CreateTime *timestamppb.Timestamp `protobuf:"bytes,3,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
	// The time at which the document was last changed.
	//
	// This value is initially set to the `create_time` then increases
	// monotonically with each change to the document. It can also be
	// compared to values from other documents and the `read_time` of a query.
	UpdateTime *timestamppb.Timestamp `protobuf:"bytes,4,opt,name=update_time,json=updateTime,proto3" json:"update_time,omitempty"`
	// contains filtered or unexported fields
}

A Firestore document.

func (*Document) ClearCreateTime

func (x *Document) ClearCreateTime()

func (*Document) ClearUpdateTime

func (x *Document) ClearUpdateTime()

func (*Document) GetCreateTime

func (x *Document) GetCreateTime() *timestamppb.Timestamp

func (*Document) GetFields

func (x *Document) GetFields() map[string]*Value

func (*Document) GetName

func (x *Document) GetName() string

func (*Document) GetUpdateTime

func (x *Document) GetUpdateTime() *timestamppb.Timestamp

func (*Document) HasCreateTime

func (x *Document) HasCreateTime() bool

func (*Document) HasUpdateTime

func (x *Document) HasUpdateTime() bool

func (*Document) ProtoMessage

func (*Document) ProtoMessage()

func (*Document) ProtoReflect

func (x *Document) ProtoReflect() protoreflect.Message

func (*Document) Reset

func (x *Document) Reset()

func (*Document) SetCreateTime

func (x *Document) SetCreateTime(v *timestamppb.Timestamp)

func (*Document) SetFields

func (x *Document) SetFields(v map[string]*Value)

func (*Document) SetName

func (x *Document) SetName(v string)

func (*Document) SetUpdateTime

func (x *Document) SetUpdateTime(v *timestamppb.Timestamp)

func (*Document) String

func (x *Document) String() string

type DocumentCreatedEvent

type DocumentCreatedEvent struct {

	// The data associated with the event.
	Data *DocumentEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

The CloudEvent raised when a Firestore document is created.

func (*DocumentCreatedEvent) ClearData

func (x *DocumentCreatedEvent) ClearData()

func (*DocumentCreatedEvent) GetData

func (*DocumentCreatedEvent) HasData

func (x *DocumentCreatedEvent) HasData() bool

func (*DocumentCreatedEvent) ProtoMessage

func (*DocumentCreatedEvent) ProtoMessage()

func (*DocumentCreatedEvent) ProtoReflect

func (x *DocumentCreatedEvent) ProtoReflect() protoreflect.Message

func (*DocumentCreatedEvent) Reset

func (x *DocumentCreatedEvent) Reset()

func (*DocumentCreatedEvent) SetData

func (x *DocumentCreatedEvent) SetData(v *DocumentEventData)

func (*DocumentCreatedEvent) String

func (x *DocumentCreatedEvent) String() string

type DocumentCreatedEventWithAuthContext

type DocumentCreatedEventWithAuthContext struct {

	// The data associated with the event.
	Data *DocumentEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

The CloudEvent with Auth Context raised when a Firestore document is created.

func (*DocumentCreatedEventWithAuthContext) ClearData

func (x *DocumentCreatedEventWithAuthContext) ClearData()

func (*DocumentCreatedEventWithAuthContext) GetData

func (*DocumentCreatedEventWithAuthContext) HasData

func (*DocumentCreatedEventWithAuthContext) ProtoMessage

func (*DocumentCreatedEventWithAuthContext) ProtoMessage()

func (*DocumentCreatedEventWithAuthContext) ProtoReflect

func (*DocumentCreatedEventWithAuthContext) Reset

func (*DocumentCreatedEventWithAuthContext) SetData

func (*DocumentCreatedEventWithAuthContext) String

type DocumentCreatedEventWithAuthContext_builder

type DocumentCreatedEventWithAuthContext_builder struct {

	// The data associated with the event.
	Data *DocumentEventData
	// contains filtered or unexported fields
}

func (DocumentCreatedEventWithAuthContext_builder) Build

type DocumentCreatedEvent_builder

type DocumentCreatedEvent_builder struct {

	// The data associated with the event.
	Data *DocumentEventData
	// contains filtered or unexported fields
}

func (DocumentCreatedEvent_builder) Build

type DocumentDeletedEvent

type DocumentDeletedEvent struct {

	// The data associated with the event.
	Data *DocumentEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

The CloudEvent raised when a Firestore document is deleted.

func (*DocumentDeletedEvent) ClearData

func (x *DocumentDeletedEvent) ClearData()

func (*DocumentDeletedEvent) GetData

func (*DocumentDeletedEvent) HasData

func (x *DocumentDeletedEvent) HasData() bool

func (*DocumentDeletedEvent) ProtoMessage

func (*DocumentDeletedEvent) ProtoMessage()

func (*DocumentDeletedEvent) ProtoReflect

func (x *DocumentDeletedEvent) ProtoReflect() protoreflect.Message

func (*DocumentDeletedEvent) Reset

func (x *DocumentDeletedEvent) Reset()

func (*DocumentDeletedEvent) SetData

func (x *DocumentDeletedEvent) SetData(v *DocumentEventData)

func (*DocumentDeletedEvent) String

func (x *DocumentDeletedEvent) String() string

type DocumentDeletedEventWithAuthContext

type DocumentDeletedEventWithAuthContext struct {

	// The data associated with the event.
	Data *DocumentEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

The CloudEvent with Auth Context raised when a Firestore document is deleted.

func (*DocumentDeletedEventWithAuthContext) ClearData

func (x *DocumentDeletedEventWithAuthContext) ClearData()

func (*DocumentDeletedEventWithAuthContext) GetData

func (*DocumentDeletedEventWithAuthContext) HasData

func (*DocumentDeletedEventWithAuthContext) ProtoMessage

func (*DocumentDeletedEventWithAuthContext) ProtoMessage()

func (*DocumentDeletedEventWithAuthContext) ProtoReflect

func (*DocumentDeletedEventWithAuthContext) Reset

func (*DocumentDeletedEventWithAuthContext) SetData

func (*DocumentDeletedEventWithAuthContext) String

type DocumentDeletedEventWithAuthContext_builder

type DocumentDeletedEventWithAuthContext_builder struct {

	// The data associated with the event.
	Data *DocumentEventData
	// contains filtered or unexported fields
}

func (DocumentDeletedEventWithAuthContext_builder) Build

type DocumentDeletedEvent_builder

type DocumentDeletedEvent_builder struct {

	// The data associated with the event.
	Data *DocumentEventData
	// contains filtered or unexported fields
}

func (DocumentDeletedEvent_builder) Build

type DocumentEventData

type DocumentEventData struct {

	// A Document object containing a post-operation document snapshot.
	// This is not populated for delete events.
	Value *Document `protobuf:"bytes,1,opt,name=value,proto3" json:"value,omitempty"`
	// A Document object containing a pre-operation document snapshot.
	// This is only populated for update and delete events.
	OldValue *Document `protobuf:"bytes,2,opt,name=old_value,json=oldValue,proto3" json:"old_value,omitempty"`
	// A DocumentMask object that lists changed fields.
	// This is only populated for update events.
	UpdateMask *DocumentMask `protobuf:"bytes,3,opt,name=update_mask,json=updateMask,proto3" json:"update_mask,omitempty"`
	// contains filtered or unexported fields
}

The data within all Firestore document events.

func (*DocumentEventData) ClearOldValue

func (x *DocumentEventData) ClearOldValue()

func (*DocumentEventData) ClearUpdateMask

func (x *DocumentEventData) ClearUpdateMask()

func (*DocumentEventData) ClearValue

func (x *DocumentEventData) ClearValue()

func (*DocumentEventData) GetOldValue

func (x *DocumentEventData) GetOldValue() *Document

func (*DocumentEventData) GetUpdateMask

func (x *DocumentEventData) GetUpdateMask() *DocumentMask

func (*DocumentEventData) GetValue

func (x *DocumentEventData) GetValue() *Document

func (*DocumentEventData) HasOldValue

func (x *DocumentEventData) HasOldValue() bool

func (*DocumentEventData) HasUpdateMask

func (x *DocumentEventData) HasUpdateMask() bool

func (*DocumentEventData) HasValue

func (x *DocumentEventData) HasValue() bool

func (*DocumentEventData) ProtoMessage

func (*DocumentEventData) ProtoMessage()

func (*DocumentEventData) ProtoReflect

func (x *DocumentEventData) ProtoReflect() protoreflect.Message

func (*DocumentEventData) Reset

func (x *DocumentEventData) Reset()

func (*DocumentEventData) SetOldValue

func (x *DocumentEventData) SetOldValue(v *Document)

func (*DocumentEventData) SetUpdateMask

func (x *DocumentEventData) SetUpdateMask(v *DocumentMask)

func (*DocumentEventData) SetValue

func (x *DocumentEventData) SetValue(v *Document)

func (*DocumentEventData) String

func (x *DocumentEventData) String() string

type DocumentEventData_builder

type DocumentEventData_builder struct {

	// A Document object containing a post-operation document snapshot.
	// This is not populated for delete events.
	Value *Document
	// A Document object containing a pre-operation document snapshot.
	// This is only populated for update and delete events.
	OldValue *Document
	// A DocumentMask object that lists changed fields.
	// This is only populated for update events.
	UpdateMask *DocumentMask
	// contains filtered or unexported fields
}

func (DocumentEventData_builder) Build

type DocumentMask

type DocumentMask struct {

	// The list of field paths in the mask.
	// See [Document.fields][google.cloud.firestore.v1.events.Document.fields]
	// for a field path syntax reference.
	FieldPaths []string `protobuf:"bytes,1,rep,name=field_paths,json=fieldPaths,proto3" json:"field_paths,omitempty"`
	// contains filtered or unexported fields
}

A set of field paths on a document.

func (*DocumentMask) GetFieldPaths

func (x *DocumentMask) GetFieldPaths() []string

func (*DocumentMask) ProtoMessage

func (*DocumentMask) ProtoMessage()

func (*DocumentMask) ProtoReflect

func (x *DocumentMask) ProtoReflect() protoreflect.Message

func (*DocumentMask) Reset

func (x *DocumentMask) Reset()

func (*DocumentMask) SetFieldPaths

func (x *DocumentMask) SetFieldPaths(v []string)

func (*DocumentMask) String

func (x *DocumentMask) String() string

type DocumentMask_builder

type DocumentMask_builder struct {

	// The list of field paths in the mask.
	// See [Document.fields][google.cloud.firestore.v1.events.Document.fields]
	// for a field path syntax reference.
	FieldPaths []string
	// contains filtered or unexported fields
}

func (DocumentMask_builder) Build

func (b0 DocumentMask_builder) Build() *DocumentMask

type DocumentUpdatedEvent

type DocumentUpdatedEvent struct {

	// The data associated with the event.
	Data *DocumentEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

The CloudEvent raised when a Firestore document is updated.

func (*DocumentUpdatedEvent) ClearData

func (x *DocumentUpdatedEvent) ClearData()

func (*DocumentUpdatedEvent) GetData

func (*DocumentUpdatedEvent) HasData

func (x *DocumentUpdatedEvent) HasData() bool

func (*DocumentUpdatedEvent) ProtoMessage

func (*DocumentUpdatedEvent) ProtoMessage()

func (*DocumentUpdatedEvent) ProtoReflect

func (x *DocumentUpdatedEvent) ProtoReflect() protoreflect.Message

func (*DocumentUpdatedEvent) Reset

func (x *DocumentUpdatedEvent) Reset()

func (*DocumentUpdatedEvent) SetData

func (x *DocumentUpdatedEvent) SetData(v *DocumentEventData)

func (*DocumentUpdatedEvent) String

func (x *DocumentUpdatedEvent) String() string

type DocumentUpdatedEventWithAuthContext

type DocumentUpdatedEventWithAuthContext struct {

	// The data associated with the event.
	Data *DocumentEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

The CloudEvent with Auth Context raised when a Firestore document is updated.

func (*DocumentUpdatedEventWithAuthContext) ClearData

func (x *DocumentUpdatedEventWithAuthContext) ClearData()

func (*DocumentUpdatedEventWithAuthContext) GetData

func (*DocumentUpdatedEventWithAuthContext) HasData

func (*DocumentUpdatedEventWithAuthContext) ProtoMessage

func (*DocumentUpdatedEventWithAuthContext) ProtoMessage()

func (*DocumentUpdatedEventWithAuthContext) ProtoReflect

func (*DocumentUpdatedEventWithAuthContext) Reset

func (*DocumentUpdatedEventWithAuthContext) SetData

func (*DocumentUpdatedEventWithAuthContext) String

type DocumentUpdatedEventWithAuthContext_builder

type DocumentUpdatedEventWithAuthContext_builder struct {

	// The data associated with the event.
	Data *DocumentEventData
	// contains filtered or unexported fields
}

func (DocumentUpdatedEventWithAuthContext_builder) Build

type DocumentUpdatedEvent_builder

type DocumentUpdatedEvent_builder struct {

	// The data associated with the event.
	Data *DocumentEventData
	// contains filtered or unexported fields
}

func (DocumentUpdatedEvent_builder) Build

type DocumentWrittenEvent

type DocumentWrittenEvent struct {

	// The data associated with the event.
	Data *DocumentEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

The CloudEvent raised when a Firestore document is created, updated or deleted.

func (*DocumentWrittenEvent) ClearData

func (x *DocumentWrittenEvent) ClearData()

func (*DocumentWrittenEvent) GetData

func (*DocumentWrittenEvent) HasData

func (x *DocumentWrittenEvent) HasData() bool

func (*DocumentWrittenEvent) ProtoMessage

func (*DocumentWrittenEvent) ProtoMessage()

func (*DocumentWrittenEvent) ProtoReflect

func (x *DocumentWrittenEvent) ProtoReflect() protoreflect.Message

func (*DocumentWrittenEvent) Reset

func (x *DocumentWrittenEvent) Reset()

func (*DocumentWrittenEvent) SetData

func (x *DocumentWrittenEvent) SetData(v *DocumentEventData)

func (*DocumentWrittenEvent) String

func (x *DocumentWrittenEvent) String() string

type DocumentWrittenEventWithAuthContext

type DocumentWrittenEventWithAuthContext struct {

	// The data associated with the event.
	Data *DocumentEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

The CloudEvent with Auth Context raised when a Firestore document is created, updated or deleted.

func (*DocumentWrittenEventWithAuthContext) ClearData

func (x *DocumentWrittenEventWithAuthContext) ClearData()

func (*DocumentWrittenEventWithAuthContext) GetData

func (*DocumentWrittenEventWithAuthContext) HasData

func (*DocumentWrittenEventWithAuthContext) ProtoMessage

func (*DocumentWrittenEventWithAuthContext) ProtoMessage()

func (*DocumentWrittenEventWithAuthContext) ProtoReflect

func (*DocumentWrittenEventWithAuthContext) Reset

func (*DocumentWrittenEventWithAuthContext) SetData

func (*DocumentWrittenEventWithAuthContext) String

type DocumentWrittenEventWithAuthContext_builder

type DocumentWrittenEventWithAuthContext_builder struct {

	// The data associated with the event.
	Data *DocumentEventData
	// contains filtered or unexported fields
}

func (DocumentWrittenEventWithAuthContext_builder) Build

type DocumentWrittenEvent_builder

type DocumentWrittenEvent_builder struct {

	// The data associated with the event.
	Data *DocumentEventData
	// contains filtered or unexported fields
}

func (DocumentWrittenEvent_builder) Build

type Document_builder

type Document_builder struct {

	// The resource name of the document. For example:
	// `projects/{project_id}/databases/{database_id}/documents/{document_path}`
	Name string
	// The document's fields.
	//
	// The map keys represent field names.
	//
	// A simple field name contains only characters `a` to `z`, `A` to `Z`,
	// `0` to `9`, or `_`, and must not start with `0` to `9`. For example,
	// `foo_bar_17`.
	//
	// Field names matching the regular expression `__.*__` are reserved. Reserved
	// field names are forbidden except in certain documented contexts. The map
	// keys, represented as UTF-8, must not exceed 1,500 bytes and cannot be
	// empty.
	//
	// Field paths may be used in other contexts to refer to structured fields
	// defined here. For `map_value`, the field path is represented by the simple
	// or quoted field names of the containing fields, delimited by `.`. For
	// example, the structured field
	// `"foo" : { map_value: { "x&y" : { string_value: "hello" }}}` would be
	// represented by the field path `foo.x&y`.
	//
	// Within a field path, a quoted field name starts and ends with “ ` “ and
	// may contain any character. Some characters, including “ ` “, must be
	// escaped using a `\`. For example, “ `x&y` “ represents `x&y` and
	// “ `bak\`tik` “ represents “ bak`tik “.
	Fields map[string]*Value
	// The time at which the document was created.
	//
	// This value increases monotonically when a document is deleted then
	// recreated. It can also be compared to values from other documents and
	// the `read_time` of a query.
	CreateTime *timestamppb.Timestamp
	// The time at which the document was last changed.
	//
	// This value is initially set to the `create_time` then increases
	// monotonically with each change to the document. It can also be
	// compared to values from other documents and the `read_time` of a query.
	UpdateTime *timestamppb.Timestamp
	// contains filtered or unexported fields
}

func (Document_builder) Build

func (b0 Document_builder) Build() *Document

type MapValue

type MapValue struct {

	// The map's fields.
	//
	// The map keys represent field names. Field names matching the regular
	// expression `__.*__` are reserved. Reserved field names are forbidden except
	// in certain documented contexts. The map keys, represented as UTF-8, must
	// not exceed 1,500 bytes and cannot be empty.
	Fields map[string]*Value `` /* 139-byte string literal not displayed */
	// contains filtered or unexported fields
}

A map value.

func (*MapValue) GetFields

func (x *MapValue) GetFields() map[string]*Value

func (*MapValue) ProtoMessage

func (*MapValue) ProtoMessage()

func (*MapValue) ProtoReflect

func (x *MapValue) ProtoReflect() protoreflect.Message

func (*MapValue) Reset

func (x *MapValue) Reset()

func (*MapValue) SetFields

func (x *MapValue) SetFields(v map[string]*Value)

func (*MapValue) String

func (x *MapValue) String() string

type MapValue_builder

type MapValue_builder struct {

	// The map's fields.
	//
	// The map keys represent field names. Field names matching the regular
	// expression `__.*__` are reserved. Reserved field names are forbidden except
	// in certain documented contexts. The map keys, represented as UTF-8, must
	// not exceed 1,500 bytes and cannot be empty.
	Fields map[string]*Value
	// contains filtered or unexported fields
}

func (MapValue_builder) Build

func (b0 MapValue_builder) Build() *MapValue

type Value

type Value struct {

	// Must have a value set.
	//
	// Types that are valid to be assigned to ValueType:
	//
	//	*Value_NullValue
	//	*Value_BooleanValue
	//	*Value_IntegerValue
	//	*Value_DoubleValue
	//	*Value_TimestampValue
	//	*Value_StringValue
	//	*Value_BytesValue
	//	*Value_ReferenceValue
	//	*Value_GeoPointValue
	//	*Value_ArrayValue
	//	*Value_MapValue
	ValueType isValue_ValueType `protobuf_oneof:"value_type"`
	// contains filtered or unexported fields
}

A message that can hold any of the supported value types.

func (*Value) ClearArrayValue

func (x *Value) ClearArrayValue()

func (*Value) ClearBooleanValue

func (x *Value) ClearBooleanValue()

func (*Value) ClearBytesValue

func (x *Value) ClearBytesValue()

func (*Value) ClearDoubleValue

func (x *Value) ClearDoubleValue()

func (*Value) ClearGeoPointValue

func (x *Value) ClearGeoPointValue()

func (*Value) ClearIntegerValue

func (x *Value) ClearIntegerValue()

func (*Value) ClearMapValue

func (x *Value) ClearMapValue()

func (*Value) ClearNullValue

func (x *Value) ClearNullValue()

func (*Value) ClearReferenceValue

func (x *Value) ClearReferenceValue()

func (*Value) ClearStringValue

func (x *Value) ClearStringValue()

func (*Value) ClearTimestampValue

func (x *Value) ClearTimestampValue()

func (*Value) ClearValueType

func (x *Value) ClearValueType()

func (*Value) GetArrayValue

func (x *Value) GetArrayValue() *ArrayValue

func (*Value) GetBooleanValue

func (x *Value) GetBooleanValue() bool

func (*Value) GetBytesValue

func (x *Value) GetBytesValue() []byte

func (*Value) GetDoubleValue

func (x *Value) GetDoubleValue() float64

func (*Value) GetGeoPointValue

func (x *Value) GetGeoPointValue() *latlng.LatLng

func (*Value) GetIntegerValue

func (x *Value) GetIntegerValue() int64

func (*Value) GetMapValue

func (x *Value) GetMapValue() *MapValue

func (*Value) GetNullValue

func (x *Value) GetNullValue() structpb.NullValue

func (*Value) GetReferenceValue

func (x *Value) GetReferenceValue() string

func (*Value) GetStringValue

func (x *Value) GetStringValue() string

func (*Value) GetTimestampValue

func (x *Value) GetTimestampValue() *timestamppb.Timestamp

func (*Value) GetValueType

func (x *Value) GetValueType() isValue_ValueType

func (*Value) HasArrayValue

func (x *Value) HasArrayValue() bool

func (*Value) HasBooleanValue

func (x *Value) HasBooleanValue() bool

func (*Value) HasBytesValue

func (x *Value) HasBytesValue() bool

func (*Value) HasDoubleValue

func (x *Value) HasDoubleValue() bool

func (*Value) HasGeoPointValue

func (x *Value) HasGeoPointValue() bool

func (*Value) HasIntegerValue

func (x *Value) HasIntegerValue() bool

func (*Value) HasMapValue

func (x *Value) HasMapValue() bool

func (*Value) HasNullValue

func (x *Value) HasNullValue() bool

func (*Value) HasReferenceValue

func (x *Value) HasReferenceValue() bool

func (*Value) HasStringValue

func (x *Value) HasStringValue() bool

func (*Value) HasTimestampValue

func (x *Value) HasTimestampValue() bool

func (*Value) HasValueType

func (x *Value) HasValueType() bool

func (*Value) ProtoMessage

func (*Value) ProtoMessage()

func (*Value) ProtoReflect

func (x *Value) ProtoReflect() protoreflect.Message

func (*Value) Reset

func (x *Value) Reset()

func (*Value) SetArrayValue

func (x *Value) SetArrayValue(v *ArrayValue)

func (*Value) SetBooleanValue

func (x *Value) SetBooleanValue(v bool)

func (*Value) SetBytesValue

func (x *Value) SetBytesValue(v []byte)

func (*Value) SetDoubleValue

func (x *Value) SetDoubleValue(v float64)

func (*Value) SetGeoPointValue

func (x *Value) SetGeoPointValue(v *latlng.LatLng)

func (*Value) SetIntegerValue

func (x *Value) SetIntegerValue(v int64)

func (*Value) SetMapValue

func (x *Value) SetMapValue(v *MapValue)

func (*Value) SetNullValue

func (x *Value) SetNullValue(v structpb.NullValue)

func (*Value) SetReferenceValue

func (x *Value) SetReferenceValue(v string)

func (*Value) SetStringValue

func (x *Value) SetStringValue(v string)

func (*Value) SetTimestampValue

func (x *Value) SetTimestampValue(v *timestamppb.Timestamp)

func (*Value) String

func (x *Value) String() string

func (*Value) WhichValueType

func (x *Value) WhichValueType() case_Value_ValueType

type Value_ArrayValue

type Value_ArrayValue struct {
	// An array value.
	//
	// Cannot directly contain another array value, though can contain an
	// map which contains another array.
	ArrayValue *ArrayValue `protobuf:"bytes,9,opt,name=array_value,json=arrayValue,proto3,oneof"`
}

type Value_BooleanValue

type Value_BooleanValue struct {
	// A boolean value.
	BooleanValue bool `protobuf:"varint,1,opt,name=boolean_value,json=booleanValue,proto3,oneof"`
}

type Value_BytesValue

type Value_BytesValue struct {
	// A bytes value.
	//
	// Must not exceed 1 MiB - 89 bytes.
	// Only the first 1,500 bytes are considered by queries.
	BytesValue []byte `protobuf:"bytes,18,opt,name=bytes_value,json=bytesValue,proto3,oneof"`
}

type Value_DoubleValue

type Value_DoubleValue struct {
	// A double value.
	DoubleValue float64 `protobuf:"fixed64,3,opt,name=double_value,json=doubleValue,proto3,oneof"`
}

type Value_GeoPointValue

type Value_GeoPointValue struct {
	// A geo point value representing a point on the surface of Earth.
	GeoPointValue *latlng.LatLng `protobuf:"bytes,8,opt,name=geo_point_value,json=geoPointValue,proto3,oneof"`
}

type Value_IntegerValue

type Value_IntegerValue struct {
	// An integer value.
	IntegerValue int64 `protobuf:"varint,2,opt,name=integer_value,json=integerValue,proto3,oneof"`
}

type Value_MapValue

type Value_MapValue struct {
	// A map value.
	MapValue *MapValue `protobuf:"bytes,6,opt,name=map_value,json=mapValue,proto3,oneof"`
}

type Value_NullValue

type Value_NullValue struct {
	// A null value.
	NullValue structpb.NullValue `protobuf:"varint,11,opt,name=null_value,json=nullValue,proto3,enum=google.protobuf.NullValue,oneof"`
}

type Value_ReferenceValue

type Value_ReferenceValue struct {
	// A reference to a document. For example:
	// `projects/{project_id}/databases/{database_id}/documents/{document_path}`.
	ReferenceValue string `protobuf:"bytes,5,opt,name=reference_value,json=referenceValue,proto3,oneof"`
}

type Value_StringValue

type Value_StringValue struct {
	// A string value.
	//
	// The string, represented as UTF-8, must not exceed 1 MiB - 89 bytes.
	// Only the first 1,500 bytes of the UTF-8 representation are considered by
	// queries.
	StringValue string `protobuf:"bytes,17,opt,name=string_value,json=stringValue,proto3,oneof"`
}

type Value_TimestampValue

type Value_TimestampValue struct {
	// A timestamp value.
	//
	// Precise only to microseconds. When stored, any additional precision is
	// rounded down.
	TimestampValue *timestamppb.Timestamp `protobuf:"bytes,10,opt,name=timestamp_value,json=timestampValue,proto3,oneof"`
}

type Value_builder

type Value_builder struct {

	// Fields of oneof ValueType:
	// A null value.
	NullValue *structpb.NullValue
	// A boolean value.
	BooleanValue *bool
	// An integer value.
	IntegerValue *int64
	// A double value.
	DoubleValue *float64
	// A timestamp value.
	//
	// Precise only to microseconds. When stored, any additional precision is
	// rounded down.
	TimestampValue *timestamppb.Timestamp
	// A string value.
	//
	// The string, represented as UTF-8, must not exceed 1 MiB - 89 bytes.
	// Only the first 1,500 bytes of the UTF-8 representation are considered by
	// queries.
	StringValue *string
	// A bytes value.
	//
	// Must not exceed 1 MiB - 89 bytes.
	// Only the first 1,500 bytes are considered by queries.
	BytesValue []byte
	// A reference to a document. For example:
	// `projects/{project_id}/databases/{database_id}/documents/{document_path}`.
	ReferenceValue *string
	// A geo point value representing a point on the surface of Earth.
	GeoPointValue *latlng.LatLng
	// An array value.
	//
	// Cannot directly contain another array value, though can contain an
	// map which contains another array.
	ArrayValue *ArrayValue
	// A map value.
	MapValue *MapValue
	// contains filtered or unexported fields
}

func (Value_builder) Build

func (b0 Value_builder) Build() *Value

Source Files

  • data.pb.go
  • events.pb.go

Jump to