memcachev1

package
v1.36.11-2024050211440... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	MemcacheVersion_name = map[int32]string{
		0: "MEMCACHE_VERSION_UNSPECIFIED",
		1: "MEMCACHE_1_5",
	}
	MemcacheVersion_value = map[string]int32{
		"MEMCACHE_VERSION_UNSPECIFIED": 0,
		"MEMCACHE_1_5":                 1,
	}
)

Enum value maps for MemcacheVersion.

var (
	Instance_State_name = map[int32]string{
		0: "STATE_UNSPECIFIED",
		1: "CREATING",
		2: "READY",
		3: "UPDATING",
		4: "DELETING",
		5: "PERFORMING_MAINTENANCE",
	}
	Instance_State_value = map[string]int32{
		"STATE_UNSPECIFIED":      0,
		"CREATING":               1,
		"READY":                  2,
		"UPDATING":               3,
		"DELETING":               4,
		"PERFORMING_MAINTENANCE": 5,
	}
)

Enum value maps for Instance_State.

var (
	Instance_Node_State_name = map[int32]string{
		0: "STATE_UNSPECIFIED",
		1: "CREATING",
		2: "READY",
		3: "DELETING",
		4: "UPDATING",
	}
	Instance_Node_State_value = map[string]int32{
		"STATE_UNSPECIFIED": 0,
		"CREATING":          1,
		"READY":             2,
		"DELETING":          3,
		"UPDATING":          4,
	}
)

Enum value maps for Instance_Node_State.

var (
	Instance_InstanceMessage_Code_name = map[int32]string{
		0: "CODE_UNSPECIFIED",
		1: "ZONE_DISTRIBUTION_UNBALANCED",
	}
	Instance_InstanceMessage_Code_value = map[string]int32{
		"CODE_UNSPECIFIED":             0,
		"ZONE_DISTRIBUTION_UNBALANCED": 1,
	}
)

Enum value maps for Instance_InstanceMessage_Code.

var File_google_events_cloud_memcache_v1_data_proto protoreflect.FileDescriptor
var File_google_events_cloud_memcache_v1_events_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type Instance

type Instance struct {

	// Required. Unique name of the resource in this scope including project and
	// location using the form:
	//
	//	`projects/{project_id}/locations/{location_id}/instances/{instance_id}`
	//
	// Note: Memcached instances are managed and addressed at the regional level
	// so `location_id` here refers to a Google Cloud region; however, users may
	// choose which zones Memcached nodes should be provisioned in within an
	// instance. Refer to [zones][google.cloud.memcache.v1.Instance.zones] field
	// for more details.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// User provided name for the instance, which is only used for display
	// purposes. Cannot be more than 80 characters.
	DisplayName string `protobuf:"bytes,2,opt,name=display_name,json=displayName,proto3" json:"display_name,omitempty"`
	// Resource labels to represent user-provided metadata.
	// Refer to cloud documentation on labels for more details.
	// https://cloud.google.com/compute/docs/labeling-resources
	Labels map[string]string `` /* 139-byte string literal not displayed */
	// The full name of the Google Compute Engine
	// [network](/compute/docs/networks-and-firewalls#networks) to which the
	// instance is connected. If left unspecified, the `default` network
	// will be used.
	AuthorizedNetwork string `protobuf:"bytes,4,opt,name=authorized_network,json=authorizedNetwork,proto3" json:"authorized_network,omitempty"`
	// Zones in which Memcached nodes should be provisioned.
	// Memcached nodes will be equally distributed across these zones. If not
	// provided, the service will by default create nodes in all zones in the
	// region for the instance.
	Zones []string `protobuf:"bytes,5,rep,name=zones,proto3" json:"zones,omitempty"`
	// Required. Number of nodes in the Memcached instance.
	NodeCount int32 `protobuf:"varint,6,opt,name=node_count,json=nodeCount,proto3" json:"node_count,omitempty"`
	// Required. Configuration for Memcached nodes.
	NodeConfig *Instance_NodeConfig `protobuf:"bytes,7,opt,name=node_config,json=nodeConfig,proto3" json:"node_config,omitempty"`
	// The major version of Memcached software.
	// If not provided, latest supported version will be used. Currently the
	// latest supported major version is `MEMCACHE_1_5`.
	// The minor version will be automatically determined by our system based on
	// the latest supported minor version.
	MemcacheVersion MemcacheVersion `` /* 160-byte string literal not displayed */
	// User defined parameters to apply to the memcached process
	// on each node.
	Parameters *MemcacheParameters `protobuf:"bytes,11,opt,name=parameters,proto3" json:"parameters,omitempty"`
	// Output only. List of Memcached nodes.
	// Refer to [Node][google.cloud.memcache.v1.Instance.Node] message for more
	// details.
	MemcacheNodes []*Instance_Node `protobuf:"bytes,12,rep,name=memcache_nodes,json=memcacheNodes,proto3" json:"memcache_nodes,omitempty"`
	// Output only. The time the instance was created.
	CreateTime *timestamppb.Timestamp `protobuf:"bytes,13,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
	// Output only. The time the instance was updated.
	UpdateTime *timestamppb.Timestamp `protobuf:"bytes,14,opt,name=update_time,json=updateTime,proto3" json:"update_time,omitempty"`
	// Output only. The state of this Memcached instance.
	State Instance_State `protobuf:"varint,15,opt,name=state,proto3,enum=google.events.cloud.memcache.v1.Instance_State" json:"state,omitempty"`
	// Output only. The full version of memcached server running on this instance.
	// System automatically determines the full memcached version for an instance
	// based on the input MemcacheVersion.
	// The full version format will be "memcached-1.5.16".
	MemcacheFullVersion string `protobuf:"bytes,18,opt,name=memcache_full_version,json=memcacheFullVersion,proto3" json:"memcache_full_version,omitempty"`
	// List of messages that describe the current state of the Memcached instance.
	InstanceMessages []*Instance_InstanceMessage `protobuf:"bytes,19,rep,name=instance_messages,json=instanceMessages,proto3" json:"instance_messages,omitempty"`
	// Output only. Endpoint for the Discovery API.
	DiscoveryEndpoint string `protobuf:"bytes,20,opt,name=discovery_endpoint,json=discoveryEndpoint,proto3" json:"discovery_endpoint,omitempty"`
	// The maintenance policy for the instance. If not provided,
	// the maintenance event will be performed based on Memorystore
	// internal rollout schedule.
	MaintenancePolicy *MaintenancePolicy `protobuf:"bytes,21,opt,name=maintenance_policy,json=maintenancePolicy,proto3" json:"maintenance_policy,omitempty"`
	// Output only. Published maintenance schedule.
	MaintenanceSchedule *MaintenanceSchedule `protobuf:"bytes,22,opt,name=maintenance_schedule,json=maintenanceSchedule,proto3" json:"maintenance_schedule,omitempty"`
	// contains filtered or unexported fields
}

A Memorystore for Memcached instance

func (*Instance) ClearCreateTime

func (x *Instance) ClearCreateTime()

func (*Instance) ClearMaintenancePolicy

func (x *Instance) ClearMaintenancePolicy()

func (*Instance) ClearMaintenanceSchedule

func (x *Instance) ClearMaintenanceSchedule()

func (*Instance) ClearNodeConfig

func (x *Instance) ClearNodeConfig()

func (*Instance) ClearParameters

func (x *Instance) ClearParameters()

func (*Instance) ClearUpdateTime

func (x *Instance) ClearUpdateTime()

func (*Instance) GetAuthorizedNetwork

func (x *Instance) GetAuthorizedNetwork() string

func (*Instance) GetCreateTime

func (x *Instance) GetCreateTime() *timestamppb.Timestamp

func (*Instance) GetDiscoveryEndpoint

func (x *Instance) GetDiscoveryEndpoint() string

func (*Instance) GetDisplayName

func (x *Instance) GetDisplayName() string

func (*Instance) GetInstanceMessages

func (x *Instance) GetInstanceMessages() []*Instance_InstanceMessage

func (*Instance) GetLabels

func (x *Instance) GetLabels() map[string]string

func (*Instance) GetMaintenancePolicy

func (x *Instance) GetMaintenancePolicy() *MaintenancePolicy

func (*Instance) GetMaintenanceSchedule

func (x *Instance) GetMaintenanceSchedule() *MaintenanceSchedule

func (*Instance) GetMemcacheFullVersion

func (x *Instance) GetMemcacheFullVersion() string

func (*Instance) GetMemcacheNodes

func (x *Instance) GetMemcacheNodes() []*Instance_Node

func (*Instance) GetMemcacheVersion

func (x *Instance) GetMemcacheVersion() MemcacheVersion

func (*Instance) GetName

func (x *Instance) GetName() string

func (*Instance) GetNodeConfig

func (x *Instance) GetNodeConfig() *Instance_NodeConfig

func (*Instance) GetNodeCount

func (x *Instance) GetNodeCount() int32

func (*Instance) GetParameters

func (x *Instance) GetParameters() *MemcacheParameters

func (*Instance) GetState

func (x *Instance) GetState() Instance_State

func (*Instance) GetUpdateTime

func (x *Instance) GetUpdateTime() *timestamppb.Timestamp

func (*Instance) GetZones

func (x *Instance) GetZones() []string

func (*Instance) HasCreateTime

func (x *Instance) HasCreateTime() bool

func (*Instance) HasMaintenancePolicy

func (x *Instance) HasMaintenancePolicy() bool

func (*Instance) HasMaintenanceSchedule

func (x *Instance) HasMaintenanceSchedule() bool

func (*Instance) HasNodeConfig

func (x *Instance) HasNodeConfig() bool

func (*Instance) HasParameters

func (x *Instance) HasParameters() bool

func (*Instance) HasUpdateTime

func (x *Instance) HasUpdateTime() bool

func (*Instance) ProtoMessage

func (*Instance) ProtoMessage()

func (*Instance) ProtoReflect

func (x *Instance) ProtoReflect() protoreflect.Message

func (*Instance) Reset

func (x *Instance) Reset()

func (*Instance) SetAuthorizedNetwork

func (x *Instance) SetAuthorizedNetwork(v string)

func (*Instance) SetCreateTime

func (x *Instance) SetCreateTime(v *timestamppb.Timestamp)

func (*Instance) SetDiscoveryEndpoint

func (x *Instance) SetDiscoveryEndpoint(v string)

func (*Instance) SetDisplayName

func (x *Instance) SetDisplayName(v string)

func (*Instance) SetInstanceMessages

func (x *Instance) SetInstanceMessages(v []*Instance_InstanceMessage)

func (*Instance) SetLabels

func (x *Instance) SetLabels(v map[string]string)

func (*Instance) SetMaintenancePolicy

func (x *Instance) SetMaintenancePolicy(v *MaintenancePolicy)

func (*Instance) SetMaintenanceSchedule

func (x *Instance) SetMaintenanceSchedule(v *MaintenanceSchedule)

func (*Instance) SetMemcacheFullVersion

func (x *Instance) SetMemcacheFullVersion(v string)

func (*Instance) SetMemcacheNodes

func (x *Instance) SetMemcacheNodes(v []*Instance_Node)

func (*Instance) SetMemcacheVersion

func (x *Instance) SetMemcacheVersion(v MemcacheVersion)

func (*Instance) SetName

func (x *Instance) SetName(v string)

func (*Instance) SetNodeConfig

func (x *Instance) SetNodeConfig(v *Instance_NodeConfig)

func (*Instance) SetNodeCount

func (x *Instance) SetNodeCount(v int32)

func (*Instance) SetParameters

func (x *Instance) SetParameters(v *MemcacheParameters)

func (*Instance) SetState

func (x *Instance) SetState(v Instance_State)

func (*Instance) SetUpdateTime

func (x *Instance) SetUpdateTime(v *timestamppb.Timestamp)

func (*Instance) SetZones

func (x *Instance) SetZones(v []string)

func (*Instance) String

func (x *Instance) String() string

type InstanceCreatedEvent

type InstanceCreatedEvent struct {

	// The data associated with the event.
	Data *InstanceEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

The CloudEvent raised when an Instance is created.

func (*InstanceCreatedEvent) ClearData

func (x *InstanceCreatedEvent) ClearData()

func (*InstanceCreatedEvent) GetData

func (*InstanceCreatedEvent) HasData

func (x *InstanceCreatedEvent) HasData() bool

func (*InstanceCreatedEvent) ProtoMessage

func (*InstanceCreatedEvent) ProtoMessage()

func (*InstanceCreatedEvent) ProtoReflect

func (x *InstanceCreatedEvent) ProtoReflect() protoreflect.Message

func (*InstanceCreatedEvent) Reset

func (x *InstanceCreatedEvent) Reset()

func (*InstanceCreatedEvent) SetData

func (x *InstanceCreatedEvent) SetData(v *InstanceEventData)

func (*InstanceCreatedEvent) String

func (x *InstanceCreatedEvent) String() string

type InstanceCreatedEvent_builder

type InstanceCreatedEvent_builder struct {

	// The data associated with the event.
	Data *InstanceEventData
	// contains filtered or unexported fields
}

func (InstanceCreatedEvent_builder) Build

type InstanceDeletedEvent

type InstanceDeletedEvent struct {

	// The data associated with the event.
	Data *InstanceEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

The CloudEvent raised when an Instance is deleted.

func (*InstanceDeletedEvent) ClearData

func (x *InstanceDeletedEvent) ClearData()

func (*InstanceDeletedEvent) GetData

func (*InstanceDeletedEvent) HasData

func (x *InstanceDeletedEvent) HasData() bool

func (*InstanceDeletedEvent) ProtoMessage

func (*InstanceDeletedEvent) ProtoMessage()

func (*InstanceDeletedEvent) ProtoReflect

func (x *InstanceDeletedEvent) ProtoReflect() protoreflect.Message

func (*InstanceDeletedEvent) Reset

func (x *InstanceDeletedEvent) Reset()

func (*InstanceDeletedEvent) SetData

func (x *InstanceDeletedEvent) SetData(v *InstanceEventData)

func (*InstanceDeletedEvent) String

func (x *InstanceDeletedEvent) String() string

type InstanceDeletedEvent_builder

type InstanceDeletedEvent_builder struct {

	// The data associated with the event.
	Data *InstanceEventData
	// contains filtered or unexported fields
}

func (InstanceDeletedEvent_builder) Build

type InstanceEventData

type InstanceEventData struct {

	// Optional. The Instance event payload. Unset for deletion events.
	Payload *Instance `protobuf:"bytes,1,opt,name=payload,proto3,oneof" json:"payload,omitempty"`
	// contains filtered or unexported fields
}

The data within all Instance events.

func (*InstanceEventData) ClearPayload

func (x *InstanceEventData) ClearPayload()

func (*InstanceEventData) GetPayload

func (x *InstanceEventData) GetPayload() *Instance

func (*InstanceEventData) HasPayload

func (x *InstanceEventData) HasPayload() bool

func (*InstanceEventData) ProtoMessage

func (*InstanceEventData) ProtoMessage()

func (*InstanceEventData) ProtoReflect

func (x *InstanceEventData) ProtoReflect() protoreflect.Message

func (*InstanceEventData) Reset

func (x *InstanceEventData) Reset()

func (*InstanceEventData) SetPayload

func (x *InstanceEventData) SetPayload(v *Instance)

func (*InstanceEventData) String

func (x *InstanceEventData) String() string

type InstanceEventData_builder

type InstanceEventData_builder struct {

	// Optional. The Instance event payload. Unset for deletion events.
	Payload *Instance
	// contains filtered or unexported fields
}

func (InstanceEventData_builder) Build

type InstanceUpdatedEvent

type InstanceUpdatedEvent struct {

	// The data associated with the event.
	Data *InstanceEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

The CloudEvent raised when an Instance is updated.

func (*InstanceUpdatedEvent) ClearData

func (x *InstanceUpdatedEvent) ClearData()

func (*InstanceUpdatedEvent) GetData

func (*InstanceUpdatedEvent) HasData

func (x *InstanceUpdatedEvent) HasData() bool

func (*InstanceUpdatedEvent) ProtoMessage

func (*InstanceUpdatedEvent) ProtoMessage()

func (*InstanceUpdatedEvent) ProtoReflect

func (x *InstanceUpdatedEvent) ProtoReflect() protoreflect.Message

func (*InstanceUpdatedEvent) Reset

func (x *InstanceUpdatedEvent) Reset()

func (*InstanceUpdatedEvent) SetData

func (x *InstanceUpdatedEvent) SetData(v *InstanceEventData)

func (*InstanceUpdatedEvent) String

func (x *InstanceUpdatedEvent) String() string

type InstanceUpdatedEvent_builder

type InstanceUpdatedEvent_builder struct {

	// The data associated with the event.
	Data *InstanceEventData
	// contains filtered or unexported fields
}

func (InstanceUpdatedEvent_builder) Build

type Instance_InstanceMessage

type Instance_InstanceMessage struct {

	// A code that correspond to one type of user-facing message.
	Code Instance_InstanceMessage_Code `` /* 129-byte string literal not displayed */
	// Message on memcached instance which will be exposed to users.
	Message string `protobuf:"bytes,2,opt,name=message,proto3" json:"message,omitempty"`
	// contains filtered or unexported fields
}

func (*Instance_InstanceMessage) GetCode

func (*Instance_InstanceMessage) GetMessage

func (x *Instance_InstanceMessage) GetMessage() string

func (*Instance_InstanceMessage) ProtoMessage

func (*Instance_InstanceMessage) ProtoMessage()

func (*Instance_InstanceMessage) ProtoReflect

func (x *Instance_InstanceMessage) ProtoReflect() protoreflect.Message

func (*Instance_InstanceMessage) Reset

func (x *Instance_InstanceMessage) Reset()

func (*Instance_InstanceMessage) SetCode

func (*Instance_InstanceMessage) SetMessage

func (x *Instance_InstanceMessage) SetMessage(v string)

func (*Instance_InstanceMessage) String

func (x *Instance_InstanceMessage) String() string

type Instance_InstanceMessage_Code

type Instance_InstanceMessage_Code int32
const (
	// Message Code not set.
	Instance_InstanceMessage_CODE_UNSPECIFIED Instance_InstanceMessage_Code = 0
	// Memcached nodes are distributed unevenly.
	Instance_InstanceMessage_ZONE_DISTRIBUTION_UNBALANCED Instance_InstanceMessage_Code = 1
)

func (Instance_InstanceMessage_Code) Descriptor

func (Instance_InstanceMessage_Code) Enum

func (Instance_InstanceMessage_Code) Number

func (Instance_InstanceMessage_Code) String

func (Instance_InstanceMessage_Code) Type

type Instance_InstanceMessage_builder

type Instance_InstanceMessage_builder struct {

	// A code that correspond to one type of user-facing message.
	Code Instance_InstanceMessage_Code
	// Message on memcached instance which will be exposed to users.
	Message string
	// contains filtered or unexported fields
}

func (Instance_InstanceMessage_builder) Build

type Instance_Node

type Instance_Node struct {

	// Output only. Identifier of the Memcached node. The node id does not
	// include project or location like the Memcached instance name.
	NodeId string `protobuf:"bytes,1,opt,name=node_id,json=nodeId,proto3" json:"node_id,omitempty"`
	// Output only. Location (GCP Zone) for the Memcached node.
	Zone string `protobuf:"bytes,2,opt,name=zone,proto3" json:"zone,omitempty"`
	// Output only. Current state of the Memcached node.
	State Instance_Node_State `protobuf:"varint,3,opt,name=state,proto3,enum=google.events.cloud.memcache.v1.Instance_Node_State" json:"state,omitempty"`
	// Output only. Hostname or IP address of the Memcached node used by the
	// clients to connect to the Memcached server on this node.
	Host string `protobuf:"bytes,4,opt,name=host,proto3" json:"host,omitempty"`
	// Output only. The port number of the Memcached server on this node.
	Port int32 `protobuf:"varint,5,opt,name=port,proto3" json:"port,omitempty"`
	// User defined parameters currently applied to the node.
	Parameters *MemcacheParameters `protobuf:"bytes,6,opt,name=parameters,proto3" json:"parameters,omitempty"`
	// contains filtered or unexported fields
}

func (*Instance_Node) ClearParameters

func (x *Instance_Node) ClearParameters()

func (*Instance_Node) GetHost

func (x *Instance_Node) GetHost() string

func (*Instance_Node) GetNodeId

func (x *Instance_Node) GetNodeId() string

func (*Instance_Node) GetParameters

func (x *Instance_Node) GetParameters() *MemcacheParameters

func (*Instance_Node) GetPort

func (x *Instance_Node) GetPort() int32

func (*Instance_Node) GetState

func (x *Instance_Node) GetState() Instance_Node_State

func (*Instance_Node) GetZone

func (x *Instance_Node) GetZone() string

func (*Instance_Node) HasParameters

func (x *Instance_Node) HasParameters() bool

func (*Instance_Node) ProtoMessage

func (*Instance_Node) ProtoMessage()

func (*Instance_Node) ProtoReflect

func (x *Instance_Node) ProtoReflect() protoreflect.Message

func (*Instance_Node) Reset

func (x *Instance_Node) Reset()

func (*Instance_Node) SetHost

func (x *Instance_Node) SetHost(v string)

func (*Instance_Node) SetNodeId

func (x *Instance_Node) SetNodeId(v string)

func (*Instance_Node) SetParameters

func (x *Instance_Node) SetParameters(v *MemcacheParameters)

func (*Instance_Node) SetPort

func (x *Instance_Node) SetPort(v int32)

func (*Instance_Node) SetState

func (x *Instance_Node) SetState(v Instance_Node_State)

func (*Instance_Node) SetZone

func (x *Instance_Node) SetZone(v string)

func (*Instance_Node) String

func (x *Instance_Node) String() string

type Instance_NodeConfig

type Instance_NodeConfig struct {

	// Required. Number of cpus per Memcached node.
	CpuCount int32 `protobuf:"varint,1,opt,name=cpu_count,json=cpuCount,proto3" json:"cpu_count,omitempty"`
	// Required. Memory size in MiB for each Memcached node.
	MemorySizeMb int32 `protobuf:"varint,2,opt,name=memory_size_mb,json=memorySizeMb,proto3" json:"memory_size_mb,omitempty"`
	// contains filtered or unexported fields
}

Configuration for a Memcached Node.

func (*Instance_NodeConfig) GetCpuCount

func (x *Instance_NodeConfig) GetCpuCount() int32

func (*Instance_NodeConfig) GetMemorySizeMb

func (x *Instance_NodeConfig) GetMemorySizeMb() int32

func (*Instance_NodeConfig) ProtoMessage

func (*Instance_NodeConfig) ProtoMessage()

func (*Instance_NodeConfig) ProtoReflect

func (x *Instance_NodeConfig) ProtoReflect() protoreflect.Message

func (*Instance_NodeConfig) Reset

func (x *Instance_NodeConfig) Reset()

func (*Instance_NodeConfig) SetCpuCount

func (x *Instance_NodeConfig) SetCpuCount(v int32)

func (*Instance_NodeConfig) SetMemorySizeMb

func (x *Instance_NodeConfig) SetMemorySizeMb(v int32)

func (*Instance_NodeConfig) String

func (x *Instance_NodeConfig) String() string

type Instance_NodeConfig_builder

type Instance_NodeConfig_builder struct {

	// Required. Number of cpus per Memcached node.
	CpuCount int32
	// Required. Memory size in MiB for each Memcached node.
	MemorySizeMb int32
	// contains filtered or unexported fields
}

func (Instance_NodeConfig_builder) Build

type Instance_Node_State

type Instance_Node_State int32

Different states of a Memcached node.

const (
	// Node state is not set.
	Instance_Node_STATE_UNSPECIFIED Instance_Node_State = 0
	// Node is being created.
	Instance_Node_CREATING Instance_Node_State = 1
	// Node has been created and ready to be used.
	Instance_Node_READY Instance_Node_State = 2
	// Node is being deleted.
	Instance_Node_DELETING Instance_Node_State = 3
	// Node is being updated.
	Instance_Node_UPDATING Instance_Node_State = 4
)

func (Instance_Node_State) Descriptor

func (Instance_Node_State) Enum

func (Instance_Node_State) Number

func (Instance_Node_State) String

func (x Instance_Node_State) String() string

func (Instance_Node_State) Type

type Instance_Node_builder

type Instance_Node_builder struct {

	// Output only. Identifier of the Memcached node. The node id does not
	// include project or location like the Memcached instance name.
	NodeId string
	// Output only. Location (GCP Zone) for the Memcached node.
	Zone string
	// Output only. Current state of the Memcached node.
	State Instance_Node_State
	// Output only. Hostname or IP address of the Memcached node used by the
	// clients to connect to the Memcached server on this node.
	Host string
	// Output only. The port number of the Memcached server on this node.
	Port int32
	// User defined parameters currently applied to the node.
	Parameters *MemcacheParameters
	// contains filtered or unexported fields
}

func (Instance_Node_builder) Build

type Instance_State

type Instance_State int32

Different states of a Memcached instance.

const (
	// State not set.
	Instance_STATE_UNSPECIFIED Instance_State = 0
	// Memcached instance is being created.
	Instance_CREATING Instance_State = 1
	// Memcached instance has been created and ready to be used.
	Instance_READY Instance_State = 2
	// Memcached instance is updating configuration such as maintenance policy
	// and schedule.
	Instance_UPDATING Instance_State = 3
	// Memcached instance is being deleted.
	Instance_DELETING Instance_State = 4
	// Memcached instance is going through maintenance, e.g. data plane rollout.
	Instance_PERFORMING_MAINTENANCE Instance_State = 5
)

func (Instance_State) Descriptor

func (Instance_State) Enum

func (x Instance_State) Enum() *Instance_State

func (Instance_State) Number

func (Instance_State) String

func (x Instance_State) String() string

func (Instance_State) Type

type Instance_builder

type Instance_builder struct {

	// Required. Unique name of the resource in this scope including project and
	// location using the form:
	//
	//	`projects/{project_id}/locations/{location_id}/instances/{instance_id}`
	//
	// Note: Memcached instances are managed and addressed at the regional level
	// so `location_id` here refers to a Google Cloud region; however, users may
	// choose which zones Memcached nodes should be provisioned in within an
	// instance. Refer to [zones][google.cloud.memcache.v1.Instance.zones] field
	// for more details.
	Name string
	// User provided name for the instance, which is only used for display
	// purposes. Cannot be more than 80 characters.
	DisplayName string
	// Resource labels to represent user-provided metadata.
	// Refer to cloud documentation on labels for more details.
	// https://cloud.google.com/compute/docs/labeling-resources
	Labels map[string]string
	// The full name of the Google Compute Engine
	// [network](/compute/docs/networks-and-firewalls#networks) to which the
	// instance is connected. If left unspecified, the `default` network
	// will be used.
	AuthorizedNetwork string
	// Zones in which Memcached nodes should be provisioned.
	// Memcached nodes will be equally distributed across these zones. If not
	// provided, the service will by default create nodes in all zones in the
	// region for the instance.
	Zones []string
	// Required. Number of nodes in the Memcached instance.
	NodeCount int32
	// Required. Configuration for Memcached nodes.
	NodeConfig *Instance_NodeConfig
	// The major version of Memcached software.
	// If not provided, latest supported version will be used. Currently the
	// latest supported major version is `MEMCACHE_1_5`.
	// The minor version will be automatically determined by our system based on
	// the latest supported minor version.
	MemcacheVersion MemcacheVersion
	// User defined parameters to apply to the memcached process
	// on each node.
	Parameters *MemcacheParameters
	// Output only. List of Memcached nodes.
	// Refer to [Node][google.cloud.memcache.v1.Instance.Node] message for more
	// details.
	MemcacheNodes []*Instance_Node
	// Output only. The time the instance was created.
	CreateTime *timestamppb.Timestamp
	// Output only. The time the instance was updated.
	UpdateTime *timestamppb.Timestamp
	// Output only. The state of this Memcached instance.
	State Instance_State
	// Output only. The full version of memcached server running on this instance.
	// System automatically determines the full memcached version for an instance
	// based on the input MemcacheVersion.
	// The full version format will be "memcached-1.5.16".
	MemcacheFullVersion string
	// List of messages that describe the current state of the Memcached instance.
	InstanceMessages []*Instance_InstanceMessage
	// Output only. Endpoint for the Discovery API.
	DiscoveryEndpoint string
	// The maintenance policy for the instance. If not provided,
	// the maintenance event will be performed based on Memorystore
	// internal rollout schedule.
	MaintenancePolicy *MaintenancePolicy
	// Output only. Published maintenance schedule.
	MaintenanceSchedule *MaintenanceSchedule
	// contains filtered or unexported fields
}

func (Instance_builder) Build

func (b0 Instance_builder) Build() *Instance

type MaintenancePolicy

type MaintenancePolicy struct {

	// Output only. The time when the policy was created.
	CreateTime *timestamppb.Timestamp `protobuf:"bytes,1,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
	// Output only. The time when the policy was updated.
	UpdateTime *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=update_time,json=updateTime,proto3" json:"update_time,omitempty"`
	// Description of what this policy is for. Create/Update methods
	// return INVALID_ARGUMENT if the length is greater than 512.
	Description string `protobuf:"bytes,3,opt,name=description,proto3" json:"description,omitempty"`
	// Required. Maintenance window that is applied to resources covered by this
	// policy. Minimum 1. For the current version, the maximum number of
	// weekly_maintenance_windows is expected to be one.
	WeeklyMaintenanceWindow []*WeeklyMaintenanceWindow `` /* 132-byte string literal not displayed */
	// contains filtered or unexported fields
}

Maintenance policy per instance.

func (*MaintenancePolicy) ClearCreateTime

func (x *MaintenancePolicy) ClearCreateTime()

func (*MaintenancePolicy) ClearUpdateTime

func (x *MaintenancePolicy) ClearUpdateTime()

func (*MaintenancePolicy) GetCreateTime

func (x *MaintenancePolicy) GetCreateTime() *timestamppb.Timestamp

func (*MaintenancePolicy) GetDescription

func (x *MaintenancePolicy) GetDescription() string

func (*MaintenancePolicy) GetUpdateTime

func (x *MaintenancePolicy) GetUpdateTime() *timestamppb.Timestamp

func (*MaintenancePolicy) GetWeeklyMaintenanceWindow

func (x *MaintenancePolicy) GetWeeklyMaintenanceWindow() []*WeeklyMaintenanceWindow

func (*MaintenancePolicy) HasCreateTime

func (x *MaintenancePolicy) HasCreateTime() bool

func (*MaintenancePolicy) HasUpdateTime

func (x *MaintenancePolicy) HasUpdateTime() bool

func (*MaintenancePolicy) ProtoMessage

func (*MaintenancePolicy) ProtoMessage()

func (*MaintenancePolicy) ProtoReflect

func (x *MaintenancePolicy) ProtoReflect() protoreflect.Message

func (*MaintenancePolicy) Reset

func (x *MaintenancePolicy) Reset()

func (*MaintenancePolicy) SetCreateTime

func (x *MaintenancePolicy) SetCreateTime(v *timestamppb.Timestamp)

func (*MaintenancePolicy) SetDescription

func (x *MaintenancePolicy) SetDescription(v string)

func (*MaintenancePolicy) SetUpdateTime

func (x *MaintenancePolicy) SetUpdateTime(v *timestamppb.Timestamp)

func (*MaintenancePolicy) SetWeeklyMaintenanceWindow

func (x *MaintenancePolicy) SetWeeklyMaintenanceWindow(v []*WeeklyMaintenanceWindow)

func (*MaintenancePolicy) String

func (x *MaintenancePolicy) String() string

type MaintenancePolicy_builder

type MaintenancePolicy_builder struct {

	// Output only. The time when the policy was created.
	CreateTime *timestamppb.Timestamp
	// Output only. The time when the policy was updated.
	UpdateTime *timestamppb.Timestamp
	// Description of what this policy is for. Create/Update methods
	// return INVALID_ARGUMENT if the length is greater than 512.
	Description string
	// Required. Maintenance window that is applied to resources covered by this
	// policy. Minimum 1. For the current version, the maximum number of
	// weekly_maintenance_windows is expected to be one.
	WeeklyMaintenanceWindow []*WeeklyMaintenanceWindow
	// contains filtered or unexported fields
}

func (MaintenancePolicy_builder) Build

type MaintenanceSchedule

type MaintenanceSchedule struct {

	// Output only. The start time of any upcoming scheduled maintenance for this
	// instance.
	StartTime *timestamppb.Timestamp `protobuf:"bytes,1,opt,name=start_time,json=startTime,proto3" json:"start_time,omitempty"`
	// Output only. The end time of any upcoming scheduled maintenance for this
	// instance.
	EndTime *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=end_time,json=endTime,proto3" json:"end_time,omitempty"`
	// Output only. The deadline that the maintenance schedule start time can not
	// go beyond, including reschedule.
	ScheduleDeadlineTime *timestamppb.Timestamp `protobuf:"bytes,4,opt,name=schedule_deadline_time,json=scheduleDeadlineTime,proto3" json:"schedule_deadline_time,omitempty"`
	// contains filtered or unexported fields
}

Upcoming maintenance schedule.

func (*MaintenanceSchedule) ClearEndTime

func (x *MaintenanceSchedule) ClearEndTime()

func (*MaintenanceSchedule) ClearScheduleDeadlineTime

func (x *MaintenanceSchedule) ClearScheduleDeadlineTime()

func (*MaintenanceSchedule) ClearStartTime

func (x *MaintenanceSchedule) ClearStartTime()

func (*MaintenanceSchedule) GetEndTime

func (x *MaintenanceSchedule) GetEndTime() *timestamppb.Timestamp

func (*MaintenanceSchedule) GetScheduleDeadlineTime

func (x *MaintenanceSchedule) GetScheduleDeadlineTime() *timestamppb.Timestamp

func (*MaintenanceSchedule) GetStartTime

func (x *MaintenanceSchedule) GetStartTime() *timestamppb.Timestamp

func (*MaintenanceSchedule) HasEndTime

func (x *MaintenanceSchedule) HasEndTime() bool

func (*MaintenanceSchedule) HasScheduleDeadlineTime

func (x *MaintenanceSchedule) HasScheduleDeadlineTime() bool

func (*MaintenanceSchedule) HasStartTime

func (x *MaintenanceSchedule) HasStartTime() bool

func (*MaintenanceSchedule) ProtoMessage

func (*MaintenanceSchedule) ProtoMessage()

func (*MaintenanceSchedule) ProtoReflect

func (x *MaintenanceSchedule) ProtoReflect() protoreflect.Message

func (*MaintenanceSchedule) Reset

func (x *MaintenanceSchedule) Reset()

func (*MaintenanceSchedule) SetEndTime

func (x *MaintenanceSchedule) SetEndTime(v *timestamppb.Timestamp)

func (*MaintenanceSchedule) SetScheduleDeadlineTime

func (x *MaintenanceSchedule) SetScheduleDeadlineTime(v *timestamppb.Timestamp)

func (*MaintenanceSchedule) SetStartTime

func (x *MaintenanceSchedule) SetStartTime(v *timestamppb.Timestamp)

func (*MaintenanceSchedule) String

func (x *MaintenanceSchedule) String() string

type MaintenanceSchedule_builder

type MaintenanceSchedule_builder struct {

	// Output only. The start time of any upcoming scheduled maintenance for this
	// instance.
	StartTime *timestamppb.Timestamp
	// Output only. The end time of any upcoming scheduled maintenance for this
	// instance.
	EndTime *timestamppb.Timestamp
	// Output only. The deadline that the maintenance schedule start time can not
	// go beyond, including reschedule.
	ScheduleDeadlineTime *timestamppb.Timestamp
	// contains filtered or unexported fields
}

func (MaintenanceSchedule_builder) Build

type MemcacheParameters

type MemcacheParameters struct {

	// Output only. The unique ID associated with this set of parameters. Users
	// can use this id to determine if the parameters associated with the instance
	// differ from the parameters associated with the nodes. A discrepancy between
	// parameter ids can inform users that they may need to take action to apply
	// parameters on nodes.
	Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	// User defined set of parameters to use in the memcached process.
	Params map[string]string `` /* 139-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*MemcacheParameters) GetId

func (x *MemcacheParameters) GetId() string

func (*MemcacheParameters) GetParams

func (x *MemcacheParameters) GetParams() map[string]string

func (*MemcacheParameters) ProtoMessage

func (*MemcacheParameters) ProtoMessage()

func (*MemcacheParameters) ProtoReflect

func (x *MemcacheParameters) ProtoReflect() protoreflect.Message

func (*MemcacheParameters) Reset

func (x *MemcacheParameters) Reset()

func (*MemcacheParameters) SetId

func (x *MemcacheParameters) SetId(v string)

func (*MemcacheParameters) SetParams

func (x *MemcacheParameters) SetParams(v map[string]string)

func (*MemcacheParameters) String

func (x *MemcacheParameters) String() string

type MemcacheParameters_builder

type MemcacheParameters_builder struct {

	// Output only. The unique ID associated with this set of parameters. Users
	// can use this id to determine if the parameters associated with the instance
	// differ from the parameters associated with the nodes. A discrepancy between
	// parameter ids can inform users that they may need to take action to apply
	// parameters on nodes.
	Id string
	// User defined set of parameters to use in the memcached process.
	Params map[string]string
	// contains filtered or unexported fields
}

func (MemcacheParameters_builder) Build

type MemcacheVersion

type MemcacheVersion int32

Memcached versions supported by our service.

const (
	MemcacheVersion_MEMCACHE_VERSION_UNSPECIFIED MemcacheVersion = 0
	// Memcached 1.5 version.
	MemcacheVersion_MEMCACHE_1_5 MemcacheVersion = 1
)

func (MemcacheVersion) Descriptor

func (MemcacheVersion) Enum

func (x MemcacheVersion) Enum() *MemcacheVersion

func (MemcacheVersion) Number

func (MemcacheVersion) String

func (x MemcacheVersion) String() string

func (MemcacheVersion) Type

type WeeklyMaintenanceWindow

type WeeklyMaintenanceWindow struct {

	// Required. Allows to define schedule that runs specified day of the week.
	Day dayofweek.DayOfWeek `protobuf:"varint,1,opt,name=day,proto3,enum=google.type.DayOfWeek" json:"day,omitempty"`
	// Required. Start time of the window in UTC.
	StartTime *timeofday.TimeOfDay `protobuf:"bytes,2,opt,name=start_time,json=startTime,proto3" json:"start_time,omitempty"`
	// Required. Duration of the time window.
	Duration *durationpb.Duration `protobuf:"bytes,3,opt,name=duration,proto3" json:"duration,omitempty"`
	// contains filtered or unexported fields
}

Time window specified for weekly operations.

func (*WeeklyMaintenanceWindow) ClearDuration

func (x *WeeklyMaintenanceWindow) ClearDuration()

func (*WeeklyMaintenanceWindow) ClearStartTime

func (x *WeeklyMaintenanceWindow) ClearStartTime()

func (*WeeklyMaintenanceWindow) GetDay

func (*WeeklyMaintenanceWindow) GetDuration

func (x *WeeklyMaintenanceWindow) GetDuration() *durationpb.Duration

func (*WeeklyMaintenanceWindow) GetStartTime

func (x *WeeklyMaintenanceWindow) GetStartTime() *timeofday.TimeOfDay

func (*WeeklyMaintenanceWindow) HasDuration

func (x *WeeklyMaintenanceWindow) HasDuration() bool

func (*WeeklyMaintenanceWindow) HasStartTime

func (x *WeeklyMaintenanceWindow) HasStartTime() bool

func (*WeeklyMaintenanceWindow) ProtoMessage

func (*WeeklyMaintenanceWindow) ProtoMessage()

func (*WeeklyMaintenanceWindow) ProtoReflect

func (x *WeeklyMaintenanceWindow) ProtoReflect() protoreflect.Message

func (*WeeklyMaintenanceWindow) Reset

func (x *WeeklyMaintenanceWindow) Reset()

func (*WeeklyMaintenanceWindow) SetDay

func (*WeeklyMaintenanceWindow) SetDuration

func (x *WeeklyMaintenanceWindow) SetDuration(v *durationpb.Duration)

func (*WeeklyMaintenanceWindow) SetStartTime

func (x *WeeklyMaintenanceWindow) SetStartTime(v *timeofday.TimeOfDay)

func (*WeeklyMaintenanceWindow) String

func (x *WeeklyMaintenanceWindow) String() string

type WeeklyMaintenanceWindow_builder

type WeeklyMaintenanceWindow_builder struct {

	// Required. Allows to define schedule that runs specified day of the week.
	Day dayofweek.DayOfWeek
	// Required. Start time of the window in UTC.
	StartTime *timeofday.TimeOfDay
	// Required. Duration of the time window.
	Duration *durationpb.Duration
	// contains filtered or unexported fields
}

func (WeeklyMaintenanceWindow_builder) Build

Source Files

  • data.pb.go
  • events.pb.go

Jump to