redisv1

package
v1.36.11-2024050211440... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	Instance_State_name = map[int32]string{
		0: "STATE_UNSPECIFIED",
		1: "CREATING",
		2: "READY",
		3: "UPDATING",
		4: "DELETING",
		5: "REPAIRING",
		6: "MAINTENANCE",
		8: "IMPORTING",
		9: "FAILING_OVER",
	}
	Instance_State_value = map[string]int32{
		"STATE_UNSPECIFIED": 0,
		"CREATING":          1,
		"READY":             2,
		"UPDATING":          3,
		"DELETING":          4,
		"REPAIRING":         5,
		"MAINTENANCE":       6,
		"IMPORTING":         8,
		"FAILING_OVER":      9,
	}
)

Enum value maps for Instance_State.

var (
	Instance_Tier_name = map[int32]string{
		0: "TIER_UNSPECIFIED",
		1: "BASIC",
		3: "STANDARD_HA",
	}
	Instance_Tier_value = map[string]int32{
		"TIER_UNSPECIFIED": 0,
		"BASIC":            1,
		"STANDARD_HA":      3,
	}
)

Enum value maps for Instance_Tier.

var (
	Instance_ConnectMode_name = map[int32]string{
		0: "CONNECT_MODE_UNSPECIFIED",
		1: "DIRECT_PEERING",
		2: "PRIVATE_SERVICE_ACCESS",
	}
	Instance_ConnectMode_value = map[string]int32{
		"CONNECT_MODE_UNSPECIFIED": 0,
		"DIRECT_PEERING":           1,
		"PRIVATE_SERVICE_ACCESS":   2,
	}
)

Enum value maps for Instance_ConnectMode.

var (
	Instance_TransitEncryptionMode_name = map[int32]string{
		0: "TRANSIT_ENCRYPTION_MODE_UNSPECIFIED",
		1: "SERVER_AUTHENTICATION",
		2: "DISABLED",
	}
	Instance_TransitEncryptionMode_value = map[string]int32{
		"TRANSIT_ENCRYPTION_MODE_UNSPECIFIED": 0,
		"SERVER_AUTHENTICATION":               1,
		"DISABLED":                            2,
	}
)

Enum value maps for Instance_TransitEncryptionMode.

var (
	Instance_ReadReplicasMode_name = map[int32]string{
		0: "READ_REPLICAS_MODE_UNSPECIFIED",
		1: "READ_REPLICAS_DISABLED",
		2: "READ_REPLICAS_ENABLED",
	}
	Instance_ReadReplicasMode_value = map[string]int32{
		"READ_REPLICAS_MODE_UNSPECIFIED": 0,
		"READ_REPLICAS_DISABLED":         1,
		"READ_REPLICAS_ENABLED":          2,
	}
)

Enum value maps for Instance_ReadReplicasMode.

var (
	Instance_SuspensionReason_name = map[int32]string{
		0: "SUSPENSION_REASON_UNSPECIFIED",
		1: "CUSTOMER_MANAGED_KEY_ISSUE",
	}
	Instance_SuspensionReason_value = map[string]int32{
		"SUSPENSION_REASON_UNSPECIFIED": 0,
		"CUSTOMER_MANAGED_KEY_ISSUE":    1,
	}
)

Enum value maps for Instance_SuspensionReason.

var (
	PersistenceConfig_PersistenceMode_name = map[int32]string{
		0: "PERSISTENCE_MODE_UNSPECIFIED",
		1: "DISABLED",
		2: "RDB",
	}
	PersistenceConfig_PersistenceMode_value = map[string]int32{
		"PERSISTENCE_MODE_UNSPECIFIED": 0,
		"DISABLED":                     1,
		"RDB":                          2,
	}
)

Enum value maps for PersistenceConfig_PersistenceMode.

var (
	PersistenceConfig_SnapshotPeriod_name = map[int32]string{
		0: "SNAPSHOT_PERIOD_UNSPECIFIED",
		3: "ONE_HOUR",
		4: "SIX_HOURS",
		5: "TWELVE_HOURS",
		6: "TWENTY_FOUR_HOURS",
	}
	PersistenceConfig_SnapshotPeriod_value = map[string]int32{
		"SNAPSHOT_PERIOD_UNSPECIFIED": 0,
		"ONE_HOUR":                    3,
		"SIX_HOURS":                   4,
		"TWELVE_HOURS":                5,
		"TWENTY_FOUR_HOURS":           6,
	}
)

Enum value maps for PersistenceConfig_SnapshotPeriod.

var File_google_events_cloud_redis_v1_data_proto protoreflect.FileDescriptor
var File_google_events_cloud_redis_v1_events_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type Instance

type Instance struct {

	// Required. Unique name of the resource in this scope including project and
	// location using the form:
	//
	//	`projects/{project_id}/locations/{location_id}/instances/{instance_id}`
	//
	// Note: Redis instances are managed and addressed at regional level so
	// location_id here refers to a GCP region; however, users may choose which
	// specific zone (or collection of zones for cross-zone instances) an instance
	// should be provisioned in. Refer to
	// [location_id][google.cloud.redis.v1.Instance.location_id] and
	// [alternative_location_id][google.cloud.redis.v1.Instance.alternative_location_id]
	// fields for more details.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// An arbitrary and optional user-provided name for the instance.
	DisplayName string `protobuf:"bytes,2,opt,name=display_name,json=displayName,proto3" json:"display_name,omitempty"`
	// Resource labels to represent user provided metadata
	Labels map[string]string `` /* 139-byte string literal not displayed */
	// Optional. The zone where the instance will be provisioned. If not provided,
	// the service will choose a zone from the specified region for the instance.
	// For standard tier, additional nodes will be added across multiple zones for
	// protection against zonal failures. If specified, at least one node will be
	// provisioned in this zone.
	LocationId string `protobuf:"bytes,4,opt,name=location_id,json=locationId,proto3" json:"location_id,omitempty"`
	// Optional. If specified, at least one node will be provisioned in this zone
	// in addition to the zone specified in location_id. Only applicable to
	// standard tier. If provided, it must be a different zone from the one
	// provided in [location_id]. Additional nodes beyond the first 2 will be
	// placed in zones selected by the service.
	AlternativeLocationId string `` /* 126-byte string literal not displayed */
	// Optional. The version of Redis software.
	// If not provided, latest supported version will be used. Currently, the
	// supported values are:
	//
	//   - `REDIS_3_2` for Redis 3.2 compatibility
	//   - `REDIS_4_0` for Redis 4.0 compatibility (default)
	//   - `REDIS_5_0` for Redis 5.0 compatibility
	//   - `REDIS_6_X` for Redis 6.x compatibility
	RedisVersion string `protobuf:"bytes,7,opt,name=redis_version,json=redisVersion,proto3" json:"redis_version,omitempty"`
	// Optional. For DIRECT_PEERING mode, the CIDR range of internal addresses
	// that are reserved for this instance. Range must
	// be unique and non-overlapping with existing subnets in an authorized
	// network. For PRIVATE_SERVICE_ACCESS mode, the name of one allocated IP
	// address ranges associated with this private service access connection.
	// If not provided, the service will choose an unused /29 block, for
	// example, 10.0.0.0/29 or 192.168.0.0/29.  For READ_REPLICAS_ENABLED
	// the default block size is /28.
	ReservedIpRange string `protobuf:"bytes,9,opt,name=reserved_ip_range,json=reservedIpRange,proto3" json:"reserved_ip_range,omitempty"`
	// Optional. Additional IP range for node placement. Required when enabling
	// read replicas on an existing instance. For DIRECT_PEERING mode value must
	// be a CIDR range of size /28, or "auto". For PRIVATE_SERVICE_ACCESS mode
	// value must be the name of an allocated address range associated with the
	// private service access connection, or "auto".
	SecondaryIpRange string `protobuf:"bytes,30,opt,name=secondary_ip_range,json=secondaryIpRange,proto3" json:"secondary_ip_range,omitempty"`
	// Output only. Hostname or IP address of the exposed Redis endpoint used by
	// clients to connect to the service.
	Host string `protobuf:"bytes,10,opt,name=host,proto3" json:"host,omitempty"`
	// Output only. The port number of the exposed Redis endpoint.
	Port int32 `protobuf:"varint,11,opt,name=port,proto3" json:"port,omitempty"`
	// Output only. The current zone where the Redis primary node is located. In
	// basic tier, this will always be the same as [location_id]. In
	// standard tier, this can be the zone of any node in the instance.
	CurrentLocationId string `protobuf:"bytes,12,opt,name=current_location_id,json=currentLocationId,proto3" json:"current_location_id,omitempty"`
	// Output only. The time the instance was created.
	CreateTime *timestamppb.Timestamp `protobuf:"bytes,13,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
	// Output only. The current state of this instance.
	State Instance_State `protobuf:"varint,14,opt,name=state,proto3,enum=google.events.cloud.redis.v1.Instance_State" json:"state,omitempty"`
	// Output only. Additional information about the current status of this
	// instance, if available.
	StatusMessage string `protobuf:"bytes,15,opt,name=status_message,json=statusMessage,proto3" json:"status_message,omitempty"`
	// Optional. Redis configuration parameters, according to
	// http://redis.io/topics/config. Currently, the only supported parameters
	// are:
	//
	//	Redis version 3.2 and newer:
	//
	//	*   maxmemory-policy
	//	*   notify-keyspace-events
	//
	//	Redis version 4.0 and newer:
	//
	//	*   activedefrag
	//	*   lfu-decay-time
	//	*   lfu-log-factor
	//	*   maxmemory-gb
	//
	//	Redis version 5.0 and newer:
	//
	//	*   stream-node-max-bytes
	//	*   stream-node-max-entries
	RedisConfigs map[string]string `` /* 172-byte string literal not displayed */
	// Required. The service tier of the instance.
	Tier Instance_Tier `protobuf:"varint,17,opt,name=tier,proto3,enum=google.events.cloud.redis.v1.Instance_Tier" json:"tier,omitempty"`
	// Required. Redis memory size in GiB.
	MemorySizeGb int32 `protobuf:"varint,18,opt,name=memory_size_gb,json=memorySizeGb,proto3" json:"memory_size_gb,omitempty"`
	// Optional. The full name of the Google Compute Engine
	// [network](https://cloud.google.com/vpc/docs/vpc) to which the
	// instance is connected. If left unspecified, the `default` network
	// will be used.
	AuthorizedNetwork string `protobuf:"bytes,20,opt,name=authorized_network,json=authorizedNetwork,proto3" json:"authorized_network,omitempty"`
	// Output only. Cloud IAM identity used by import / export operations to
	// transfer data to/from Cloud Storage. Format is
	// "serviceAccount:<service_account_email>". The value may change over time
	// for a given instance so should be checked before each import/export
	// operation.
	PersistenceIamIdentity string `` /* 130-byte string literal not displayed */
	// Optional. The network connect mode of the Redis instance.
	// If not provided, the connect mode defaults to DIRECT_PEERING.
	ConnectMode Instance_ConnectMode `` /* 151-byte string literal not displayed */
	// Optional. Indicates whether OSS Redis AUTH is enabled for the instance. If
	// set to "true" AUTH is enabled on the instance. Default value is "false"
	// meaning AUTH is disabled.
	AuthEnabled bool `protobuf:"varint,23,opt,name=auth_enabled,json=authEnabled,proto3" json:"auth_enabled,omitempty"`
	// Output only. List of server CA certificates for the instance.
	ServerCaCerts []*TlsCertificate `protobuf:"bytes,25,rep,name=server_ca_certs,json=serverCaCerts,proto3" json:"server_ca_certs,omitempty"`
	// Optional. The TLS mode of the Redis instance.
	// If not provided, TLS is disabled for the instance.
	TransitEncryptionMode Instance_TransitEncryptionMode `` /* 193-byte string literal not displayed */
	// Optional. The maintenance policy for the instance. If not provided,
	// maintenance events can be performed at any time.
	MaintenancePolicy *MaintenancePolicy `protobuf:"bytes,27,opt,name=maintenance_policy,json=maintenancePolicy,proto3" json:"maintenance_policy,omitempty"`
	// Output only. Date and time of upcoming maintenance events which have been
	// scheduled.
	MaintenanceSchedule *MaintenanceSchedule `protobuf:"bytes,28,opt,name=maintenance_schedule,json=maintenanceSchedule,proto3" json:"maintenance_schedule,omitempty"`
	// Optional. The number of replica nodes. The valid range for the Standard
	// Tier with read replicas enabled is [1-5] and defaults to 2. If read
	// replicas are not enabled for a Standard Tier instance, the only valid value
	// is 1 and the default is 1. The valid value for basic tier is 0 and the
	// default is also 0.
	ReplicaCount int32 `protobuf:"varint,31,opt,name=replica_count,json=replicaCount,proto3" json:"replica_count,omitempty"`
	// Output only. Info per node.
	Nodes []*NodeInfo `protobuf:"bytes,32,rep,name=nodes,proto3" json:"nodes,omitempty"`
	// Output only. Hostname or IP address of the exposed readonly Redis
	// endpoint. Standard tier only. Targets all healthy replica nodes in
	// instance. Replication is asynchronous and replica nodes will exhibit some
	// lag behind the primary. Write requests must target 'host'.
	ReadEndpoint string `protobuf:"bytes,33,opt,name=read_endpoint,json=readEndpoint,proto3" json:"read_endpoint,omitempty"`
	// Output only. The port number of the exposed readonly redis
	// endpoint. Standard tier only. Write requests should target 'port'.
	ReadEndpointPort int32 `protobuf:"varint,34,opt,name=read_endpoint_port,json=readEndpointPort,proto3" json:"read_endpoint_port,omitempty"`
	// Optional. Read replicas mode for the instance. Defaults to
	// READ_REPLICAS_DISABLED.
	ReadReplicasMode Instance_ReadReplicasMode `` /* 173-byte string literal not displayed */
	// Optional. The KMS key reference that the customer provides when trying to
	// create the instance.
	CustomerManagedKey string `protobuf:"bytes,36,opt,name=customer_managed_key,json=customerManagedKey,proto3" json:"customer_managed_key,omitempty"`
	// Optional. Persistence configuration parameters
	PersistenceConfig *PersistenceConfig `protobuf:"bytes,37,opt,name=persistence_config,json=persistenceConfig,proto3" json:"persistence_config,omitempty"`
	// Optional. reasons that causes instance in "SUSPENDED" state.
	SuspensionReasons []Instance_SuspensionReason `` /* 181-byte string literal not displayed */
	// Optional. The self service update maintenance version.
	// The version is date based such as "20210712_00_00".
	MaintenanceVersion string `protobuf:"bytes,39,opt,name=maintenance_version,json=maintenanceVersion,proto3" json:"maintenance_version,omitempty"`
	// Optional. The available maintenance versions that an instance could update
	// to.
	AvailableMaintenanceVersions []string `` /* 148-byte string literal not displayed */
	// contains filtered or unexported fields
}

A Memorystore for Redis instance.

func (*Instance) ClearCreateTime

func (x *Instance) ClearCreateTime()

func (*Instance) ClearMaintenancePolicy

func (x *Instance) ClearMaintenancePolicy()

func (*Instance) ClearMaintenanceSchedule

func (x *Instance) ClearMaintenanceSchedule()

func (*Instance) ClearPersistenceConfig

func (x *Instance) ClearPersistenceConfig()

func (*Instance) GetAlternativeLocationId

func (x *Instance) GetAlternativeLocationId() string

func (*Instance) GetAuthEnabled

func (x *Instance) GetAuthEnabled() bool

func (*Instance) GetAuthorizedNetwork

func (x *Instance) GetAuthorizedNetwork() string

func (*Instance) GetAvailableMaintenanceVersions

func (x *Instance) GetAvailableMaintenanceVersions() []string

func (*Instance) GetConnectMode

func (x *Instance) GetConnectMode() Instance_ConnectMode

func (*Instance) GetCreateTime

func (x *Instance) GetCreateTime() *timestamppb.Timestamp

func (*Instance) GetCurrentLocationId

func (x *Instance) GetCurrentLocationId() string

func (*Instance) GetCustomerManagedKey

func (x *Instance) GetCustomerManagedKey() string

func (*Instance) GetDisplayName

func (x *Instance) GetDisplayName() string

func (*Instance) GetHost

func (x *Instance) GetHost() string

func (*Instance) GetLabels

func (x *Instance) GetLabels() map[string]string

func (*Instance) GetLocationId

func (x *Instance) GetLocationId() string

func (*Instance) GetMaintenancePolicy

func (x *Instance) GetMaintenancePolicy() *MaintenancePolicy

func (*Instance) GetMaintenanceSchedule

func (x *Instance) GetMaintenanceSchedule() *MaintenanceSchedule

func (*Instance) GetMaintenanceVersion

func (x *Instance) GetMaintenanceVersion() string

func (*Instance) GetMemorySizeGb

func (x *Instance) GetMemorySizeGb() int32

func (*Instance) GetName

func (x *Instance) GetName() string

func (*Instance) GetNodes

func (x *Instance) GetNodes() []*NodeInfo

func (*Instance) GetPersistenceConfig

func (x *Instance) GetPersistenceConfig() *PersistenceConfig

func (*Instance) GetPersistenceIamIdentity

func (x *Instance) GetPersistenceIamIdentity() string

func (*Instance) GetPort

func (x *Instance) GetPort() int32

func (*Instance) GetReadEndpoint

func (x *Instance) GetReadEndpoint() string

func (*Instance) GetReadEndpointPort

func (x *Instance) GetReadEndpointPort() int32

func (*Instance) GetReadReplicasMode

func (x *Instance) GetReadReplicasMode() Instance_ReadReplicasMode

func (*Instance) GetRedisConfigs

func (x *Instance) GetRedisConfigs() map[string]string

func (*Instance) GetRedisVersion

func (x *Instance) GetRedisVersion() string

func (*Instance) GetReplicaCount

func (x *Instance) GetReplicaCount() int32

func (*Instance) GetReservedIpRange

func (x *Instance) GetReservedIpRange() string

func (*Instance) GetSecondaryIpRange

func (x *Instance) GetSecondaryIpRange() string

func (*Instance) GetServerCaCerts

func (x *Instance) GetServerCaCerts() []*TlsCertificate

func (*Instance) GetState

func (x *Instance) GetState() Instance_State

func (*Instance) GetStatusMessage

func (x *Instance) GetStatusMessage() string

func (*Instance) GetSuspensionReasons

func (x *Instance) GetSuspensionReasons() []Instance_SuspensionReason

func (*Instance) GetTier

func (x *Instance) GetTier() Instance_Tier

func (*Instance) GetTransitEncryptionMode

func (x *Instance) GetTransitEncryptionMode() Instance_TransitEncryptionMode

func (*Instance) HasCreateTime

func (x *Instance) HasCreateTime() bool

func (*Instance) HasMaintenancePolicy

func (x *Instance) HasMaintenancePolicy() bool

func (*Instance) HasMaintenanceSchedule

func (x *Instance) HasMaintenanceSchedule() bool

func (*Instance) HasPersistenceConfig

func (x *Instance) HasPersistenceConfig() bool

func (*Instance) ProtoMessage

func (*Instance) ProtoMessage()

func (*Instance) ProtoReflect

func (x *Instance) ProtoReflect() protoreflect.Message

func (*Instance) Reset

func (x *Instance) Reset()

func (*Instance) SetAlternativeLocationId

func (x *Instance) SetAlternativeLocationId(v string)

func (*Instance) SetAuthEnabled

func (x *Instance) SetAuthEnabled(v bool)

func (*Instance) SetAuthorizedNetwork

func (x *Instance) SetAuthorizedNetwork(v string)

func (*Instance) SetAvailableMaintenanceVersions

func (x *Instance) SetAvailableMaintenanceVersions(v []string)

func (*Instance) SetConnectMode

func (x *Instance) SetConnectMode(v Instance_ConnectMode)

func (*Instance) SetCreateTime

func (x *Instance) SetCreateTime(v *timestamppb.Timestamp)

func (*Instance) SetCurrentLocationId

func (x *Instance) SetCurrentLocationId(v string)

func (*Instance) SetCustomerManagedKey

func (x *Instance) SetCustomerManagedKey(v string)

func (*Instance) SetDisplayName

func (x *Instance) SetDisplayName(v string)

func (*Instance) SetHost

func (x *Instance) SetHost(v string)

func (*Instance) SetLabels

func (x *Instance) SetLabels(v map[string]string)

func (*Instance) SetLocationId

func (x *Instance) SetLocationId(v string)

func (*Instance) SetMaintenancePolicy

func (x *Instance) SetMaintenancePolicy(v *MaintenancePolicy)

func (*Instance) SetMaintenanceSchedule

func (x *Instance) SetMaintenanceSchedule(v *MaintenanceSchedule)

func (*Instance) SetMaintenanceVersion

func (x *Instance) SetMaintenanceVersion(v string)

func (*Instance) SetMemorySizeGb

func (x *Instance) SetMemorySizeGb(v int32)

func (*Instance) SetName

func (x *Instance) SetName(v string)

func (*Instance) SetNodes

func (x *Instance) SetNodes(v []*NodeInfo)

func (*Instance) SetPersistenceConfig

func (x *Instance) SetPersistenceConfig(v *PersistenceConfig)

func (*Instance) SetPersistenceIamIdentity

func (x *Instance) SetPersistenceIamIdentity(v string)

func (*Instance) SetPort

func (x *Instance) SetPort(v int32)

func (*Instance) SetReadEndpoint

func (x *Instance) SetReadEndpoint(v string)

func (*Instance) SetReadEndpointPort

func (x *Instance) SetReadEndpointPort(v int32)

func (*Instance) SetReadReplicasMode

func (x *Instance) SetReadReplicasMode(v Instance_ReadReplicasMode)

func (*Instance) SetRedisConfigs

func (x *Instance) SetRedisConfigs(v map[string]string)

func (*Instance) SetRedisVersion

func (x *Instance) SetRedisVersion(v string)

func (*Instance) SetReplicaCount

func (x *Instance) SetReplicaCount(v int32)

func (*Instance) SetReservedIpRange

func (x *Instance) SetReservedIpRange(v string)

func (*Instance) SetSecondaryIpRange

func (x *Instance) SetSecondaryIpRange(v string)

func (*Instance) SetServerCaCerts

func (x *Instance) SetServerCaCerts(v []*TlsCertificate)

func (*Instance) SetState

func (x *Instance) SetState(v Instance_State)

func (*Instance) SetStatusMessage

func (x *Instance) SetStatusMessage(v string)

func (*Instance) SetSuspensionReasons

func (x *Instance) SetSuspensionReasons(v []Instance_SuspensionReason)

func (*Instance) SetTier

func (x *Instance) SetTier(v Instance_Tier)

func (*Instance) SetTransitEncryptionMode

func (x *Instance) SetTransitEncryptionMode(v Instance_TransitEncryptionMode)

func (*Instance) String

func (x *Instance) String() string

type InstanceCreatedEvent

type InstanceCreatedEvent struct {

	// The data associated with the event.
	Data *InstanceEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

The CloudEvent raised when an Instance is created.

func (*InstanceCreatedEvent) ClearData

func (x *InstanceCreatedEvent) ClearData()

func (*InstanceCreatedEvent) GetData

func (*InstanceCreatedEvent) HasData

func (x *InstanceCreatedEvent) HasData() bool

func (*InstanceCreatedEvent) ProtoMessage

func (*InstanceCreatedEvent) ProtoMessage()

func (*InstanceCreatedEvent) ProtoReflect

func (x *InstanceCreatedEvent) ProtoReflect() protoreflect.Message

func (*InstanceCreatedEvent) Reset

func (x *InstanceCreatedEvent) Reset()

func (*InstanceCreatedEvent) SetData

func (x *InstanceCreatedEvent) SetData(v *InstanceEventData)

func (*InstanceCreatedEvent) String

func (x *InstanceCreatedEvent) String() string

type InstanceCreatedEvent_builder

type InstanceCreatedEvent_builder struct {

	// The data associated with the event.
	Data *InstanceEventData
	// contains filtered or unexported fields
}

func (InstanceCreatedEvent_builder) Build

type InstanceDeletedEvent

type InstanceDeletedEvent struct {

	// The data associated with the event.
	Data *InstanceEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

The CloudEvent raised when an Instance is deleted.

func (*InstanceDeletedEvent) ClearData

func (x *InstanceDeletedEvent) ClearData()

func (*InstanceDeletedEvent) GetData

func (*InstanceDeletedEvent) HasData

func (x *InstanceDeletedEvent) HasData() bool

func (*InstanceDeletedEvent) ProtoMessage

func (*InstanceDeletedEvent) ProtoMessage()

func (*InstanceDeletedEvent) ProtoReflect

func (x *InstanceDeletedEvent) ProtoReflect() protoreflect.Message

func (*InstanceDeletedEvent) Reset

func (x *InstanceDeletedEvent) Reset()

func (*InstanceDeletedEvent) SetData

func (x *InstanceDeletedEvent) SetData(v *InstanceEventData)

func (*InstanceDeletedEvent) String

func (x *InstanceDeletedEvent) String() string

type InstanceDeletedEvent_builder

type InstanceDeletedEvent_builder struct {

	// The data associated with the event.
	Data *InstanceEventData
	// contains filtered or unexported fields
}

func (InstanceDeletedEvent_builder) Build

type InstanceEventData

type InstanceEventData struct {

	// Optional. The Instance event payload. Unset for deletion events.
	Payload *Instance `protobuf:"bytes,1,opt,name=payload,proto3,oneof" json:"payload,omitempty"`
	// contains filtered or unexported fields
}

The data within all Instance events.

func (*InstanceEventData) ClearPayload

func (x *InstanceEventData) ClearPayload()

func (*InstanceEventData) GetPayload

func (x *InstanceEventData) GetPayload() *Instance

func (*InstanceEventData) HasPayload

func (x *InstanceEventData) HasPayload() bool

func (*InstanceEventData) ProtoMessage

func (*InstanceEventData) ProtoMessage()

func (*InstanceEventData) ProtoReflect

func (x *InstanceEventData) ProtoReflect() protoreflect.Message

func (*InstanceEventData) Reset

func (x *InstanceEventData) Reset()

func (*InstanceEventData) SetPayload

func (x *InstanceEventData) SetPayload(v *Instance)

func (*InstanceEventData) String

func (x *InstanceEventData) String() string

type InstanceEventData_builder

type InstanceEventData_builder struct {

	// Optional. The Instance event payload. Unset for deletion events.
	Payload *Instance
	// contains filtered or unexported fields
}

func (InstanceEventData_builder) Build

type InstanceUpdatedEvent

type InstanceUpdatedEvent struct {

	// The data associated with the event.
	Data *InstanceEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

The CloudEvent raised when an Instance is updated.

func (*InstanceUpdatedEvent) ClearData

func (x *InstanceUpdatedEvent) ClearData()

func (*InstanceUpdatedEvent) GetData

func (*InstanceUpdatedEvent) HasData

func (x *InstanceUpdatedEvent) HasData() bool

func (*InstanceUpdatedEvent) ProtoMessage

func (*InstanceUpdatedEvent) ProtoMessage()

func (*InstanceUpdatedEvent) ProtoReflect

func (x *InstanceUpdatedEvent) ProtoReflect() protoreflect.Message

func (*InstanceUpdatedEvent) Reset

func (x *InstanceUpdatedEvent) Reset()

func (*InstanceUpdatedEvent) SetData

func (x *InstanceUpdatedEvent) SetData(v *InstanceEventData)

func (*InstanceUpdatedEvent) String

func (x *InstanceUpdatedEvent) String() string

type InstanceUpdatedEvent_builder

type InstanceUpdatedEvent_builder struct {

	// The data associated with the event.
	Data *InstanceEventData
	// contains filtered or unexported fields
}

func (InstanceUpdatedEvent_builder) Build

type Instance_ConnectMode

type Instance_ConnectMode int32

Available connection modes.

const (
	// Not set.
	Instance_CONNECT_MODE_UNSPECIFIED Instance_ConnectMode = 0
	// Connect via direct peering to the Memorystore for Redis hosted service.
	Instance_DIRECT_PEERING Instance_ConnectMode = 1
	// Connect your Memorystore for Redis instance using Private Service
	// Access. Private services access provides an IP address range for multiple
	// Google Cloud services, including Memorystore.
	Instance_PRIVATE_SERVICE_ACCESS Instance_ConnectMode = 2
)

func (Instance_ConnectMode) Descriptor

func (Instance_ConnectMode) Enum

func (Instance_ConnectMode) Number

func (Instance_ConnectMode) String

func (x Instance_ConnectMode) String() string

func (Instance_ConnectMode) Type

type Instance_ReadReplicasMode

type Instance_ReadReplicasMode int32

Read replicas mode.

const (
	// If not set, Memorystore Redis backend will default to
	// READ_REPLICAS_DISABLED.
	Instance_READ_REPLICAS_MODE_UNSPECIFIED Instance_ReadReplicasMode = 0
	// If disabled, read endpoint will not be provided and the instance cannot
	// scale up or down the number of replicas.
	Instance_READ_REPLICAS_DISABLED Instance_ReadReplicasMode = 1
	// If enabled, read endpoint will be provided and the instance can scale
	// up and down the number of replicas. Not valid for basic tier.
	Instance_READ_REPLICAS_ENABLED Instance_ReadReplicasMode = 2
)

func (Instance_ReadReplicasMode) Descriptor

func (Instance_ReadReplicasMode) Enum

func (Instance_ReadReplicasMode) Number

func (Instance_ReadReplicasMode) String

func (x Instance_ReadReplicasMode) String() string

func (Instance_ReadReplicasMode) Type

type Instance_State

type Instance_State int32

Represents the different states of a Redis instance.

const (
	// Not set.
	Instance_STATE_UNSPECIFIED Instance_State = 0
	// Redis instance is being created.
	Instance_CREATING Instance_State = 1
	// Redis instance has been created and is fully usable.
	Instance_READY Instance_State = 2
	// Redis instance configuration is being updated. Certain kinds of updates
	// may cause the instance to become unusable while the update is in
	// progress.
	Instance_UPDATING Instance_State = 3
	// Redis instance is being deleted.
	Instance_DELETING Instance_State = 4
	// Redis instance is being repaired and may be unusable.
	Instance_REPAIRING Instance_State = 5
	// Maintenance is being performed on this Redis instance.
	Instance_MAINTENANCE Instance_State = 6
	// Redis instance is importing data (availability may be affected).
	Instance_IMPORTING Instance_State = 8
	// Redis instance is failing over (availability may be affected).
	Instance_FAILING_OVER Instance_State = 9
)

func (Instance_State) Descriptor

func (Instance_State) Enum

func (x Instance_State) Enum() *Instance_State

func (Instance_State) Number

func (Instance_State) String

func (x Instance_State) String() string

func (Instance_State) Type

type Instance_SuspensionReason

type Instance_SuspensionReason int32

Possible reasons for the instance to be in a "SUSPENDED" state.

const (
	// Not set.
	Instance_SUSPENSION_REASON_UNSPECIFIED Instance_SuspensionReason = 0
	// Something wrong with the CMEK key provided by customer.
	Instance_CUSTOMER_MANAGED_KEY_ISSUE Instance_SuspensionReason = 1
)

func (Instance_SuspensionReason) Descriptor

func (Instance_SuspensionReason) Enum

func (Instance_SuspensionReason) Number

func (Instance_SuspensionReason) String

func (x Instance_SuspensionReason) String() string

func (Instance_SuspensionReason) Type

type Instance_Tier

type Instance_Tier int32

Available service tiers to choose from

const (
	// Not set.
	Instance_TIER_UNSPECIFIED Instance_Tier = 0
	// BASIC tier: standalone instance
	Instance_BASIC Instance_Tier = 1
	// STANDARD_HA tier: highly available primary/replica instances
	Instance_STANDARD_HA Instance_Tier = 3
)

func (Instance_Tier) Descriptor

func (Instance_Tier) Enum

func (x Instance_Tier) Enum() *Instance_Tier

func (Instance_Tier) Number

func (Instance_Tier) String

func (x Instance_Tier) String() string

func (Instance_Tier) Type

type Instance_TransitEncryptionMode

type Instance_TransitEncryptionMode int32

Available TLS modes.

const (
	// Not set.
	Instance_TRANSIT_ENCRYPTION_MODE_UNSPECIFIED Instance_TransitEncryptionMode = 0
	// Client to Server traffic encryption enabled with server authentication.
	Instance_SERVER_AUTHENTICATION Instance_TransitEncryptionMode = 1
	// TLS is disabled for the instance.
	Instance_DISABLED Instance_TransitEncryptionMode = 2
)

func (Instance_TransitEncryptionMode) Descriptor

func (Instance_TransitEncryptionMode) Enum

func (Instance_TransitEncryptionMode) Number

func (Instance_TransitEncryptionMode) String

func (Instance_TransitEncryptionMode) Type

type Instance_builder

type Instance_builder struct {

	// Required. Unique name of the resource in this scope including project and
	// location using the form:
	//
	//	`projects/{project_id}/locations/{location_id}/instances/{instance_id}`
	//
	// Note: Redis instances are managed and addressed at regional level so
	// location_id here refers to a GCP region; however, users may choose which
	// specific zone (or collection of zones for cross-zone instances) an instance
	// should be provisioned in. Refer to
	// [location_id][google.cloud.redis.v1.Instance.location_id] and
	// [alternative_location_id][google.cloud.redis.v1.Instance.alternative_location_id]
	// fields for more details.
	Name string
	// An arbitrary and optional user-provided name for the instance.
	DisplayName string
	// Resource labels to represent user provided metadata
	Labels map[string]string
	// Optional. The zone where the instance will be provisioned. If not provided,
	// the service will choose a zone from the specified region for the instance.
	// For standard tier, additional nodes will be added across multiple zones for
	// protection against zonal failures. If specified, at least one node will be
	// provisioned in this zone.
	LocationId string
	// Optional. If specified, at least one node will be provisioned in this zone
	// in addition to the zone specified in location_id. Only applicable to
	// standard tier. If provided, it must be a different zone from the one
	// provided in [location_id]. Additional nodes beyond the first 2 will be
	// placed in zones selected by the service.
	AlternativeLocationId string
	// Optional. The version of Redis software.
	// If not provided, latest supported version will be used. Currently, the
	// supported values are:
	//
	//   - `REDIS_3_2` for Redis 3.2 compatibility
	//   - `REDIS_4_0` for Redis 4.0 compatibility (default)
	//   - `REDIS_5_0` for Redis 5.0 compatibility
	//   - `REDIS_6_X` for Redis 6.x compatibility
	RedisVersion string
	// Optional. For DIRECT_PEERING mode, the CIDR range of internal addresses
	// that are reserved for this instance. Range must
	// be unique and non-overlapping with existing subnets in an authorized
	// network. For PRIVATE_SERVICE_ACCESS mode, the name of one allocated IP
	// address ranges associated with this private service access connection.
	// If not provided, the service will choose an unused /29 block, for
	// example, 10.0.0.0/29 or 192.168.0.0/29.  For READ_REPLICAS_ENABLED
	// the default block size is /28.
	ReservedIpRange string
	// Optional. Additional IP range for node placement. Required when enabling
	// read replicas on an existing instance. For DIRECT_PEERING mode value must
	// be a CIDR range of size /28, or "auto". For PRIVATE_SERVICE_ACCESS mode
	// value must be the name of an allocated address range associated with the
	// private service access connection, or "auto".
	SecondaryIpRange string
	// Output only. Hostname or IP address of the exposed Redis endpoint used by
	// clients to connect to the service.
	Host string
	// Output only. The port number of the exposed Redis endpoint.
	Port int32
	// Output only. The current zone where the Redis primary node is located. In
	// basic tier, this will always be the same as [location_id]. In
	// standard tier, this can be the zone of any node in the instance.
	CurrentLocationId string
	// Output only. The time the instance was created.
	CreateTime *timestamppb.Timestamp
	// Output only. The current state of this instance.
	State Instance_State
	// Output only. Additional information about the current status of this
	// instance, if available.
	StatusMessage string
	// Optional. Redis configuration parameters, according to
	// http://redis.io/topics/config. Currently, the only supported parameters
	// are:
	//
	//	Redis version 3.2 and newer:
	//
	//	*   maxmemory-policy
	//	*   notify-keyspace-events
	//
	//	Redis version 4.0 and newer:
	//
	//	*   activedefrag
	//	*   lfu-decay-time
	//	*   lfu-log-factor
	//	*   maxmemory-gb
	//
	//	Redis version 5.0 and newer:
	//
	//	*   stream-node-max-bytes
	//	*   stream-node-max-entries
	RedisConfigs map[string]string
	// Required. The service tier of the instance.
	Tier Instance_Tier
	// Required. Redis memory size in GiB.
	MemorySizeGb int32
	// Optional. The full name of the Google Compute Engine
	// [network](https://cloud.google.com/vpc/docs/vpc) to which the
	// instance is connected. If left unspecified, the `default` network
	// will be used.
	AuthorizedNetwork string
	// Output only. Cloud IAM identity used by import / export operations to
	// transfer data to/from Cloud Storage. Format is
	// "serviceAccount:<service_account_email>". The value may change over time
	// for a given instance so should be checked before each import/export
	// operation.
	PersistenceIamIdentity string
	// Optional. The network connect mode of the Redis instance.
	// If not provided, the connect mode defaults to DIRECT_PEERING.
	ConnectMode Instance_ConnectMode
	// Optional. Indicates whether OSS Redis AUTH is enabled for the instance. If
	// set to "true" AUTH is enabled on the instance. Default value is "false"
	// meaning AUTH is disabled.
	AuthEnabled bool
	// Output only. List of server CA certificates for the instance.
	ServerCaCerts []*TlsCertificate
	// Optional. The TLS mode of the Redis instance.
	// If not provided, TLS is disabled for the instance.
	TransitEncryptionMode Instance_TransitEncryptionMode
	// Optional. The maintenance policy for the instance. If not provided,
	// maintenance events can be performed at any time.
	MaintenancePolicy *MaintenancePolicy
	// Output only. Date and time of upcoming maintenance events which have been
	// scheduled.
	MaintenanceSchedule *MaintenanceSchedule
	// Optional. The number of replica nodes. The valid range for the Standard
	// Tier with read replicas enabled is [1-5] and defaults to 2. If read
	// replicas are not enabled for a Standard Tier instance, the only valid value
	// is 1 and the default is 1. The valid value for basic tier is 0 and the
	// default is also 0.
	ReplicaCount int32
	// Output only. Info per node.
	Nodes []*NodeInfo
	// Output only. Hostname or IP address of the exposed readonly Redis
	// endpoint. Standard tier only. Targets all healthy replica nodes in
	// instance. Replication is asynchronous and replica nodes will exhibit some
	// lag behind the primary. Write requests must target 'host'.
	ReadEndpoint string
	// Output only. The port number of the exposed readonly redis
	// endpoint. Standard tier only. Write requests should target 'port'.
	ReadEndpointPort int32
	// Optional. Read replicas mode for the instance. Defaults to
	// READ_REPLICAS_DISABLED.
	ReadReplicasMode Instance_ReadReplicasMode
	// Optional. The KMS key reference that the customer provides when trying to
	// create the instance.
	CustomerManagedKey string
	// Optional. Persistence configuration parameters
	PersistenceConfig *PersistenceConfig
	// Optional. reasons that causes instance in "SUSPENDED" state.
	SuspensionReasons []Instance_SuspensionReason
	// Optional. The self service update maintenance version.
	// The version is date based such as "20210712_00_00".
	MaintenanceVersion string
	// Optional. The available maintenance versions that an instance could update
	// to.
	AvailableMaintenanceVersions []string
	// contains filtered or unexported fields
}

func (Instance_builder) Build

func (b0 Instance_builder) Build() *Instance

type MaintenancePolicy

type MaintenancePolicy struct {

	// Output only. The time when the policy was created.
	CreateTime *timestamppb.Timestamp `protobuf:"bytes,1,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
	// Output only. The time when the policy was last updated.
	UpdateTime *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=update_time,json=updateTime,proto3" json:"update_time,omitempty"`
	// Optional. Description of what this policy is for. Create/Update methods
	// return INVALID_ARGUMENT if the length is greater than 512.
	Description string `protobuf:"bytes,3,opt,name=description,proto3" json:"description,omitempty"`
	// Optional. Maintenance window that is applied to resources covered by this
	// policy. Minimum 1. For the current version, the maximum number of
	// weekly_window is expected to be one.
	WeeklyMaintenanceWindow []*WeeklyMaintenanceWindow `` /* 132-byte string literal not displayed */
	// contains filtered or unexported fields
}

Maintenance policy for an instance.

func (*MaintenancePolicy) ClearCreateTime

func (x *MaintenancePolicy) ClearCreateTime()

func (*MaintenancePolicy) ClearUpdateTime

func (x *MaintenancePolicy) ClearUpdateTime()

func (*MaintenancePolicy) GetCreateTime

func (x *MaintenancePolicy) GetCreateTime() *timestamppb.Timestamp

func (*MaintenancePolicy) GetDescription

func (x *MaintenancePolicy) GetDescription() string

func (*MaintenancePolicy) GetUpdateTime

func (x *MaintenancePolicy) GetUpdateTime() *timestamppb.Timestamp

func (*MaintenancePolicy) GetWeeklyMaintenanceWindow

func (x *MaintenancePolicy) GetWeeklyMaintenanceWindow() []*WeeklyMaintenanceWindow

func (*MaintenancePolicy) HasCreateTime

func (x *MaintenancePolicy) HasCreateTime() bool

func (*MaintenancePolicy) HasUpdateTime

func (x *MaintenancePolicy) HasUpdateTime() bool

func (*MaintenancePolicy) ProtoMessage

func (*MaintenancePolicy) ProtoMessage()

func (*MaintenancePolicy) ProtoReflect

func (x *MaintenancePolicy) ProtoReflect() protoreflect.Message

func (*MaintenancePolicy) Reset

func (x *MaintenancePolicy) Reset()

func (*MaintenancePolicy) SetCreateTime

func (x *MaintenancePolicy) SetCreateTime(v *timestamppb.Timestamp)

func (*MaintenancePolicy) SetDescription

func (x *MaintenancePolicy) SetDescription(v string)

func (*MaintenancePolicy) SetUpdateTime

func (x *MaintenancePolicy) SetUpdateTime(v *timestamppb.Timestamp)

func (*MaintenancePolicy) SetWeeklyMaintenanceWindow

func (x *MaintenancePolicy) SetWeeklyMaintenanceWindow(v []*WeeklyMaintenanceWindow)

func (*MaintenancePolicy) String

func (x *MaintenancePolicy) String() string

type MaintenancePolicy_builder

type MaintenancePolicy_builder struct {

	// Output only. The time when the policy was created.
	CreateTime *timestamppb.Timestamp
	// Output only. The time when the policy was last updated.
	UpdateTime *timestamppb.Timestamp
	// Optional. Description of what this policy is for. Create/Update methods
	// return INVALID_ARGUMENT if the length is greater than 512.
	Description string
	// Optional. Maintenance window that is applied to resources covered by this
	// policy. Minimum 1. For the current version, the maximum number of
	// weekly_window is expected to be one.
	WeeklyMaintenanceWindow []*WeeklyMaintenanceWindow
	// contains filtered or unexported fields
}

func (MaintenancePolicy_builder) Build

type MaintenanceSchedule

type MaintenanceSchedule struct {

	// Output only. The start time of any upcoming scheduled maintenance for this
	// instance.
	StartTime *timestamppb.Timestamp `protobuf:"bytes,1,opt,name=start_time,json=startTime,proto3" json:"start_time,omitempty"`
	// Output only. The end time of any upcoming scheduled maintenance for this
	// instance.
	EndTime *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=end_time,json=endTime,proto3" json:"end_time,omitempty"`
	// If the scheduled maintenance can be rescheduled, default is true.
	CanReschedule bool `protobuf:"varint,3,opt,name=can_reschedule,json=canReschedule,proto3" json:"can_reschedule,omitempty"`
	// Output only. The deadline that the maintenance schedule start time can not
	// go beyond, including reschedule.
	ScheduleDeadlineTime *timestamppb.Timestamp `protobuf:"bytes,5,opt,name=schedule_deadline_time,json=scheduleDeadlineTime,proto3" json:"schedule_deadline_time,omitempty"`
	// contains filtered or unexported fields
}

Upcoming maintenance schedule. If no maintenance is scheduled, fields are not populated.

func (*MaintenanceSchedule) ClearEndTime

func (x *MaintenanceSchedule) ClearEndTime()

func (*MaintenanceSchedule) ClearScheduleDeadlineTime

func (x *MaintenanceSchedule) ClearScheduleDeadlineTime()

func (*MaintenanceSchedule) ClearStartTime

func (x *MaintenanceSchedule) ClearStartTime()

func (*MaintenanceSchedule) GetCanReschedule

func (x *MaintenanceSchedule) GetCanReschedule() bool

func (*MaintenanceSchedule) GetEndTime

func (x *MaintenanceSchedule) GetEndTime() *timestamppb.Timestamp

func (*MaintenanceSchedule) GetScheduleDeadlineTime

func (x *MaintenanceSchedule) GetScheduleDeadlineTime() *timestamppb.Timestamp

func (*MaintenanceSchedule) GetStartTime

func (x *MaintenanceSchedule) GetStartTime() *timestamppb.Timestamp

func (*MaintenanceSchedule) HasEndTime

func (x *MaintenanceSchedule) HasEndTime() bool

func (*MaintenanceSchedule) HasScheduleDeadlineTime

func (x *MaintenanceSchedule) HasScheduleDeadlineTime() bool

func (*MaintenanceSchedule) HasStartTime

func (x *MaintenanceSchedule) HasStartTime() bool

func (*MaintenanceSchedule) ProtoMessage

func (*MaintenanceSchedule) ProtoMessage()

func (*MaintenanceSchedule) ProtoReflect

func (x *MaintenanceSchedule) ProtoReflect() protoreflect.Message

func (*MaintenanceSchedule) Reset

func (x *MaintenanceSchedule) Reset()

func (*MaintenanceSchedule) SetCanReschedule

func (x *MaintenanceSchedule) SetCanReschedule(v bool)

func (*MaintenanceSchedule) SetEndTime

func (x *MaintenanceSchedule) SetEndTime(v *timestamppb.Timestamp)

func (*MaintenanceSchedule) SetScheduleDeadlineTime

func (x *MaintenanceSchedule) SetScheduleDeadlineTime(v *timestamppb.Timestamp)

func (*MaintenanceSchedule) SetStartTime

func (x *MaintenanceSchedule) SetStartTime(v *timestamppb.Timestamp)

func (*MaintenanceSchedule) String

func (x *MaintenanceSchedule) String() string

type MaintenanceSchedule_builder

type MaintenanceSchedule_builder struct {

	// Output only. The start time of any upcoming scheduled maintenance for this
	// instance.
	StartTime *timestamppb.Timestamp
	// Output only. The end time of any upcoming scheduled maintenance for this
	// instance.
	EndTime *timestamppb.Timestamp
	// If the scheduled maintenance can be rescheduled, default is true.
	CanReschedule bool
	// Output only. The deadline that the maintenance schedule start time can not
	// go beyond, including reschedule.
	ScheduleDeadlineTime *timestamppb.Timestamp
	// contains filtered or unexported fields
}

func (MaintenanceSchedule_builder) Build

type NodeInfo

type NodeInfo struct {

	// Output only. Node identifying string. e.g. 'node-0', 'node-1'
	Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	// Output only. Location of the node.
	Zone string `protobuf:"bytes,2,opt,name=zone,proto3" json:"zone,omitempty"`
	// contains filtered or unexported fields
}

Node specific properties.

func (*NodeInfo) GetId

func (x *NodeInfo) GetId() string

func (*NodeInfo) GetZone

func (x *NodeInfo) GetZone() string

func (*NodeInfo) ProtoMessage

func (*NodeInfo) ProtoMessage()

func (*NodeInfo) ProtoReflect

func (x *NodeInfo) ProtoReflect() protoreflect.Message

func (*NodeInfo) Reset

func (x *NodeInfo) Reset()

func (*NodeInfo) SetId

func (x *NodeInfo) SetId(v string)

func (*NodeInfo) SetZone

func (x *NodeInfo) SetZone(v string)

func (*NodeInfo) String

func (x *NodeInfo) String() string

type NodeInfo_builder

type NodeInfo_builder struct {

	// Output only. Node identifying string. e.g. 'node-0', 'node-1'
	Id string
	// Output only. Location of the node.
	Zone string
	// contains filtered or unexported fields
}

func (NodeInfo_builder) Build

func (b0 NodeInfo_builder) Build() *NodeInfo

type PersistenceConfig

type PersistenceConfig struct {

	// Optional. Controls whether Persistence features are enabled.
	// If not provided, the existing value will be used.
	PersistenceMode PersistenceConfig_PersistenceMode `` /* 175-byte string literal not displayed */
	// Optional. Period between RDB snapshots. Snapshots will be attempted every
	// period starting from the provided snapshot start time. For example, a start
	// time of 01/01/2033 06:45 and SIX_HOURS snapshot period will do nothing
	// until 01/01/2033, and then trigger snapshots every day at 06:45, 12:45,
	// 18:45, and 00:45 the next day, and so on. If not provided,
	// TWENTY_FOUR_HOURS will be used as default.
	RdbSnapshotPeriod PersistenceConfig_SnapshotPeriod `` /* 182-byte string literal not displayed */
	// Output only. The next time that a snapshot attempt is scheduled to occur.
	RdbNextSnapshotTime *timestamppb.Timestamp `protobuf:"bytes,4,opt,name=rdb_next_snapshot_time,json=rdbNextSnapshotTime,proto3" json:"rdb_next_snapshot_time,omitempty"`
	// Optional. Date and time that the first snapshot was/will be attempted, and
	// to which future snapshots will be aligned. If not provided, the current
	// time will be used.
	RdbSnapshotStartTime *timestamppb.Timestamp `protobuf:"bytes,5,opt,name=rdb_snapshot_start_time,json=rdbSnapshotStartTime,proto3" json:"rdb_snapshot_start_time,omitempty"`
	// contains filtered or unexported fields
}

Configuration of the persistence functionality.

func (*PersistenceConfig) ClearRdbNextSnapshotTime

func (x *PersistenceConfig) ClearRdbNextSnapshotTime()

func (*PersistenceConfig) ClearRdbSnapshotStartTime

func (x *PersistenceConfig) ClearRdbSnapshotStartTime()

func (*PersistenceConfig) GetPersistenceMode

func (x *PersistenceConfig) GetPersistenceMode() PersistenceConfig_PersistenceMode

func (*PersistenceConfig) GetRdbNextSnapshotTime

func (x *PersistenceConfig) GetRdbNextSnapshotTime() *timestamppb.Timestamp

func (*PersistenceConfig) GetRdbSnapshotPeriod

func (x *PersistenceConfig) GetRdbSnapshotPeriod() PersistenceConfig_SnapshotPeriod

func (*PersistenceConfig) GetRdbSnapshotStartTime

func (x *PersistenceConfig) GetRdbSnapshotStartTime() *timestamppb.Timestamp

func (*PersistenceConfig) HasRdbNextSnapshotTime

func (x *PersistenceConfig) HasRdbNextSnapshotTime() bool

func (*PersistenceConfig) HasRdbSnapshotStartTime

func (x *PersistenceConfig) HasRdbSnapshotStartTime() bool

func (*PersistenceConfig) ProtoMessage

func (*PersistenceConfig) ProtoMessage()

func (*PersistenceConfig) ProtoReflect

func (x *PersistenceConfig) ProtoReflect() protoreflect.Message

func (*PersistenceConfig) Reset

func (x *PersistenceConfig) Reset()

func (*PersistenceConfig) SetPersistenceMode

func (x *PersistenceConfig) SetPersistenceMode(v PersistenceConfig_PersistenceMode)

func (*PersistenceConfig) SetRdbNextSnapshotTime

func (x *PersistenceConfig) SetRdbNextSnapshotTime(v *timestamppb.Timestamp)

func (*PersistenceConfig) SetRdbSnapshotPeriod

func (x *PersistenceConfig) SetRdbSnapshotPeriod(v PersistenceConfig_SnapshotPeriod)

func (*PersistenceConfig) SetRdbSnapshotStartTime

func (x *PersistenceConfig) SetRdbSnapshotStartTime(v *timestamppb.Timestamp)

func (*PersistenceConfig) String

func (x *PersistenceConfig) String() string

type PersistenceConfig_PersistenceMode

type PersistenceConfig_PersistenceMode int32

Available Persistence modes.

const (
	// Not set.
	PersistenceConfig_PERSISTENCE_MODE_UNSPECIFIED PersistenceConfig_PersistenceMode = 0
	// Persistence is disabled for the instance,
	// and any existing snapshots are deleted.
	PersistenceConfig_DISABLED PersistenceConfig_PersistenceMode = 1
	// RDB based Persistence is enabled.
	PersistenceConfig_RDB PersistenceConfig_PersistenceMode = 2
)

func (PersistenceConfig_PersistenceMode) Descriptor

func (PersistenceConfig_PersistenceMode) Enum

func (PersistenceConfig_PersistenceMode) Number

func (PersistenceConfig_PersistenceMode) String

func (PersistenceConfig_PersistenceMode) Type

type PersistenceConfig_SnapshotPeriod

type PersistenceConfig_SnapshotPeriod int32

Available snapshot periods for scheduling.

const (
	// Not set.
	PersistenceConfig_SNAPSHOT_PERIOD_UNSPECIFIED PersistenceConfig_SnapshotPeriod = 0
	// Snapshot every 1 hour.
	PersistenceConfig_ONE_HOUR PersistenceConfig_SnapshotPeriod = 3
	// Snapshot every 6 hours.
	PersistenceConfig_SIX_HOURS PersistenceConfig_SnapshotPeriod = 4
	// Snapshot every 12 hours.
	PersistenceConfig_TWELVE_HOURS PersistenceConfig_SnapshotPeriod = 5
	// Snapshot every 24 hours.
	PersistenceConfig_TWENTY_FOUR_HOURS PersistenceConfig_SnapshotPeriod = 6
)

func (PersistenceConfig_SnapshotPeriod) Descriptor

func (PersistenceConfig_SnapshotPeriod) Enum

func (PersistenceConfig_SnapshotPeriod) Number

func (PersistenceConfig_SnapshotPeriod) String

func (PersistenceConfig_SnapshotPeriod) Type

type PersistenceConfig_builder

type PersistenceConfig_builder struct {

	// Optional. Controls whether Persistence features are enabled.
	// If not provided, the existing value will be used.
	PersistenceMode PersistenceConfig_PersistenceMode
	// Optional. Period between RDB snapshots. Snapshots will be attempted every
	// period starting from the provided snapshot start time. For example, a start
	// time of 01/01/2033 06:45 and SIX_HOURS snapshot period will do nothing
	// until 01/01/2033, and then trigger snapshots every day at 06:45, 12:45,
	// 18:45, and 00:45 the next day, and so on. If not provided,
	// TWENTY_FOUR_HOURS will be used as default.
	RdbSnapshotPeriod PersistenceConfig_SnapshotPeriod
	// Output only. The next time that a snapshot attempt is scheduled to occur.
	RdbNextSnapshotTime *timestamppb.Timestamp
	// Optional. Date and time that the first snapshot was/will be attempted, and
	// to which future snapshots will be aligned. If not provided, the current
	// time will be used.
	RdbSnapshotStartTime *timestamppb.Timestamp
	// contains filtered or unexported fields
}

func (PersistenceConfig_builder) Build

type TlsCertificate

type TlsCertificate struct {

	// Serial number, as extracted from the certificate.
	SerialNumber string `protobuf:"bytes,1,opt,name=serial_number,json=serialNumber,proto3" json:"serial_number,omitempty"`
	// Output only. The time when the certificate was created in [RFC
	// 3339](https://tools.ietf.org/html/rfc3339) format, for example
	// `2020-05-18T00:00:00.094Z`.
	CreateTime *timestamppb.Timestamp `protobuf:"bytes,3,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
	// Output only. The time when the certificate expires in [RFC
	// 3339](https://tools.ietf.org/html/rfc3339) format, for example
	// `2020-05-18T00:00:00.094Z`.
	ExpireTime *timestamppb.Timestamp `protobuf:"bytes,4,opt,name=expire_time,json=expireTime,proto3" json:"expire_time,omitempty"`
	// Sha1 Fingerprint of the certificate.
	Sha1Fingerprint string `protobuf:"bytes,5,opt,name=sha1_fingerprint,json=sha1Fingerprint,proto3" json:"sha1_fingerprint,omitempty"`
	// contains filtered or unexported fields
}

TlsCertificate Resource

func (*TlsCertificate) ClearCreateTime

func (x *TlsCertificate) ClearCreateTime()

func (*TlsCertificate) ClearExpireTime

func (x *TlsCertificate) ClearExpireTime()

func (*TlsCertificate) GetCreateTime

func (x *TlsCertificate) GetCreateTime() *timestamppb.Timestamp

func (*TlsCertificate) GetExpireTime

func (x *TlsCertificate) GetExpireTime() *timestamppb.Timestamp

func (*TlsCertificate) GetSerialNumber

func (x *TlsCertificate) GetSerialNumber() string

func (*TlsCertificate) GetSha1Fingerprint

func (x *TlsCertificate) GetSha1Fingerprint() string

func (*TlsCertificate) HasCreateTime

func (x *TlsCertificate) HasCreateTime() bool

func (*TlsCertificate) HasExpireTime

func (x *TlsCertificate) HasExpireTime() bool

func (*TlsCertificate) ProtoMessage

func (*TlsCertificate) ProtoMessage()

func (*TlsCertificate) ProtoReflect

func (x *TlsCertificate) ProtoReflect() protoreflect.Message

func (*TlsCertificate) Reset

func (x *TlsCertificate) Reset()

func (*TlsCertificate) SetCreateTime

func (x *TlsCertificate) SetCreateTime(v *timestamppb.Timestamp)

func (*TlsCertificate) SetExpireTime

func (x *TlsCertificate) SetExpireTime(v *timestamppb.Timestamp)

func (*TlsCertificate) SetSerialNumber

func (x *TlsCertificate) SetSerialNumber(v string)

func (*TlsCertificate) SetSha1Fingerprint

func (x *TlsCertificate) SetSha1Fingerprint(v string)

func (*TlsCertificate) String

func (x *TlsCertificate) String() string

type TlsCertificate_builder

type TlsCertificate_builder struct {

	// Serial number, as extracted from the certificate.
	SerialNumber string
	// Output only. The time when the certificate was created in [RFC
	// 3339](https://tools.ietf.org/html/rfc3339) format, for example
	// `2020-05-18T00:00:00.094Z`.
	CreateTime *timestamppb.Timestamp
	// Output only. The time when the certificate expires in [RFC
	// 3339](https://tools.ietf.org/html/rfc3339) format, for example
	// `2020-05-18T00:00:00.094Z`.
	ExpireTime *timestamppb.Timestamp
	// Sha1 Fingerprint of the certificate.
	Sha1Fingerprint string
	// contains filtered or unexported fields
}

func (TlsCertificate_builder) Build

type WeeklyMaintenanceWindow

type WeeklyMaintenanceWindow struct {

	// Required. The day of week that maintenance updates occur.
	Day dayofweek.DayOfWeek `protobuf:"varint,1,opt,name=day,proto3,enum=google.type.DayOfWeek" json:"day,omitempty"`
	// Required. Start time of the window in UTC time.
	StartTime *timeofday.TimeOfDay `protobuf:"bytes,2,opt,name=start_time,json=startTime,proto3" json:"start_time,omitempty"`
	// Output only. Duration of the maintenance window. The current window is
	// fixed at 1 hour.
	Duration *durationpb.Duration `protobuf:"bytes,3,opt,name=duration,proto3" json:"duration,omitempty"`
	// contains filtered or unexported fields
}

Time window in which disruptive maintenance updates occur. Non-disruptive updates can occur inside or outside this window.

func (*WeeklyMaintenanceWindow) ClearDuration

func (x *WeeklyMaintenanceWindow) ClearDuration()

func (*WeeklyMaintenanceWindow) ClearStartTime

func (x *WeeklyMaintenanceWindow) ClearStartTime()

func (*WeeklyMaintenanceWindow) GetDay

func (*WeeklyMaintenanceWindow) GetDuration

func (x *WeeklyMaintenanceWindow) GetDuration() *durationpb.Duration

func (*WeeklyMaintenanceWindow) GetStartTime

func (x *WeeklyMaintenanceWindow) GetStartTime() *timeofday.TimeOfDay

func (*WeeklyMaintenanceWindow) HasDuration

func (x *WeeklyMaintenanceWindow) HasDuration() bool

func (*WeeklyMaintenanceWindow) HasStartTime

func (x *WeeklyMaintenanceWindow) HasStartTime() bool

func (*WeeklyMaintenanceWindow) ProtoMessage

func (*WeeklyMaintenanceWindow) ProtoMessage()

func (*WeeklyMaintenanceWindow) ProtoReflect

func (x *WeeklyMaintenanceWindow) ProtoReflect() protoreflect.Message

func (*WeeklyMaintenanceWindow) Reset

func (x *WeeklyMaintenanceWindow) Reset()

func (*WeeklyMaintenanceWindow) SetDay

func (*WeeklyMaintenanceWindow) SetDuration

func (x *WeeklyMaintenanceWindow) SetDuration(v *durationpb.Duration)

func (*WeeklyMaintenanceWindow) SetStartTime

func (x *WeeklyMaintenanceWindow) SetStartTime(v *timeofday.TimeOfDay)

func (*WeeklyMaintenanceWindow) String

func (x *WeeklyMaintenanceWindow) String() string

type WeeklyMaintenanceWindow_builder

type WeeklyMaintenanceWindow_builder struct {

	// Required. The day of week that maintenance updates occur.
	Day dayofweek.DayOfWeek
	// Required. Start time of the window in UTC time.
	StartTime *timeofday.TimeOfDay
	// Output only. Duration of the maintenance window. The current window is
	// fixed at 1 hour.
	Duration *durationpb.Duration
	// contains filtered or unexported fields
}

func (WeeklyMaintenanceWindow_builder) Build

Source Files

  • data.pb.go
  • events.pb.go

Jump to