storagev1

package
v1.36.11-2024050211440... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var File_google_events_cloud_storage_v1_data_proto protoreflect.FileDescriptor
var File_google_events_cloud_storage_v1_events_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type ObjectArchivedEvent

type ObjectArchivedEvent struct {

	// The data associated with the event.
	Data *StorageObjectData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

The CloudEvent raised when an object is archived in Google Cloud Storage.

func (*ObjectArchivedEvent) ClearData

func (x *ObjectArchivedEvent) ClearData()

func (*ObjectArchivedEvent) GetData

func (x *ObjectArchivedEvent) GetData() *StorageObjectData

func (*ObjectArchivedEvent) HasData

func (x *ObjectArchivedEvent) HasData() bool

func (*ObjectArchivedEvent) ProtoMessage

func (*ObjectArchivedEvent) ProtoMessage()

func (*ObjectArchivedEvent) ProtoReflect

func (x *ObjectArchivedEvent) ProtoReflect() protoreflect.Message

func (*ObjectArchivedEvent) Reset

func (x *ObjectArchivedEvent) Reset()

func (*ObjectArchivedEvent) SetData

func (x *ObjectArchivedEvent) SetData(v *StorageObjectData)

func (*ObjectArchivedEvent) String

func (x *ObjectArchivedEvent) String() string

type ObjectArchivedEvent_builder

type ObjectArchivedEvent_builder struct {

	// The data associated with the event.
	Data *StorageObjectData
	// contains filtered or unexported fields
}

func (ObjectArchivedEvent_builder) Build

type ObjectDeletedEvent

type ObjectDeletedEvent struct {

	// The data associated with the event.
	Data *StorageObjectData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

The CloudEvent raised when an object is deleted in Google Cloud Storage.

func (*ObjectDeletedEvent) ClearData

func (x *ObjectDeletedEvent) ClearData()

func (*ObjectDeletedEvent) GetData

func (x *ObjectDeletedEvent) GetData() *StorageObjectData

func (*ObjectDeletedEvent) HasData

func (x *ObjectDeletedEvent) HasData() bool

func (*ObjectDeletedEvent) ProtoMessage

func (*ObjectDeletedEvent) ProtoMessage()

func (*ObjectDeletedEvent) ProtoReflect

func (x *ObjectDeletedEvent) ProtoReflect() protoreflect.Message

func (*ObjectDeletedEvent) Reset

func (x *ObjectDeletedEvent) Reset()

func (*ObjectDeletedEvent) SetData

func (x *ObjectDeletedEvent) SetData(v *StorageObjectData)

func (*ObjectDeletedEvent) String

func (x *ObjectDeletedEvent) String() string

type ObjectDeletedEvent_builder

type ObjectDeletedEvent_builder struct {

	// The data associated with the event.
	Data *StorageObjectData
	// contains filtered or unexported fields
}

func (ObjectDeletedEvent_builder) Build

type ObjectFinalizedEvent

type ObjectFinalizedEvent struct {

	// The data associated with the event.
	Data *StorageObjectData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

The CloudEvent raised when an object is finalized in Google Cloud Storage.

func (*ObjectFinalizedEvent) ClearData

func (x *ObjectFinalizedEvent) ClearData()

func (*ObjectFinalizedEvent) GetData

func (*ObjectFinalizedEvent) HasData

func (x *ObjectFinalizedEvent) HasData() bool

func (*ObjectFinalizedEvent) ProtoMessage

func (*ObjectFinalizedEvent) ProtoMessage()

func (*ObjectFinalizedEvent) ProtoReflect

func (x *ObjectFinalizedEvent) ProtoReflect() protoreflect.Message

func (*ObjectFinalizedEvent) Reset

func (x *ObjectFinalizedEvent) Reset()

func (*ObjectFinalizedEvent) SetData

func (x *ObjectFinalizedEvent) SetData(v *StorageObjectData)

func (*ObjectFinalizedEvent) String

func (x *ObjectFinalizedEvent) String() string

type ObjectFinalizedEvent_builder

type ObjectFinalizedEvent_builder struct {

	// The data associated with the event.
	Data *StorageObjectData
	// contains filtered or unexported fields
}

func (ObjectFinalizedEvent_builder) Build

type ObjectMetadataUpdatedEvent

type ObjectMetadataUpdatedEvent struct {

	// The data associated with the event.
	Data *StorageObjectData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

The CloudEvent raised when an object's metadata is updated in Google Cloud Storage.

func (*ObjectMetadataUpdatedEvent) ClearData

func (x *ObjectMetadataUpdatedEvent) ClearData()

func (*ObjectMetadataUpdatedEvent) GetData

func (*ObjectMetadataUpdatedEvent) HasData

func (x *ObjectMetadataUpdatedEvent) HasData() bool

func (*ObjectMetadataUpdatedEvent) ProtoMessage

func (*ObjectMetadataUpdatedEvent) ProtoMessage()

func (*ObjectMetadataUpdatedEvent) ProtoReflect

func (*ObjectMetadataUpdatedEvent) Reset

func (x *ObjectMetadataUpdatedEvent) Reset()

func (*ObjectMetadataUpdatedEvent) SetData

func (*ObjectMetadataUpdatedEvent) String

func (x *ObjectMetadataUpdatedEvent) String() string

type ObjectMetadataUpdatedEvent_builder

type ObjectMetadataUpdatedEvent_builder struct {

	// The data associated with the event.
	Data *StorageObjectData
	// contains filtered or unexported fields
}

func (ObjectMetadataUpdatedEvent_builder) Build

type StorageObjectData

type StorageObjectData struct {

	// Content-Encoding of the object data, matching
	// [https://tools.ietf.org/html/rfc7231#section-3.1.2.2][RFC 7231 3.1.2.2]
	ContentEncoding string `protobuf:"bytes,1,opt,name=content_encoding,json=contentEncoding,proto3" json:"content_encoding,omitempty"`
	// Content-Disposition of the object data, matching
	// [https://tools.ietf.org/html/rfc6266][RFC 6266].
	ContentDisposition string `protobuf:"bytes,2,opt,name=content_disposition,json=contentDisposition,proto3" json:"content_disposition,omitempty"`
	// Cache-Control directive for the object data, matching
	// [https://tools.ietf.org/html/rfc7234#section-5.2"][RFC 7234 5.2].
	CacheControl string `protobuf:"bytes,3,opt,name=cache_control,json=cacheControl,proto3" json:"cache_control,omitempty"`
	// Content-Language of the object data, matching
	// [https://tools.ietf.org/html/rfc7231#section-3.1.3.2][RFC 7231 3.1.3.2].
	ContentLanguage string `protobuf:"bytes,5,opt,name=content_language,json=contentLanguage,proto3" json:"content_language,omitempty"`
	// The version of the metadata for this object at this generation. Used for
	// preconditions and for detecting changes in metadata. A metageneration
	// number is only meaningful in the context of a particular generation of a
	// particular object.
	Metageneration int64 `protobuf:"varint,6,opt,name=metageneration,proto3" json:"metageneration,omitempty"`
	// The deletion time of the object. Will be returned if and only if this
	// version of the object has been deleted.
	TimeDeleted *timestamppb.Timestamp `protobuf:"bytes,7,opt,name=time_deleted,json=timeDeleted,proto3" json:"time_deleted,omitempty"`
	// Content-Type of the object data, matching
	// [https://tools.ietf.org/html/rfc7231#section-3.1.1.5][RFC 7231 3.1.1.5].
	// If an object is stored without a Content-Type, it is served as
	// `application/octet-stream`.
	ContentType string `protobuf:"bytes,8,opt,name=content_type,json=contentType,proto3" json:"content_type,omitempty"`
	// Content-Length of the object data in bytes, matching
	// [https://tools.ietf.org/html/rfc7230#section-3.3.2][RFC 7230 3.3.2].
	Size int64 `protobuf:"varint,9,opt,name=size,proto3" json:"size,omitempty"`
	// The creation time of the object.
	// Attempting to set this field will result in an error.
	TimeCreated *timestamppb.Timestamp `protobuf:"bytes,10,opt,name=time_created,json=timeCreated,proto3" json:"time_created,omitempty"`
	// CRC32c checksum. For more information about using the CRC32c
	// checksum, see
	// [https://cloud.google.com/storage/docs/hashes-etags#_JSONAPI][Hashes and
	// ETags: Best Practices].
	Crc32C string `protobuf:"bytes,11,opt,name=crc32c,proto3" json:"crc32c,omitempty"`
	// Number of underlying components that make up this object. Components are
	// accumulated by compose operations.
	// Attempting to set this field will result in an error.
	ComponentCount int32 `protobuf:"varint,12,opt,name=component_count,json=componentCount,proto3" json:"component_count,omitempty"`
	// MD5 hash of the data; encoded using base64 as per
	// [https://tools.ietf.org/html/rfc4648#section-4][RFC 4648 4]. For more
	// information about using the MD5 hash, see
	// [https://cloud.google.com/storage/docs/hashes-etags#_JSONAPI][Hashes and
	// ETags: Best Practices].
	Md5Hash string `protobuf:"bytes,13,opt,name=md5_hash,json=md5Hash,proto3" json:"md5_hash,omitempty"`
	// HTTP 1.1 Entity tag for the object. See
	// [https://tools.ietf.org/html/rfc7232#section-2.3][RFC 7232 2.3].
	Etag string `protobuf:"bytes,14,opt,name=etag,proto3" json:"etag,omitempty"`
	// The modification time of the object metadata.
	Updated *timestamppb.Timestamp `protobuf:"bytes,15,opt,name=updated,proto3" json:"updated,omitempty"`
	// Storage class of the object.
	StorageClass string `protobuf:"bytes,16,opt,name=storage_class,json=storageClass,proto3" json:"storage_class,omitempty"`
	// Cloud KMS Key used to encrypt this object, if the object is encrypted by
	// such a key.
	KmsKeyName string `protobuf:"bytes,17,opt,name=kms_key_name,json=kmsKeyName,proto3" json:"kms_key_name,omitempty"`
	// The time at which the object's storage class was last changed.
	TimeStorageClassUpdated *timestamppb.Timestamp `` /* 135-byte string literal not displayed */
	// Whether an object is under temporary hold.
	TemporaryHold bool `protobuf:"varint,19,opt,name=temporary_hold,json=temporaryHold,proto3" json:"temporary_hold,omitempty"`
	// A server-determined value that specifies the earliest time that the
	// object's retention period expires.
	RetentionExpirationTime *timestamppb.Timestamp `` /* 133-byte string literal not displayed */
	// User-provided metadata, in key/value pairs.
	Metadata map[string]string `` /* 144-byte string literal not displayed */
	// Whether an object is under event-based hold.
	EventBasedHold bool `protobuf:"varint,29,opt,name=event_based_hold,json=eventBasedHold,proto3" json:"event_based_hold,omitempty"`
	// The name of the object.
	Name string `protobuf:"bytes,23,opt,name=name,proto3" json:"name,omitempty"`
	// The ID of the object, including the bucket name, object name, and
	// generation number.
	Id string `protobuf:"bytes,24,opt,name=id,proto3" json:"id,omitempty"`
	// The name of the bucket containing this object.
	Bucket string `protobuf:"bytes,25,opt,name=bucket,proto3" json:"bucket,omitempty"`
	// The content generation of this object. Used for object versioning.
	// Attempting to set this field will result in an error.
	Generation int64 `protobuf:"varint,26,opt,name=generation,proto3" json:"generation,omitempty"`
	// Metadata of customer-supplied encryption key, if the object is encrypted by
	// such a key.
	CustomerEncryption *StorageObjectData_CustomerEncryption `protobuf:"bytes,28,opt,name=customer_encryption,json=customerEncryption,proto3" json:"customer_encryption,omitempty"`
	// Media download link.
	MediaLink string `protobuf:"bytes,100,opt,name=media_link,json=mediaLink,proto3" json:"media_link,omitempty"`
	// The link to this object.
	SelfLink string `protobuf:"bytes,101,opt,name=self_link,json=selfLink,proto3" json:"self_link,omitempty"`
	// The kind of item this is. For objects, this is always "storage#object".
	Kind string `protobuf:"bytes,102,opt,name=kind,proto3" json:"kind,omitempty"`
	// contains filtered or unexported fields
}

An object within Google Cloud Storage.

func (*StorageObjectData) ClearCustomerEncryption

func (x *StorageObjectData) ClearCustomerEncryption()

func (*StorageObjectData) ClearRetentionExpirationTime

func (x *StorageObjectData) ClearRetentionExpirationTime()

func (*StorageObjectData) ClearTimeCreated

func (x *StorageObjectData) ClearTimeCreated()

func (*StorageObjectData) ClearTimeDeleted

func (x *StorageObjectData) ClearTimeDeleted()

func (*StorageObjectData) ClearTimeStorageClassUpdated

func (x *StorageObjectData) ClearTimeStorageClassUpdated()

func (*StorageObjectData) ClearUpdated

func (x *StorageObjectData) ClearUpdated()

func (*StorageObjectData) GetBucket

func (x *StorageObjectData) GetBucket() string

func (*StorageObjectData) GetCacheControl

func (x *StorageObjectData) GetCacheControl() string

func (*StorageObjectData) GetComponentCount

func (x *StorageObjectData) GetComponentCount() int32

func (*StorageObjectData) GetContentDisposition

func (x *StorageObjectData) GetContentDisposition() string

func (*StorageObjectData) GetContentEncoding

func (x *StorageObjectData) GetContentEncoding() string

func (*StorageObjectData) GetContentLanguage

func (x *StorageObjectData) GetContentLanguage() string

func (*StorageObjectData) GetContentType

func (x *StorageObjectData) GetContentType() string

func (*StorageObjectData) GetCrc32C

func (x *StorageObjectData) GetCrc32C() string

func (*StorageObjectData) GetCustomerEncryption

func (x *StorageObjectData) GetCustomerEncryption() *StorageObjectData_CustomerEncryption

func (*StorageObjectData) GetEtag

func (x *StorageObjectData) GetEtag() string

func (*StorageObjectData) GetEventBasedHold

func (x *StorageObjectData) GetEventBasedHold() bool

func (*StorageObjectData) GetGeneration

func (x *StorageObjectData) GetGeneration() int64

func (*StorageObjectData) GetId

func (x *StorageObjectData) GetId() string

func (*StorageObjectData) GetKind

func (x *StorageObjectData) GetKind() string

func (*StorageObjectData) GetKmsKeyName

func (x *StorageObjectData) GetKmsKeyName() string

func (*StorageObjectData) GetMd5Hash

func (x *StorageObjectData) GetMd5Hash() string
func (x *StorageObjectData) GetMediaLink() string

func (*StorageObjectData) GetMetadata

func (x *StorageObjectData) GetMetadata() map[string]string

func (*StorageObjectData) GetMetageneration

func (x *StorageObjectData) GetMetageneration() int64

func (*StorageObjectData) GetName

func (x *StorageObjectData) GetName() string

func (*StorageObjectData) GetRetentionExpirationTime

func (x *StorageObjectData) GetRetentionExpirationTime() *timestamppb.Timestamp
func (x *StorageObjectData) GetSelfLink() string

func (*StorageObjectData) GetSize

func (x *StorageObjectData) GetSize() int64

func (*StorageObjectData) GetStorageClass

func (x *StorageObjectData) GetStorageClass() string

func (*StorageObjectData) GetTemporaryHold

func (x *StorageObjectData) GetTemporaryHold() bool

func (*StorageObjectData) GetTimeCreated

func (x *StorageObjectData) GetTimeCreated() *timestamppb.Timestamp

func (*StorageObjectData) GetTimeDeleted

func (x *StorageObjectData) GetTimeDeleted() *timestamppb.Timestamp

func (*StorageObjectData) GetTimeStorageClassUpdated

func (x *StorageObjectData) GetTimeStorageClassUpdated() *timestamppb.Timestamp

func (*StorageObjectData) GetUpdated

func (x *StorageObjectData) GetUpdated() *timestamppb.Timestamp

func (*StorageObjectData) HasCustomerEncryption

func (x *StorageObjectData) HasCustomerEncryption() bool

func (*StorageObjectData) HasRetentionExpirationTime

func (x *StorageObjectData) HasRetentionExpirationTime() bool

func (*StorageObjectData) HasTimeCreated

func (x *StorageObjectData) HasTimeCreated() bool

func (*StorageObjectData) HasTimeDeleted

func (x *StorageObjectData) HasTimeDeleted() bool

func (*StorageObjectData) HasTimeStorageClassUpdated

func (x *StorageObjectData) HasTimeStorageClassUpdated() bool

func (*StorageObjectData) HasUpdated

func (x *StorageObjectData) HasUpdated() bool

func (*StorageObjectData) ProtoMessage

func (*StorageObjectData) ProtoMessage()

func (*StorageObjectData) ProtoReflect

func (x *StorageObjectData) ProtoReflect() protoreflect.Message

func (*StorageObjectData) Reset

func (x *StorageObjectData) Reset()

func (*StorageObjectData) SetBucket

func (x *StorageObjectData) SetBucket(v string)

func (*StorageObjectData) SetCacheControl

func (x *StorageObjectData) SetCacheControl(v string)

func (*StorageObjectData) SetComponentCount

func (x *StorageObjectData) SetComponentCount(v int32)

func (*StorageObjectData) SetContentDisposition

func (x *StorageObjectData) SetContentDisposition(v string)

func (*StorageObjectData) SetContentEncoding

func (x *StorageObjectData) SetContentEncoding(v string)

func (*StorageObjectData) SetContentLanguage

func (x *StorageObjectData) SetContentLanguage(v string)

func (*StorageObjectData) SetContentType

func (x *StorageObjectData) SetContentType(v string)

func (*StorageObjectData) SetCrc32C

func (x *StorageObjectData) SetCrc32C(v string)

func (*StorageObjectData) SetCustomerEncryption

func (x *StorageObjectData) SetCustomerEncryption(v *StorageObjectData_CustomerEncryption)

func (*StorageObjectData) SetEtag

func (x *StorageObjectData) SetEtag(v string)

func (*StorageObjectData) SetEventBasedHold

func (x *StorageObjectData) SetEventBasedHold(v bool)

func (*StorageObjectData) SetGeneration

func (x *StorageObjectData) SetGeneration(v int64)

func (*StorageObjectData) SetId

func (x *StorageObjectData) SetId(v string)

func (*StorageObjectData) SetKind

func (x *StorageObjectData) SetKind(v string)

func (*StorageObjectData) SetKmsKeyName

func (x *StorageObjectData) SetKmsKeyName(v string)

func (*StorageObjectData) SetMd5Hash

func (x *StorageObjectData) SetMd5Hash(v string)
func (x *StorageObjectData) SetMediaLink(v string)

func (*StorageObjectData) SetMetadata

func (x *StorageObjectData) SetMetadata(v map[string]string)

func (*StorageObjectData) SetMetageneration

func (x *StorageObjectData) SetMetageneration(v int64)

func (*StorageObjectData) SetName

func (x *StorageObjectData) SetName(v string)

func (*StorageObjectData) SetRetentionExpirationTime

func (x *StorageObjectData) SetRetentionExpirationTime(v *timestamppb.Timestamp)
func (x *StorageObjectData) SetSelfLink(v string)

func (*StorageObjectData) SetSize

func (x *StorageObjectData) SetSize(v int64)

func (*StorageObjectData) SetStorageClass

func (x *StorageObjectData) SetStorageClass(v string)

func (*StorageObjectData) SetTemporaryHold

func (x *StorageObjectData) SetTemporaryHold(v bool)

func (*StorageObjectData) SetTimeCreated

func (x *StorageObjectData) SetTimeCreated(v *timestamppb.Timestamp)

func (*StorageObjectData) SetTimeDeleted

func (x *StorageObjectData) SetTimeDeleted(v *timestamppb.Timestamp)

func (*StorageObjectData) SetTimeStorageClassUpdated

func (x *StorageObjectData) SetTimeStorageClassUpdated(v *timestamppb.Timestamp)

func (*StorageObjectData) SetUpdated

func (x *StorageObjectData) SetUpdated(v *timestamppb.Timestamp)

func (*StorageObjectData) String

func (x *StorageObjectData) String() string

type StorageObjectData_CustomerEncryption

type StorageObjectData_CustomerEncryption struct {

	// The encryption algorithm.
	EncryptionAlgorithm string `protobuf:"bytes,1,opt,name=encryption_algorithm,json=encryptionAlgorithm,proto3" json:"encryption_algorithm,omitempty"`
	// SHA256 hash value of the encryption key.
	KeySha256 string `protobuf:"bytes,2,opt,name=key_sha256,json=keySha256,proto3" json:"key_sha256,omitempty"`
	// contains filtered or unexported fields
}

Describes the customer-specified mechanism used to store the data at rest.

func (*StorageObjectData_CustomerEncryption) GetEncryptionAlgorithm

func (x *StorageObjectData_CustomerEncryption) GetEncryptionAlgorithm() string

func (*StorageObjectData_CustomerEncryption) GetKeySha256

func (x *StorageObjectData_CustomerEncryption) GetKeySha256() string

func (*StorageObjectData_CustomerEncryption) ProtoMessage

func (*StorageObjectData_CustomerEncryption) ProtoMessage()

func (*StorageObjectData_CustomerEncryption) ProtoReflect

func (*StorageObjectData_CustomerEncryption) Reset

func (*StorageObjectData_CustomerEncryption) SetEncryptionAlgorithm

func (x *StorageObjectData_CustomerEncryption) SetEncryptionAlgorithm(v string)

func (*StorageObjectData_CustomerEncryption) SetKeySha256

func (x *StorageObjectData_CustomerEncryption) SetKeySha256(v string)

func (*StorageObjectData_CustomerEncryption) String

type StorageObjectData_CustomerEncryption_builder

type StorageObjectData_CustomerEncryption_builder struct {

	// The encryption algorithm.
	EncryptionAlgorithm string
	// SHA256 hash value of the encryption key.
	KeySha256 string
	// contains filtered or unexported fields
}

func (StorageObjectData_CustomerEncryption_builder) Build

type StorageObjectData_builder

type StorageObjectData_builder struct {

	// Content-Encoding of the object data, matching
	// [https://tools.ietf.org/html/rfc7231#section-3.1.2.2][RFC 7231 3.1.2.2]
	ContentEncoding string
	// Content-Disposition of the object data, matching
	// [https://tools.ietf.org/html/rfc6266][RFC 6266].
	ContentDisposition string
	// Cache-Control directive for the object data, matching
	// [https://tools.ietf.org/html/rfc7234#section-5.2"][RFC 7234 5.2].
	CacheControl string
	// Content-Language of the object data, matching
	// [https://tools.ietf.org/html/rfc7231#section-3.1.3.2][RFC 7231 3.1.3.2].
	ContentLanguage string
	// The version of the metadata for this object at this generation. Used for
	// preconditions and for detecting changes in metadata. A metageneration
	// number is only meaningful in the context of a particular generation of a
	// particular object.
	Metageneration int64
	// The deletion time of the object. Will be returned if and only if this
	// version of the object has been deleted.
	TimeDeleted *timestamppb.Timestamp
	// Content-Type of the object data, matching
	// [https://tools.ietf.org/html/rfc7231#section-3.1.1.5][RFC 7231 3.1.1.5].
	// If an object is stored without a Content-Type, it is served as
	// `application/octet-stream`.
	ContentType string
	// Content-Length of the object data in bytes, matching
	// [https://tools.ietf.org/html/rfc7230#section-3.3.2][RFC 7230 3.3.2].
	Size int64
	// The creation time of the object.
	// Attempting to set this field will result in an error.
	TimeCreated *timestamppb.Timestamp
	// CRC32c checksum. For more information about using the CRC32c
	// checksum, see
	// [https://cloud.google.com/storage/docs/hashes-etags#_JSONAPI][Hashes and
	// ETags: Best Practices].
	Crc32C string
	// Number of underlying components that make up this object. Components are
	// accumulated by compose operations.
	// Attempting to set this field will result in an error.
	ComponentCount int32
	// MD5 hash of the data; encoded using base64 as per
	// [https://tools.ietf.org/html/rfc4648#section-4][RFC 4648 4]. For more
	// information about using the MD5 hash, see
	// [https://cloud.google.com/storage/docs/hashes-etags#_JSONAPI][Hashes and
	// ETags: Best Practices].
	Md5Hash string
	// HTTP 1.1 Entity tag for the object. See
	// [https://tools.ietf.org/html/rfc7232#section-2.3][RFC 7232 2.3].
	Etag string
	// The modification time of the object metadata.
	Updated *timestamppb.Timestamp
	// Storage class of the object.
	StorageClass string
	// Cloud KMS Key used to encrypt this object, if the object is encrypted by
	// such a key.
	KmsKeyName string
	// The time at which the object's storage class was last changed.
	TimeStorageClassUpdated *timestamppb.Timestamp
	// Whether an object is under temporary hold.
	TemporaryHold bool
	// A server-determined value that specifies the earliest time that the
	// object's retention period expires.
	RetentionExpirationTime *timestamppb.Timestamp
	// User-provided metadata, in key/value pairs.
	Metadata map[string]string
	// Whether an object is under event-based hold.
	EventBasedHold bool
	// The name of the object.
	Name string
	// The ID of the object, including the bucket name, object name, and
	// generation number.
	Id string
	// The name of the bucket containing this object.
	Bucket string
	// The content generation of this object. Used for object versioning.
	// Attempting to set this field will result in an error.
	Generation int64
	// Metadata of customer-supplied encryption key, if the object is encrypted by
	// such a key.
	CustomerEncryption *StorageObjectData_CustomerEncryption
	// Media download link.
	MediaLink string
	// The link to this object.
	SelfLink string
	// The kind of item this is. For objects, this is always "storage#object".
	Kind string
	// contains filtered or unexported fields
}

func (StorageObjectData_builder) Build

Source Files

  • data.pb.go
  • events.pb.go

Jump to