authv1

package
v1.36.11-2024050211440... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var File_google_events_firebase_auth_v1_data_proto protoreflect.FileDescriptor
var File_google_events_firebase_auth_v1_events_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type AuthEventData

type AuthEventData struct {

	// The user identifier in the Firebase app.
	Uid string `protobuf:"bytes,1,opt,name=uid,proto3" json:"uid,omitempty"`
	// The user's primary email, if set.
	Email string `protobuf:"bytes,2,opt,name=email,proto3" json:"email,omitempty"`
	// Whether or not the user's primary email is verified.
	EmailVerified bool `protobuf:"varint,3,opt,name=email_verified,json=emailVerified,proto3" json:"email_verified,omitempty"`
	// The user's display name.
	DisplayName string `protobuf:"bytes,4,opt,name=display_name,json=displayName,proto3" json:"display_name,omitempty"`
	// The user's photo URL.
	Photo_URL string `protobuf:"bytes,5,opt,name=photo_URL,json=photoURL,proto3" json:"photo_URL,omitempty"`
	// Whether the user is disabled.
	Disabled bool `protobuf:"varint,6,opt,name=disabled,proto3" json:"disabled,omitempty"`
	// Additional metadata about the user.
	Metadata *UserMetadata `protobuf:"bytes,7,opt,name=metadata,proto3" json:"metadata,omitempty"`
	// User's info at the providers
	ProviderData []*UserInfo `protobuf:"bytes,8,rep,name=provider_data,json=providerData,proto3" json:"provider_data,omitempty"`
	// The user's phone number.
	PhoneNumber string `protobuf:"bytes,9,opt,name=phone_number,json=phoneNumber,proto3" json:"phone_number,omitempty"`
	// User's custom claims, typically used to define user roles and propagated
	// to an authenticated user's ID token.
	CustomClaims *structpb.Struct `protobuf:"bytes,10,opt,name=custom_claims,json=customClaims,proto3" json:"custom_claims,omitempty"`
	// contains filtered or unexported fields
}

The data within all Firebase Auth events.

func (*AuthEventData) ClearCustomClaims

func (x *AuthEventData) ClearCustomClaims()

func (*AuthEventData) ClearMetadata

func (x *AuthEventData) ClearMetadata()

func (*AuthEventData) GetCustomClaims

func (x *AuthEventData) GetCustomClaims() *structpb.Struct

func (*AuthEventData) GetDisabled

func (x *AuthEventData) GetDisabled() bool

func (*AuthEventData) GetDisplayName

func (x *AuthEventData) GetDisplayName() string

func (*AuthEventData) GetEmail

func (x *AuthEventData) GetEmail() string

func (*AuthEventData) GetEmailVerified

func (x *AuthEventData) GetEmailVerified() bool

func (*AuthEventData) GetMetadata

func (x *AuthEventData) GetMetadata() *UserMetadata

func (*AuthEventData) GetPhoneNumber

func (x *AuthEventData) GetPhoneNumber() string

func (*AuthEventData) GetPhoto_URL

func (x *AuthEventData) GetPhoto_URL() string

func (*AuthEventData) GetProviderData

func (x *AuthEventData) GetProviderData() []*UserInfo

func (*AuthEventData) GetUid

func (x *AuthEventData) GetUid() string

func (*AuthEventData) HasCustomClaims

func (x *AuthEventData) HasCustomClaims() bool

func (*AuthEventData) HasMetadata

func (x *AuthEventData) HasMetadata() bool

func (*AuthEventData) ProtoMessage

func (*AuthEventData) ProtoMessage()

func (*AuthEventData) ProtoReflect

func (x *AuthEventData) ProtoReflect() protoreflect.Message

func (*AuthEventData) Reset

func (x *AuthEventData) Reset()

func (*AuthEventData) SetCustomClaims

func (x *AuthEventData) SetCustomClaims(v *structpb.Struct)

func (*AuthEventData) SetDisabled

func (x *AuthEventData) SetDisabled(v bool)

func (*AuthEventData) SetDisplayName

func (x *AuthEventData) SetDisplayName(v string)

func (*AuthEventData) SetEmail

func (x *AuthEventData) SetEmail(v string)

func (*AuthEventData) SetEmailVerified

func (x *AuthEventData) SetEmailVerified(v bool)

func (*AuthEventData) SetMetadata

func (x *AuthEventData) SetMetadata(v *UserMetadata)

func (*AuthEventData) SetPhoneNumber

func (x *AuthEventData) SetPhoneNumber(v string)

func (*AuthEventData) SetPhoto_URL

func (x *AuthEventData) SetPhoto_URL(v string)

func (*AuthEventData) SetProviderData

func (x *AuthEventData) SetProviderData(v []*UserInfo)

func (*AuthEventData) SetUid

func (x *AuthEventData) SetUid(v string)

func (*AuthEventData) String

func (x *AuthEventData) String() string

type AuthEventData_builder

type AuthEventData_builder struct {

	// The user identifier in the Firebase app.
	Uid string
	// The user's primary email, if set.
	Email string
	// Whether or not the user's primary email is verified.
	EmailVerified bool
	// The user's display name.
	DisplayName string
	// The user's photo URL.
	Photo_URL string
	// Whether the user is disabled.
	Disabled bool
	// Additional metadata about the user.
	Metadata *UserMetadata
	// User's info at the providers
	ProviderData []*UserInfo
	// The user's phone number.
	PhoneNumber string
	// User's custom claims, typically used to define user roles and propagated
	// to an authenticated user's ID token.
	CustomClaims *structpb.Struct
	// contains filtered or unexported fields
}

func (AuthEventData_builder) Build

type UserCreatedEvent

type UserCreatedEvent struct {

	// The data associated with the event.
	Data *AuthEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

The CloudEvent raised when a Firebase user is created.

func (*UserCreatedEvent) ClearData

func (x *UserCreatedEvent) ClearData()

func (*UserCreatedEvent) GetData

func (x *UserCreatedEvent) GetData() *AuthEventData

func (*UserCreatedEvent) HasData

func (x *UserCreatedEvent) HasData() bool

func (*UserCreatedEvent) ProtoMessage

func (*UserCreatedEvent) ProtoMessage()

func (*UserCreatedEvent) ProtoReflect

func (x *UserCreatedEvent) ProtoReflect() protoreflect.Message

func (*UserCreatedEvent) Reset

func (x *UserCreatedEvent) Reset()

func (*UserCreatedEvent) SetData

func (x *UserCreatedEvent) SetData(v *AuthEventData)

func (*UserCreatedEvent) String

func (x *UserCreatedEvent) String() string

type UserCreatedEvent_builder

type UserCreatedEvent_builder struct {

	// The data associated with the event.
	Data *AuthEventData
	// contains filtered or unexported fields
}

func (UserCreatedEvent_builder) Build

type UserDeletedEvent

type UserDeletedEvent struct {

	// The data associated with the event.
	Data *AuthEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

The CloudEvent raised when a Firebase user is deleted.

func (*UserDeletedEvent) ClearData

func (x *UserDeletedEvent) ClearData()

func (*UserDeletedEvent) GetData

func (x *UserDeletedEvent) GetData() *AuthEventData

func (*UserDeletedEvent) HasData

func (x *UserDeletedEvent) HasData() bool

func (*UserDeletedEvent) ProtoMessage

func (*UserDeletedEvent) ProtoMessage()

func (*UserDeletedEvent) ProtoReflect

func (x *UserDeletedEvent) ProtoReflect() protoreflect.Message

func (*UserDeletedEvent) Reset

func (x *UserDeletedEvent) Reset()

func (*UserDeletedEvent) SetData

func (x *UserDeletedEvent) SetData(v *AuthEventData)

func (*UserDeletedEvent) String

func (x *UserDeletedEvent) String() string

type UserDeletedEvent_builder

type UserDeletedEvent_builder struct {

	// The data associated with the event.
	Data *AuthEventData
	// contains filtered or unexported fields
}

func (UserDeletedEvent_builder) Build

type UserInfo

type UserInfo struct {

	// The user identifier for the linked provider.
	Uid string `protobuf:"bytes,1,opt,name=uid,proto3" json:"uid,omitempty"`
	// The email for the linked provider.
	Email string `protobuf:"bytes,2,opt,name=email,proto3" json:"email,omitempty"`
	// The display name for the linked provider.
	DisplayName string `protobuf:"bytes,3,opt,name=display_name,json=displayName,proto3" json:"display_name,omitempty"`
	// The photo URL for the linked provider.
	Photo_URL string `protobuf:"bytes,4,opt,name=photo_URL,json=photoURL,proto3" json:"photo_URL,omitempty"`
	// The linked provider ID (e.g. "google.com" for the Google provider).
	ProviderId string `protobuf:"bytes,5,opt,name=provider_id,json=providerId,proto3" json:"provider_id,omitempty"`
	// contains filtered or unexported fields
}

User's info at the identity provider

func (*UserInfo) GetDisplayName

func (x *UserInfo) GetDisplayName() string

func (*UserInfo) GetEmail

func (x *UserInfo) GetEmail() string

func (*UserInfo) GetPhoto_URL

func (x *UserInfo) GetPhoto_URL() string

func (*UserInfo) GetProviderId

func (x *UserInfo) GetProviderId() string

func (*UserInfo) GetUid

func (x *UserInfo) GetUid() string

func (*UserInfo) ProtoMessage

func (*UserInfo) ProtoMessage()

func (*UserInfo) ProtoReflect

func (x *UserInfo) ProtoReflect() protoreflect.Message

func (*UserInfo) Reset

func (x *UserInfo) Reset()

func (*UserInfo) SetDisplayName

func (x *UserInfo) SetDisplayName(v string)

func (*UserInfo) SetEmail

func (x *UserInfo) SetEmail(v string)

func (*UserInfo) SetPhoto_URL

func (x *UserInfo) SetPhoto_URL(v string)

func (*UserInfo) SetProviderId

func (x *UserInfo) SetProviderId(v string)

func (*UserInfo) SetUid

func (x *UserInfo) SetUid(v string)

func (*UserInfo) String

func (x *UserInfo) String() string

type UserInfo_builder

type UserInfo_builder struct {

	// The user identifier for the linked provider.
	Uid string
	// The email for the linked provider.
	Email string
	// The display name for the linked provider.
	DisplayName string
	// The photo URL for the linked provider.
	Photo_URL string
	// The linked provider ID (e.g. "google.com" for the Google provider).
	ProviderId string
	// contains filtered or unexported fields
}

func (UserInfo_builder) Build

func (b0 UserInfo_builder) Build() *UserInfo

type UserMetadata

type UserMetadata struct {

	// The date the user was created.
	CreateTime *timestamppb.Timestamp `protobuf:"bytes,1,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
	// The date the user last signed in.
	LastSignInTime *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=last_sign_in_time,json=lastSignInTime,proto3" json:"last_sign_in_time,omitempty"`
	// contains filtered or unexported fields
}

Additional metadata about the user.

func (*UserMetadata) ClearCreateTime

func (x *UserMetadata) ClearCreateTime()

func (*UserMetadata) ClearLastSignInTime

func (x *UserMetadata) ClearLastSignInTime()

func (*UserMetadata) GetCreateTime

func (x *UserMetadata) GetCreateTime() *timestamppb.Timestamp

func (*UserMetadata) GetLastSignInTime

func (x *UserMetadata) GetLastSignInTime() *timestamppb.Timestamp

func (*UserMetadata) HasCreateTime

func (x *UserMetadata) HasCreateTime() bool

func (*UserMetadata) HasLastSignInTime

func (x *UserMetadata) HasLastSignInTime() bool

func (*UserMetadata) ProtoMessage

func (*UserMetadata) ProtoMessage()

func (*UserMetadata) ProtoReflect

func (x *UserMetadata) ProtoReflect() protoreflect.Message

func (*UserMetadata) Reset

func (x *UserMetadata) Reset()

func (*UserMetadata) SetCreateTime

func (x *UserMetadata) SetCreateTime(v *timestamppb.Timestamp)

func (*UserMetadata) SetLastSignInTime

func (x *UserMetadata) SetLastSignInTime(v *timestamppb.Timestamp)

func (*UserMetadata) String

func (x *UserMetadata) String() string

type UserMetadata_builder

type UserMetadata_builder struct {

	// The date the user was created.
	CreateTime *timestamppb.Timestamp
	// The date the user last signed in.
	LastSignInTime *timestamppb.Timestamp
	// contains filtered or unexported fields
}

func (UserMetadata_builder) Build

func (b0 UserMetadata_builder) Build() *UserMetadata

Source Files

  • data.pb.go
  • events.pb.go

Jump to