firebasealertsv1

package
v1.36.11-2024050211440... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var File_google_events_firebase_firebasealerts_v1_cloud_event_payload_proto protoreflect.FileDescriptor
var File_google_events_firebase_firebasealerts_v1_data_proto protoreflect.FileDescriptor
var File_google_events_firebase_firebasealerts_v1_events_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type AlertData

type AlertData struct {

	// Time that the event has created
	CreateTime *timestamppb.Timestamp `protobuf:"bytes,1,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
	// Time that the event has ended. Optional, only present for alertsthat are
	// ongoing
	EndTime *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=end_time,json=endTime,proto3" json:"end_time,omitempty"`
	// Payload of the event, which includes the details of the specific alert.
	// It's a map of keys of String type and values of various types
	Payload *structpb.Struct `protobuf:"bytes,3,opt,name=payload,proto3" json:"payload,omitempty"`
	// contains filtered or unexported fields
}

The data within all Firebase Alerts.

func (*AlertData) ClearCreateTime

func (x *AlertData) ClearCreateTime()

func (*AlertData) ClearEndTime

func (x *AlertData) ClearEndTime()

func (*AlertData) ClearPayload

func (x *AlertData) ClearPayload()

func (*AlertData) GetCreateTime

func (x *AlertData) GetCreateTime() *timestamppb.Timestamp

func (*AlertData) GetEndTime

func (x *AlertData) GetEndTime() *timestamppb.Timestamp

func (*AlertData) GetPayload

func (x *AlertData) GetPayload() *structpb.Struct

func (*AlertData) HasCreateTime

func (x *AlertData) HasCreateTime() bool

func (*AlertData) HasEndTime

func (x *AlertData) HasEndTime() bool

func (*AlertData) HasPayload

func (x *AlertData) HasPayload() bool

func (*AlertData) ProtoMessage

func (*AlertData) ProtoMessage()

func (*AlertData) ProtoReflect

func (x *AlertData) ProtoReflect() protoreflect.Message

func (*AlertData) Reset

func (x *AlertData) Reset()

func (*AlertData) SetCreateTime

func (x *AlertData) SetCreateTime(v *timestamppb.Timestamp)

func (*AlertData) SetEndTime

func (x *AlertData) SetEndTime(v *timestamppb.Timestamp)

func (*AlertData) SetPayload

func (x *AlertData) SetPayload(v *structpb.Struct)

func (*AlertData) String

func (x *AlertData) String() string

type AlertData_builder

type AlertData_builder struct {

	// Time that the event has created
	CreateTime *timestamppb.Timestamp
	// Time that the event has ended. Optional, only present for alertsthat are
	// ongoing
	EndTime *timestamppb.Timestamp
	// Payload of the event, which includes the details of the specific alert.
	// It's a map of keys of String type and values of various types
	Payload *structpb.Struct
	// contains filtered or unexported fields
}

func (AlertData_builder) Build

func (b0 AlertData_builder) Build() *AlertData

type AlertPublishedEvent

type AlertPublishedEvent struct {

	// The data associated with the event.
	Data *AlertData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

The CloudEvent raised when a alert has been published by Firebase Alerts.

func (*AlertPublishedEvent) ClearData

func (x *AlertPublishedEvent) ClearData()

func (*AlertPublishedEvent) GetData

func (x *AlertPublishedEvent) GetData() *AlertData

func (*AlertPublishedEvent) HasData

func (x *AlertPublishedEvent) HasData() bool

func (*AlertPublishedEvent) ProtoMessage

func (*AlertPublishedEvent) ProtoMessage()

func (*AlertPublishedEvent) ProtoReflect

func (x *AlertPublishedEvent) ProtoReflect() protoreflect.Message

func (*AlertPublishedEvent) Reset

func (x *AlertPublishedEvent) Reset()

func (*AlertPublishedEvent) SetData

func (x *AlertPublishedEvent) SetData(v *AlertData)

func (*AlertPublishedEvent) String

func (x *AlertPublishedEvent) String() string

type AlertPublishedEvent_builder

type AlertPublishedEvent_builder struct {

	// The data associated with the event.
	Data *AlertData
	// contains filtered or unexported fields
}

func (AlertPublishedEvent_builder) Build

type AppDistroInAppFeedbackPayload

type AppDistroInAppFeedbackPayload struct {

	// Resource name. Format:
	// projects/{project_number}/apps/{app_id}/releases/{release_id}/feedbackReports/{feedback_id}
	FeedbackReport string `protobuf:"bytes,1,opt,name=feedback_report,json=feedbackReport,proto3" json:"feedback_report,omitempty"`
	// Deep link back to the Firebase console.
	FeedbackConsoleUri string `protobuf:"bytes,8,opt,name=feedback_console_uri,json=feedbackConsoleUri,proto3" json:"feedback_console_uri,omitempty"`
	// Name of the tester.
	TesterName string `protobuf:"bytes,2,opt,name=tester_name,json=testerName,proto3" json:"tester_name,omitempty"`
	// Email address of the tester.
	TesterEmail string `protobuf:"bytes,3,opt,name=tester_email,json=testerEmail,proto3" json:"tester_email,omitempty"`
	// Version consisting of `versionName` and `versionCode` for Android and
	// `CFBundleShortVersionString` and `CFBundleVersion` for iOS.
	AppVersion string `protobuf:"bytes,9,opt,name=app_version,json=appVersion,proto3" json:"app_version,omitempty"`
	// Text entered by the tester.
	Text string `protobuf:"bytes,6,opt,name=text,proto3" json:"text,omitempty"`
	// URI to download screenshot.  This URI is fast expiring.
	ScreenshotUri string `protobuf:"bytes,7,opt,name=screenshot_uri,json=screenshotUri,proto3" json:"screenshot_uri,omitempty"`
	// contains filtered or unexported fields
}

func (*AppDistroInAppFeedbackPayload) GetAppVersion

func (x *AppDistroInAppFeedbackPayload) GetAppVersion() string

func (*AppDistroInAppFeedbackPayload) GetFeedbackConsoleUri

func (x *AppDistroInAppFeedbackPayload) GetFeedbackConsoleUri() string

func (*AppDistroInAppFeedbackPayload) GetFeedbackReport

func (x *AppDistroInAppFeedbackPayload) GetFeedbackReport() string

func (*AppDistroInAppFeedbackPayload) GetScreenshotUri

func (x *AppDistroInAppFeedbackPayload) GetScreenshotUri() string

func (*AppDistroInAppFeedbackPayload) GetTesterEmail

func (x *AppDistroInAppFeedbackPayload) GetTesterEmail() string

func (*AppDistroInAppFeedbackPayload) GetTesterName

func (x *AppDistroInAppFeedbackPayload) GetTesterName() string

func (*AppDistroInAppFeedbackPayload) GetText

func (*AppDistroInAppFeedbackPayload) ProtoMessage

func (*AppDistroInAppFeedbackPayload) ProtoMessage()

func (*AppDistroInAppFeedbackPayload) ProtoReflect

func (*AppDistroInAppFeedbackPayload) Reset

func (x *AppDistroInAppFeedbackPayload) Reset()

func (*AppDistroInAppFeedbackPayload) SetAppVersion

func (x *AppDistroInAppFeedbackPayload) SetAppVersion(v string)

func (*AppDistroInAppFeedbackPayload) SetFeedbackConsoleUri

func (x *AppDistroInAppFeedbackPayload) SetFeedbackConsoleUri(v string)

func (*AppDistroInAppFeedbackPayload) SetFeedbackReport

func (x *AppDistroInAppFeedbackPayload) SetFeedbackReport(v string)

func (*AppDistroInAppFeedbackPayload) SetScreenshotUri

func (x *AppDistroInAppFeedbackPayload) SetScreenshotUri(v string)

func (*AppDistroInAppFeedbackPayload) SetTesterEmail

func (x *AppDistroInAppFeedbackPayload) SetTesterEmail(v string)

func (*AppDistroInAppFeedbackPayload) SetTesterName

func (x *AppDistroInAppFeedbackPayload) SetTesterName(v string)

func (*AppDistroInAppFeedbackPayload) SetText

func (x *AppDistroInAppFeedbackPayload) SetText(v string)

func (*AppDistroInAppFeedbackPayload) String

type AppDistroInAppFeedbackPayload_builder

type AppDistroInAppFeedbackPayload_builder struct {

	// Resource name. Format:
	// projects/{project_number}/apps/{app_id}/releases/{release_id}/feedbackReports/{feedback_id}
	FeedbackReport string
	// Deep link back to the Firebase console.
	FeedbackConsoleUri string
	// Name of the tester.
	TesterName string
	// Email address of the tester.
	TesterEmail string
	// Version consisting of `versionName` and `versionCode` for Android and
	// `CFBundleShortVersionString` and `CFBundleVersion` for iOS.
	AppVersion string
	// Text entered by the tester.
	Text string
	// URI to download screenshot.  This URI is fast expiring.
	ScreenshotUri string
	// contains filtered or unexported fields
}

func (AppDistroInAppFeedbackPayload_builder) Build

type AppDistroNewTesterIosDevicePayload

type AppDistroNewTesterIosDevicePayload struct {
	TesterName             string `protobuf:"bytes,1,opt,name=tester_name,json=testerName,proto3" json:"tester_name,omitempty"`
	TesterEmail            string `protobuf:"bytes,2,opt,name=tester_email,json=testerEmail,proto3" json:"tester_email,omitempty"`
	TesterDeviceModelName  string `` /* 128-byte string literal not displayed */
	TesterDeviceIdentifier string `` /* 129-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*AppDistroNewTesterIosDevicePayload) GetTesterDeviceIdentifier

func (x *AppDistroNewTesterIosDevicePayload) GetTesterDeviceIdentifier() string

func (*AppDistroNewTesterIosDevicePayload) GetTesterDeviceModelName

func (x *AppDistroNewTesterIosDevicePayload) GetTesterDeviceModelName() string

func (*AppDistroNewTesterIosDevicePayload) GetTesterEmail

func (x *AppDistroNewTesterIosDevicePayload) GetTesterEmail() string

func (*AppDistroNewTesterIosDevicePayload) GetTesterName

func (x *AppDistroNewTesterIosDevicePayload) GetTesterName() string

func (*AppDistroNewTesterIosDevicePayload) ProtoMessage

func (*AppDistroNewTesterIosDevicePayload) ProtoMessage()

func (*AppDistroNewTesterIosDevicePayload) ProtoReflect

func (*AppDistroNewTesterIosDevicePayload) Reset

func (*AppDistroNewTesterIosDevicePayload) SetTesterDeviceIdentifier

func (x *AppDistroNewTesterIosDevicePayload) SetTesterDeviceIdentifier(v string)

func (*AppDistroNewTesterIosDevicePayload) SetTesterDeviceModelName

func (x *AppDistroNewTesterIosDevicePayload) SetTesterDeviceModelName(v string)

func (*AppDistroNewTesterIosDevicePayload) SetTesterEmail

func (x *AppDistroNewTesterIosDevicePayload) SetTesterEmail(v string)

func (*AppDistroNewTesterIosDevicePayload) SetTesterName

func (x *AppDistroNewTesterIosDevicePayload) SetTesterName(v string)

func (*AppDistroNewTesterIosDevicePayload) String

type AppDistroNewTesterIosDevicePayload_builder

type AppDistroNewTesterIosDevicePayload_builder struct {
	TesterName             string
	TesterEmail            string
	TesterDeviceModelName  string
	TesterDeviceIdentifier string
	// contains filtered or unexported fields
}

func (AppDistroNewTesterIosDevicePayload_builder) Build

type BillingPlanAutomatedUpdatePayload

type BillingPlanAutomatedUpdatePayload struct {

	// A Firebase plan
	BillingPlan string `protobuf:"bytes,1,opt,name=billing_plan,json=billingPlan,proto3" json:"billing_plan,omitempty"`
	// The type of the notification, e.g. upgrade, downgrade
	NotificationType string `protobuf:"bytes,2,opt,name=notification_type,json=notificationType,proto3" json:"notification_type,omitempty"`
	// contains filtered or unexported fields
}

func (*BillingPlanAutomatedUpdatePayload) GetBillingPlan

func (x *BillingPlanAutomatedUpdatePayload) GetBillingPlan() string

func (*BillingPlanAutomatedUpdatePayload) GetNotificationType

func (x *BillingPlanAutomatedUpdatePayload) GetNotificationType() string

func (*BillingPlanAutomatedUpdatePayload) ProtoMessage

func (*BillingPlanAutomatedUpdatePayload) ProtoMessage()

func (*BillingPlanAutomatedUpdatePayload) ProtoReflect

func (*BillingPlanAutomatedUpdatePayload) Reset

func (*BillingPlanAutomatedUpdatePayload) SetBillingPlan

func (x *BillingPlanAutomatedUpdatePayload) SetBillingPlan(v string)

func (*BillingPlanAutomatedUpdatePayload) SetNotificationType

func (x *BillingPlanAutomatedUpdatePayload) SetNotificationType(v string)

func (*BillingPlanAutomatedUpdatePayload) String

type BillingPlanAutomatedUpdatePayload_builder

type BillingPlanAutomatedUpdatePayload_builder struct {

	// A Firebase plan
	BillingPlan string
	// The type of the notification, e.g. upgrade, downgrade
	NotificationType string
	// contains filtered or unexported fields
}

func (BillingPlanAutomatedUpdatePayload_builder) Build

type BillingPlanUpdatePayload

type BillingPlanUpdatePayload struct {

	// A Firebase plan
	BillingPlan string `protobuf:"bytes,1,opt,name=billing_plan,json=billingPlan,proto3" json:"billing_plan,omitempty"`
	// The email address of the person that triggered billing plan change
	PrincipalEmail string `protobuf:"bytes,2,opt,name=principal_email,json=principalEmail,proto3" json:"principal_email,omitempty"`
	// The type of the notification, e.g. upgrade, downgrade
	NotificationType string `protobuf:"bytes,3,opt,name=notification_type,json=notificationType,proto3" json:"notification_type,omitempty"`
	// contains filtered or unexported fields
}

func (*BillingPlanUpdatePayload) GetBillingPlan

func (x *BillingPlanUpdatePayload) GetBillingPlan() string

func (*BillingPlanUpdatePayload) GetNotificationType

func (x *BillingPlanUpdatePayload) GetNotificationType() string

func (*BillingPlanUpdatePayload) GetPrincipalEmail

func (x *BillingPlanUpdatePayload) GetPrincipalEmail() string

func (*BillingPlanUpdatePayload) ProtoMessage

func (*BillingPlanUpdatePayload) ProtoMessage()

func (*BillingPlanUpdatePayload) ProtoReflect

func (x *BillingPlanUpdatePayload) ProtoReflect() protoreflect.Message

func (*BillingPlanUpdatePayload) Reset

func (x *BillingPlanUpdatePayload) Reset()

func (*BillingPlanUpdatePayload) SetBillingPlan

func (x *BillingPlanUpdatePayload) SetBillingPlan(v string)

func (*BillingPlanUpdatePayload) SetNotificationType

func (x *BillingPlanUpdatePayload) SetNotificationType(v string)

func (*BillingPlanUpdatePayload) SetPrincipalEmail

func (x *BillingPlanUpdatePayload) SetPrincipalEmail(v string)

func (*BillingPlanUpdatePayload) String

func (x *BillingPlanUpdatePayload) String() string

type BillingPlanUpdatePayload_builder

type BillingPlanUpdatePayload_builder struct {

	// A Firebase plan
	BillingPlan string
	// The email address of the person that triggered billing plan change
	PrincipalEmail string
	// The type of the notification, e.g. upgrade, downgrade
	NotificationType string
	// contains filtered or unexported fields
}

func (BillingPlanUpdatePayload_builder) Build

type CrashlyticsIssue

type CrashlyticsIssue struct {
	Id         string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	Title      string `protobuf:"bytes,2,opt,name=title,proto3" json:"title,omitempty"`
	Subtitle   string `protobuf:"bytes,3,opt,name=subtitle,proto3" json:"subtitle,omitempty"`
	AppVersion string `protobuf:"bytes,4,opt,name=app_version,json=appVersion,proto3" json:"app_version,omitempty"`
	// contains filtered or unexported fields
}

Basic information of the Crashlytics issue

func (*CrashlyticsIssue) GetAppVersion

func (x *CrashlyticsIssue) GetAppVersion() string

func (*CrashlyticsIssue) GetId

func (x *CrashlyticsIssue) GetId() string

func (*CrashlyticsIssue) GetSubtitle

func (x *CrashlyticsIssue) GetSubtitle() string

func (*CrashlyticsIssue) GetTitle

func (x *CrashlyticsIssue) GetTitle() string

func (*CrashlyticsIssue) ProtoMessage

func (*CrashlyticsIssue) ProtoMessage()

func (*CrashlyticsIssue) ProtoReflect

func (x *CrashlyticsIssue) ProtoReflect() protoreflect.Message

func (*CrashlyticsIssue) Reset

func (x *CrashlyticsIssue) Reset()

func (*CrashlyticsIssue) SetAppVersion

func (x *CrashlyticsIssue) SetAppVersion(v string)

func (*CrashlyticsIssue) SetId

func (x *CrashlyticsIssue) SetId(v string)

func (*CrashlyticsIssue) SetSubtitle

func (x *CrashlyticsIssue) SetSubtitle(v string)

func (*CrashlyticsIssue) SetTitle

func (x *CrashlyticsIssue) SetTitle(v string)

func (*CrashlyticsIssue) String

func (x *CrashlyticsIssue) String() string

type CrashlyticsIssue_builder

type CrashlyticsIssue_builder struct {
	Id         string
	Title      string
	Subtitle   string
	AppVersion string
	// contains filtered or unexported fields
}

func (CrashlyticsIssue_builder) Build

type CrashlyticsMissingSymbolsPayload

type CrashlyticsMissingSymbolsPayload struct {
	AppVersion string `protobuf:"bytes,1,opt,name=app_version,json=appVersion,proto3" json:"app_version,omitempty"`
	Uuid       string `protobuf:"bytes,2,opt,name=uuid,proto3" json:"uuid,omitempty"`
	// contains filtered or unexported fields
}

func (*CrashlyticsMissingSymbolsPayload) GetAppVersion

func (x *CrashlyticsMissingSymbolsPayload) GetAppVersion() string

func (*CrashlyticsMissingSymbolsPayload) GetUuid

func (*CrashlyticsMissingSymbolsPayload) ProtoMessage

func (*CrashlyticsMissingSymbolsPayload) ProtoMessage()

func (*CrashlyticsMissingSymbolsPayload) ProtoReflect

func (*CrashlyticsMissingSymbolsPayload) Reset

func (*CrashlyticsMissingSymbolsPayload) SetAppVersion

func (x *CrashlyticsMissingSymbolsPayload) SetAppVersion(v string)

func (*CrashlyticsMissingSymbolsPayload) SetUuid

func (*CrashlyticsMissingSymbolsPayload) String

type CrashlyticsMissingSymbolsPayload_builder

type CrashlyticsMissingSymbolsPayload_builder struct {
	AppVersion string
	Uuid       string
	// contains filtered or unexported fields
}

func (CrashlyticsMissingSymbolsPayload_builder) Build

type CrashlyticsNewAnrIssuePayload

type CrashlyticsNewAnrIssuePayload struct {
	Issue *CrashlyticsIssue `protobuf:"bytes,1,opt,name=issue,proto3" json:"issue,omitempty"`
	// contains filtered or unexported fields
}

func (*CrashlyticsNewAnrIssuePayload) ClearIssue

func (x *CrashlyticsNewAnrIssuePayload) ClearIssue()

func (*CrashlyticsNewAnrIssuePayload) GetIssue

func (*CrashlyticsNewAnrIssuePayload) HasIssue

func (x *CrashlyticsNewAnrIssuePayload) HasIssue() bool

func (*CrashlyticsNewAnrIssuePayload) ProtoMessage

func (*CrashlyticsNewAnrIssuePayload) ProtoMessage()

func (*CrashlyticsNewAnrIssuePayload) ProtoReflect

func (*CrashlyticsNewAnrIssuePayload) Reset

func (x *CrashlyticsNewAnrIssuePayload) Reset()

func (*CrashlyticsNewAnrIssuePayload) SetIssue

func (*CrashlyticsNewAnrIssuePayload) String

type CrashlyticsNewAnrIssuePayload_builder

type CrashlyticsNewAnrIssuePayload_builder struct {
	Issue *CrashlyticsIssue
	// contains filtered or unexported fields
}

func (CrashlyticsNewAnrIssuePayload_builder) Build

type CrashlyticsNewFatalIssuePayload

type CrashlyticsNewFatalIssuePayload struct {

	// Basic information of the Crashlytics issue
	Issue *CrashlyticsIssue `protobuf:"bytes,1,opt,name=issue,proto3" json:"issue,omitempty"`
	// contains filtered or unexported fields
}

func (*CrashlyticsNewFatalIssuePayload) ClearIssue

func (x *CrashlyticsNewFatalIssuePayload) ClearIssue()

func (*CrashlyticsNewFatalIssuePayload) GetIssue

func (*CrashlyticsNewFatalIssuePayload) HasIssue

func (x *CrashlyticsNewFatalIssuePayload) HasIssue() bool

func (*CrashlyticsNewFatalIssuePayload) ProtoMessage

func (*CrashlyticsNewFatalIssuePayload) ProtoMessage()

func (*CrashlyticsNewFatalIssuePayload) ProtoReflect

func (*CrashlyticsNewFatalIssuePayload) Reset

func (*CrashlyticsNewFatalIssuePayload) SetIssue

func (*CrashlyticsNewFatalIssuePayload) String

type CrashlyticsNewFatalIssuePayload_builder

type CrashlyticsNewFatalIssuePayload_builder struct {

	// Basic information of the Crashlytics issue
	Issue *CrashlyticsIssue
	// contains filtered or unexported fields
}

func (CrashlyticsNewFatalIssuePayload_builder) Build

type CrashlyticsNewNonfatalIssuePayload

type CrashlyticsNewNonfatalIssuePayload struct {

	// Basic information of the Crashlytics issue
	Issue *CrashlyticsIssue `protobuf:"bytes,1,opt,name=issue,proto3" json:"issue,omitempty"`
	// contains filtered or unexported fields
}

func (*CrashlyticsNewNonfatalIssuePayload) ClearIssue

func (x *CrashlyticsNewNonfatalIssuePayload) ClearIssue()

func (*CrashlyticsNewNonfatalIssuePayload) GetIssue

func (*CrashlyticsNewNonfatalIssuePayload) HasIssue

func (*CrashlyticsNewNonfatalIssuePayload) ProtoMessage

func (*CrashlyticsNewNonfatalIssuePayload) ProtoMessage()

func (*CrashlyticsNewNonfatalIssuePayload) ProtoReflect

func (*CrashlyticsNewNonfatalIssuePayload) Reset

func (*CrashlyticsNewNonfatalIssuePayload) SetIssue

func (*CrashlyticsNewNonfatalIssuePayload) String

type CrashlyticsNewNonfatalIssuePayload_builder

type CrashlyticsNewNonfatalIssuePayload_builder struct {

	// Basic information of the Crashlytics issue
	Issue *CrashlyticsIssue
	// contains filtered or unexported fields
}

func (CrashlyticsNewNonfatalIssuePayload_builder) Build

type CrashlyticsRegressionAlertPayload

type CrashlyticsRegressionAlertPayload struct {

	// The type of the Crashlytics issue, e.g. new fatal, new nonfatal, ANR
	Type string `protobuf:"bytes,1,opt,name=type,proto3" json:"type,omitempty"`
	// Basic information of the Crashlytics issue
	Issue *CrashlyticsIssue `protobuf:"bytes,2,opt,name=issue,proto3" json:"issue,omitempty"`
	// The time that the Crashlytics issues was most recently resolved before it
	// began to reoccur
	ResolveTime *timestamppb.Timestamp `protobuf:"bytes,3,opt,name=resolve_time,json=resolveTime,proto3" json:"resolve_time,omitempty"`
	// contains filtered or unexported fields
}

func (*CrashlyticsRegressionAlertPayload) ClearIssue

func (x *CrashlyticsRegressionAlertPayload) ClearIssue()

func (*CrashlyticsRegressionAlertPayload) ClearResolveTime

func (x *CrashlyticsRegressionAlertPayload) ClearResolveTime()

func (*CrashlyticsRegressionAlertPayload) GetIssue

func (*CrashlyticsRegressionAlertPayload) GetResolveTime

func (*CrashlyticsRegressionAlertPayload) GetType

func (*CrashlyticsRegressionAlertPayload) HasIssue

func (*CrashlyticsRegressionAlertPayload) HasResolveTime

func (x *CrashlyticsRegressionAlertPayload) HasResolveTime() bool

func (*CrashlyticsRegressionAlertPayload) ProtoMessage

func (*CrashlyticsRegressionAlertPayload) ProtoMessage()

func (*CrashlyticsRegressionAlertPayload) ProtoReflect

func (*CrashlyticsRegressionAlertPayload) Reset

func (*CrashlyticsRegressionAlertPayload) SetIssue

func (*CrashlyticsRegressionAlertPayload) SetResolveTime

func (*CrashlyticsRegressionAlertPayload) SetType

func (*CrashlyticsRegressionAlertPayload) String

type CrashlyticsRegressionAlertPayload_builder

type CrashlyticsRegressionAlertPayload_builder struct {

	// The type of the Crashlytics issue, e.g. new fatal, new nonfatal, ANR
	Type string
	// Basic information of the Crashlytics issue
	Issue *CrashlyticsIssue
	// The time that the Crashlytics issues was most recently resolved before it
	// began to reoccur
	ResolveTime *timestamppb.Timestamp
	// contains filtered or unexported fields
}

func (CrashlyticsRegressionAlertPayload_builder) Build

type CrashlyticsStabilityDigestPayload

type CrashlyticsStabilityDigestPayload struct {

	// The date that the digest gets created, issues in the digest should
	// have the same date as the digest date
	DigestDate *date.Date `protobuf:"bytes,5,opt,name=digest_date,json=digestDate,proto3" json:"digest_date,omitempty"`
	// A stability digest contains several trending Crashlytics issues
	TrendingIssues []*CrashlyticsStabilityDigestPayload_TrendingIssueDetails `protobuf:"bytes,6,rep,name=trending_issues,json=trendingIssues,proto3" json:"trending_issues,omitempty"`
	// contains filtered or unexported fields
}

func (*CrashlyticsStabilityDigestPayload) ClearDigestDate

func (x *CrashlyticsStabilityDigestPayload) ClearDigestDate()

func (*CrashlyticsStabilityDigestPayload) GetDigestDate

func (x *CrashlyticsStabilityDigestPayload) GetDigestDate() *date.Date

func (*CrashlyticsStabilityDigestPayload) GetTrendingIssues

func (*CrashlyticsStabilityDigestPayload) HasDigestDate

func (x *CrashlyticsStabilityDigestPayload) HasDigestDate() bool

func (*CrashlyticsStabilityDigestPayload) ProtoMessage

func (*CrashlyticsStabilityDigestPayload) ProtoMessage()

func (*CrashlyticsStabilityDigestPayload) ProtoReflect

func (*CrashlyticsStabilityDigestPayload) Reset

func (*CrashlyticsStabilityDigestPayload) SetDigestDate

func (x *CrashlyticsStabilityDigestPayload) SetDigestDate(v *date.Date)

func (*CrashlyticsStabilityDigestPayload) SetTrendingIssues

func (*CrashlyticsStabilityDigestPayload) String

type CrashlyticsStabilityDigestPayload_TrendingIssueDetails

type CrashlyticsStabilityDigestPayload_TrendingIssueDetails struct {

	// The type of the Crashlytics issue, e.g. new fatal, new nonfatal, ANR
	Type string `protobuf:"bytes,1,opt,name=type,proto3" json:"type,omitempty"`
	// Basic information of the Crashlytics issue
	Issue *CrashlyticsIssue `protobuf:"bytes,2,opt,name=issue,proto3" json:"issue,omitempty"`
	// The number of crashes that occurred with the issue
	EventCount int64 `protobuf:"varint,3,opt,name=event_count,json=eventCount,proto3" json:"event_count,omitempty"`
	// The number of distinct users that were affected by the issue
	UserCount int64 `protobuf:"varint,4,opt,name=user_count,json=userCount,proto3" json:"user_count,omitempty"`
	// contains filtered or unexported fields
}

func (*CrashlyticsStabilityDigestPayload_TrendingIssueDetails) ClearIssue

func (*CrashlyticsStabilityDigestPayload_TrendingIssueDetails) GetEventCount

func (*CrashlyticsStabilityDigestPayload_TrendingIssueDetails) GetIssue

func (*CrashlyticsStabilityDigestPayload_TrendingIssueDetails) GetType

func (*CrashlyticsStabilityDigestPayload_TrendingIssueDetails) GetUserCount

func (*CrashlyticsStabilityDigestPayload_TrendingIssueDetails) HasIssue

func (*CrashlyticsStabilityDigestPayload_TrendingIssueDetails) ProtoMessage

func (*CrashlyticsStabilityDigestPayload_TrendingIssueDetails) ProtoReflect

func (*CrashlyticsStabilityDigestPayload_TrendingIssueDetails) Reset

func (*CrashlyticsStabilityDigestPayload_TrendingIssueDetails) SetEventCount

func (*CrashlyticsStabilityDigestPayload_TrendingIssueDetails) SetIssue

func (*CrashlyticsStabilityDigestPayload_TrendingIssueDetails) SetType

func (*CrashlyticsStabilityDigestPayload_TrendingIssueDetails) SetUserCount

func (*CrashlyticsStabilityDigestPayload_TrendingIssueDetails) String

type CrashlyticsStabilityDigestPayload_TrendingIssueDetails_builder

type CrashlyticsStabilityDigestPayload_TrendingIssueDetails_builder struct {

	// The type of the Crashlytics issue, e.g. new fatal, new nonfatal, ANR
	Type string
	// Basic information of the Crashlytics issue
	Issue *CrashlyticsIssue
	// The number of crashes that occurred with the issue
	EventCount int64
	// The number of distinct users that were affected by the issue
	UserCount int64
	// contains filtered or unexported fields
}

func (CrashlyticsStabilityDigestPayload_TrendingIssueDetails_builder) Build

type CrashlyticsStabilityDigestPayload_builder

type CrashlyticsStabilityDigestPayload_builder struct {

	// The date that the digest gets created, issues in the digest should
	// have the same date as the digest date
	DigestDate *date.Date
	// A stability digest contains several trending Crashlytics issues
	TrendingIssues []*CrashlyticsStabilityDigestPayload_TrendingIssueDetails
	// contains filtered or unexported fields
}

func (CrashlyticsStabilityDigestPayload_builder) Build

type CrashlyticsVelocityAlertPayload

type CrashlyticsVelocityAlertPayload struct {

	// Basic information of the Crashlytics issue
	Issue *CrashlyticsIssue `protobuf:"bytes,1,opt,name=issue,proto3" json:"issue,omitempty"`
	// The time that the Crashlytics issue gets created
	CreateTime *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
	// The number of user sessions for the given app version that had this
	// specific crash issue in the time period used to trigger the velocity alert,
	// which is currently 1h
	CrashCount int64 `protobuf:"varint,3,opt,name=crash_count,json=crashCount,proto3" json:"crash_count,omitempty"`
	// The percentage of user sessions for the given app version that had this
	// specific crash issue in the time period used to trigger the velocity alert,
	// which is currently 1h
	CrashPercentage float64 `protobuf:"fixed64,4,opt,name=crash_percentage,json=crashPercentage,proto3" json:"crash_percentage,omitempty"`
	// The first app version where this issue was seen, and not necessarily the
	// version that has triggered the alert
	FirstVersion string `protobuf:"bytes,5,opt,name=first_version,json=firstVersion,proto3" json:"first_version,omitempty"`
	// contains filtered or unexported fields
}

func (*CrashlyticsVelocityAlertPayload) ClearCreateTime

func (x *CrashlyticsVelocityAlertPayload) ClearCreateTime()

func (*CrashlyticsVelocityAlertPayload) ClearIssue

func (x *CrashlyticsVelocityAlertPayload) ClearIssue()

func (*CrashlyticsVelocityAlertPayload) GetCrashCount

func (x *CrashlyticsVelocityAlertPayload) GetCrashCount() int64

func (*CrashlyticsVelocityAlertPayload) GetCrashPercentage

func (x *CrashlyticsVelocityAlertPayload) GetCrashPercentage() float64

func (*CrashlyticsVelocityAlertPayload) GetCreateTime

func (*CrashlyticsVelocityAlertPayload) GetFirstVersion

func (x *CrashlyticsVelocityAlertPayload) GetFirstVersion() string

func (*CrashlyticsVelocityAlertPayload) GetIssue

func (*CrashlyticsVelocityAlertPayload) HasCreateTime

func (x *CrashlyticsVelocityAlertPayload) HasCreateTime() bool

func (*CrashlyticsVelocityAlertPayload) HasIssue

func (x *CrashlyticsVelocityAlertPayload) HasIssue() bool

func (*CrashlyticsVelocityAlertPayload) ProtoMessage

func (*CrashlyticsVelocityAlertPayload) ProtoMessage()

func (*CrashlyticsVelocityAlertPayload) ProtoReflect

func (*CrashlyticsVelocityAlertPayload) Reset

func (*CrashlyticsVelocityAlertPayload) SetCrashCount

func (x *CrashlyticsVelocityAlertPayload) SetCrashCount(v int64)

func (*CrashlyticsVelocityAlertPayload) SetCrashPercentage

func (x *CrashlyticsVelocityAlertPayload) SetCrashPercentage(v float64)

func (*CrashlyticsVelocityAlertPayload) SetCreateTime

func (*CrashlyticsVelocityAlertPayload) SetFirstVersion

func (x *CrashlyticsVelocityAlertPayload) SetFirstVersion(v string)

func (*CrashlyticsVelocityAlertPayload) SetIssue

func (*CrashlyticsVelocityAlertPayload) String

type CrashlyticsVelocityAlertPayload_builder

type CrashlyticsVelocityAlertPayload_builder struct {

	// Basic information of the Crashlytics issue
	Issue *CrashlyticsIssue
	// The time that the Crashlytics issue gets created
	CreateTime *timestamppb.Timestamp
	// The number of user sessions for the given app version that had this
	// specific crash issue in the time period used to trigger the velocity alert,
	// which is currently 1h
	CrashCount int64
	// The percentage of user sessions for the given app version that had this
	// specific crash issue in the time period used to trigger the velocity alert,
	// which is currently 1h
	CrashPercentage float64
	// The first app version where this issue was seen, and not necessarily the
	// version that has triggered the alert
	FirstVersion string
	// contains filtered or unexported fields
}

func (CrashlyticsVelocityAlertPayload_builder) Build

type FireperfThresholdAlertPayload

type FireperfThresholdAlertPayload struct {

	// Name of the trace or network request this alert is for (e.g.
	// my_custom_trace, firebase.com/api/123)
	EventName string `protobuf:"bytes,1,opt,name=event_name,json=eventName,proto3" json:"event_name,omitempty"`
	// The resource type this alert is for (i.e. trace, network request, screen
	// rendering, etc.)
	EventType string `protobuf:"bytes,2,opt,name=event_type,json=eventType,proto3" json:"event_type,omitempty"`
	// The metric type this alert is for (i.e. success rate, response time,
	// duration, etc.)
	MetricType string `protobuf:"bytes,3,opt,name=metric_type,json=metricType,proto3" json:"metric_type,omitempty"`
	// The number of events checked for this alert condition
	NumSamples int64 `protobuf:"varint,4,opt,name=num_samples,json=numSamples,proto3" json:"num_samples,omitempty"`
	// The threshold value of the alert condition without units (e.g. "75", "2.1")
	ThresholdValue float32 `protobuf:"fixed32,5,opt,name=threshold_value,json=thresholdValue,proto3" json:"threshold_value,omitempty"`
	// The unit for the alert threshold (e.g. "percent", "seconds")
	ThresholdUnit string `protobuf:"bytes,6,opt,name=threshold_unit,json=thresholdUnit,proto3" json:"threshold_unit,omitempty"`
	// The percentile of the alert condition, can be 0 if percentile is not
	// applicable to the alert condition; range: [0, 100]
	ConditionPercentile int32 `protobuf:"varint,7,opt,name=condition_percentile,json=conditionPercentile,proto3" json:"condition_percentile,omitempty"`
	// The app version this alert was triggered for, can be empty if the alert is
	// for a network request (because the alert was checked against data from all
	// versions of app) or a web app (where the app is versionless)
	AppVersion string `protobuf:"bytes,8,opt,name=app_version,json=appVersion,proto3" json:"app_version,omitempty"`
	// The value that violated the alert condition (e.g. "76.5", "3")
	ViolationValue float32 `protobuf:"fixed32,9,opt,name=violation_value,json=violationValue,proto3" json:"violation_value,omitempty"`
	// The unit for the violation value (e.g. "percent", "seconds")
	ViolationUnit string `protobuf:"bytes,10,opt,name=violation_unit,json=violationUnit,proto3" json:"violation_unit,omitempty"`
	// The link to Fireconsole to investigate more into this alert
	InvestigateUri string `protobuf:"bytes,11,opt,name=investigate_uri,json=investigateUri,proto3" json:"investigate_uri,omitempty"`
	// contains filtered or unexported fields
}

func (*FireperfThresholdAlertPayload) GetAppVersion

func (x *FireperfThresholdAlertPayload) GetAppVersion() string

func (*FireperfThresholdAlertPayload) GetConditionPercentile

func (x *FireperfThresholdAlertPayload) GetConditionPercentile() int32

func (*FireperfThresholdAlertPayload) GetEventName

func (x *FireperfThresholdAlertPayload) GetEventName() string

func (*FireperfThresholdAlertPayload) GetEventType

func (x *FireperfThresholdAlertPayload) GetEventType() string

func (*FireperfThresholdAlertPayload) GetInvestigateUri

func (x *FireperfThresholdAlertPayload) GetInvestigateUri() string

func (*FireperfThresholdAlertPayload) GetMetricType

func (x *FireperfThresholdAlertPayload) GetMetricType() string

func (*FireperfThresholdAlertPayload) GetNumSamples

func (x *FireperfThresholdAlertPayload) GetNumSamples() int64

func (*FireperfThresholdAlertPayload) GetThresholdUnit

func (x *FireperfThresholdAlertPayload) GetThresholdUnit() string

func (*FireperfThresholdAlertPayload) GetThresholdValue

func (x *FireperfThresholdAlertPayload) GetThresholdValue() float32

func (*FireperfThresholdAlertPayload) GetViolationUnit

func (x *FireperfThresholdAlertPayload) GetViolationUnit() string

func (*FireperfThresholdAlertPayload) GetViolationValue

func (x *FireperfThresholdAlertPayload) GetViolationValue() float32

func (*FireperfThresholdAlertPayload) ProtoMessage

func (*FireperfThresholdAlertPayload) ProtoMessage()

func (*FireperfThresholdAlertPayload) ProtoReflect

func (*FireperfThresholdAlertPayload) Reset

func (x *FireperfThresholdAlertPayload) Reset()

func (*FireperfThresholdAlertPayload) SetAppVersion

func (x *FireperfThresholdAlertPayload) SetAppVersion(v string)

func (*FireperfThresholdAlertPayload) SetConditionPercentile

func (x *FireperfThresholdAlertPayload) SetConditionPercentile(v int32)

func (*FireperfThresholdAlertPayload) SetEventName

func (x *FireperfThresholdAlertPayload) SetEventName(v string)

func (*FireperfThresholdAlertPayload) SetEventType

func (x *FireperfThresholdAlertPayload) SetEventType(v string)

func (*FireperfThresholdAlertPayload) SetInvestigateUri

func (x *FireperfThresholdAlertPayload) SetInvestigateUri(v string)

func (*FireperfThresholdAlertPayload) SetMetricType

func (x *FireperfThresholdAlertPayload) SetMetricType(v string)

func (*FireperfThresholdAlertPayload) SetNumSamples

func (x *FireperfThresholdAlertPayload) SetNumSamples(v int64)

func (*FireperfThresholdAlertPayload) SetThresholdUnit

func (x *FireperfThresholdAlertPayload) SetThresholdUnit(v string)

func (*FireperfThresholdAlertPayload) SetThresholdValue

func (x *FireperfThresholdAlertPayload) SetThresholdValue(v float32)

func (*FireperfThresholdAlertPayload) SetViolationUnit

func (x *FireperfThresholdAlertPayload) SetViolationUnit(v string)

func (*FireperfThresholdAlertPayload) SetViolationValue

func (x *FireperfThresholdAlertPayload) SetViolationValue(v float32)

func (*FireperfThresholdAlertPayload) String

type FireperfThresholdAlertPayload_builder

type FireperfThresholdAlertPayload_builder struct {

	// Name of the trace or network request this alert is for (e.g.
	// my_custom_trace, firebase.com/api/123)
	EventName string
	// The resource type this alert is for (i.e. trace, network request, screen
	// rendering, etc.)
	EventType string
	// The metric type this alert is for (i.e. success rate, response time,
	// duration, etc.)
	MetricType string
	// The number of events checked for this alert condition
	NumSamples int64
	// The threshold value of the alert condition without units (e.g. "75", "2.1")
	ThresholdValue float32
	// The unit for the alert threshold (e.g. "percent", "seconds")
	ThresholdUnit string
	// The percentile of the alert condition, can be 0 if percentile is not
	// applicable to the alert condition; range: [0, 100]
	ConditionPercentile int32
	// The app version this alert was triggered for, can be empty if the alert is
	// for a network request (because the alert was checked against data from all
	// versions of app) or a web app (where the app is versionless)
	AppVersion string
	// The value that violated the alert condition (e.g. "76.5", "3")
	ViolationValue float32
	// The unit for the violation value (e.g. "percent", "seconds")
	ViolationUnit string
	// The link to Fireconsole to investigate more into this alert
	InvestigateUri string
	// contains filtered or unexported fields
}

func (FireperfThresholdAlertPayload_builder) Build

Source Files

  • cloud_event_payload.pb.go
  • data.pb.go
  • events.pb.go

Jump to