remoteconfigv1

package
v1.36.11-2024050211440... Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: unknown License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	RemoteConfigUpdateOrigin_name = map[int32]string{
		0: "REMOTE_CONFIG_UPDATE_ORIGIN_UNSPECIFIED",
		1: "CONSOLE",
		2: "REST_API",
		3: "ADMIN_SDK_NODE",
	}
	RemoteConfigUpdateOrigin_value = map[string]int32{
		"REMOTE_CONFIG_UPDATE_ORIGIN_UNSPECIFIED": 0,
		"CONSOLE":        1,
		"REST_API":       2,
		"ADMIN_SDK_NODE": 3,
	}
)

Enum value maps for RemoteConfigUpdateOrigin.

var (
	RemoteConfigUpdateType_name = map[int32]string{
		0: "REMOTE_CONFIG_UPDATE_TYPE_UNSPECIFIED",
		1: "INCREMENTAL_UPDATE",
		2: "FORCED_UPDATE",
		3: "ROLLBACK",
	}
	RemoteConfigUpdateType_value = map[string]int32{
		"REMOTE_CONFIG_UPDATE_TYPE_UNSPECIFIED": 0,
		"INCREMENTAL_UPDATE":                    1,
		"FORCED_UPDATE":                         2,
		"ROLLBACK":                              3,
	}
)

Enum value maps for RemoteConfigUpdateType.

var File_google_events_firebase_remoteconfig_v1_data_proto protoreflect.FileDescriptor
var File_google_events_firebase_remoteconfig_v1_events_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type RemoteConfigEventData

type RemoteConfigEventData struct {

	// The version number of the version's corresponding Remote Config template.
	VersionNumber int64 `protobuf:"varint,1,opt,name=version_number,json=versionNumber,proto3" json:"version_number,omitempty"`
	// When the Remote Config template was written to the Remote Config server.
	UpdateTime *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=update_time,json=updateTime,proto3" json:"update_time,omitempty"`
	// Aggregation of all metadata fields about the account that performed the
	// update.
	UpdateUser *RemoteConfigUser `protobuf:"bytes,3,opt,name=update_user,json=updateUser,proto3" json:"update_user,omitempty"`
	// The user-provided description of the corresponding Remote Config template.
	Description string `protobuf:"bytes,4,opt,name=description,proto3" json:"description,omitempty"`
	// Where the update action originated.
	UpdateOrigin RemoteConfigUpdateOrigin `` /* 167-byte string literal not displayed */
	// What type of update was made.
	UpdateType RemoteConfigUpdateType `` /* 159-byte string literal not displayed */
	// Only present if this version is the result of a rollback, and will be the
	// version number of the Remote Config template that was rolled-back to.
	RollbackSource int64 `protobuf:"varint,7,opt,name=rollback_source,json=rollbackSource,proto3" json:"rollback_source,omitempty"`
	// contains filtered or unexported fields
}

The data within all Firebase Remote Config events.

func (*RemoteConfigEventData) ClearUpdateTime

func (x *RemoteConfigEventData) ClearUpdateTime()

func (*RemoteConfigEventData) ClearUpdateUser

func (x *RemoteConfigEventData) ClearUpdateUser()

func (*RemoteConfigEventData) GetDescription

func (x *RemoteConfigEventData) GetDescription() string

func (*RemoteConfigEventData) GetRollbackSource

func (x *RemoteConfigEventData) GetRollbackSource() int64

func (*RemoteConfigEventData) GetUpdateOrigin

func (x *RemoteConfigEventData) GetUpdateOrigin() RemoteConfigUpdateOrigin

func (*RemoteConfigEventData) GetUpdateTime

func (x *RemoteConfigEventData) GetUpdateTime() *timestamppb.Timestamp

func (*RemoteConfigEventData) GetUpdateType

func (x *RemoteConfigEventData) GetUpdateType() RemoteConfigUpdateType

func (*RemoteConfigEventData) GetUpdateUser

func (x *RemoteConfigEventData) GetUpdateUser() *RemoteConfigUser

func (*RemoteConfigEventData) GetVersionNumber

func (x *RemoteConfigEventData) GetVersionNumber() int64

func (*RemoteConfigEventData) HasUpdateTime

func (x *RemoteConfigEventData) HasUpdateTime() bool

func (*RemoteConfigEventData) HasUpdateUser

func (x *RemoteConfigEventData) HasUpdateUser() bool

func (*RemoteConfigEventData) ProtoMessage

func (*RemoteConfigEventData) ProtoMessage()

func (*RemoteConfigEventData) ProtoReflect

func (x *RemoteConfigEventData) ProtoReflect() protoreflect.Message

func (*RemoteConfigEventData) Reset

func (x *RemoteConfigEventData) Reset()

func (*RemoteConfigEventData) SetDescription

func (x *RemoteConfigEventData) SetDescription(v string)

func (*RemoteConfigEventData) SetRollbackSource

func (x *RemoteConfigEventData) SetRollbackSource(v int64)

func (*RemoteConfigEventData) SetUpdateOrigin

func (x *RemoteConfigEventData) SetUpdateOrigin(v RemoteConfigUpdateOrigin)

func (*RemoteConfigEventData) SetUpdateTime

func (x *RemoteConfigEventData) SetUpdateTime(v *timestamppb.Timestamp)

func (*RemoteConfigEventData) SetUpdateType

func (x *RemoteConfigEventData) SetUpdateType(v RemoteConfigUpdateType)

func (*RemoteConfigEventData) SetUpdateUser

func (x *RemoteConfigEventData) SetUpdateUser(v *RemoteConfigUser)

func (*RemoteConfigEventData) SetVersionNumber

func (x *RemoteConfigEventData) SetVersionNumber(v int64)

func (*RemoteConfigEventData) String

func (x *RemoteConfigEventData) String() string

type RemoteConfigEventData_builder

type RemoteConfigEventData_builder struct {

	// The version number of the version's corresponding Remote Config template.
	VersionNumber int64
	// When the Remote Config template was written to the Remote Config server.
	UpdateTime *timestamppb.Timestamp
	// Aggregation of all metadata fields about the account that performed the
	// update.
	UpdateUser *RemoteConfigUser
	// The user-provided description of the corresponding Remote Config template.
	Description string
	// Where the update action originated.
	UpdateOrigin RemoteConfigUpdateOrigin
	// What type of update was made.
	UpdateType RemoteConfigUpdateType
	// Only present if this version is the result of a rollback, and will be the
	// version number of the Remote Config template that was rolled-back to.
	RollbackSource int64
	// contains filtered or unexported fields
}

func (RemoteConfigEventData_builder) Build

type RemoteConfigUpdateOrigin

type RemoteConfigUpdateOrigin int32

What type of update was associated with the Remote Config template version.

const (
	// Catch-all for unrecognized values.
	RemoteConfigUpdateOrigin_REMOTE_CONFIG_UPDATE_ORIGIN_UNSPECIFIED RemoteConfigUpdateOrigin = 0
	// The update came from the Firebase UI.
	RemoteConfigUpdateOrigin_CONSOLE RemoteConfigUpdateOrigin = 1
	// The update came from the Remote Config REST API.
	RemoteConfigUpdateOrigin_REST_API RemoteConfigUpdateOrigin = 2
	// The update came from the Firebase Admin Node SDK.
	RemoteConfigUpdateOrigin_ADMIN_SDK_NODE RemoteConfigUpdateOrigin = 3
)

func (RemoteConfigUpdateOrigin) Descriptor

func (RemoteConfigUpdateOrigin) Enum

func (RemoteConfigUpdateOrigin) Number

func (RemoteConfigUpdateOrigin) String

func (x RemoteConfigUpdateOrigin) String() string

func (RemoteConfigUpdateOrigin) Type

type RemoteConfigUpdateType

type RemoteConfigUpdateType int32

Where the Remote Config update action originated.

const (
	// Catch-all for unrecognized enum values.
	RemoteConfigUpdateType_REMOTE_CONFIG_UPDATE_TYPE_UNSPECIFIED RemoteConfigUpdateType = 0
	// A regular incremental update.
	RemoteConfigUpdateType_INCREMENTAL_UPDATE RemoteConfigUpdateType = 1
	// A forced update.
	// The ETag was specified as "*" in an UpdateRemoteConfigRequest
	// request or the "Force Update" button was pressed on the console.
	RemoteConfigUpdateType_FORCED_UPDATE RemoteConfigUpdateType = 2
	// A rollback to a previous Remote Config template.
	RemoteConfigUpdateType_ROLLBACK RemoteConfigUpdateType = 3
)

func (RemoteConfigUpdateType) Descriptor

func (RemoteConfigUpdateType) Enum

func (RemoteConfigUpdateType) Number

func (RemoteConfigUpdateType) String

func (x RemoteConfigUpdateType) String() string

func (RemoteConfigUpdateType) Type

type RemoteConfigUpdatedEvent

type RemoteConfigUpdatedEvent struct {

	// The data associated with the event.
	Data *RemoteConfigEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

The CloudEvent raised when a Remote Config is updated

func (*RemoteConfigUpdatedEvent) ClearData

func (x *RemoteConfigUpdatedEvent) ClearData()

func (*RemoteConfigUpdatedEvent) GetData

func (*RemoteConfigUpdatedEvent) HasData

func (x *RemoteConfigUpdatedEvent) HasData() bool

func (*RemoteConfigUpdatedEvent) ProtoMessage

func (*RemoteConfigUpdatedEvent) ProtoMessage()

func (*RemoteConfigUpdatedEvent) ProtoReflect

func (x *RemoteConfigUpdatedEvent) ProtoReflect() protoreflect.Message

func (*RemoteConfigUpdatedEvent) Reset

func (x *RemoteConfigUpdatedEvent) Reset()

func (*RemoteConfigUpdatedEvent) SetData

func (*RemoteConfigUpdatedEvent) String

func (x *RemoteConfigUpdatedEvent) String() string

type RemoteConfigUpdatedEvent_builder

type RemoteConfigUpdatedEvent_builder struct {

	// The data associated with the event.
	Data *RemoteConfigEventData
	// contains filtered or unexported fields
}

func (RemoteConfigUpdatedEvent_builder) Build

type RemoteConfigUser

type RemoteConfigUser struct {

	// Display name.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Email address.
	Email string `protobuf:"bytes,2,opt,name=email,proto3" json:"email,omitempty"`
	// Image URL.
	ImageUrl string `protobuf:"bytes,3,opt,name=image_url,json=imageUrl,proto3" json:"image_url,omitempty"`
	// contains filtered or unexported fields
}

All the fields associated with the person/service account that wrote a Remote Config template.

func (*RemoteConfigUser) GetEmail

func (x *RemoteConfigUser) GetEmail() string

func (*RemoteConfigUser) GetImageUrl

func (x *RemoteConfigUser) GetImageUrl() string

func (*RemoteConfigUser) GetName

func (x *RemoteConfigUser) GetName() string

func (*RemoteConfigUser) ProtoMessage

func (*RemoteConfigUser) ProtoMessage()

func (*RemoteConfigUser) ProtoReflect

func (x *RemoteConfigUser) ProtoReflect() protoreflect.Message

func (*RemoteConfigUser) Reset

func (x *RemoteConfigUser) Reset()

func (*RemoteConfigUser) SetEmail

func (x *RemoteConfigUser) SetEmail(v string)

func (*RemoteConfigUser) SetImageUrl

func (x *RemoteConfigUser) SetImageUrl(v string)

func (*RemoteConfigUser) SetName

func (x *RemoteConfigUser) SetName(v string)

func (*RemoteConfigUser) String

func (x *RemoteConfigUser) String() string

type RemoteConfigUser_builder

type RemoteConfigUser_builder struct {

	// Display name.
	Name string
	// Email address.
	Email string
	// Image URL.
	ImageUrl string
	// contains filtered or unexported fields
}

func (RemoteConfigUser_builder) Build

Source Files

  • data.pb.go
  • events.pb.go

Jump to