Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterOptimisticExecutionServiceServer(s grpc.ServiceRegistrar, srv OptimisticExecutionServiceServer)
- type OptimisticExecutionServiceClient
- type OptimisticExecutionServiceServer
- type OptimisticExecutionService_ExecuteOptimisticBlockStreamClient
- type OptimisticExecutionService_ExecuteOptimisticBlockStreamServer
- type UnimplementedOptimisticExecutionServiceServer
- type UnsafeOptimisticExecutionServiceServer
Constants ¶
const (
OptimisticExecutionService_ExecuteOptimisticBlockStream_FullMethodName = "/astria.optimistic_execution.v1alpha1.OptimisticExecutionService/ExecuteOptimisticBlockStream"
)
Variables ¶
var OptimisticExecutionService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "astria.optimistic_execution.v1alpha1.OptimisticExecutionService", HandlerType: (*OptimisticExecutionServiceServer)(nil), Methods: []grpc.MethodDesc{}, Streams: []grpc.StreamDesc{ { StreamName: "ExecuteOptimisticBlockStream", Handler: _OptimisticExecutionService_ExecuteOptimisticBlockStream_Handler, ServerStreams: true, ClientStreams: true, }, }, Metadata: "astria/optimistic_execution/v1alpha1/optimistic_execution_service.proto", }
OptimisticExecutionService_ServiceDesc is the grpc.ServiceDesc for OptimisticExecutionService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterOptimisticExecutionServiceServer ¶
func RegisterOptimisticExecutionServiceServer(s grpc.ServiceRegistrar, srv OptimisticExecutionServiceServer)
Types ¶
type OptimisticExecutionServiceClient ¶
type OptimisticExecutionServiceClient interface {
// Stream blocks from the Auctioneer to Geth for optimistic execution. Geth will stream back
// metadata from the executed blocks.
ExecuteOptimisticBlockStream(ctx context.Context, opts ...grpc.CallOption) (grpc.BidiStreamingClient[v1alpha1.ExecuteOptimisticBlockStreamRequest, v1alpha1.ExecuteOptimisticBlockStreamResponse], error)
}
OptimisticExecutionServiceClient is the client API for OptimisticExecutionService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewOptimisticExecutionServiceClient ¶
func NewOptimisticExecutionServiceClient(cc grpc.ClientConnInterface) OptimisticExecutionServiceClient
type OptimisticExecutionServiceServer ¶
type OptimisticExecutionServiceServer interface {
// Stream blocks from the Auctioneer to Geth for optimistic execution. Geth will stream back
// metadata from the executed blocks.
ExecuteOptimisticBlockStream(grpc.BidiStreamingServer[v1alpha1.ExecuteOptimisticBlockStreamRequest, v1alpha1.ExecuteOptimisticBlockStreamResponse]) error
}
OptimisticExecutionServiceServer is the server API for OptimisticExecutionService service. All implementations should embed UnimplementedOptimisticExecutionServiceServer for forward compatibility.
type OptimisticExecutionService_ExecuteOptimisticBlockStreamClient ¶
type OptimisticExecutionService_ExecuteOptimisticBlockStreamClient = grpc.BidiStreamingClient[v1alpha1.ExecuteOptimisticBlockStreamRequest, v1alpha1.ExecuteOptimisticBlockStreamResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type OptimisticExecutionService_ExecuteOptimisticBlockStreamServer ¶
type OptimisticExecutionService_ExecuteOptimisticBlockStreamServer = grpc.BidiStreamingServer[v1alpha1.ExecuteOptimisticBlockStreamRequest, v1alpha1.ExecuteOptimisticBlockStreamResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type UnimplementedOptimisticExecutionServiceServer ¶
type UnimplementedOptimisticExecutionServiceServer struct{}
UnimplementedOptimisticExecutionServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedOptimisticExecutionServiceServer) ExecuteOptimisticBlockStream ¶
func (UnimplementedOptimisticExecutionServiceServer) ExecuteOptimisticBlockStream(grpc.BidiStreamingServer[v1alpha1.ExecuteOptimisticBlockStreamRequest, v1alpha1.ExecuteOptimisticBlockStreamResponse]) error
type UnsafeOptimisticExecutionServiceServer ¶
type UnsafeOptimisticExecutionServiceServer interface {
// contains filtered or unexported methods
}
UnsafeOptimisticExecutionServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to OptimisticExecutionServiceServer will result in compilation errors.
Source Files
¶
- optimistic_execution_service_grpc.pb.go