Documentation
¶
Index ¶
- Variables
- type Allocation
- func (x *Allocation) ClearBid()
- func (x *Allocation) GetBid() *anypb.Any
- func (x *Allocation) GetPublicKey() []byte
- func (x *Allocation) GetSignature() []byte
- func (x *Allocation) HasBid() bool
- func (*Allocation) ProtoMessage()
- func (x *Allocation) ProtoReflect() protoreflect.Message
- func (x *Allocation) Reset()
- func (x *Allocation) SetBid(v *anypb.Any)
- func (x *Allocation) SetPublicKey(v []byte)
- func (x *Allocation) SetSignature(v []byte)
- func (x *Allocation) String() string
- type Allocation_builder
- type Bid
- func (x *Bid) GetFee() uint64
- func (x *Bid) GetRollupParentBlockHash() []byte
- func (x *Bid) GetSequencerParentBlockHash() []byte
- func (x *Bid) GetTransactions() [][]byte
- func (*Bid) ProtoMessage()
- func (x *Bid) ProtoReflect() protoreflect.Message
- func (x *Bid) Reset()
- func (x *Bid) SetFee(v uint64)
- func (x *Bid) SetRollupParentBlockHash(v []byte)
- func (x *Bid) SetSequencerParentBlockHash(v []byte)
- func (x *Bid) SetTransactions(v [][]byte)
- func (x *Bid) String() string
- type Bid_builder
- type GetBidStreamRequest
- type GetBidStreamRequest_builder
- type GetBidStreamResponse
- func (x *GetBidStreamResponse) ClearBid()
- func (x *GetBidStreamResponse) GetBid() *Bid
- func (x *GetBidStreamResponse) HasBid() bool
- func (*GetBidStreamResponse) ProtoMessage()
- func (x *GetBidStreamResponse) ProtoReflect() protoreflect.Message
- func (x *GetBidStreamResponse) Reset()
- func (x *GetBidStreamResponse) SetBid(v *Bid)
- func (x *GetBidStreamResponse) String() string
- type GetBidStreamResponse_builder
Constants ¶
This section is empty.
Variables ¶
var File_astria_auction_v1alpha1_allocation_proto protoreflect.FileDescriptor
var File_astria_auction_v1alpha1_auction_service_proto protoreflect.FileDescriptor
var File_astria_auction_v1alpha1_bid_proto protoreflect.FileDescriptor
var File_astria_auction_v1alpha1_get_bid_stream_request_proto protoreflect.FileDescriptor
var File_astria_auction_v1alpha1_get_bid_stream_response_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Allocation ¶
type Allocation struct {
// The Ed25519 signature of the Auctioneer, to be verified against config by the
// rollup.
Signature []byte `protobuf:"bytes,1,opt,name=signature,proto3" json:"signature,omitempty"`
// The Ed25519 public key of the Auctioneer, to be verified against config by the
// rollup.
PublicKey []byte `protobuf:"bytes,2,opt,name=public_key,json=publicKey,proto3" json:"public_key,omitempty"`
// The bid that was allocated the winning slot by the Auctioneer. This is a
// google.protobuf.Any to avoid decoding and re-encoding after receiving an Allocation
// over the wire and checking if signature and public key match the signed bid.
// Implementors are expected to read and write an encoded Bid into this field.
Bid *anypb.Any `protobuf:"bytes,3,opt,name=bid,proto3" json:"bid,omitempty"`
// contains filtered or unexported fields
}
The Allocation message is submitted by the Auctioneer to the rollup as a `RollupDataSubmission` on the sequencer. The rollup will verify the signature and public key against its configuration, then unbundle the body into rollup transactions and execute them first in the block.
func (*Allocation) ClearBid ¶
func (x *Allocation) ClearBid()
func (*Allocation) GetBid ¶
func (x *Allocation) GetBid() *anypb.Any
func (*Allocation) GetPublicKey ¶
func (x *Allocation) GetPublicKey() []byte
func (*Allocation) GetSignature ¶
func (x *Allocation) GetSignature() []byte
func (*Allocation) HasBid ¶
func (x *Allocation) HasBid() bool
func (*Allocation) ProtoMessage ¶
func (*Allocation) ProtoMessage()
func (*Allocation) ProtoReflect ¶
func (x *Allocation) ProtoReflect() protoreflect.Message
func (*Allocation) Reset ¶
func (x *Allocation) Reset()
func (*Allocation) SetBid ¶
func (x *Allocation) SetBid(v *anypb.Any)
func (*Allocation) SetPublicKey ¶
func (x *Allocation) SetPublicKey(v []byte)
func (*Allocation) SetSignature ¶
func (x *Allocation) SetSignature(v []byte)
func (*Allocation) String ¶
func (x *Allocation) String() string
type Allocation_builder ¶
type Allocation_builder struct {
// The Ed25519 signature of the Auctioneer, to be verified against config by the
// rollup.
Signature []byte
// The Ed25519 public key of the Auctioneer, to be verified against config by the
// rollup.
PublicKey []byte
// The bid that was allocated the winning slot by the Auctioneer. This is a
// google.protobuf.Any to avoid decoding and re-encoding after receiving an Allocation
// over the wire and checking if signature and public key match the signed bid.
// Implementors are expected to read and write an encoded Bid into this field.
Bid *anypb.Any
// contains filtered or unexported fields
}
func (Allocation_builder) Build ¶
func (b0 Allocation_builder) Build() *Allocation
type Bid ¶
type Bid struct {
// The hash of previous rollup block, on top of which the bundle will be executed as ToB.
RollupParentBlockHash []byte `` /* 128-byte string literal not displayed */
// The hash of the previous sequencer block, identifying the auction for which the bid is intended.
// This is the hash of the sequencer block on top of which the bundle will be executed as ToB.
SequencerParentBlockHash []byte `` /* 137-byte string literal not displayed */
// The fee paid by the bundle submitter. The auctioneer's rollup node calculates this based
// on the bundles submitted by users. For example, this can be the sum of the coinbase transfers
// in the bundle's transactions.
Fee uint64 `protobuf:"varint,3,opt,name=fee,proto3" json:"fee,omitempty"`
// The list of serialized rollup transactions from the bundle.
Transactions [][]byte `protobuf:"bytes,4,rep,name=transactions,proto3" json:"transactions,omitempty"`
// contains filtered or unexported fields
}
A bid is a bundle of transactions that was submitted to the auctioneer's rollup node. The rollup node will verify that the bundle is valid and pays the fee, and will stream it to the auctioneer for participation in the auction for a given block. The sequencer block hash and the rollup parent block hash are used by the auctioneer to identify the block for which the bundle is intended (i.e. which auction the bid is for).
func (*Bid) ProtoReflect ¶
func (x *Bid) ProtoReflect() protoreflect.Message
type Bid_builder ¶
type Bid_builder struct {
// The hash of previous rollup block, on top of which the bundle will be executed as ToB.
RollupParentBlockHash []byte
// The hash of the previous sequencer block, identifying the auction for which the bid is intended.
// This is the hash of the sequencer block on top of which the bundle will be executed as ToB.
SequencerParentBlockHash []byte
// The fee paid by the bundle submitter. The auctioneer's rollup node calculates this based
// on the bundles submitted by users. For example, this can be the sum of the coinbase transfers
// in the bundle's transactions.
Fee uint64
// The list of serialized rollup transactions from the bundle.
Transactions [][]byte
// contains filtered or unexported fields
}
func (Bid_builder) Build ¶
func (b0 Bid_builder) Build() *Bid
type GetBidStreamRequest ¶
type GetBidStreamRequest struct {
// contains filtered or unexported fields
}
func (*GetBidStreamRequest) ProtoMessage ¶
func (*GetBidStreamRequest) ProtoMessage()
func (*GetBidStreamRequest) ProtoReflect ¶
func (x *GetBidStreamRequest) ProtoReflect() protoreflect.Message
func (*GetBidStreamRequest) Reset ¶
func (x *GetBidStreamRequest) Reset()
func (*GetBidStreamRequest) String ¶
func (x *GetBidStreamRequest) String() string
type GetBidStreamRequest_builder ¶
type GetBidStreamRequest_builder struct {
// contains filtered or unexported fields
}
func (GetBidStreamRequest_builder) Build ¶
func (b0 GetBidStreamRequest_builder) Build() *GetBidStreamRequest
type GetBidStreamResponse ¶
type GetBidStreamResponse struct {
Bid *Bid `protobuf:"bytes,1,opt,name=bid,proto3" json:"bid,omitempty"`
// contains filtered or unexported fields
}
func (*GetBidStreamResponse) ClearBid ¶
func (x *GetBidStreamResponse) ClearBid()
func (*GetBidStreamResponse) GetBid ¶
func (x *GetBidStreamResponse) GetBid() *Bid
func (*GetBidStreamResponse) HasBid ¶
func (x *GetBidStreamResponse) HasBid() bool
func (*GetBidStreamResponse) ProtoMessage ¶
func (*GetBidStreamResponse) ProtoMessage()
func (*GetBidStreamResponse) ProtoReflect ¶
func (x *GetBidStreamResponse) ProtoReflect() protoreflect.Message
func (*GetBidStreamResponse) Reset ¶
func (x *GetBidStreamResponse) Reset()
func (*GetBidStreamResponse) SetBid ¶
func (x *GetBidStreamResponse) SetBid(v *Bid)
func (*GetBidStreamResponse) String ¶
func (x *GetBidStreamResponse) String() string
type GetBidStreamResponse_builder ¶
type GetBidStreamResponse_builder struct {
Bid *Bid
// contains filtered or unexported fields
}
func (GetBidStreamResponse_builder) Build ¶
func (b0 GetBidStreamResponse_builder) Build() *GetBidStreamResponse
Source Files
¶
- allocation.pb.go
- auction_service.pb.go
- bid.pb.go
- get_bid_stream_request.pb.go
- get_bid_stream_response.pb.go