Documentation
¶
Index ¶
- Variables
- type Account
- func (x *Account) ClearAddress()
- func (x *Account) ClearBalance()
- func (x *Account) GetAddress() *v1.Address
- func (x *Account) GetBalance() *v1.Uint128
- func (x *Account) HasAddress() bool
- func (x *Account) HasBalance() bool
- func (*Account) ProtoMessage()
- func (x *Account) ProtoReflect() protoreflect.Message
- func (x *Account) Reset()
- func (x *Account) SetAddress(v *v1.Address)
- func (x *Account) SetBalance(v *v1.Uint128)
- func (x *Account) String() string
- type Account_builder
- type AddressPrefixes
- func (x *AddressPrefixes) GetBase() string
- func (x *AddressPrefixes) GetIbcCompat() string
- func (*AddressPrefixes) ProtoMessage()
- func (x *AddressPrefixes) ProtoReflect() protoreflect.Message
- func (x *AddressPrefixes) Reset()
- func (x *AddressPrefixes) SetBase(v string)
- func (x *AddressPrefixes) SetIbcCompat(v string)
- func (x *AddressPrefixes) String() string
- type AddressPrefixes_builder
- type GenesisAppState
- func (x *GenesisAppState) ClearAddressPrefixes()
- func (x *GenesisAppState) ClearAuthoritySudoAddress()
- func (x *GenesisAppState) ClearFees()
- func (x *GenesisAppState) ClearIbcParameters()
- func (x *GenesisAppState) ClearIbcSudoAddress()
- func (x *GenesisAppState) GetAccounts() []*Account
- func (x *GenesisAppState) GetAddressPrefixes() *AddressPrefixes
- func (x *GenesisAppState) GetAllowedFeeAssets() []string
- func (x *GenesisAppState) GetAuthoritySudoAddress() *v1.Address
- func (x *GenesisAppState) GetChainId() string
- func (x *GenesisAppState) GetFees() *GenesisFees
- func (x *GenesisAppState) GetIbcParameters() *IbcParameters
- func (x *GenesisAppState) GetIbcRelayerAddresses() []*v1.Address
- func (x *GenesisAppState) GetIbcSudoAddress() *v1.Address
- func (x *GenesisAppState) GetNativeAssetBaseDenomination() string
- func (x *GenesisAppState) HasAddressPrefixes() bool
- func (x *GenesisAppState) HasAuthoritySudoAddress() bool
- func (x *GenesisAppState) HasFees() bool
- func (x *GenesisAppState) HasIbcParameters() bool
- func (x *GenesisAppState) HasIbcSudoAddress() bool
- func (*GenesisAppState) ProtoMessage()
- func (x *GenesisAppState) ProtoReflect() protoreflect.Message
- func (x *GenesisAppState) Reset()
- func (x *GenesisAppState) SetAccounts(v []*Account)
- func (x *GenesisAppState) SetAddressPrefixes(v *AddressPrefixes)
- func (x *GenesisAppState) SetAllowedFeeAssets(v []string)
- func (x *GenesisAppState) SetAuthoritySudoAddress(v *v1.Address)
- func (x *GenesisAppState) SetChainId(v string)
- func (x *GenesisAppState) SetFees(v *GenesisFees)
- func (x *GenesisAppState) SetIbcParameters(v *IbcParameters)
- func (x *GenesisAppState) SetIbcRelayerAddresses(v []*v1.Address)
- func (x *GenesisAppState) SetIbcSudoAddress(v *v1.Address)
- func (x *GenesisAppState) SetNativeAssetBaseDenomination(v string)
- func (x *GenesisAppState) String() string
- type GenesisAppState_builder
- type GenesisFees
- func (x *GenesisFees) ClearBridgeLock()
- func (x *GenesisFees) ClearBridgeSudoChange()
- func (x *GenesisFees) ClearBridgeTransfer()
- func (x *GenesisFees) ClearBridgeUnlock()
- func (x *GenesisFees) ClearCurrencyPairsChange()
- func (x *GenesisFees) ClearFeeAssetChange()
- func (x *GenesisFees) ClearFeeChange()
- func (x *GenesisFees) ClearIbcRelay()
- func (x *GenesisFees) ClearIbcRelayerChange()
- func (x *GenesisFees) ClearIbcSudoChange()
- func (x *GenesisFees) ClearIcs20Withdrawal()
- func (x *GenesisFees) ClearInitBridgeAccount()
- func (x *GenesisFees) ClearMarketsChange()
- func (x *GenesisFees) ClearRecoverIbcClient()
- func (x *GenesisFees) ClearRollupDataSubmission()
- func (x *GenesisFees) ClearSudoAddressChange()
- func (x *GenesisFees) ClearTransfer()
- func (x *GenesisFees) ClearValidatorUpdate()
- func (x *GenesisFees) GetBridgeLock() *v11.BridgeLockFeeComponents
- func (x *GenesisFees) GetBridgeSudoChange() *v11.BridgeSudoChangeFeeComponents
- func (x *GenesisFees) GetBridgeTransfer() *v11.BridgeTransferFeeComponents
- func (x *GenesisFees) GetBridgeUnlock() *v11.BridgeUnlockFeeComponents
- func (x *GenesisFees) GetCurrencyPairsChange() *v11.CurrencyPairsChangeFeeComponents
- func (x *GenesisFees) GetFeeAssetChange() *v11.FeeAssetChangeFeeComponents
- func (x *GenesisFees) GetFeeChange() *v11.FeeChangeFeeComponents
- func (x *GenesisFees) GetIbcRelay() *v11.IbcRelayFeeComponents
- func (x *GenesisFees) GetIbcRelayerChange() *v11.IbcRelayerChangeFeeComponents
- func (x *GenesisFees) GetIbcSudoChange() *v11.IbcSudoChangeFeeComponents
- func (x *GenesisFees) GetIcs20Withdrawal() *v11.Ics20WithdrawalFeeComponents
- func (x *GenesisFees) GetInitBridgeAccount() *v11.InitBridgeAccountFeeComponents
- func (x *GenesisFees) GetMarketsChange() *v11.MarketsChangeFeeComponents
- func (x *GenesisFees) GetRecoverIbcClient() *v11.RecoverIbcClientFeeComponents
- func (x *GenesisFees) GetRollupDataSubmission() *v11.RollupDataSubmissionFeeComponents
- func (x *GenesisFees) GetSudoAddressChange() *v11.SudoAddressChangeFeeComponents
- func (x *GenesisFees) GetTransfer() *v11.TransferFeeComponents
- func (x *GenesisFees) GetValidatorUpdate() *v11.ValidatorUpdateFeeComponents
- func (x *GenesisFees) HasBridgeLock() bool
- func (x *GenesisFees) HasBridgeSudoChange() bool
- func (x *GenesisFees) HasBridgeTransfer() bool
- func (x *GenesisFees) HasBridgeUnlock() bool
- func (x *GenesisFees) HasCurrencyPairsChange() bool
- func (x *GenesisFees) HasFeeAssetChange() bool
- func (x *GenesisFees) HasFeeChange() bool
- func (x *GenesisFees) HasIbcRelay() bool
- func (x *GenesisFees) HasIbcRelayerChange() bool
- func (x *GenesisFees) HasIbcSudoChange() bool
- func (x *GenesisFees) HasIcs20Withdrawal() bool
- func (x *GenesisFees) HasInitBridgeAccount() bool
- func (x *GenesisFees) HasMarketsChange() bool
- func (x *GenesisFees) HasRecoverIbcClient() bool
- func (x *GenesisFees) HasRollupDataSubmission() bool
- func (x *GenesisFees) HasSudoAddressChange() bool
- func (x *GenesisFees) HasTransfer() bool
- func (x *GenesisFees) HasValidatorUpdate() bool
- func (*GenesisFees) ProtoMessage()
- func (x *GenesisFees) ProtoReflect() protoreflect.Message
- func (x *GenesisFees) Reset()
- func (x *GenesisFees) SetBridgeLock(v *v11.BridgeLockFeeComponents)
- func (x *GenesisFees) SetBridgeSudoChange(v *v11.BridgeSudoChangeFeeComponents)
- func (x *GenesisFees) SetBridgeTransfer(v *v11.BridgeTransferFeeComponents)
- func (x *GenesisFees) SetBridgeUnlock(v *v11.BridgeUnlockFeeComponents)
- func (x *GenesisFees) SetCurrencyPairsChange(v *v11.CurrencyPairsChangeFeeComponents)
- func (x *GenesisFees) SetFeeAssetChange(v *v11.FeeAssetChangeFeeComponents)
- func (x *GenesisFees) SetFeeChange(v *v11.FeeChangeFeeComponents)
- func (x *GenesisFees) SetIbcRelay(v *v11.IbcRelayFeeComponents)
- func (x *GenesisFees) SetIbcRelayerChange(v *v11.IbcRelayerChangeFeeComponents)
- func (x *GenesisFees) SetIbcSudoChange(v *v11.IbcSudoChangeFeeComponents)
- func (x *GenesisFees) SetIcs20Withdrawal(v *v11.Ics20WithdrawalFeeComponents)
- func (x *GenesisFees) SetInitBridgeAccount(v *v11.InitBridgeAccountFeeComponents)
- func (x *GenesisFees) SetMarketsChange(v *v11.MarketsChangeFeeComponents)
- func (x *GenesisFees) SetRecoverIbcClient(v *v11.RecoverIbcClientFeeComponents)
- func (x *GenesisFees) SetRollupDataSubmission(v *v11.RollupDataSubmissionFeeComponents)
- func (x *GenesisFees) SetSudoAddressChange(v *v11.SudoAddressChangeFeeComponents)
- func (x *GenesisFees) SetTransfer(v *v11.TransferFeeComponents)
- func (x *GenesisFees) SetValidatorUpdate(v *v11.ValidatorUpdateFeeComponents)
- func (x *GenesisFees) String() string
- type GenesisFees_builder
- type IbcParameters
- func (x *IbcParameters) GetIbcEnabled() bool
- func (x *IbcParameters) GetInboundIcs20TransfersEnabled() bool
- func (x *IbcParameters) GetOutboundIcs20TransfersEnabled() bool
- func (*IbcParameters) ProtoMessage()
- func (x *IbcParameters) ProtoReflect() protoreflect.Message
- func (x *IbcParameters) Reset()
- func (x *IbcParameters) SetIbcEnabled(v bool)
- func (x *IbcParameters) SetInboundIcs20TransfersEnabled(v bool)
- func (x *IbcParameters) SetOutboundIcs20TransfersEnabled(v bool)
- func (x *IbcParameters) String() string
- type IbcParameters_builder
Constants ¶
This section is empty.
Variables ¶
var File_astria_protocol_genesis_v1_types_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Account ¶
type Account struct {
Address *v1.Address `protobuf:"bytes,1,opt,name=address,proto3" json:"address,omitempty"`
Balance *v1.Uint128 `protobuf:"bytes,2,opt,name=balance,proto3" json:"balance,omitempty"`
// contains filtered or unexported fields
}
func (*Account) ProtoReflect ¶
func (x *Account) ProtoReflect() protoreflect.Message
type Account_builder ¶
type Account_builder struct {
Address *v1.Address
Balance *v1.Uint128
// contains filtered or unexported fields
}
func (Account_builder) Build ¶
func (b0 Account_builder) Build() *Account
type AddressPrefixes ¶
type AddressPrefixes struct {
// The base prefix used for most Astria Sequencer addresses.
Base string `protobuf:"bytes,1,opt,name=base,proto3" json:"base,omitempty"`
// The prefix used for sending ics20 transfers to IBC chains
// that enforce a bech32 format of the packet sender.
IbcCompat string `protobuf:"bytes,2,opt,name=ibc_compat,json=ibcCompat,proto3" json:"ibc_compat,omitempty"`
// contains filtered or unexported fields
}
func (*AddressPrefixes) GetBase ¶
func (x *AddressPrefixes) GetBase() string
func (*AddressPrefixes) GetIbcCompat ¶
func (x *AddressPrefixes) GetIbcCompat() string
func (*AddressPrefixes) ProtoMessage ¶
func (*AddressPrefixes) ProtoMessage()
func (*AddressPrefixes) ProtoReflect ¶
func (x *AddressPrefixes) ProtoReflect() protoreflect.Message
func (*AddressPrefixes) Reset ¶
func (x *AddressPrefixes) Reset()
func (*AddressPrefixes) SetBase ¶
func (x *AddressPrefixes) SetBase(v string)
func (*AddressPrefixes) SetIbcCompat ¶
func (x *AddressPrefixes) SetIbcCompat(v string)
func (*AddressPrefixes) String ¶
func (x *AddressPrefixes) String() string
type AddressPrefixes_builder ¶
type AddressPrefixes_builder struct {
// The base prefix used for most Astria Sequencer addresses.
Base string
// The prefix used for sending ics20 transfers to IBC chains
// that enforce a bech32 format of the packet sender.
IbcCompat string
// contains filtered or unexported fields
}
func (AddressPrefixes_builder) Build ¶
func (b0 AddressPrefixes_builder) Build() *AddressPrefixes
type GenesisAppState ¶
type GenesisAppState struct {
ChainId string `protobuf:"bytes,1,opt,name=chain_id,json=chainId,proto3" json:"chain_id,omitempty"`
AddressPrefixes *AddressPrefixes `protobuf:"bytes,2,opt,name=address_prefixes,json=addressPrefixes,proto3" json:"address_prefixes,omitempty"`
Accounts []*Account `protobuf:"bytes,3,rep,name=accounts,proto3" json:"accounts,omitempty"`
AuthoritySudoAddress *v1.Address `protobuf:"bytes,4,opt,name=authority_sudo_address,json=authoritySudoAddress,proto3" json:"authority_sudo_address,omitempty"`
IbcSudoAddress *v1.Address `protobuf:"bytes,5,opt,name=ibc_sudo_address,json=ibcSudoAddress,proto3" json:"ibc_sudo_address,omitempty"`
IbcRelayerAddresses []*v1.Address `protobuf:"bytes,6,rep,name=ibc_relayer_addresses,json=ibcRelayerAddresses,proto3" json:"ibc_relayer_addresses,omitempty"`
NativeAssetBaseDenomination string `` /* 146-byte string literal not displayed */
IbcParameters *IbcParameters `protobuf:"bytes,8,opt,name=ibc_parameters,json=ibcParameters,proto3" json:"ibc_parameters,omitempty"`
AllowedFeeAssets []string `protobuf:"bytes,9,rep,name=allowed_fee_assets,json=allowedFeeAssets,proto3" json:"allowed_fee_assets,omitempty"`
Fees *GenesisFees `protobuf:"bytes,10,opt,name=fees,proto3" json:"fees,omitempty"`
// contains filtered or unexported fields
}
func (*GenesisAppState) ClearAddressPrefixes ¶
func (x *GenesisAppState) ClearAddressPrefixes()
func (*GenesisAppState) ClearAuthoritySudoAddress ¶
func (x *GenesisAppState) ClearAuthoritySudoAddress()
func (*GenesisAppState) ClearFees ¶
func (x *GenesisAppState) ClearFees()
func (*GenesisAppState) ClearIbcParameters ¶
func (x *GenesisAppState) ClearIbcParameters()
func (*GenesisAppState) ClearIbcSudoAddress ¶
func (x *GenesisAppState) ClearIbcSudoAddress()
func (*GenesisAppState) GetAccounts ¶
func (x *GenesisAppState) GetAccounts() []*Account
func (*GenesisAppState) GetAddressPrefixes ¶
func (x *GenesisAppState) GetAddressPrefixes() *AddressPrefixes
func (*GenesisAppState) GetAllowedFeeAssets ¶
func (x *GenesisAppState) GetAllowedFeeAssets() []string
func (*GenesisAppState) GetAuthoritySudoAddress ¶
func (x *GenesisAppState) GetAuthoritySudoAddress() *v1.Address
func (*GenesisAppState) GetChainId ¶
func (x *GenesisAppState) GetChainId() string
func (*GenesisAppState) GetFees ¶
func (x *GenesisAppState) GetFees() *GenesisFees
func (*GenesisAppState) GetIbcParameters ¶
func (x *GenesisAppState) GetIbcParameters() *IbcParameters
func (*GenesisAppState) GetIbcRelayerAddresses ¶
func (x *GenesisAppState) GetIbcRelayerAddresses() []*v1.Address
func (*GenesisAppState) GetIbcSudoAddress ¶
func (x *GenesisAppState) GetIbcSudoAddress() *v1.Address
func (*GenesisAppState) GetNativeAssetBaseDenomination ¶
func (x *GenesisAppState) GetNativeAssetBaseDenomination() string
func (*GenesisAppState) HasAddressPrefixes ¶
func (x *GenesisAppState) HasAddressPrefixes() bool
func (*GenesisAppState) HasAuthoritySudoAddress ¶
func (x *GenesisAppState) HasAuthoritySudoAddress() bool
func (*GenesisAppState) HasFees ¶
func (x *GenesisAppState) HasFees() bool
func (*GenesisAppState) HasIbcParameters ¶
func (x *GenesisAppState) HasIbcParameters() bool
func (*GenesisAppState) HasIbcSudoAddress ¶
func (x *GenesisAppState) HasIbcSudoAddress() bool
func (*GenesisAppState) ProtoMessage ¶
func (*GenesisAppState) ProtoMessage()
func (*GenesisAppState) ProtoReflect ¶
func (x *GenesisAppState) ProtoReflect() protoreflect.Message
func (*GenesisAppState) Reset ¶
func (x *GenesisAppState) Reset()
func (*GenesisAppState) SetAccounts ¶
func (x *GenesisAppState) SetAccounts(v []*Account)
func (*GenesisAppState) SetAddressPrefixes ¶
func (x *GenesisAppState) SetAddressPrefixes(v *AddressPrefixes)
func (*GenesisAppState) SetAllowedFeeAssets ¶
func (x *GenesisAppState) SetAllowedFeeAssets(v []string)
func (*GenesisAppState) SetAuthoritySudoAddress ¶
func (x *GenesisAppState) SetAuthoritySudoAddress(v *v1.Address)
func (*GenesisAppState) SetChainId ¶
func (x *GenesisAppState) SetChainId(v string)
func (*GenesisAppState) SetFees ¶
func (x *GenesisAppState) SetFees(v *GenesisFees)
func (*GenesisAppState) SetIbcParameters ¶
func (x *GenesisAppState) SetIbcParameters(v *IbcParameters)
func (*GenesisAppState) SetIbcRelayerAddresses ¶
func (x *GenesisAppState) SetIbcRelayerAddresses(v []*v1.Address)
func (*GenesisAppState) SetIbcSudoAddress ¶
func (x *GenesisAppState) SetIbcSudoAddress(v *v1.Address)
func (*GenesisAppState) SetNativeAssetBaseDenomination ¶
func (x *GenesisAppState) SetNativeAssetBaseDenomination(v string)
func (*GenesisAppState) String ¶
func (x *GenesisAppState) String() string
type GenesisAppState_builder ¶
type GenesisAppState_builder struct {
ChainId string
AddressPrefixes *AddressPrefixes
Accounts []*Account
AuthoritySudoAddress *v1.Address
IbcSudoAddress *v1.Address
IbcRelayerAddresses []*v1.Address
NativeAssetBaseDenomination string
IbcParameters *IbcParameters
AllowedFeeAssets []string
Fees *GenesisFees
// contains filtered or unexported fields
}
func (GenesisAppState_builder) Build ¶
func (b0 GenesisAppState_builder) Build() *GenesisAppState
type GenesisFees ¶
type GenesisFees struct {
BridgeLock *v11.BridgeLockFeeComponents `protobuf:"bytes,1,opt,name=bridge_lock,json=bridgeLock,proto3" json:"bridge_lock,omitempty"`
BridgeSudoChange *v11.BridgeSudoChangeFeeComponents `protobuf:"bytes,2,opt,name=bridge_sudo_change,json=bridgeSudoChange,proto3" json:"bridge_sudo_change,omitempty"`
BridgeUnlock *v11.BridgeUnlockFeeComponents `protobuf:"bytes,3,opt,name=bridge_unlock,json=bridgeUnlock,proto3" json:"bridge_unlock,omitempty"`
FeeAssetChange *v11.FeeAssetChangeFeeComponents `protobuf:"bytes,4,opt,name=fee_asset_change,json=feeAssetChange,proto3" json:"fee_asset_change,omitempty"`
FeeChange *v11.FeeChangeFeeComponents `protobuf:"bytes,5,opt,name=fee_change,json=feeChange,proto3" json:"fee_change,omitempty"`
IbcRelay *v11.IbcRelayFeeComponents `protobuf:"bytes,7,opt,name=ibc_relay,json=ibcRelay,proto3" json:"ibc_relay,omitempty"`
IbcRelayerChange *v11.IbcRelayerChangeFeeComponents `protobuf:"bytes,6,opt,name=ibc_relayer_change,json=ibcRelayerChange,proto3" json:"ibc_relayer_change,omitempty"`
IbcSudoChange *v11.IbcSudoChangeFeeComponents `protobuf:"bytes,8,opt,name=ibc_sudo_change,json=ibcSudoChange,proto3" json:"ibc_sudo_change,omitempty"`
Ics20Withdrawal *v11.Ics20WithdrawalFeeComponents `protobuf:"bytes,9,opt,name=ics20_withdrawal,json=ics20Withdrawal,proto3" json:"ics20_withdrawal,omitempty"`
InitBridgeAccount *v11.InitBridgeAccountFeeComponents `protobuf:"bytes,10,opt,name=init_bridge_account,json=initBridgeAccount,proto3" json:"init_bridge_account,omitempty"`
RollupDataSubmission *v11.RollupDataSubmissionFeeComponents `protobuf:"bytes,11,opt,name=rollup_data_submission,json=rollupDataSubmission,proto3" json:"rollup_data_submission,omitempty"`
SudoAddressChange *v11.SudoAddressChangeFeeComponents `protobuf:"bytes,12,opt,name=sudo_address_change,json=sudoAddressChange,proto3" json:"sudo_address_change,omitempty"`
Transfer *v11.TransferFeeComponents `protobuf:"bytes,13,opt,name=transfer,proto3" json:"transfer,omitempty"`
ValidatorUpdate *v11.ValidatorUpdateFeeComponents `protobuf:"bytes,14,opt,name=validator_update,json=validatorUpdate,proto3" json:"validator_update,omitempty"`
BridgeTransfer *v11.BridgeTransferFeeComponents `protobuf:"bytes,15,opt,name=bridge_transfer,json=bridgeTransfer,proto3" json:"bridge_transfer,omitempty"`
RecoverIbcClient *v11.RecoverIbcClientFeeComponents `protobuf:"bytes,16,opt,name=recover_ibc_client,json=recoverIbcClient,proto3" json:"recover_ibc_client,omitempty"`
CurrencyPairsChange *v11.CurrencyPairsChangeFeeComponents `protobuf:"bytes,17,opt,name=currency_pairs_change,json=currencyPairsChange,proto3" json:"currency_pairs_change,omitempty"`
MarketsChange *v11.MarketsChangeFeeComponents `protobuf:"bytes,18,opt,name=markets_change,json=marketsChange,proto3" json:"markets_change,omitempty"`
// contains filtered or unexported fields
}
func (*GenesisFees) ClearBridgeLock ¶
func (x *GenesisFees) ClearBridgeLock()
func (*GenesisFees) ClearBridgeSudoChange ¶
func (x *GenesisFees) ClearBridgeSudoChange()
func (*GenesisFees) ClearBridgeTransfer ¶
func (x *GenesisFees) ClearBridgeTransfer()
func (*GenesisFees) ClearBridgeUnlock ¶
func (x *GenesisFees) ClearBridgeUnlock()
func (*GenesisFees) ClearCurrencyPairsChange ¶
func (x *GenesisFees) ClearCurrencyPairsChange()
func (*GenesisFees) ClearFeeAssetChange ¶
func (x *GenesisFees) ClearFeeAssetChange()
func (*GenesisFees) ClearFeeChange ¶
func (x *GenesisFees) ClearFeeChange()
func (*GenesisFees) ClearIbcRelay ¶
func (x *GenesisFees) ClearIbcRelay()
func (*GenesisFees) ClearIbcRelayerChange ¶
func (x *GenesisFees) ClearIbcRelayerChange()
func (*GenesisFees) ClearIbcSudoChange ¶
func (x *GenesisFees) ClearIbcSudoChange()
func (*GenesisFees) ClearIcs20Withdrawal ¶
func (x *GenesisFees) ClearIcs20Withdrawal()
func (*GenesisFees) ClearInitBridgeAccount ¶
func (x *GenesisFees) ClearInitBridgeAccount()
func (*GenesisFees) ClearMarketsChange ¶
func (x *GenesisFees) ClearMarketsChange()
func (*GenesisFees) ClearRecoverIbcClient ¶
func (x *GenesisFees) ClearRecoverIbcClient()
func (*GenesisFees) ClearRollupDataSubmission ¶
func (x *GenesisFees) ClearRollupDataSubmission()
func (*GenesisFees) ClearSudoAddressChange ¶
func (x *GenesisFees) ClearSudoAddressChange()
func (*GenesisFees) ClearTransfer ¶
func (x *GenesisFees) ClearTransfer()
func (*GenesisFees) ClearValidatorUpdate ¶
func (x *GenesisFees) ClearValidatorUpdate()
func (*GenesisFees) GetBridgeLock ¶
func (x *GenesisFees) GetBridgeLock() *v11.BridgeLockFeeComponents
func (*GenesisFees) GetBridgeSudoChange ¶
func (x *GenesisFees) GetBridgeSudoChange() *v11.BridgeSudoChangeFeeComponents
func (*GenesisFees) GetBridgeTransfer ¶
func (x *GenesisFees) GetBridgeTransfer() *v11.BridgeTransferFeeComponents
func (*GenesisFees) GetBridgeUnlock ¶
func (x *GenesisFees) GetBridgeUnlock() *v11.BridgeUnlockFeeComponents
func (*GenesisFees) GetCurrencyPairsChange ¶
func (x *GenesisFees) GetCurrencyPairsChange() *v11.CurrencyPairsChangeFeeComponents
func (*GenesisFees) GetFeeAssetChange ¶
func (x *GenesisFees) GetFeeAssetChange() *v11.FeeAssetChangeFeeComponents
func (*GenesisFees) GetFeeChange ¶
func (x *GenesisFees) GetFeeChange() *v11.FeeChangeFeeComponents
func (*GenesisFees) GetIbcRelay ¶
func (x *GenesisFees) GetIbcRelay() *v11.IbcRelayFeeComponents
func (*GenesisFees) GetIbcRelayerChange ¶
func (x *GenesisFees) GetIbcRelayerChange() *v11.IbcRelayerChangeFeeComponents
func (*GenesisFees) GetIbcSudoChange ¶
func (x *GenesisFees) GetIbcSudoChange() *v11.IbcSudoChangeFeeComponents
func (*GenesisFees) GetIcs20Withdrawal ¶
func (x *GenesisFees) GetIcs20Withdrawal() *v11.Ics20WithdrawalFeeComponents
func (*GenesisFees) GetInitBridgeAccount ¶
func (x *GenesisFees) GetInitBridgeAccount() *v11.InitBridgeAccountFeeComponents
func (*GenesisFees) GetMarketsChange ¶
func (x *GenesisFees) GetMarketsChange() *v11.MarketsChangeFeeComponents
func (*GenesisFees) GetRecoverIbcClient ¶
func (x *GenesisFees) GetRecoverIbcClient() *v11.RecoverIbcClientFeeComponents
func (*GenesisFees) GetRollupDataSubmission ¶
func (x *GenesisFees) GetRollupDataSubmission() *v11.RollupDataSubmissionFeeComponents
func (*GenesisFees) GetSudoAddressChange ¶
func (x *GenesisFees) GetSudoAddressChange() *v11.SudoAddressChangeFeeComponents
func (*GenesisFees) GetTransfer ¶
func (x *GenesisFees) GetTransfer() *v11.TransferFeeComponents
func (*GenesisFees) GetValidatorUpdate ¶
func (x *GenesisFees) GetValidatorUpdate() *v11.ValidatorUpdateFeeComponents
func (*GenesisFees) HasBridgeLock ¶
func (x *GenesisFees) HasBridgeLock() bool
func (*GenesisFees) HasBridgeSudoChange ¶
func (x *GenesisFees) HasBridgeSudoChange() bool
func (*GenesisFees) HasBridgeTransfer ¶
func (x *GenesisFees) HasBridgeTransfer() bool
func (*GenesisFees) HasBridgeUnlock ¶
func (x *GenesisFees) HasBridgeUnlock() bool
func (*GenesisFees) HasCurrencyPairsChange ¶
func (x *GenesisFees) HasCurrencyPairsChange() bool
func (*GenesisFees) HasFeeAssetChange ¶
func (x *GenesisFees) HasFeeAssetChange() bool
func (*GenesisFees) HasFeeChange ¶
func (x *GenesisFees) HasFeeChange() bool
func (*GenesisFees) HasIbcRelay ¶
func (x *GenesisFees) HasIbcRelay() bool
func (*GenesisFees) HasIbcRelayerChange ¶
func (x *GenesisFees) HasIbcRelayerChange() bool
func (*GenesisFees) HasIbcSudoChange ¶
func (x *GenesisFees) HasIbcSudoChange() bool
func (*GenesisFees) HasIcs20Withdrawal ¶
func (x *GenesisFees) HasIcs20Withdrawal() bool
func (*GenesisFees) HasInitBridgeAccount ¶
func (x *GenesisFees) HasInitBridgeAccount() bool
func (*GenesisFees) HasMarketsChange ¶
func (x *GenesisFees) HasMarketsChange() bool
func (*GenesisFees) HasRecoverIbcClient ¶
func (x *GenesisFees) HasRecoverIbcClient() bool
func (*GenesisFees) HasRollupDataSubmission ¶
func (x *GenesisFees) HasRollupDataSubmission() bool
func (*GenesisFees) HasSudoAddressChange ¶
func (x *GenesisFees) HasSudoAddressChange() bool
func (*GenesisFees) HasTransfer ¶
func (x *GenesisFees) HasTransfer() bool
func (*GenesisFees) HasValidatorUpdate ¶
func (x *GenesisFees) HasValidatorUpdate() bool
func (*GenesisFees) ProtoMessage ¶
func (*GenesisFees) ProtoMessage()
func (*GenesisFees) ProtoReflect ¶
func (x *GenesisFees) ProtoReflect() protoreflect.Message
func (*GenesisFees) Reset ¶
func (x *GenesisFees) Reset()
func (*GenesisFees) SetBridgeLock ¶
func (x *GenesisFees) SetBridgeLock(v *v11.BridgeLockFeeComponents)
func (*GenesisFees) SetBridgeSudoChange ¶
func (x *GenesisFees) SetBridgeSudoChange(v *v11.BridgeSudoChangeFeeComponents)
func (*GenesisFees) SetBridgeTransfer ¶
func (x *GenesisFees) SetBridgeTransfer(v *v11.BridgeTransferFeeComponents)
func (*GenesisFees) SetBridgeUnlock ¶
func (x *GenesisFees) SetBridgeUnlock(v *v11.BridgeUnlockFeeComponents)
func (*GenesisFees) SetCurrencyPairsChange ¶
func (x *GenesisFees) SetCurrencyPairsChange(v *v11.CurrencyPairsChangeFeeComponents)
func (*GenesisFees) SetFeeAssetChange ¶
func (x *GenesisFees) SetFeeAssetChange(v *v11.FeeAssetChangeFeeComponents)
func (*GenesisFees) SetFeeChange ¶
func (x *GenesisFees) SetFeeChange(v *v11.FeeChangeFeeComponents)
func (*GenesisFees) SetIbcRelay ¶
func (x *GenesisFees) SetIbcRelay(v *v11.IbcRelayFeeComponents)
func (*GenesisFees) SetIbcRelayerChange ¶
func (x *GenesisFees) SetIbcRelayerChange(v *v11.IbcRelayerChangeFeeComponents)
func (*GenesisFees) SetIbcSudoChange ¶
func (x *GenesisFees) SetIbcSudoChange(v *v11.IbcSudoChangeFeeComponents)
func (*GenesisFees) SetIcs20Withdrawal ¶
func (x *GenesisFees) SetIcs20Withdrawal(v *v11.Ics20WithdrawalFeeComponents)
func (*GenesisFees) SetInitBridgeAccount ¶
func (x *GenesisFees) SetInitBridgeAccount(v *v11.InitBridgeAccountFeeComponents)
func (*GenesisFees) SetMarketsChange ¶
func (x *GenesisFees) SetMarketsChange(v *v11.MarketsChangeFeeComponents)
func (*GenesisFees) SetRecoverIbcClient ¶
func (x *GenesisFees) SetRecoverIbcClient(v *v11.RecoverIbcClientFeeComponents)
func (*GenesisFees) SetRollupDataSubmission ¶
func (x *GenesisFees) SetRollupDataSubmission(v *v11.RollupDataSubmissionFeeComponents)
func (*GenesisFees) SetSudoAddressChange ¶
func (x *GenesisFees) SetSudoAddressChange(v *v11.SudoAddressChangeFeeComponents)
func (*GenesisFees) SetTransfer ¶
func (x *GenesisFees) SetTransfer(v *v11.TransferFeeComponents)
func (*GenesisFees) SetValidatorUpdate ¶
func (x *GenesisFees) SetValidatorUpdate(v *v11.ValidatorUpdateFeeComponents)
func (*GenesisFees) String ¶
func (x *GenesisFees) String() string
type GenesisFees_builder ¶
type GenesisFees_builder struct {
BridgeLock *v11.BridgeLockFeeComponents
BridgeSudoChange *v11.BridgeSudoChangeFeeComponents
BridgeUnlock *v11.BridgeUnlockFeeComponents
FeeAssetChange *v11.FeeAssetChangeFeeComponents
FeeChange *v11.FeeChangeFeeComponents
IbcRelay *v11.IbcRelayFeeComponents
IbcRelayerChange *v11.IbcRelayerChangeFeeComponents
IbcSudoChange *v11.IbcSudoChangeFeeComponents
Ics20Withdrawal *v11.Ics20WithdrawalFeeComponents
InitBridgeAccount *v11.InitBridgeAccountFeeComponents
RollupDataSubmission *v11.RollupDataSubmissionFeeComponents
SudoAddressChange *v11.SudoAddressChangeFeeComponents
Transfer *v11.TransferFeeComponents
ValidatorUpdate *v11.ValidatorUpdateFeeComponents
BridgeTransfer *v11.BridgeTransferFeeComponents
RecoverIbcClient *v11.RecoverIbcClientFeeComponents
CurrencyPairsChange *v11.CurrencyPairsChangeFeeComponents
MarketsChange *v11.MarketsChangeFeeComponents
// contains filtered or unexported fields
}
func (GenesisFees_builder) Build ¶
func (b0 GenesisFees_builder) Build() *GenesisFees
type IbcParameters ¶
type IbcParameters struct {
// Whether IBC (forming connections, processing IBC packets) is enabled.
IbcEnabled bool `protobuf:"varint,1,opt,name=ibc_enabled,json=ibcEnabled,proto3" json:"ibc_enabled,omitempty"`
// Whether inbound ICS-20 transfers are enabled
InboundIcs20TransfersEnabled bool `` /* 150-byte string literal not displayed */
// Whether outbound ICS-20 transfers are enabled
OutboundIcs20TransfersEnabled bool `` /* 153-byte string literal not displayed */
// contains filtered or unexported fields
}
IBC configuration data.
func (*IbcParameters) GetIbcEnabled ¶
func (x *IbcParameters) GetIbcEnabled() bool
func (*IbcParameters) GetInboundIcs20TransfersEnabled ¶
func (x *IbcParameters) GetInboundIcs20TransfersEnabled() bool
func (*IbcParameters) GetOutboundIcs20TransfersEnabled ¶
func (x *IbcParameters) GetOutboundIcs20TransfersEnabled() bool
func (*IbcParameters) ProtoMessage ¶
func (*IbcParameters) ProtoMessage()
func (*IbcParameters) ProtoReflect ¶
func (x *IbcParameters) ProtoReflect() protoreflect.Message
func (*IbcParameters) Reset ¶
func (x *IbcParameters) Reset()
func (*IbcParameters) SetIbcEnabled ¶
func (x *IbcParameters) SetIbcEnabled(v bool)
func (*IbcParameters) SetInboundIcs20TransfersEnabled ¶
func (x *IbcParameters) SetInboundIcs20TransfersEnabled(v bool)
func (*IbcParameters) SetOutboundIcs20TransfersEnabled ¶
func (x *IbcParameters) SetOutboundIcs20TransfersEnabled(v bool)
func (*IbcParameters) String ¶
func (x *IbcParameters) String() string
type IbcParameters_builder ¶
type IbcParameters_builder struct {
// Whether IBC (forming connections, processing IBC packets) is enabled.
IbcEnabled bool
// Whether inbound ICS-20 transfers are enabled
InboundIcs20TransfersEnabled bool
// Whether outbound ICS-20 transfers are enabled
OutboundIcs20TransfersEnabled bool
// contains filtered or unexported fields
}
func (IbcParameters_builder) Build ¶
func (b0 IbcParameters_builder) Build() *IbcParameters
Source Files
¶
- types.pb.go
Click to show internal directories.
Click to hide internal directories.