Documentation
¶
Index ¶
- Variables
- type BlockIDFlag
- type ExtendedCommitInfo
- func (x *ExtendedCommitInfo) GetRound() int32
- func (x *ExtendedCommitInfo) GetVotes() []*ExtendedVoteInfo
- func (*ExtendedCommitInfo) ProtoMessage()
- func (x *ExtendedCommitInfo) ProtoReflect() protoreflect.Message
- func (x *ExtendedCommitInfo) Reset()
- func (x *ExtendedCommitInfo) SetRound(v int32)
- func (x *ExtendedCommitInfo) SetVotes(v []*ExtendedVoteInfo)
- func (x *ExtendedCommitInfo) String() string
- type ExtendedCommitInfo_builder
- type ExtendedVoteInfo
- func (x *ExtendedVoteInfo) ClearValidator()
- func (x *ExtendedVoteInfo) GetBlockIdFlag() BlockIDFlag
- func (x *ExtendedVoteInfo) GetExtensionSignature() []byte
- func (x *ExtendedVoteInfo) GetValidator() *Validator
- func (x *ExtendedVoteInfo) GetVoteExtension() []byte
- func (x *ExtendedVoteInfo) HasValidator() bool
- func (*ExtendedVoteInfo) ProtoMessage()
- func (x *ExtendedVoteInfo) ProtoReflect() protoreflect.Message
- func (x *ExtendedVoteInfo) Reset()
- func (x *ExtendedVoteInfo) SetBlockIdFlag(v BlockIDFlag)
- func (x *ExtendedVoteInfo) SetExtensionSignature(v []byte)
- func (x *ExtendedVoteInfo) SetValidator(v *Validator)
- func (x *ExtendedVoteInfo) SetVoteExtension(v []byte)
- func (x *ExtendedVoteInfo) String() string
- type ExtendedVoteInfo_builder
- type Validator
- func (x *Validator) GetAddress() []byte
- func (x *Validator) GetPower() int64
- func (*Validator) ProtoMessage()
- func (x *Validator) ProtoReflect() protoreflect.Message
- func (x *Validator) Reset()
- func (x *Validator) SetAddress(v []byte)
- func (x *Validator) SetPower(v int64)
- func (x *Validator) String() string
- type ValidatorUpdate
- func (x *ValidatorUpdate) ClearPubKey()
- func (x *ValidatorUpdate) GetPower() int64
- func (x *ValidatorUpdate) GetPubKey() *crypto.PublicKey
- func (x *ValidatorUpdate) HasPubKey() bool
- func (*ValidatorUpdate) ProtoMessage()
- func (x *ValidatorUpdate) ProtoReflect() protoreflect.Message
- func (x *ValidatorUpdate) Reset()
- func (x *ValidatorUpdate) SetPower(v int64)
- func (x *ValidatorUpdate) SetPubKey(v *crypto.PublicKey)
- func (x *ValidatorUpdate) String() string
- type ValidatorUpdate_builder
- type Validator_builder
Constants ¶
This section is empty.
Variables ¶
var ( BlockIDFlag_name = map[int32]string{ 0: "BLOCK_ID_FLAG_UNKNOWN", 1: "BLOCK_ID_FLAG_ABSENT", 2: "BLOCK_ID_FLAG_COMMIT", 3: "BLOCK_ID_FLAG_NIL", } BlockIDFlag_value = map[string]int32{ "BLOCK_ID_FLAG_UNKNOWN": 0, "BLOCK_ID_FLAG_ABSENT": 1, "BLOCK_ID_FLAG_COMMIT": 2, "BLOCK_ID_FLAG_NIL": 3, } )
Enum value maps for BlockIDFlag.
var File_astria_vendored_tendermint_abci_types_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type BlockIDFlag ¶
type BlockIDFlag int32
const ( BlockIDFlag_BLOCK_ID_FLAG_UNKNOWN BlockIDFlag = 0 BlockIDFlag_BLOCK_ID_FLAG_ABSENT BlockIDFlag = 1 BlockIDFlag_BLOCK_ID_FLAG_COMMIT BlockIDFlag = 2 BlockIDFlag_BLOCK_ID_FLAG_NIL BlockIDFlag = 3 )
func (BlockIDFlag) Descriptor ¶
func (BlockIDFlag) Descriptor() protoreflect.EnumDescriptor
func (BlockIDFlag) Enum ¶
func (x BlockIDFlag) Enum() *BlockIDFlag
func (BlockIDFlag) Number ¶
func (x BlockIDFlag) Number() protoreflect.EnumNumber
func (BlockIDFlag) String ¶
func (x BlockIDFlag) String() string
func (BlockIDFlag) Type ¶
func (BlockIDFlag) Type() protoreflect.EnumType
type ExtendedCommitInfo ¶
type ExtendedCommitInfo struct {
// The round at which the block proposer decided in the previous height.
Round int32 `protobuf:"varint,1,opt,name=round,proto3" json:"round,omitempty"`
// List of validators' addresses in the last validator set with their voting
// information, including vote extensions.
Votes []*ExtendedVoteInfo `protobuf:"bytes,2,rep,name=votes,proto3" json:"votes,omitempty"`
// contains filtered or unexported fields
}
func (*ExtendedCommitInfo) GetRound ¶
func (x *ExtendedCommitInfo) GetRound() int32
func (*ExtendedCommitInfo) GetVotes ¶
func (x *ExtendedCommitInfo) GetVotes() []*ExtendedVoteInfo
func (*ExtendedCommitInfo) ProtoMessage ¶
func (*ExtendedCommitInfo) ProtoMessage()
func (*ExtendedCommitInfo) ProtoReflect ¶
func (x *ExtendedCommitInfo) ProtoReflect() protoreflect.Message
func (*ExtendedCommitInfo) Reset ¶
func (x *ExtendedCommitInfo) Reset()
func (*ExtendedCommitInfo) SetRound ¶
func (x *ExtendedCommitInfo) SetRound(v int32)
func (*ExtendedCommitInfo) SetVotes ¶
func (x *ExtendedCommitInfo) SetVotes(v []*ExtendedVoteInfo)
func (*ExtendedCommitInfo) String ¶
func (x *ExtendedCommitInfo) String() string
type ExtendedCommitInfo_builder ¶
type ExtendedCommitInfo_builder struct {
// The round at which the block proposer decided in the previous height.
Round int32
// List of validators' addresses in the last validator set with their voting
// information, including vote extensions.
Votes []*ExtendedVoteInfo
// contains filtered or unexported fields
}
func (ExtendedCommitInfo_builder) Build ¶
func (b0 ExtendedCommitInfo_builder) Build() *ExtendedCommitInfo
type ExtendedVoteInfo ¶
type ExtendedVoteInfo struct {
// The validator that sent the vote.
Validator *Validator `protobuf:"bytes,1,opt,name=validator,proto3" json:"validator,omitempty"`
// Non-deterministic extension provided by the sending validator's application.
VoteExtension []byte `protobuf:"bytes,3,opt,name=vote_extension,json=voteExtension,proto3" json:"vote_extension,omitempty"`
// Vote extension signature created by CometBFT
ExtensionSignature []byte `protobuf:"bytes,4,opt,name=extension_signature,json=extensionSignature,proto3" json:"extension_signature,omitempty"`
// block_id_flag indicates whether the validator voted for a block, nil, or did not vote at all
BlockIdFlag BlockIDFlag `` /* 146-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*ExtendedVoteInfo) ClearValidator ¶
func (x *ExtendedVoteInfo) ClearValidator()
func (*ExtendedVoteInfo) GetBlockIdFlag ¶
func (x *ExtendedVoteInfo) GetBlockIdFlag() BlockIDFlag
func (*ExtendedVoteInfo) GetExtensionSignature ¶
func (x *ExtendedVoteInfo) GetExtensionSignature() []byte
func (*ExtendedVoteInfo) GetValidator ¶
func (x *ExtendedVoteInfo) GetValidator() *Validator
func (*ExtendedVoteInfo) GetVoteExtension ¶
func (x *ExtendedVoteInfo) GetVoteExtension() []byte
func (*ExtendedVoteInfo) HasValidator ¶
func (x *ExtendedVoteInfo) HasValidator() bool
func (*ExtendedVoteInfo) ProtoMessage ¶
func (*ExtendedVoteInfo) ProtoMessage()
func (*ExtendedVoteInfo) ProtoReflect ¶
func (x *ExtendedVoteInfo) ProtoReflect() protoreflect.Message
func (*ExtendedVoteInfo) Reset ¶
func (x *ExtendedVoteInfo) Reset()
func (*ExtendedVoteInfo) SetBlockIdFlag ¶
func (x *ExtendedVoteInfo) SetBlockIdFlag(v BlockIDFlag)
func (*ExtendedVoteInfo) SetExtensionSignature ¶
func (x *ExtendedVoteInfo) SetExtensionSignature(v []byte)
func (*ExtendedVoteInfo) SetValidator ¶
func (x *ExtendedVoteInfo) SetValidator(v *Validator)
func (*ExtendedVoteInfo) SetVoteExtension ¶
func (x *ExtendedVoteInfo) SetVoteExtension(v []byte)
func (*ExtendedVoteInfo) String ¶
func (x *ExtendedVoteInfo) String() string
type ExtendedVoteInfo_builder ¶
type ExtendedVoteInfo_builder struct {
// The validator that sent the vote.
Validator *Validator
// Non-deterministic extension provided by the sending validator's application.
VoteExtension []byte
// Vote extension signature created by CometBFT
ExtensionSignature []byte
// block_id_flag indicates whether the validator voted for a block, nil, or did not vote at all
BlockIdFlag BlockIDFlag
// contains filtered or unexported fields
}
func (ExtendedVoteInfo_builder) Build ¶
func (b0 ExtendedVoteInfo_builder) Build() *ExtendedVoteInfo
type Validator ¶
type Validator struct {
Address []byte `protobuf:"bytes,1,opt,name=address,proto3" json:"address,omitempty"`
Power int64 `protobuf:"varint,3,opt,name=power,proto3" json:"power,omitempty"`
// contains filtered or unexported fields
}
func (*Validator) ProtoReflect ¶
func (x *Validator) ProtoReflect() protoreflect.Message
type ValidatorUpdate ¶
type ValidatorUpdate struct {
PubKey *crypto.PublicKey `protobuf:"bytes,1,opt,name=pub_key,json=pubKey,proto3" json:"pub_key,omitempty"`
Power int64 `protobuf:"varint,2,opt,name=power,proto3" json:"power,omitempty"`
// contains filtered or unexported fields
}
func (*ValidatorUpdate) ClearPubKey ¶
func (x *ValidatorUpdate) ClearPubKey()
func (*ValidatorUpdate) GetPower ¶
func (x *ValidatorUpdate) GetPower() int64
func (*ValidatorUpdate) GetPubKey ¶
func (x *ValidatorUpdate) GetPubKey() *crypto.PublicKey
func (*ValidatorUpdate) HasPubKey ¶
func (x *ValidatorUpdate) HasPubKey() bool
func (*ValidatorUpdate) ProtoMessage ¶
func (*ValidatorUpdate) ProtoMessage()
func (*ValidatorUpdate) ProtoReflect ¶
func (x *ValidatorUpdate) ProtoReflect() protoreflect.Message
func (*ValidatorUpdate) Reset ¶
func (x *ValidatorUpdate) Reset()
func (*ValidatorUpdate) SetPower ¶
func (x *ValidatorUpdate) SetPower(v int64)
func (*ValidatorUpdate) SetPubKey ¶
func (x *ValidatorUpdate) SetPubKey(v *crypto.PublicKey)
func (*ValidatorUpdate) String ¶
func (x *ValidatorUpdate) String() string
type ValidatorUpdate_builder ¶
type ValidatorUpdate_builder struct {
PubKey *crypto.PublicKey
Power int64
// contains filtered or unexported fields
}
func (ValidatorUpdate_builder) Build ¶
func (b0 ValidatorUpdate_builder) Build() *ValidatorUpdate
Source Files
¶
- types.pb.go
Click to show internal directories.
Click to hide internal directories.