Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterOptimisticBlockServiceServer(s grpc.ServiceRegistrar, srv OptimisticBlockServiceServer)
- type OptimisticBlockServiceClient
- type OptimisticBlockServiceServer
- type OptimisticBlockService_GetBlockCommitmentStreamClient
- type OptimisticBlockService_GetBlockCommitmentStreamServer
- type OptimisticBlockService_GetOptimisticBlockStreamClient
- type OptimisticBlockService_GetOptimisticBlockStreamServer
- type UnimplementedOptimisticBlockServiceServer
- type UnsafeOptimisticBlockServiceServer
Constants ¶
const ( OptimisticBlockService_GetOptimisticBlockStream_FullMethodName = "/astria.sequencerblock.optimistic.v1alpha1.OptimisticBlockService/GetOptimisticBlockStream" OptimisticBlockService_GetBlockCommitmentStream_FullMethodName = "/astria.sequencerblock.optimistic.v1alpha1.OptimisticBlockService/GetBlockCommitmentStream" )
Variables ¶
var OptimisticBlockService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "astria.sequencerblock.optimistic.v1alpha1.OptimisticBlockService", HandlerType: (*OptimisticBlockServiceServer)(nil), Methods: []grpc.MethodDesc{}, Streams: []grpc.StreamDesc{ { StreamName: "GetOptimisticBlockStream", Handler: _OptimisticBlockService_GetOptimisticBlockStream_Handler, ServerStreams: true, }, { StreamName: "GetBlockCommitmentStream", Handler: _OptimisticBlockService_GetBlockCommitmentStream_Handler, ServerStreams: true, }, }, Metadata: "astria/sequencerblock/optimistic/v1alpha1/service.proto", }
OptimisticBlockService_ServiceDesc is the grpc.ServiceDesc for OptimisticBlockService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterOptimisticBlockServiceServer ¶
func RegisterOptimisticBlockServiceServer(s grpc.ServiceRegistrar, srv OptimisticBlockServiceServer)
Types ¶
type OptimisticBlockServiceClient ¶
type OptimisticBlockServiceClient interface {
// The Sequencer will stream the optimistic Sequencer block (filtered for the provided
// rollup id) to the Auctioneer.
GetOptimisticBlockStream(ctx context.Context, in *v1alpha1.GetOptimisticBlockStreamRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[v1alpha1.GetOptimisticBlockStreamResponse], error)
// The Sequencer will stream the block commits to the Auctioneer.
GetBlockCommitmentStream(ctx context.Context, in *v1alpha1.GetBlockCommitmentStreamRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[v1alpha1.GetBlockCommitmentStreamResponse], error)
}
OptimisticBlockServiceClient is the client API for OptimisticBlockService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
The Sequencer will serve this to the aucitoneer
func NewOptimisticBlockServiceClient ¶
func NewOptimisticBlockServiceClient(cc grpc.ClientConnInterface) OptimisticBlockServiceClient
type OptimisticBlockServiceServer ¶
type OptimisticBlockServiceServer interface {
// The Sequencer will stream the optimistic Sequencer block (filtered for the provided
// rollup id) to the Auctioneer.
GetOptimisticBlockStream(*v1alpha1.GetOptimisticBlockStreamRequest, grpc.ServerStreamingServer[v1alpha1.GetOptimisticBlockStreamResponse]) error
// The Sequencer will stream the block commits to the Auctioneer.
GetBlockCommitmentStream(*v1alpha1.GetBlockCommitmentStreamRequest, grpc.ServerStreamingServer[v1alpha1.GetBlockCommitmentStreamResponse]) error
}
OptimisticBlockServiceServer is the server API for OptimisticBlockService service. All implementations should embed UnimplementedOptimisticBlockServiceServer for forward compatibility.
The Sequencer will serve this to the aucitoneer
type OptimisticBlockService_GetBlockCommitmentStreamClient ¶
type OptimisticBlockService_GetBlockCommitmentStreamClient = grpc.ServerStreamingClient[v1alpha1.GetBlockCommitmentStreamResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type OptimisticBlockService_GetBlockCommitmentStreamServer ¶
type OptimisticBlockService_GetBlockCommitmentStreamServer = grpc.ServerStreamingServer[v1alpha1.GetBlockCommitmentStreamResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type OptimisticBlockService_GetOptimisticBlockStreamClient ¶
type OptimisticBlockService_GetOptimisticBlockStreamClient = grpc.ServerStreamingClient[v1alpha1.GetOptimisticBlockStreamResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type OptimisticBlockService_GetOptimisticBlockStreamServer ¶
type OptimisticBlockService_GetOptimisticBlockStreamServer = grpc.ServerStreamingServer[v1alpha1.GetOptimisticBlockStreamResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type UnimplementedOptimisticBlockServiceServer ¶
type UnimplementedOptimisticBlockServiceServer struct{}
UnimplementedOptimisticBlockServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedOptimisticBlockServiceServer) GetBlockCommitmentStream ¶
func (UnimplementedOptimisticBlockServiceServer) GetBlockCommitmentStream(*v1alpha1.GetBlockCommitmentStreamRequest, grpc.ServerStreamingServer[v1alpha1.GetBlockCommitmentStreamResponse]) error
func (UnimplementedOptimisticBlockServiceServer) GetOptimisticBlockStream ¶
func (UnimplementedOptimisticBlockServiceServer) GetOptimisticBlockStream(*v1alpha1.GetOptimisticBlockStreamRequest, grpc.ServerStreamingServer[v1alpha1.GetOptimisticBlockStreamResponse]) error
type UnsafeOptimisticBlockServiceServer ¶
type UnsafeOptimisticBlockServiceServer interface {
// contains filtered or unexported methods
}
UnsafeOptimisticBlockServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to OptimisticBlockServiceServer will result in compilation errors.
Source Files
¶
- service_grpc.pb.go