Documentation
¶
Overview ¶
Package apiv1gateway is a reverse proxy.
It translates gRPC into RESTful JSON APIs.
Package apiv1gateway is a reverse proxy.
It translates gRPC into RESTful JSON APIs.
Package apiv1gateway is a reverse proxy.
It translates gRPC into RESTful JSON APIs.
Package apiv1gateway is a reverse proxy.
It translates gRPC into RESTful JSON APIs.
Index ¶
- func RegisterExperimentalServiceHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error
- func RegisterExperimentalServiceHandlerClient(ctx context.Context, mux *runtime.ServeMux, ...) error
- func RegisterExperimentalServiceHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, ...) (err error)
- func RegisterExperimentalServiceHandlerServer(ctx context.Context, mux *runtime.ServeMux, ...) error
- func RegisterPermissionsServiceHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error
- func RegisterPermissionsServiceHandlerClient(ctx context.Context, mux *runtime.ServeMux, ...) error
- func RegisterPermissionsServiceHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, ...) (err error)
- func RegisterPermissionsServiceHandlerServer(ctx context.Context, mux *runtime.ServeMux, ...) error
- func RegisterSchemaServiceHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error
- func RegisterSchemaServiceHandlerClient(ctx context.Context, mux *runtime.ServeMux, ...) error
- func RegisterSchemaServiceHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, ...) (err error)
- func RegisterSchemaServiceHandlerServer(ctx context.Context, mux *runtime.ServeMux, ...) error
- func RegisterWatchServiceHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error
- func RegisterWatchServiceHandlerClient(ctx context.Context, mux *runtime.ServeMux, ...) error
- func RegisterWatchServiceHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, ...) (err error)
- func RegisterWatchServiceHandlerServer(ctx context.Context, mux *runtime.ServeMux, ...) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func RegisterExperimentalServiceHandler ¶
func RegisterExperimentalServiceHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error
RegisterExperimentalServiceHandler registers the http handlers for service ExperimentalService to "mux". The handlers forward requests to the grpc endpoint over "conn".
func RegisterExperimentalServiceHandlerClient ¶
func RegisterExperimentalServiceHandlerClient(ctx context.Context, mux *runtime.ServeMux, client apiv1grpc.ExperimentalServiceClient) error
RegisterExperimentalServiceHandlerClient registers the http handlers for service ExperimentalService to "mux". The handlers forward requests to the grpc endpoint over the given implementation of "apiv1grpc.ExperimentalServiceClient". Note: the gRPC framework executes interceptors within the gRPC handler. If the passed in "apiv1grpc.ExperimentalServiceClient" doesn't go through the normal gRPC flow (creating a gRPC client etc.) then it will be up to the passed in "apiv1grpc.ExperimentalServiceClient" to call the correct interceptors. This client ignores the HTTP middlewares.
func RegisterExperimentalServiceHandlerFromEndpoint ¶
func RegisterExperimentalServiceHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, opts []grpc.DialOption) (err error)
RegisterExperimentalServiceHandlerFromEndpoint is same as RegisterExperimentalServiceHandler but automatically dials to "endpoint" and closes the connection when "ctx" gets done.
func RegisterExperimentalServiceHandlerServer ¶
func RegisterExperimentalServiceHandlerServer(ctx context.Context, mux *runtime.ServeMux, server apiv1grpc.ExperimentalServiceServer) error
RegisterExperimentalServiceHandlerServer registers the http handlers for service ExperimentalService to "mux". UnaryRPC :call ExperimentalServiceServer directly. StreamingRPC :currently unsupported pending https://github.com/grpc/grpc-go/issues/906. Note that using this registration option will cause many gRPC library features to stop working. Consider using RegisterExperimentalServiceHandlerFromEndpoint instead. GRPC interceptors will not work for this type of registration. To use interceptors, you must use the "runtime.WithMiddlewares" option in the "runtime.NewServeMux" call.
func RegisterPermissionsServiceHandler ¶
func RegisterPermissionsServiceHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error
RegisterPermissionsServiceHandler registers the http handlers for service PermissionsService to "mux". The handlers forward requests to the grpc endpoint over "conn".
func RegisterPermissionsServiceHandlerClient ¶
func RegisterPermissionsServiceHandlerClient(ctx context.Context, mux *runtime.ServeMux, client apiv1grpc.PermissionsServiceClient) error
RegisterPermissionsServiceHandlerClient registers the http handlers for service PermissionsService to "mux". The handlers forward requests to the grpc endpoint over the given implementation of "apiv1grpc.PermissionsServiceClient". Note: the gRPC framework executes interceptors within the gRPC handler. If the passed in "apiv1grpc.PermissionsServiceClient" doesn't go through the normal gRPC flow (creating a gRPC client etc.) then it will be up to the passed in "apiv1grpc.PermissionsServiceClient" to call the correct interceptors. This client ignores the HTTP middlewares.
func RegisterPermissionsServiceHandlerFromEndpoint ¶
func RegisterPermissionsServiceHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, opts []grpc.DialOption) (err error)
RegisterPermissionsServiceHandlerFromEndpoint is same as RegisterPermissionsServiceHandler but automatically dials to "endpoint" and closes the connection when "ctx" gets done.
func RegisterPermissionsServiceHandlerServer ¶
func RegisterPermissionsServiceHandlerServer(ctx context.Context, mux *runtime.ServeMux, server apiv1grpc.PermissionsServiceServer) error
RegisterPermissionsServiceHandlerServer registers the http handlers for service PermissionsService to "mux". UnaryRPC :call PermissionsServiceServer directly. StreamingRPC :currently unsupported pending https://github.com/grpc/grpc-go/issues/906. Note that using this registration option will cause many gRPC library features to stop working. Consider using RegisterPermissionsServiceHandlerFromEndpoint instead. GRPC interceptors will not work for this type of registration. To use interceptors, you must use the "runtime.WithMiddlewares" option in the "runtime.NewServeMux" call.
func RegisterSchemaServiceHandler ¶
func RegisterSchemaServiceHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error
RegisterSchemaServiceHandler registers the http handlers for service SchemaService to "mux". The handlers forward requests to the grpc endpoint over "conn".
func RegisterSchemaServiceHandlerClient ¶
func RegisterSchemaServiceHandlerClient(ctx context.Context, mux *runtime.ServeMux, client apiv1grpc.SchemaServiceClient) error
RegisterSchemaServiceHandlerClient registers the http handlers for service SchemaService to "mux". The handlers forward requests to the grpc endpoint over the given implementation of "apiv1grpc.SchemaServiceClient". Note: the gRPC framework executes interceptors within the gRPC handler. If the passed in "apiv1grpc.SchemaServiceClient" doesn't go through the normal gRPC flow (creating a gRPC client etc.) then it will be up to the passed in "apiv1grpc.SchemaServiceClient" to call the correct interceptors. This client ignores the HTTP middlewares.
func RegisterSchemaServiceHandlerFromEndpoint ¶
func RegisterSchemaServiceHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, opts []grpc.DialOption) (err error)
RegisterSchemaServiceHandlerFromEndpoint is same as RegisterSchemaServiceHandler but automatically dials to "endpoint" and closes the connection when "ctx" gets done.
func RegisterSchemaServiceHandlerServer ¶
func RegisterSchemaServiceHandlerServer(ctx context.Context, mux *runtime.ServeMux, server apiv1grpc.SchemaServiceServer) error
RegisterSchemaServiceHandlerServer registers the http handlers for service SchemaService to "mux". UnaryRPC :call SchemaServiceServer directly. StreamingRPC :currently unsupported pending https://github.com/grpc/grpc-go/issues/906. Note that using this registration option will cause many gRPC library features to stop working. Consider using RegisterSchemaServiceHandlerFromEndpoint instead. GRPC interceptors will not work for this type of registration. To use interceptors, you must use the "runtime.WithMiddlewares" option in the "runtime.NewServeMux" call.
func RegisterWatchServiceHandler ¶
func RegisterWatchServiceHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error
RegisterWatchServiceHandler registers the http handlers for service WatchService to "mux". The handlers forward requests to the grpc endpoint over "conn".
func RegisterWatchServiceHandlerClient ¶
func RegisterWatchServiceHandlerClient(ctx context.Context, mux *runtime.ServeMux, client apiv1grpc.WatchServiceClient) error
RegisterWatchServiceHandlerClient registers the http handlers for service WatchService to "mux". The handlers forward requests to the grpc endpoint over the given implementation of "apiv1grpc.WatchServiceClient". Note: the gRPC framework executes interceptors within the gRPC handler. If the passed in "apiv1grpc.WatchServiceClient" doesn't go through the normal gRPC flow (creating a gRPC client etc.) then it will be up to the passed in "apiv1grpc.WatchServiceClient" to call the correct interceptors. This client ignores the HTTP middlewares.
func RegisterWatchServiceHandlerFromEndpoint ¶
func RegisterWatchServiceHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, opts []grpc.DialOption) (err error)
RegisterWatchServiceHandlerFromEndpoint is same as RegisterWatchServiceHandler but automatically dials to "endpoint" and closes the connection when "ctx" gets done.
func RegisterWatchServiceHandlerServer ¶
func RegisterWatchServiceHandlerServer(ctx context.Context, mux *runtime.ServeMux, server apiv1grpc.WatchServiceServer) error
RegisterWatchServiceHandlerServer registers the http handlers for service WatchService to "mux". UnaryRPC :call WatchServiceServer directly. StreamingRPC :currently unsupported pending https://github.com/grpc/grpc-go/issues/906. Note that using this registration option will cause many gRPC library features to stop working. Consider using RegisterWatchServiceHandlerFromEndpoint instead. GRPC interceptors will not work for this type of registration. To use interceptors, you must use the "runtime.WithMiddlewares" option in the "runtime.NewServeMux" call.
Types ¶
This section is empty.
Source Files
¶
- experimental_service.pb.gw.go
- permission_service.pb.gw.go
- schema_service.pb.gw.go
- watch_service.pb.gw.go