Documentation
¶
Index ¶
- Variables
- type FetchBlobRequest
- func (x *FetchBlobRequest) ClearOldestContentAccepted()
- func (x *FetchBlobRequest) ClearTimeout()
- func (x *FetchBlobRequest) GetInstanceName() string
- func (x *FetchBlobRequest) GetOldestContentAccepted() *timestamppb.Timestamp
- func (x *FetchBlobRequest) GetQualifiers() []*Qualifier
- func (x *FetchBlobRequest) GetTimeout() *durationpb.Duration
- func (x *FetchBlobRequest) GetUris() []string
- func (x *FetchBlobRequest) HasOldestContentAccepted() bool
- func (x *FetchBlobRequest) HasTimeout() bool
- func (*FetchBlobRequest) ProtoMessage()
- func (x *FetchBlobRequest) ProtoReflect() protoreflect.Message
- func (x *FetchBlobRequest) Reset()
- func (x *FetchBlobRequest) SetInstanceName(v string)
- func (x *FetchBlobRequest) SetOldestContentAccepted(v *timestamppb.Timestamp)
- func (x *FetchBlobRequest) SetQualifiers(v []*Qualifier)
- func (x *FetchBlobRequest) SetTimeout(v *durationpb.Duration)
- func (x *FetchBlobRequest) SetUris(v []string)
- func (x *FetchBlobRequest) String() string
- type FetchBlobRequest_builder
- type FetchBlobResponse
- func (x *FetchBlobResponse) ClearBlobDigest()
- func (x *FetchBlobResponse) ClearExpiresAt()
- func (x *FetchBlobResponse) ClearStatus()
- func (x *FetchBlobResponse) GetBlobDigest() *v2.Digest
- func (x *FetchBlobResponse) GetExpiresAt() *timestamppb.Timestamp
- func (x *FetchBlobResponse) GetQualifiers() []*Qualifier
- func (x *FetchBlobResponse) GetStatus() *status.Status
- func (x *FetchBlobResponse) GetUri() string
- func (x *FetchBlobResponse) HasBlobDigest() bool
- func (x *FetchBlobResponse) HasExpiresAt() bool
- func (x *FetchBlobResponse) HasStatus() bool
- func (*FetchBlobResponse) ProtoMessage()
- func (x *FetchBlobResponse) ProtoReflect() protoreflect.Message
- func (x *FetchBlobResponse) Reset()
- func (x *FetchBlobResponse) SetBlobDigest(v *v2.Digest)
- func (x *FetchBlobResponse) SetExpiresAt(v *timestamppb.Timestamp)
- func (x *FetchBlobResponse) SetQualifiers(v []*Qualifier)
- func (x *FetchBlobResponse) SetStatus(v *status.Status)
- func (x *FetchBlobResponse) SetUri(v string)
- func (x *FetchBlobResponse) String() string
- type FetchBlobResponse_builder
- type FetchDirectoryRequest
- func (x *FetchDirectoryRequest) ClearOldestContentAccepted()
- func (x *FetchDirectoryRequest) ClearTimeout()
- func (x *FetchDirectoryRequest) GetInstanceName() string
- func (x *FetchDirectoryRequest) GetOldestContentAccepted() *timestamppb.Timestamp
- func (x *FetchDirectoryRequest) GetQualifiers() []*Qualifier
- func (x *FetchDirectoryRequest) GetTimeout() *durationpb.Duration
- func (x *FetchDirectoryRequest) GetUris() []string
- func (x *FetchDirectoryRequest) HasOldestContentAccepted() bool
- func (x *FetchDirectoryRequest) HasTimeout() bool
- func (*FetchDirectoryRequest) ProtoMessage()
- func (x *FetchDirectoryRequest) ProtoReflect() protoreflect.Message
- func (x *FetchDirectoryRequest) Reset()
- func (x *FetchDirectoryRequest) SetInstanceName(v string)
- func (x *FetchDirectoryRequest) SetOldestContentAccepted(v *timestamppb.Timestamp)
- func (x *FetchDirectoryRequest) SetQualifiers(v []*Qualifier)
- func (x *FetchDirectoryRequest) SetTimeout(v *durationpb.Duration)
- func (x *FetchDirectoryRequest) SetUris(v []string)
- func (x *FetchDirectoryRequest) String() string
- type FetchDirectoryRequest_builder
- type FetchDirectoryResponse
- func (x *FetchDirectoryResponse) ClearExpiresAt()
- func (x *FetchDirectoryResponse) ClearRootDirectoryDigest()
- func (x *FetchDirectoryResponse) ClearStatus()
- func (x *FetchDirectoryResponse) GetExpiresAt() *timestamppb.Timestamp
- func (x *FetchDirectoryResponse) GetQualifiers() []*Qualifier
- func (x *FetchDirectoryResponse) GetRootDirectoryDigest() *v2.Digest
- func (x *FetchDirectoryResponse) GetStatus() *status.Status
- func (x *FetchDirectoryResponse) GetUri() string
- func (x *FetchDirectoryResponse) HasExpiresAt() bool
- func (x *FetchDirectoryResponse) HasRootDirectoryDigest() bool
- func (x *FetchDirectoryResponse) HasStatus() bool
- func (*FetchDirectoryResponse) ProtoMessage()
- func (x *FetchDirectoryResponse) ProtoReflect() protoreflect.Message
- func (x *FetchDirectoryResponse) Reset()
- func (x *FetchDirectoryResponse) SetExpiresAt(v *timestamppb.Timestamp)
- func (x *FetchDirectoryResponse) SetQualifiers(v []*Qualifier)
- func (x *FetchDirectoryResponse) SetRootDirectoryDigest(v *v2.Digest)
- func (x *FetchDirectoryResponse) SetStatus(v *status.Status)
- func (x *FetchDirectoryResponse) SetUri(v string)
- func (x *FetchDirectoryResponse) String() string
- type FetchDirectoryResponse_builder
- type PushBlobRequest
- func (x *PushBlobRequest) ClearBlobDigest()
- func (x *PushBlobRequest) ClearExpireAt()
- func (x *PushBlobRequest) GetBlobDigest() *v2.Digest
- func (x *PushBlobRequest) GetExpireAt() *timestamppb.Timestamp
- func (x *PushBlobRequest) GetInstanceName() string
- func (x *PushBlobRequest) GetQualifiers() []*Qualifier
- func (x *PushBlobRequest) GetReferencesBlobs() []*v2.Digest
- func (x *PushBlobRequest) GetReferencesDirectories() []*v2.Digest
- func (x *PushBlobRequest) GetUris() []string
- func (x *PushBlobRequest) HasBlobDigest() bool
- func (x *PushBlobRequest) HasExpireAt() bool
- func (*PushBlobRequest) ProtoMessage()
- func (x *PushBlobRequest) ProtoReflect() protoreflect.Message
- func (x *PushBlobRequest) Reset()
- func (x *PushBlobRequest) SetBlobDigest(v *v2.Digest)
- func (x *PushBlobRequest) SetExpireAt(v *timestamppb.Timestamp)
- func (x *PushBlobRequest) SetInstanceName(v string)
- func (x *PushBlobRequest) SetQualifiers(v []*Qualifier)
- func (x *PushBlobRequest) SetReferencesBlobs(v []*v2.Digest)
- func (x *PushBlobRequest) SetReferencesDirectories(v []*v2.Digest)
- func (x *PushBlobRequest) SetUris(v []string)
- func (x *PushBlobRequest) String() string
- type PushBlobRequest_builder
- type PushBlobResponse
- type PushBlobResponse_builder
- type PushDirectoryRequest
- func (x *PushDirectoryRequest) ClearExpireAt()
- func (x *PushDirectoryRequest) ClearRootDirectoryDigest()
- func (x *PushDirectoryRequest) GetExpireAt() *timestamppb.Timestamp
- func (x *PushDirectoryRequest) GetInstanceName() string
- func (x *PushDirectoryRequest) GetQualifiers() []*Qualifier
- func (x *PushDirectoryRequest) GetReferencesBlobs() []*v2.Digest
- func (x *PushDirectoryRequest) GetReferencesDirectories() []*v2.Digest
- func (x *PushDirectoryRequest) GetRootDirectoryDigest() *v2.Digest
- func (x *PushDirectoryRequest) GetUris() []string
- func (x *PushDirectoryRequest) HasExpireAt() bool
- func (x *PushDirectoryRequest) HasRootDirectoryDigest() bool
- func (*PushDirectoryRequest) ProtoMessage()
- func (x *PushDirectoryRequest) ProtoReflect() protoreflect.Message
- func (x *PushDirectoryRequest) Reset()
- func (x *PushDirectoryRequest) SetExpireAt(v *timestamppb.Timestamp)
- func (x *PushDirectoryRequest) SetInstanceName(v string)
- func (x *PushDirectoryRequest) SetQualifiers(v []*Qualifier)
- func (x *PushDirectoryRequest) SetReferencesBlobs(v []*v2.Digest)
- func (x *PushDirectoryRequest) SetReferencesDirectories(v []*v2.Digest)
- func (x *PushDirectoryRequest) SetRootDirectoryDigest(v *v2.Digest)
- func (x *PushDirectoryRequest) SetUris(v []string)
- func (x *PushDirectoryRequest) String() string
- type PushDirectoryRequest_builder
- type PushDirectoryResponse
- type PushDirectoryResponse_builder
- type Qualifier
- func (x *Qualifier) GetName() string
- func (x *Qualifier) GetValue() string
- func (*Qualifier) ProtoMessage()
- func (x *Qualifier) ProtoReflect() protoreflect.Message
- func (x *Qualifier) Reset()
- func (x *Qualifier) SetName(v string)
- func (x *Qualifier) SetValue(v string)
- func (x *Qualifier) String() string
- type Qualifier_builder
Constants ¶
This section is empty.
Variables ¶
var File_build_bazel_remote_asset_v1_remote_asset_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type FetchBlobRequest ¶
type FetchBlobRequest struct {
// The instance of the execution system to operate against. A server may
// support multiple instances of the execution system (with their own workers,
// storage, caches, etc.). The server MAY require use of this field to select
// between them in an implementation-defined fashion, otherwise it can be
// omitted.
InstanceName string `protobuf:"bytes,1,opt,name=instance_name,json=instanceName,proto3" json:"instance_name,omitempty"`
// The timeout for the underlying fetch, if content needs to be retrieved from
// origin.
//
// If unset, the server *MAY* apply an implementation-defined timeout.
//
// If set, and the user-provided timeout exceeds the RPC deadline, the server
// *SHOULD* keep the fetch going after the RPC completes, to be made
// available for future Fetch calls. The server may also enforce (via clamping
// and/or an INVALID_ARGUMENT error) implementation-defined minimum and
// maximum timeout values.
//
// If this timeout is exceeded on an attempt to retrieve content from origin
// the client will receive DEADLINE_EXCEEDED in [FetchBlobResponse.status].
Timeout *durationpb.Duration `protobuf:"bytes,2,opt,name=timeout,proto3" json:"timeout,omitempty"`
// The oldest content the client is willing to accept, as measured from the
// time it was Push'd or when the underlying retrieval from origin was
// started.
// Upon retries of Fetch requests that cannot be completed within a single
// RPC, clients *SHOULD* provide the same value for subsequent requests as the
// original, to simplify combining the request with the previous attempt.
//
// If unset, the client *SHOULD* accept content of any age.
OldestContentAccepted *timestamppb.Timestamp `` /* 126-byte string literal not displayed */
// The URI(s) of the content to fetch. These may be resources that the server
// can directly fetch from origin, in which case multiple URIs *SHOULD*
// represent the same content available at different locations (such as an
// origin and secondary mirrors). These may also be URIs for content known to
// the server through other mechanisms, e.g. pushed via the [Push][build.bazel.remote.asset.v1.Push]
// service.
//
// Clients *MUST* supply at least one URI. Servers *MAY* match any one of the
// supplied URIs.
Uris []string `protobuf:"bytes,4,rep,name=uris,proto3" json:"uris,omitempty"`
// Qualifiers sub-specifying the content to fetch - see comments on
// [Qualifier][build.bazel.remote.asset.v1.Qualifier].
// The same qualifiers apply to all URIs.
//
// Specified qualifier names *MUST* be unique.
Qualifiers []*Qualifier `protobuf:"bytes,5,rep,name=qualifiers,proto3" json:"qualifiers,omitempty"`
// contains filtered or unexported fields
}
A request message for [Fetch.FetchBlob][build.bazel.remote.asset.v1.Fetch.FetchBlob].
func (*FetchBlobRequest) ClearOldestContentAccepted ¶
func (x *FetchBlobRequest) ClearOldestContentAccepted()
func (*FetchBlobRequest) ClearTimeout ¶
func (x *FetchBlobRequest) ClearTimeout()
func (*FetchBlobRequest) GetInstanceName ¶
func (x *FetchBlobRequest) GetInstanceName() string
func (*FetchBlobRequest) GetOldestContentAccepted ¶
func (x *FetchBlobRequest) GetOldestContentAccepted() *timestamppb.Timestamp
func (*FetchBlobRequest) GetQualifiers ¶
func (x *FetchBlobRequest) GetQualifiers() []*Qualifier
func (*FetchBlobRequest) GetTimeout ¶
func (x *FetchBlobRequest) GetTimeout() *durationpb.Duration
func (*FetchBlobRequest) GetUris ¶
func (x *FetchBlobRequest) GetUris() []string
func (*FetchBlobRequest) HasOldestContentAccepted ¶
func (x *FetchBlobRequest) HasOldestContentAccepted() bool
func (*FetchBlobRequest) HasTimeout ¶
func (x *FetchBlobRequest) HasTimeout() bool
func (*FetchBlobRequest) ProtoMessage ¶
func (*FetchBlobRequest) ProtoMessage()
func (*FetchBlobRequest) ProtoReflect ¶
func (x *FetchBlobRequest) ProtoReflect() protoreflect.Message
func (*FetchBlobRequest) Reset ¶
func (x *FetchBlobRequest) Reset()
func (*FetchBlobRequest) SetInstanceName ¶
func (x *FetchBlobRequest) SetInstanceName(v string)
func (*FetchBlobRequest) SetOldestContentAccepted ¶
func (x *FetchBlobRequest) SetOldestContentAccepted(v *timestamppb.Timestamp)
func (*FetchBlobRequest) SetQualifiers ¶
func (x *FetchBlobRequest) SetQualifiers(v []*Qualifier)
func (*FetchBlobRequest) SetTimeout ¶
func (x *FetchBlobRequest) SetTimeout(v *durationpb.Duration)
func (*FetchBlobRequest) SetUris ¶
func (x *FetchBlobRequest) SetUris(v []string)
func (*FetchBlobRequest) String ¶
func (x *FetchBlobRequest) String() string
type FetchBlobRequest_builder ¶
type FetchBlobRequest_builder struct {
// The instance of the execution system to operate against. A server may
// support multiple instances of the execution system (with their own workers,
// storage, caches, etc.). The server MAY require use of this field to select
// between them in an implementation-defined fashion, otherwise it can be
// omitted.
InstanceName string
// The timeout for the underlying fetch, if content needs to be retrieved from
// origin.
//
// If unset, the server *MAY* apply an implementation-defined timeout.
//
// If set, and the user-provided timeout exceeds the RPC deadline, the server
// *SHOULD* keep the fetch going after the RPC completes, to be made
// available for future Fetch calls. The server may also enforce (via clamping
// and/or an INVALID_ARGUMENT error) implementation-defined minimum and
// maximum timeout values.
//
// If this timeout is exceeded on an attempt to retrieve content from origin
// the client will receive DEADLINE_EXCEEDED in [FetchBlobResponse.status].
Timeout *durationpb.Duration
// The oldest content the client is willing to accept, as measured from the
// time it was Push'd or when the underlying retrieval from origin was
// started.
// Upon retries of Fetch requests that cannot be completed within a single
// RPC, clients *SHOULD* provide the same value for subsequent requests as the
// original, to simplify combining the request with the previous attempt.
//
// If unset, the client *SHOULD* accept content of any age.
OldestContentAccepted *timestamppb.Timestamp
// The URI(s) of the content to fetch. These may be resources that the server
// can directly fetch from origin, in which case multiple URIs *SHOULD*
// represent the same content available at different locations (such as an
// origin and secondary mirrors). These may also be URIs for content known to
// the server through other mechanisms, e.g. pushed via the [Push][build.bazel.remote.asset.v1.Push]
// service.
//
// Clients *MUST* supply at least one URI. Servers *MAY* match any one of the
// supplied URIs.
Uris []string
// Qualifiers sub-specifying the content to fetch - see comments on
// [Qualifier][build.bazel.remote.asset.v1.Qualifier].
// The same qualifiers apply to all URIs.
//
// Specified qualifier names *MUST* be unique.
Qualifiers []*Qualifier
// contains filtered or unexported fields
}
func (FetchBlobRequest_builder) Build ¶
func (b0 FetchBlobRequest_builder) Build() *FetchBlobRequest
type FetchBlobResponse ¶
type FetchBlobResponse struct {
// If the status has a code other than `OK`, it indicates that the operation
// was unable to be completed for reasons outside the servers' control.
// The possible fetch errors include:
// - `DEADLINE_EXCEEDED`: The operation could not be completed within the
// specified timeout.
// - `NOT_FOUND`: The requested asset was not found at the specified location.
// - `PERMISSION_DENIED`: The request was rejected by a remote server, or
// requested an asset from a disallowed origin.
// - `ABORTED`: The operation could not be completed, typically due to a
// failed consistency check.
// - `RESOURCE_EXHAUSTED`: There is insufficient quota of some resource to
// perform the requested operation. The client may retry after a delay.
Status *status.Status `protobuf:"bytes,1,opt,name=status,proto3" json:"status,omitempty"`
// The uri from the request that resulted in a successful retrieval, or from
// which the error indicated in `status` was obtained.
Uri string `protobuf:"bytes,2,opt,name=uri,proto3" json:"uri,omitempty"`
// Any qualifiers known to the server and of interest to clients.
Qualifiers []*Qualifier `protobuf:"bytes,3,rep,name=qualifiers,proto3" json:"qualifiers,omitempty"`
// A minimum timestamp the content is expected to be available through.
// Servers *MAY* omit this field, if not known with confidence.
ExpiresAt *timestamppb.Timestamp `protobuf:"bytes,4,opt,name=expires_at,json=expiresAt,proto3" json:"expires_at,omitempty"`
// The result of the fetch, if the status had code `OK`.
// The digest of the file's contents, available for download through the CAS.
BlobDigest *v2.Digest `protobuf:"bytes,5,opt,name=blob_digest,json=blobDigest,proto3" json:"blob_digest,omitempty"`
// contains filtered or unexported fields
}
A response message for [Fetch.FetchBlob][build.bazel.remote.asset.v1.Fetch.FetchBlob].
func (*FetchBlobResponse) ClearBlobDigest ¶
func (x *FetchBlobResponse) ClearBlobDigest()
func (*FetchBlobResponse) ClearExpiresAt ¶
func (x *FetchBlobResponse) ClearExpiresAt()
func (*FetchBlobResponse) ClearStatus ¶
func (x *FetchBlobResponse) ClearStatus()
func (*FetchBlobResponse) GetBlobDigest ¶
func (x *FetchBlobResponse) GetBlobDigest() *v2.Digest
func (*FetchBlobResponse) GetExpiresAt ¶
func (x *FetchBlobResponse) GetExpiresAt() *timestamppb.Timestamp
func (*FetchBlobResponse) GetQualifiers ¶
func (x *FetchBlobResponse) GetQualifiers() []*Qualifier
func (*FetchBlobResponse) GetStatus ¶
func (x *FetchBlobResponse) GetStatus() *status.Status
func (*FetchBlobResponse) GetUri ¶
func (x *FetchBlobResponse) GetUri() string
func (*FetchBlobResponse) HasBlobDigest ¶
func (x *FetchBlobResponse) HasBlobDigest() bool
func (*FetchBlobResponse) HasExpiresAt ¶
func (x *FetchBlobResponse) HasExpiresAt() bool
func (*FetchBlobResponse) HasStatus ¶
func (x *FetchBlobResponse) HasStatus() bool
func (*FetchBlobResponse) ProtoMessage ¶
func (*FetchBlobResponse) ProtoMessage()
func (*FetchBlobResponse) ProtoReflect ¶
func (x *FetchBlobResponse) ProtoReflect() protoreflect.Message
func (*FetchBlobResponse) Reset ¶
func (x *FetchBlobResponse) Reset()
func (*FetchBlobResponse) SetBlobDigest ¶
func (x *FetchBlobResponse) SetBlobDigest(v *v2.Digest)
func (*FetchBlobResponse) SetExpiresAt ¶
func (x *FetchBlobResponse) SetExpiresAt(v *timestamppb.Timestamp)
func (*FetchBlobResponse) SetQualifiers ¶
func (x *FetchBlobResponse) SetQualifiers(v []*Qualifier)
func (*FetchBlobResponse) SetStatus ¶
func (x *FetchBlobResponse) SetStatus(v *status.Status)
func (*FetchBlobResponse) SetUri ¶
func (x *FetchBlobResponse) SetUri(v string)
func (*FetchBlobResponse) String ¶
func (x *FetchBlobResponse) String() string
type FetchBlobResponse_builder ¶
type FetchBlobResponse_builder struct {
// If the status has a code other than `OK`, it indicates that the operation
// was unable to be completed for reasons outside the servers' control.
// The possible fetch errors include:
// - `DEADLINE_EXCEEDED`: The operation could not be completed within the
// specified timeout.
// - `NOT_FOUND`: The requested asset was not found at the specified location.
// - `PERMISSION_DENIED`: The request was rejected by a remote server, or
// requested an asset from a disallowed origin.
// - `ABORTED`: The operation could not be completed, typically due to a
// failed consistency check.
// - `RESOURCE_EXHAUSTED`: There is insufficient quota of some resource to
// perform the requested operation. The client may retry after a delay.
Status *status.Status
// The uri from the request that resulted in a successful retrieval, or from
// which the error indicated in `status` was obtained.
Uri string
// Any qualifiers known to the server and of interest to clients.
Qualifiers []*Qualifier
// A minimum timestamp the content is expected to be available through.
// Servers *MAY* omit this field, if not known with confidence.
ExpiresAt *timestamppb.Timestamp
// The result of the fetch, if the status had code `OK`.
// The digest of the file's contents, available for download through the CAS.
BlobDigest *v2.Digest
// contains filtered or unexported fields
}
func (FetchBlobResponse_builder) Build ¶
func (b0 FetchBlobResponse_builder) Build() *FetchBlobResponse
type FetchDirectoryRequest ¶
type FetchDirectoryRequest struct {
// The instance of the execution system to operate against. A server may
// support multiple instances of the execution system (with their own workers,
// storage, caches, etc.). The server MAY require use of this field to select
// between them in an implementation-defined fashion, otherwise it can be
// omitted.
InstanceName string `protobuf:"bytes,1,opt,name=instance_name,json=instanceName,proto3" json:"instance_name,omitempty"`
// The timeout for the underlying fetch, if content needs to be retrieved from
// origin. This value is allowed to exceed the RPC deadline, in which case the
// server *SHOULD* keep the fetch going after the RPC completes, to be made
// available for future Fetch calls.
//
// If this timeout is exceeded on an attempt to retrieve content from origin
// the client will receive DEADLINE_EXCEEDED in [FetchDirectoryResponse.status].
Timeout *durationpb.Duration `protobuf:"bytes,2,opt,name=timeout,proto3" json:"timeout,omitempty"`
// The oldest content the client is willing to accept, as measured from the
// time it was Push'd or when the underlying retrieval from origin was
// started.
// Upon retries of Fetch requests that cannot be completed within a single
// RPC, clients *SHOULD* provide the same value for subsequent requests as the
// original, to simplify combining the request with the previous attempt.
//
// If unset, the client *SHOULD* accept content of any age.
OldestContentAccepted *timestamppb.Timestamp `` /* 126-byte string literal not displayed */
// The URI(s) of the content to fetch. These may be resources that the server
// can directly fetch from origin, in which case multiple URIs *SHOULD*
// represent the same content available at different locations (such as an
// origin and secondary mirrors). These may also be URIs for content known to
// the server through other mechanisms, e.g. pushed via the [Push][build.bazel.remote.asset.v1.Push]
// service.
//
// Clients *MUST* supply at least one URI. Servers *MAY* match any one of the
// supplied URIs.
Uris []string `protobuf:"bytes,4,rep,name=uris,proto3" json:"uris,omitempty"`
// Qualifiers sub-specifying the content to fetch - see comments on
// [Qualifier][build.bazel.remote.asset.v1.Qualifier].
// The same qualifiers apply to all URIs.
//
// Specified qualifier names *MUST* be unique.
Qualifiers []*Qualifier `protobuf:"bytes,5,rep,name=qualifiers,proto3" json:"qualifiers,omitempty"`
// contains filtered or unexported fields
}
A request message for [Fetch.FetchDirectory][build.bazel.remote.asset.v1.Fetch.FetchDirectory].
func (*FetchDirectoryRequest) ClearOldestContentAccepted ¶
func (x *FetchDirectoryRequest) ClearOldestContentAccepted()
func (*FetchDirectoryRequest) ClearTimeout ¶
func (x *FetchDirectoryRequest) ClearTimeout()
func (*FetchDirectoryRequest) GetInstanceName ¶
func (x *FetchDirectoryRequest) GetInstanceName() string
func (*FetchDirectoryRequest) GetOldestContentAccepted ¶
func (x *FetchDirectoryRequest) GetOldestContentAccepted() *timestamppb.Timestamp
func (*FetchDirectoryRequest) GetQualifiers ¶
func (x *FetchDirectoryRequest) GetQualifiers() []*Qualifier
func (*FetchDirectoryRequest) GetTimeout ¶
func (x *FetchDirectoryRequest) GetTimeout() *durationpb.Duration
func (*FetchDirectoryRequest) GetUris ¶
func (x *FetchDirectoryRequest) GetUris() []string
func (*FetchDirectoryRequest) HasOldestContentAccepted ¶
func (x *FetchDirectoryRequest) HasOldestContentAccepted() bool
func (*FetchDirectoryRequest) HasTimeout ¶
func (x *FetchDirectoryRequest) HasTimeout() bool
func (*FetchDirectoryRequest) ProtoMessage ¶
func (*FetchDirectoryRequest) ProtoMessage()
func (*FetchDirectoryRequest) ProtoReflect ¶
func (x *FetchDirectoryRequest) ProtoReflect() protoreflect.Message
func (*FetchDirectoryRequest) Reset ¶
func (x *FetchDirectoryRequest) Reset()
func (*FetchDirectoryRequest) SetInstanceName ¶
func (x *FetchDirectoryRequest) SetInstanceName(v string)
func (*FetchDirectoryRequest) SetOldestContentAccepted ¶
func (x *FetchDirectoryRequest) SetOldestContentAccepted(v *timestamppb.Timestamp)
func (*FetchDirectoryRequest) SetQualifiers ¶
func (x *FetchDirectoryRequest) SetQualifiers(v []*Qualifier)
func (*FetchDirectoryRequest) SetTimeout ¶
func (x *FetchDirectoryRequest) SetTimeout(v *durationpb.Duration)
func (*FetchDirectoryRequest) SetUris ¶
func (x *FetchDirectoryRequest) SetUris(v []string)
func (*FetchDirectoryRequest) String ¶
func (x *FetchDirectoryRequest) String() string
type FetchDirectoryRequest_builder ¶
type FetchDirectoryRequest_builder struct {
// The instance of the execution system to operate against. A server may
// support multiple instances of the execution system (with their own workers,
// storage, caches, etc.). The server MAY require use of this field to select
// between them in an implementation-defined fashion, otherwise it can be
// omitted.
InstanceName string
// The timeout for the underlying fetch, if content needs to be retrieved from
// origin. This value is allowed to exceed the RPC deadline, in which case the
// server *SHOULD* keep the fetch going after the RPC completes, to be made
// available for future Fetch calls.
//
// If this timeout is exceeded on an attempt to retrieve content from origin
// the client will receive DEADLINE_EXCEEDED in [FetchDirectoryResponse.status].
Timeout *durationpb.Duration
// The oldest content the client is willing to accept, as measured from the
// time it was Push'd or when the underlying retrieval from origin was
// started.
// Upon retries of Fetch requests that cannot be completed within a single
// RPC, clients *SHOULD* provide the same value for subsequent requests as the
// original, to simplify combining the request with the previous attempt.
//
// If unset, the client *SHOULD* accept content of any age.
OldestContentAccepted *timestamppb.Timestamp
// The URI(s) of the content to fetch. These may be resources that the server
// can directly fetch from origin, in which case multiple URIs *SHOULD*
// represent the same content available at different locations (such as an
// origin and secondary mirrors). These may also be URIs for content known to
// the server through other mechanisms, e.g. pushed via the [Push][build.bazel.remote.asset.v1.Push]
// service.
//
// Clients *MUST* supply at least one URI. Servers *MAY* match any one of the
// supplied URIs.
Uris []string
// Qualifiers sub-specifying the content to fetch - see comments on
// [Qualifier][build.bazel.remote.asset.v1.Qualifier].
// The same qualifiers apply to all URIs.
//
// Specified qualifier names *MUST* be unique.
Qualifiers []*Qualifier
// contains filtered or unexported fields
}
func (FetchDirectoryRequest_builder) Build ¶
func (b0 FetchDirectoryRequest_builder) Build() *FetchDirectoryRequest
type FetchDirectoryResponse ¶
type FetchDirectoryResponse struct {
// If the status has a code other than `OK`, it indicates that the operation
// was unable to be completed for reasons outside the servers' control.
// The possible fetch errors include:
// - `DEADLINE_EXCEEDED`: The operation could not be completed within the
// specified timeout.
// - `NOT_FOUND`: The requested asset was not found at the specified location.
// - `PERMISSION_DENIED`: The request was rejected by a remote server, or
// requested an asset from a disallowed origin.
// - `ABORTED`: The operation could not be completed, typically due to a
// failed consistency check.
// - `RESOURCE_EXHAUSTED`: There is insufficient quota of some resource to
// perform the requested operation. The client may retry after a delay.
Status *status.Status `protobuf:"bytes,1,opt,name=status,proto3" json:"status,omitempty"`
// The uri from the request that resulted in a successful retrieval, or from
// which the error indicated in `status` was obtained.
Uri string `protobuf:"bytes,2,opt,name=uri,proto3" json:"uri,omitempty"`
// Any qualifiers known to the server and of interest to clients.
Qualifiers []*Qualifier `protobuf:"bytes,3,rep,name=qualifiers,proto3" json:"qualifiers,omitempty"`
// A minimum timestamp the content is expected to be available through.
// Servers *MAY* omit this field, if not known with confidence.
ExpiresAt *timestamppb.Timestamp `protobuf:"bytes,4,opt,name=expires_at,json=expiresAt,proto3" json:"expires_at,omitempty"`
// The result of the fetch, if the status had code `OK`.
// the root digest of a directory tree, suitable for fetching via
// [ContentAddressableStorage.GetTree].
RootDirectoryDigest *v2.Digest `protobuf:"bytes,5,opt,name=root_directory_digest,json=rootDirectoryDigest,proto3" json:"root_directory_digest,omitempty"`
// contains filtered or unexported fields
}
A response message for [Fetch.FetchDirectory][build.bazel.remote.asset.v1.Fetch.FetchDirectory].
func (*FetchDirectoryResponse) ClearExpiresAt ¶
func (x *FetchDirectoryResponse) ClearExpiresAt()
func (*FetchDirectoryResponse) ClearRootDirectoryDigest ¶
func (x *FetchDirectoryResponse) ClearRootDirectoryDigest()
func (*FetchDirectoryResponse) ClearStatus ¶
func (x *FetchDirectoryResponse) ClearStatus()
func (*FetchDirectoryResponse) GetExpiresAt ¶
func (x *FetchDirectoryResponse) GetExpiresAt() *timestamppb.Timestamp
func (*FetchDirectoryResponse) GetQualifiers ¶
func (x *FetchDirectoryResponse) GetQualifiers() []*Qualifier
func (*FetchDirectoryResponse) GetRootDirectoryDigest ¶
func (x *FetchDirectoryResponse) GetRootDirectoryDigest() *v2.Digest
func (*FetchDirectoryResponse) GetStatus ¶
func (x *FetchDirectoryResponse) GetStatus() *status.Status
func (*FetchDirectoryResponse) GetUri ¶
func (x *FetchDirectoryResponse) GetUri() string
func (*FetchDirectoryResponse) HasExpiresAt ¶
func (x *FetchDirectoryResponse) HasExpiresAt() bool
func (*FetchDirectoryResponse) HasRootDirectoryDigest ¶
func (x *FetchDirectoryResponse) HasRootDirectoryDigest() bool
func (*FetchDirectoryResponse) HasStatus ¶
func (x *FetchDirectoryResponse) HasStatus() bool
func (*FetchDirectoryResponse) ProtoMessage ¶
func (*FetchDirectoryResponse) ProtoMessage()
func (*FetchDirectoryResponse) ProtoReflect ¶
func (x *FetchDirectoryResponse) ProtoReflect() protoreflect.Message
func (*FetchDirectoryResponse) Reset ¶
func (x *FetchDirectoryResponse) Reset()
func (*FetchDirectoryResponse) SetExpiresAt ¶
func (x *FetchDirectoryResponse) SetExpiresAt(v *timestamppb.Timestamp)
func (*FetchDirectoryResponse) SetQualifiers ¶
func (x *FetchDirectoryResponse) SetQualifiers(v []*Qualifier)
func (*FetchDirectoryResponse) SetRootDirectoryDigest ¶
func (x *FetchDirectoryResponse) SetRootDirectoryDigest(v *v2.Digest)
func (*FetchDirectoryResponse) SetStatus ¶
func (x *FetchDirectoryResponse) SetStatus(v *status.Status)
func (*FetchDirectoryResponse) SetUri ¶
func (x *FetchDirectoryResponse) SetUri(v string)
func (*FetchDirectoryResponse) String ¶
func (x *FetchDirectoryResponse) String() string
type FetchDirectoryResponse_builder ¶
type FetchDirectoryResponse_builder struct {
// If the status has a code other than `OK`, it indicates that the operation
// was unable to be completed for reasons outside the servers' control.
// The possible fetch errors include:
// - `DEADLINE_EXCEEDED`: The operation could not be completed within the
// specified timeout.
// - `NOT_FOUND`: The requested asset was not found at the specified location.
// - `PERMISSION_DENIED`: The request was rejected by a remote server, or
// requested an asset from a disallowed origin.
// - `ABORTED`: The operation could not be completed, typically due to a
// failed consistency check.
// - `RESOURCE_EXHAUSTED`: There is insufficient quota of some resource to
// perform the requested operation. The client may retry after a delay.
Status *status.Status
// The uri from the request that resulted in a successful retrieval, or from
// which the error indicated in `status` was obtained.
Uri string
// Any qualifiers known to the server and of interest to clients.
Qualifiers []*Qualifier
// A minimum timestamp the content is expected to be available through.
// Servers *MAY* omit this field, if not known with confidence.
ExpiresAt *timestamppb.Timestamp
// The result of the fetch, if the status had code `OK`.
// the root digest of a directory tree, suitable for fetching via
// [ContentAddressableStorage.GetTree].
RootDirectoryDigest *v2.Digest
// contains filtered or unexported fields
}
func (FetchDirectoryResponse_builder) Build ¶
func (b0 FetchDirectoryResponse_builder) Build() *FetchDirectoryResponse
type PushBlobRequest ¶
type PushBlobRequest struct {
// The instance of the execution system to operate against. A server may
// support multiple instances of the execution system (with their own workers,
// storage, caches, etc.). The server MAY require use of this field to select
// between them in an implementation-defined fashion, otherwise it can be
// omitted.
InstanceName string `protobuf:"bytes,1,opt,name=instance_name,json=instanceName,proto3" json:"instance_name,omitempty"`
// The URI(s) of the content to associate. If multiple URIs are specified, the
// pushed content will be available to fetch by specifying any of them.
Uris []string `protobuf:"bytes,2,rep,name=uris,proto3" json:"uris,omitempty"`
// Qualifiers sub-specifying the content that is being pushed - see comments
// on [Qualifier][build.bazel.remote.asset.v1.Qualifier].
// The same qualifiers apply to all URIs.
Qualifiers []*Qualifier `protobuf:"bytes,3,rep,name=qualifiers,proto3" json:"qualifiers,omitempty"`
// A time after which this content should stop being returned via [FetchBlob][build.bazel.remote.asset.v1.Fetch.FetchBlob].
// Servers *MAY* expire content early, e.g. due to storage pressure.
ExpireAt *timestamppb.Timestamp `protobuf:"bytes,4,opt,name=expire_at,json=expireAt,proto3" json:"expire_at,omitempty"`
// The blob to associate.
BlobDigest *v2.Digest `protobuf:"bytes,5,opt,name=blob_digest,json=blobDigest,proto3" json:"blob_digest,omitempty"`
// Referenced blobs or directories that need to not expire before expiration
// of this association, in addition to `blob_digest` itself.
// These fields are hints - clients *MAY* omit them, and servers *SHOULD*
// respect them, at the risk of increased incidents of Fetch responses
// indirectly referencing unavailable blobs.
ReferencesBlobs []*v2.Digest `protobuf:"bytes,6,rep,name=references_blobs,json=referencesBlobs,proto3" json:"references_blobs,omitempty"`
ReferencesDirectories []*v2.Digest `protobuf:"bytes,7,rep,name=references_directories,json=referencesDirectories,proto3" json:"references_directories,omitempty"`
// contains filtered or unexported fields
}
A request message for [Push.PushBlob][build.bazel.remote.asset.v1.Push.PushBlob].
func (*PushBlobRequest) ClearBlobDigest ¶
func (x *PushBlobRequest) ClearBlobDigest()
func (*PushBlobRequest) ClearExpireAt ¶
func (x *PushBlobRequest) ClearExpireAt()
func (*PushBlobRequest) GetBlobDigest ¶
func (x *PushBlobRequest) GetBlobDigest() *v2.Digest
func (*PushBlobRequest) GetExpireAt ¶
func (x *PushBlobRequest) GetExpireAt() *timestamppb.Timestamp
func (*PushBlobRequest) GetInstanceName ¶
func (x *PushBlobRequest) GetInstanceName() string
func (*PushBlobRequest) GetQualifiers ¶
func (x *PushBlobRequest) GetQualifiers() []*Qualifier
func (*PushBlobRequest) GetReferencesBlobs ¶
func (x *PushBlobRequest) GetReferencesBlobs() []*v2.Digest
func (*PushBlobRequest) GetReferencesDirectories ¶
func (x *PushBlobRequest) GetReferencesDirectories() []*v2.Digest
func (*PushBlobRequest) GetUris ¶
func (x *PushBlobRequest) GetUris() []string
func (*PushBlobRequest) HasBlobDigest ¶
func (x *PushBlobRequest) HasBlobDigest() bool
func (*PushBlobRequest) HasExpireAt ¶
func (x *PushBlobRequest) HasExpireAt() bool
func (*PushBlobRequest) ProtoMessage ¶
func (*PushBlobRequest) ProtoMessage()
func (*PushBlobRequest) ProtoReflect ¶
func (x *PushBlobRequest) ProtoReflect() protoreflect.Message
func (*PushBlobRequest) Reset ¶
func (x *PushBlobRequest) Reset()
func (*PushBlobRequest) SetBlobDigest ¶
func (x *PushBlobRequest) SetBlobDigest(v *v2.Digest)
func (*PushBlobRequest) SetExpireAt ¶
func (x *PushBlobRequest) SetExpireAt(v *timestamppb.Timestamp)
func (*PushBlobRequest) SetInstanceName ¶
func (x *PushBlobRequest) SetInstanceName(v string)
func (*PushBlobRequest) SetQualifiers ¶
func (x *PushBlobRequest) SetQualifiers(v []*Qualifier)
func (*PushBlobRequest) SetReferencesBlobs ¶
func (x *PushBlobRequest) SetReferencesBlobs(v []*v2.Digest)
func (*PushBlobRequest) SetReferencesDirectories ¶
func (x *PushBlobRequest) SetReferencesDirectories(v []*v2.Digest)
func (*PushBlobRequest) SetUris ¶
func (x *PushBlobRequest) SetUris(v []string)
func (*PushBlobRequest) String ¶
func (x *PushBlobRequest) String() string
type PushBlobRequest_builder ¶
type PushBlobRequest_builder struct {
// The instance of the execution system to operate against. A server may
// support multiple instances of the execution system (with their own workers,
// storage, caches, etc.). The server MAY require use of this field to select
// between them in an implementation-defined fashion, otherwise it can be
// omitted.
InstanceName string
// The URI(s) of the content to associate. If multiple URIs are specified, the
// pushed content will be available to fetch by specifying any of them.
Uris []string
// Qualifiers sub-specifying the content that is being pushed - see comments
// on [Qualifier][build.bazel.remote.asset.v1.Qualifier].
// The same qualifiers apply to all URIs.
Qualifiers []*Qualifier
// A time after which this content should stop being returned via [FetchBlob][build.bazel.remote.asset.v1.Fetch.FetchBlob].
// Servers *MAY* expire content early, e.g. due to storage pressure.
ExpireAt *timestamppb.Timestamp
// The blob to associate.
BlobDigest *v2.Digest
// Referenced blobs or directories that need to not expire before expiration
// of this association, in addition to `blob_digest` itself.
// These fields are hints - clients *MAY* omit them, and servers *SHOULD*
// respect them, at the risk of increased incidents of Fetch responses
// indirectly referencing unavailable blobs.
ReferencesBlobs []*v2.Digest
ReferencesDirectories []*v2.Digest
// contains filtered or unexported fields
}
func (PushBlobRequest_builder) Build ¶
func (b0 PushBlobRequest_builder) Build() *PushBlobRequest
type PushBlobResponse ¶
type PushBlobResponse struct {
// contains filtered or unexported fields
}
A response message for [Push.PushBlob][build.bazel.remote.asset.v1.Push.PushBlob].
func (*PushBlobResponse) ProtoMessage ¶
func (*PushBlobResponse) ProtoMessage()
func (*PushBlobResponse) ProtoReflect ¶
func (x *PushBlobResponse) ProtoReflect() protoreflect.Message
func (*PushBlobResponse) Reset ¶
func (x *PushBlobResponse) Reset()
func (*PushBlobResponse) String ¶
func (x *PushBlobResponse) String() string
type PushBlobResponse_builder ¶
type PushBlobResponse_builder struct {
// contains filtered or unexported fields
}
func (PushBlobResponse_builder) Build ¶
func (b0 PushBlobResponse_builder) Build() *PushBlobResponse
type PushDirectoryRequest ¶
type PushDirectoryRequest struct {
// The instance of the execution system to operate against. A server may
// support multiple instances of the execution system (with their own workers,
// storage, caches, etc.). The server MAY require use of this field to select
// between them in an implementation-defined fashion, otherwise it can be
// omitted.
InstanceName string `protobuf:"bytes,1,opt,name=instance_name,json=instanceName,proto3" json:"instance_name,omitempty"`
// The URI(s) of the content to associate. If multiple URIs are specified, the
// pushed content will be available to fetch by specifying any of them.
Uris []string `protobuf:"bytes,2,rep,name=uris,proto3" json:"uris,omitempty"`
// Qualifiers sub-specifying the content that is being pushed - see comments
// on [Qualifier][build.bazel.remote.asset.v1.Qualifier].
// The same qualifiers apply to all URIs.
Qualifiers []*Qualifier `protobuf:"bytes,3,rep,name=qualifiers,proto3" json:"qualifiers,omitempty"`
// A time after which this content should stop being returned via
// [FetchDirectory][build.bazel.remote.asset.v1.Fetch.FetchDirectory].
// Servers *MAY* expire content early, e.g. due to storage pressure.
ExpireAt *timestamppb.Timestamp `protobuf:"bytes,4,opt,name=expire_at,json=expireAt,proto3" json:"expire_at,omitempty"`
// Directory to associate
RootDirectoryDigest *v2.Digest `protobuf:"bytes,5,opt,name=root_directory_digest,json=rootDirectoryDigest,proto3" json:"root_directory_digest,omitempty"`
// Referenced blobs or directories that need to not expire before expiration
// of this association, in addition to `root_directory_digest` itself.
// These fields are hints - clients *MAY* omit them, and servers *SHOULD*
// respect them, at the risk of increased incidents of Fetch responses
// indirectly referencing unavailable blobs.
ReferencesBlobs []*v2.Digest `protobuf:"bytes,6,rep,name=references_blobs,json=referencesBlobs,proto3" json:"references_blobs,omitempty"`
ReferencesDirectories []*v2.Digest `protobuf:"bytes,7,rep,name=references_directories,json=referencesDirectories,proto3" json:"references_directories,omitempty"`
// contains filtered or unexported fields
}
A request message for [Push.PushDirectory][build.bazel.remote.asset.v1.Push.PushDirectory].
func (*PushDirectoryRequest) ClearExpireAt ¶
func (x *PushDirectoryRequest) ClearExpireAt()
func (*PushDirectoryRequest) ClearRootDirectoryDigest ¶
func (x *PushDirectoryRequest) ClearRootDirectoryDigest()
func (*PushDirectoryRequest) GetExpireAt ¶
func (x *PushDirectoryRequest) GetExpireAt() *timestamppb.Timestamp
func (*PushDirectoryRequest) GetInstanceName ¶
func (x *PushDirectoryRequest) GetInstanceName() string
func (*PushDirectoryRequest) GetQualifiers ¶
func (x *PushDirectoryRequest) GetQualifiers() []*Qualifier
func (*PushDirectoryRequest) GetReferencesBlobs ¶
func (x *PushDirectoryRequest) GetReferencesBlobs() []*v2.Digest
func (*PushDirectoryRequest) GetReferencesDirectories ¶
func (x *PushDirectoryRequest) GetReferencesDirectories() []*v2.Digest
func (*PushDirectoryRequest) GetRootDirectoryDigest ¶
func (x *PushDirectoryRequest) GetRootDirectoryDigest() *v2.Digest
func (*PushDirectoryRequest) GetUris ¶
func (x *PushDirectoryRequest) GetUris() []string
func (*PushDirectoryRequest) HasExpireAt ¶
func (x *PushDirectoryRequest) HasExpireAt() bool
func (*PushDirectoryRequest) HasRootDirectoryDigest ¶
func (x *PushDirectoryRequest) HasRootDirectoryDigest() bool
func (*PushDirectoryRequest) ProtoMessage ¶
func (*PushDirectoryRequest) ProtoMessage()
func (*PushDirectoryRequest) ProtoReflect ¶
func (x *PushDirectoryRequest) ProtoReflect() protoreflect.Message
func (*PushDirectoryRequest) Reset ¶
func (x *PushDirectoryRequest) Reset()
func (*PushDirectoryRequest) SetExpireAt ¶
func (x *PushDirectoryRequest) SetExpireAt(v *timestamppb.Timestamp)
func (*PushDirectoryRequest) SetInstanceName ¶
func (x *PushDirectoryRequest) SetInstanceName(v string)
func (*PushDirectoryRequest) SetQualifiers ¶
func (x *PushDirectoryRequest) SetQualifiers(v []*Qualifier)
func (*PushDirectoryRequest) SetReferencesBlobs ¶
func (x *PushDirectoryRequest) SetReferencesBlobs(v []*v2.Digest)
func (*PushDirectoryRequest) SetReferencesDirectories ¶
func (x *PushDirectoryRequest) SetReferencesDirectories(v []*v2.Digest)
func (*PushDirectoryRequest) SetRootDirectoryDigest ¶
func (x *PushDirectoryRequest) SetRootDirectoryDigest(v *v2.Digest)
func (*PushDirectoryRequest) SetUris ¶
func (x *PushDirectoryRequest) SetUris(v []string)
func (*PushDirectoryRequest) String ¶
func (x *PushDirectoryRequest) String() string
type PushDirectoryRequest_builder ¶
type PushDirectoryRequest_builder struct {
// The instance of the execution system to operate against. A server may
// support multiple instances of the execution system (with their own workers,
// storage, caches, etc.). The server MAY require use of this field to select
// between them in an implementation-defined fashion, otherwise it can be
// omitted.
InstanceName string
// The URI(s) of the content to associate. If multiple URIs are specified, the
// pushed content will be available to fetch by specifying any of them.
Uris []string
// Qualifiers sub-specifying the content that is being pushed - see comments
// on [Qualifier][build.bazel.remote.asset.v1.Qualifier].
// The same qualifiers apply to all URIs.
Qualifiers []*Qualifier
// A time after which this content should stop being returned via
// [FetchDirectory][build.bazel.remote.asset.v1.Fetch.FetchDirectory].
// Servers *MAY* expire content early, e.g. due to storage pressure.
ExpireAt *timestamppb.Timestamp
// Directory to associate
RootDirectoryDigest *v2.Digest
// Referenced blobs or directories that need to not expire before expiration
// of this association, in addition to `root_directory_digest` itself.
// These fields are hints - clients *MAY* omit them, and servers *SHOULD*
// respect them, at the risk of increased incidents of Fetch responses
// indirectly referencing unavailable blobs.
ReferencesBlobs []*v2.Digest
ReferencesDirectories []*v2.Digest
// contains filtered or unexported fields
}
func (PushDirectoryRequest_builder) Build ¶
func (b0 PushDirectoryRequest_builder) Build() *PushDirectoryRequest
type PushDirectoryResponse ¶
type PushDirectoryResponse struct {
// contains filtered or unexported fields
}
A response message for [Push.PushDirectory][build.bazel.remote.asset.v1.Push.PushDirectory].
func (*PushDirectoryResponse) ProtoMessage ¶
func (*PushDirectoryResponse) ProtoMessage()
func (*PushDirectoryResponse) ProtoReflect ¶
func (x *PushDirectoryResponse) ProtoReflect() protoreflect.Message
func (*PushDirectoryResponse) Reset ¶
func (x *PushDirectoryResponse) Reset()
func (*PushDirectoryResponse) String ¶
func (x *PushDirectoryResponse) String() string
type PushDirectoryResponse_builder ¶
type PushDirectoryResponse_builder struct {
// contains filtered or unexported fields
}
func (PushDirectoryResponse_builder) Build ¶
func (b0 PushDirectoryResponse_builder) Build() *PushDirectoryResponse
type Qualifier ¶
type Qualifier struct {
// The "name" of the qualifier, for example "resource_type".
// No separation is made between 'standard' and 'nonstandard'
// qualifiers, in accordance with https://tools.ietf.org/html/rfc6648,
// however implementers *SHOULD* take care to avoid ambiguity.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// The "value" of the qualifier. Semantics will be dictated by the name.
Value string `protobuf:"bytes,2,opt,name=value,proto3" json:"value,omitempty"`
// contains filtered or unexported fields
}
Qualifiers are used to disambiguate or sub-select content that shares a URI. This may include specifying a particular commit or branch, in the case of URIs referencing a repository; they could also be used to specify a particular subdirectory of a repository or tarball. Qualifiers may also be used to ensure content matches what the client expects, even when there is no ambiguity to be had - for example, a qualifier specifying a checksum value.
In cases where the semantics of the request are not immediately clear from the URL and/or qualifiers - e.g. dictated by URL scheme - it is recommended to use an additional qualifier to remove the ambiguity. The `resource_type` qualifier is recommended for this purpose.
Qualifiers may be supplied in any order.
func (*Qualifier) ProtoReflect ¶
func (x *Qualifier) ProtoReflect() protoreflect.Message
type Qualifier_builder ¶
type Qualifier_builder struct {
// The "name" of the qualifier, for example "resource_type".
// No separation is made between 'standard' and 'nonstandard'
// qualifiers, in accordance with https://tools.ietf.org/html/rfc6648,
// however implementers *SHOULD* take care to avoid ambiguity.
Name string
// The "value" of the qualifier. Semantics will be dictated by the name.
Value string
// contains filtered or unexported fields
}
func (Qualifier_builder) Build ¶
func (b0 Qualifier_builder) Build() *Qualifier
Source Files
¶
- remote_asset.pb.go