Documentation
¶
Index ¶
- Variables
- type Headers
- type Headers_builder
- type InvokeRequest
- func (x *InvokeRequest) GetBody() []byte
- func (x *InvokeRequest) GetHeaders() []*Headers
- func (x *InvokeRequest) GetTarget() string
- func (*InvokeRequest) ProtoMessage()
- func (x *InvokeRequest) ProtoReflect() protoreflect.Message
- func (x *InvokeRequest) Reset()
- func (x *InvokeRequest) SetBody(v []byte)
- func (x *InvokeRequest) SetHeaders(v []*Headers)
- func (x *InvokeRequest) SetTarget(v string)
- func (x *InvokeRequest) String() string
- type InvokeRequest_builder
- type InvokeResponse
- func (x *InvokeResponse) GetBody() []byte
- func (x *InvokeResponse) GetHeaders() []*Headers
- func (x *InvokeResponse) GetTrailers() []*Headers
- func (*InvokeResponse) ProtoMessage()
- func (x *InvokeResponse) ProtoReflect() protoreflect.Message
- func (x *InvokeResponse) Reset()
- func (x *InvokeResponse) SetBody(v []byte)
- func (x *InvokeResponse) SetHeaders(v []*Headers)
- func (x *InvokeResponse) SetTrailers(v []*Headers)
- func (x *InvokeResponse) String() string
- type InvokeResponse_builder
Constants ¶
This section is empty.
Variables ¶
var File_buf_alpha_studio_v1alpha1_invoke_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Headers ¶
type Headers struct {
Key string `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
Value []string `protobuf:"bytes,2,rep,name=value,proto3" json:"value,omitempty"`
// contains filtered or unexported fields
}
Headers encode HTTP headers.
func (*Headers) ProtoReflect ¶
func (x *Headers) ProtoReflect() protoreflect.Message
type Headers_builder ¶
func (Headers_builder) Build ¶
func (b0 Headers_builder) Build() *Headers
type InvokeRequest ¶
type InvokeRequest struct {
// Target server the agent should forward this request to, e.g.
// "https://api.acme.corp/pkg.Service/Method". Using the "http" scheme will
// cause the request to be forwarded as h2c, whereas "https" forwards the
// request with regular h2.
Target string `protobuf:"bytes,1,opt,name=target,proto3" json:"target,omitempty"`
// Headers to send with the request. If body is set, a Content-Type header
// must be specified.
Headers []*Headers `protobuf:"bytes,2,rep,name=headers,proto3" json:"headers,omitempty"`
// The message to be sent in the request (without any protocol specific framing).
Body []byte `protobuf:"bytes,3,opt,name=body,proto3" json:"body,omitempty"`
// contains filtered or unexported fields
}
InvokeRequest encodes an enveloped RPC request. See the package documentation for more information.
func (*InvokeRequest) GetBody ¶
func (x *InvokeRequest) GetBody() []byte
func (*InvokeRequest) GetHeaders ¶
func (x *InvokeRequest) GetHeaders() []*Headers
func (*InvokeRequest) GetTarget ¶
func (x *InvokeRequest) GetTarget() string
func (*InvokeRequest) ProtoMessage ¶
func (*InvokeRequest) ProtoMessage()
func (*InvokeRequest) ProtoReflect ¶
func (x *InvokeRequest) ProtoReflect() protoreflect.Message
func (*InvokeRequest) Reset ¶
func (x *InvokeRequest) Reset()
func (*InvokeRequest) SetBody ¶
func (x *InvokeRequest) SetBody(v []byte)
func (*InvokeRequest) SetHeaders ¶
func (x *InvokeRequest) SetHeaders(v []*Headers)
func (*InvokeRequest) SetTarget ¶
func (x *InvokeRequest) SetTarget(v string)
func (*InvokeRequest) String ¶
func (x *InvokeRequest) String() string
type InvokeRequest_builder ¶
type InvokeRequest_builder struct {
// Target server the agent should forward this request to, e.g.
// "https://api.acme.corp/pkg.Service/Method". Using the "http" scheme will
// cause the request to be forwarded as h2c, whereas "https" forwards the
// request with regular h2.
Target string
// Headers to send with the request. If body is set, a Content-Type header
// must be specified.
Headers []*Headers
// The message to be sent in the request (without any protocol specific framing).
Body []byte
// contains filtered or unexported fields
}
func (InvokeRequest_builder) Build ¶
func (b0 InvokeRequest_builder) Build() *InvokeRequest
type InvokeResponse ¶
type InvokeResponse struct {
// Headers received in the response.
Headers []*Headers `protobuf:"bytes,1,rep,name=headers,proto3" json:"headers,omitempty"`
// The encoded message received in the response (without protocol specific framing).
Body []byte `protobuf:"bytes,2,opt,name=body,proto3" json:"body,omitempty"`
// Trailers received in the response.
Trailers []*Headers `protobuf:"bytes,3,rep,name=trailers,proto3" json:"trailers,omitempty"`
// contains filtered or unexported fields
}
InvokeResponse encodes an enveloped RPC response. See the package documentation for more information.
func (*InvokeResponse) GetBody ¶
func (x *InvokeResponse) GetBody() []byte
func (*InvokeResponse) GetHeaders ¶
func (x *InvokeResponse) GetHeaders() []*Headers
func (*InvokeResponse) GetTrailers ¶
func (x *InvokeResponse) GetTrailers() []*Headers
func (*InvokeResponse) ProtoMessage ¶
func (*InvokeResponse) ProtoMessage()
func (*InvokeResponse) ProtoReflect ¶
func (x *InvokeResponse) ProtoReflect() protoreflect.Message
func (*InvokeResponse) Reset ¶
func (x *InvokeResponse) Reset()
func (*InvokeResponse) SetBody ¶
func (x *InvokeResponse) SetBody(v []byte)
func (*InvokeResponse) SetHeaders ¶
func (x *InvokeResponse) SetHeaders(v []*Headers)
func (*InvokeResponse) SetTrailers ¶
func (x *InvokeResponse) SetTrailers(v []*Headers)
func (*InvokeResponse) String ¶
func (x *InvokeResponse) String() string
type InvokeResponse_builder ¶
type InvokeResponse_builder struct {
// Headers received in the response.
Headers []*Headers
// The encoded message received in the response (without protocol specific framing).
Body []byte
// Trailers received in the response.
Trailers []*Headers
// contains filtered or unexported fields
}
func (InvokeResponse_builder) Build ¶
func (b0 InvokeResponse_builder) Build() *InvokeResponse
Source Files
¶
- invoke.pb.go
Click to show internal directories.
Click to hide internal directories.