Documentation
¶
Index ¶
- Constants
- Variables
- type GetPluginInfoRequest
- type GetPluginInfoRequest_builder
- type GetPluginInfoResponse
- func (x *GetPluginInfoResponse) ClearPluginInfo()
- func (x *GetPluginInfoResponse) GetPluginInfo() *PluginInfo
- func (x *GetPluginInfoResponse) HasPluginInfo() bool
- func (*GetPluginInfoResponse) ProtoMessage()
- func (x *GetPluginInfoResponse) ProtoReflect() protoreflect.Message
- func (x *GetPluginInfoResponse) Reset()
- func (x *GetPluginInfoResponse) SetPluginInfo(v *PluginInfo)
- func (x *GetPluginInfoResponse) String() string
- type GetPluginInfoResponse_builder
- type License
- func (x *License) ClearSource()
- func (x *License) ClearText()
- func (x *License) ClearUrl()
- func (x *License) GetSource() isLicense_Source
- func (x *License) GetSpdxLicenseId() string
- func (x *License) GetText() string
- func (x *License) GetUrl() string
- func (x *License) HasSource() bool
- func (x *License) HasText() bool
- func (x *License) HasUrl() bool
- func (*License) ProtoMessage()
- func (x *License) ProtoReflect() protoreflect.Message
- func (x *License) Reset()
- func (x *License) SetSpdxLicenseId(v string)
- func (x *License) SetText(v string)
- func (x *License) SetUrl(v string)
- func (x *License) String() string
- func (x *License) WhichSource() case_License_Source
- type License_Text
- type License_Url
- type License_builder
- type PluginInfo
- func (x *PluginInfo) ClearLicense()
- func (x *PluginInfo) GetDocumentation() string
- func (x *PluginInfo) GetLicense() *License
- func (x *PluginInfo) HasLicense() bool
- func (*PluginInfo) ProtoMessage()
- func (x *PluginInfo) ProtoReflect() protoreflect.Message
- func (x *PluginInfo) Reset()
- func (x *PluginInfo) SetDocumentation(v string)
- func (x *PluginInfo) SetLicense(v *License)
- func (x *PluginInfo) String() string
- type PluginInfo_builder
Constants ¶
const License_Source_not_set_case case_License_Source = 0
const License_Text_case case_License_Source = 2
const License_Url_case case_License_Source = 3
Variables ¶
var File_buf_plugin_info_v1_license_proto protoreflect.FileDescriptor
var File_buf_plugin_info_v1_plugin_info_proto protoreflect.FileDescriptor
var File_buf_plugin_info_v1_plugin_info_service_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type GetPluginInfoRequest ¶
type GetPluginInfoRequest struct {
// contains filtered or unexported fields
}
A request to get information about a plugin.
func (*GetPluginInfoRequest) ProtoMessage ¶
func (*GetPluginInfoRequest) ProtoMessage()
func (*GetPluginInfoRequest) ProtoReflect ¶
func (x *GetPluginInfoRequest) ProtoReflect() protoreflect.Message
func (*GetPluginInfoRequest) Reset ¶
func (x *GetPluginInfoRequest) Reset()
func (*GetPluginInfoRequest) String ¶
func (x *GetPluginInfoRequest) String() string
type GetPluginInfoRequest_builder ¶
type GetPluginInfoRequest_builder struct {
// contains filtered or unexported fields
}
func (GetPluginInfoRequest_builder) Build ¶
func (b0 GetPluginInfoRequest_builder) Build() *GetPluginInfoRequest
type GetPluginInfoResponse ¶
type GetPluginInfoResponse struct {
// The information about the plugin.
PluginInfo *PluginInfo `protobuf:"bytes,1,opt,name=plugin_info,json=pluginInfo,proto3" json:"plugin_info,omitempty"`
// contains filtered or unexported fields
}
A response containing information about a plugin.
func (*GetPluginInfoResponse) ClearPluginInfo ¶
func (x *GetPluginInfoResponse) ClearPluginInfo()
func (*GetPluginInfoResponse) GetPluginInfo ¶
func (x *GetPluginInfoResponse) GetPluginInfo() *PluginInfo
func (*GetPluginInfoResponse) HasPluginInfo ¶
func (x *GetPluginInfoResponse) HasPluginInfo() bool
func (*GetPluginInfoResponse) ProtoMessage ¶
func (*GetPluginInfoResponse) ProtoMessage()
func (*GetPluginInfoResponse) ProtoReflect ¶
func (x *GetPluginInfoResponse) ProtoReflect() protoreflect.Message
func (*GetPluginInfoResponse) Reset ¶
func (x *GetPluginInfoResponse) Reset()
func (*GetPluginInfoResponse) SetPluginInfo ¶
func (x *GetPluginInfoResponse) SetPluginInfo(v *PluginInfo)
func (*GetPluginInfoResponse) String ¶
func (x *GetPluginInfoResponse) String() string
type GetPluginInfoResponse_builder ¶
type GetPluginInfoResponse_builder struct {
// The information about the plugin.
PluginInfo *PluginInfo
// contains filtered or unexported fields
}
func (GetPluginInfoResponse_builder) Build ¶
func (b0 GetPluginInfoResponse_builder) Build() *GetPluginInfoResponse
type License ¶
type License struct {
// The SPDX license ID.
//
// See https://spdx.org/licenses.
SpdxLicenseId string `protobuf:"bytes,1,opt,name=spdx_license_id,json=spdxLicenseId,proto3" json:"spdx_license_id,omitempty"`
// The source of a license is either raw text, or a URL that contains the license.
//
// Types that are valid to be assigned to Source:
//
// *License_Text
// *License_Url
Source isLicense_Source `protobuf_oneof:"source"`
// contains filtered or unexported fields
}
A plugin license.
func (*License) ProtoReflect ¶
func (x *License) ProtoReflect() protoreflect.Message
type License_Text ¶
type License_Text struct {
// The raw text of the license.
Text string `protobuf:"bytes,2,opt,name=text,proto3,oneof"`
}
type License_Url ¶
type License_Url struct {
// The url that contains the license.
Url string `protobuf:"bytes,3,opt,name=url,proto3,oneof"`
}
type License_builder ¶
type License_builder struct {
// The SPDX license ID.
//
// See https://spdx.org/licenses.
SpdxLicenseId string
// Fields of oneof Source:
// The raw text of the license.
Text *string
// The url that contains the license.
Url *string
// contains filtered or unexported fields
}
func (License_builder) Build ¶
func (b0 License_builder) Build() *License
type PluginInfo ¶
type PluginInfo struct {
// A long string providing more details on using the plugin.
//
// This is equivalent to a README.md in effect.
Documentation string `protobuf:"bytes,1,opt,name=documentation,proto3" json:"documentation,omitempty"`
// The license of the plugin.
License *License `protobuf:"bytes,2,opt,name=license,proto3" json:"license,omitempty"`
// contains filtered or unexported fields
}
Information about a plugin.
func (*PluginInfo) ClearLicense ¶
func (x *PluginInfo) ClearLicense()
func (*PluginInfo) GetDocumentation ¶
func (x *PluginInfo) GetDocumentation() string
func (*PluginInfo) GetLicense ¶
func (x *PluginInfo) GetLicense() *License
func (*PluginInfo) HasLicense ¶
func (x *PluginInfo) HasLicense() bool
func (*PluginInfo) ProtoMessage ¶
func (*PluginInfo) ProtoMessage()
func (*PluginInfo) ProtoReflect ¶
func (x *PluginInfo) ProtoReflect() protoreflect.Message
func (*PluginInfo) Reset ¶
func (x *PluginInfo) Reset()
func (*PluginInfo) SetDocumentation ¶
func (x *PluginInfo) SetDocumentation(v string)
func (*PluginInfo) SetLicense ¶
func (x *PluginInfo) SetLicense(v *License)
func (*PluginInfo) String ¶
func (x *PluginInfo) String() string
type PluginInfo_builder ¶
type PluginInfo_builder struct {
// A long string providing more details on using the plugin.
//
// This is equivalent to a README.md in effect.
Documentation string
// The license of the plugin.
License *License
// contains filtered or unexported fields
}
func (PluginInfo_builder) Build ¶
func (b0 PluginInfo_builder) Build() *PluginInfo
Source Files
¶
- license.pb.go
- plugin_info.pb.go
- plugin_info_service.pb.go
Click to show internal directories.
Click to hide internal directories.