Documentation
¶
Index ¶
- Variables
- type GlobalState
- type GlobalStateReference
- func (x *GlobalStateReference) GetLatestReference() string
- func (x *GlobalStateReference) GetModuleName() string
- func (*GlobalStateReference) ProtoMessage()
- func (x *GlobalStateReference) ProtoReflect() protoreflect.Message
- func (x *GlobalStateReference) Reset()
- func (x *GlobalStateReference) SetLatestReference(v string)
- func (x *GlobalStateReference) SetModuleName(v string)
- func (x *GlobalStateReference) String() string
- type GlobalStateReference_builder
- type GlobalState_builder
- type ModuleReference
- func (x *ModuleReference) GetDigest() string
- func (x *ModuleReference) GetName() string
- func (*ModuleReference) ProtoMessage()
- func (x *ModuleReference) ProtoReflect() protoreflect.Message
- func (x *ModuleReference) Reset()
- func (x *ModuleReference) SetDigest(v string)
- func (x *ModuleReference) SetName(v string)
- func (x *ModuleReference) String() string
- type ModuleReference_builder
- type ModuleState
- type ModuleState_builder
Constants ¶
This section is empty.
Variables ¶
var File_state_v1alpha1_state_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type GlobalState ¶
type GlobalState struct {
Modules []*GlobalStateReference `protobuf:"bytes,1,rep,name=modules,proto3" json:"modules,omitempty"`
// contains filtered or unexported fields
}
GlobalState is a sorted array managed modules, each one with the latest reference from its local array of references. This is kept updated in a global state file at the root sync directory.
func (*GlobalState) GetModules ¶
func (x *GlobalState) GetModules() []*GlobalStateReference
func (*GlobalState) ProtoMessage ¶
func (*GlobalState) ProtoMessage()
func (*GlobalState) ProtoReflect ¶
func (x *GlobalState) ProtoReflect() protoreflect.Message
func (*GlobalState) Reset ¶
func (x *GlobalState) Reset()
func (*GlobalState) SetModules ¶
func (x *GlobalState) SetModules(v []*GlobalStateReference)
func (*GlobalState) String ¶
func (x *GlobalState) String() string
type GlobalStateReference ¶
type GlobalStateReference struct {
ModuleName string `protobuf:"bytes,1,opt,name=module_name,json=moduleName,proto3" json:"module_name,omitempty"`
LatestReference string `protobuf:"bytes,2,opt,name=latest_reference,json=latestReference,proto3" json:"latest_reference,omitempty"`
// contains filtered or unexported fields
}
GlobalReference is a single managed module reference with the latest reference from its local array of references.
func (*GlobalStateReference) GetLatestReference ¶
func (x *GlobalStateReference) GetLatestReference() string
func (*GlobalStateReference) GetModuleName ¶
func (x *GlobalStateReference) GetModuleName() string
func (*GlobalStateReference) ProtoMessage ¶
func (*GlobalStateReference) ProtoMessage()
func (*GlobalStateReference) ProtoReflect ¶
func (x *GlobalStateReference) ProtoReflect() protoreflect.Message
func (*GlobalStateReference) Reset ¶
func (x *GlobalStateReference) Reset()
func (*GlobalStateReference) SetLatestReference ¶
func (x *GlobalStateReference) SetLatestReference(v string)
func (*GlobalStateReference) SetModuleName ¶
func (x *GlobalStateReference) SetModuleName(v string)
func (*GlobalStateReference) String ¶
func (x *GlobalStateReference) String() string
type GlobalStateReference_builder ¶
type GlobalStateReference_builder struct {
ModuleName string
LatestReference string
// contains filtered or unexported fields
}
func (GlobalStateReference_builder) Build ¶
func (b0 GlobalStateReference_builder) Build() *GlobalStateReference
type GlobalState_builder ¶
type GlobalState_builder struct {
Modules []*GlobalStateReference
// contains filtered or unexported fields
}
func (GlobalState_builder) Build ¶
func (b0 GlobalState_builder) Build() *GlobalState
type ModuleReference ¶
type ModuleReference struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
Digest string `protobuf:"bytes,2,opt,name=digest,proto3" json:"digest,omitempty"`
// contains filtered or unexported fields
}
ModuleReference is a single git reference of a managed module that will be synced to a BSR cluster.
func (*ModuleReference) GetDigest ¶
func (x *ModuleReference) GetDigest() string
func (*ModuleReference) GetName ¶
func (x *ModuleReference) GetName() string
func (*ModuleReference) ProtoMessage ¶
func (*ModuleReference) ProtoMessage()
func (*ModuleReference) ProtoReflect ¶
func (x *ModuleReference) ProtoReflect() protoreflect.Message
func (*ModuleReference) Reset ¶
func (x *ModuleReference) Reset()
func (*ModuleReference) SetDigest ¶
func (x *ModuleReference) SetDigest(v string)
func (*ModuleReference) SetName ¶
func (x *ModuleReference) SetName(v string)
func (*ModuleReference) String ¶
func (x *ModuleReference) String() string
type ModuleReference_builder ¶
type ModuleReference_builder struct {
Name string
Digest string
// contains filtered or unexported fields
}
func (ModuleReference_builder) Build ¶
func (b0 ModuleReference_builder) Build() *ModuleReference
type ModuleState ¶
type ModuleState struct {
References []*ModuleReference `protobuf:"bytes,1,rep,name=references,proto3" json:"references,omitempty"`
// contains filtered or unexported fields
}
ModuleState is an array of references that will be synced to a BSR cluster for a managed module. This is kept updated in a state file at the managed module directory.
func (*ModuleState) GetReferences ¶
func (x *ModuleState) GetReferences() []*ModuleReference
func (*ModuleState) ProtoMessage ¶
func (*ModuleState) ProtoMessage()
func (*ModuleState) ProtoReflect ¶
func (x *ModuleState) ProtoReflect() protoreflect.Message
func (*ModuleState) Reset ¶
func (x *ModuleState) Reset()
func (*ModuleState) SetReferences ¶
func (x *ModuleState) SetReferences(v []*ModuleReference)
func (*ModuleState) String ¶
func (x *ModuleState) String() string
type ModuleState_builder ¶
type ModuleState_builder struct {
References []*ModuleReference
// contains filtered or unexported fields
}
func (ModuleState_builder) Build ¶
func (b0 ModuleState_builder) Build() *ModuleState
Source Files
¶
- state.pb.go
Click to show internal directories.
Click to hide internal directories.