Documentation
¶
Index ¶
- Constants
- func NewCheckServiceHandler(svc CheckServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
- func NewCollectionServiceHandler(svc CollectionServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
- func NewCommitServiceHandler(svc CommitServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
- func NewDownloadServiceHandler(svc DownloadServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
- func NewLabelServiceHandler(svc LabelServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
- func NewPluginServiceHandler(svc PluginServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
- func NewResourceServiceHandler(svc ResourceServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
- func NewUploadServiceHandler(svc UploadServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
- type CheckServiceClient
- type CheckServiceHandler
- type CollectionServiceClient
- type CollectionServiceHandler
- type CommitServiceClient
- type CommitServiceHandler
- type DownloadServiceClient
- type DownloadServiceHandler
- type LabelServiceClient
- type LabelServiceHandler
- type PluginServiceClient
- type PluginServiceHandler
- type ResourceServiceClient
- type ResourceServiceHandler
- type UnimplementedCheckServiceHandler
- func (UnimplementedCheckServiceHandler) ListCategories(context.Context, *connect.Request[v1beta1.ListCategoriesRequest]) (*connect.Response[v1beta1.ListCategoriesResponse], error)
- func (UnimplementedCheckServiceHandler) ListRules(context.Context, *connect.Request[v1beta1.ListRulesRequest]) (*connect.Response[v1beta1.ListRulesResponse], error)
- type UnimplementedCollectionServiceHandler
- func (UnimplementedCollectionServiceHandler) GetCollections(context.Context, *connect.Request[v1beta1.GetCollectionsRequest]) (*connect.Response[v1beta1.GetCollectionsResponse], error)
- func (UnimplementedCollectionServiceHandler) GetPluginCollectionAssociations(context.Context, ...) (*connect.Response[v1beta1.GetPluginCollectionAssociationsResponse], error)
- func (UnimplementedCollectionServiceHandler) ListCollections(context.Context, *connect.Request[v1beta1.ListCollectionsRequest]) (*connect.Response[v1beta1.ListCollectionsResponse], error)
- type UnimplementedCommitServiceHandler
- func (UnimplementedCommitServiceHandler) GetCommits(context.Context, *connect.Request[v1beta1.GetCommitsRequest]) (*connect.Response[v1beta1.GetCommitsResponse], error)
- func (UnimplementedCommitServiceHandler) ListCommits(context.Context, *connect.Request[v1beta1.ListCommitsRequest]) (*connect.Response[v1beta1.ListCommitsResponse], error)
- type UnimplementedDownloadServiceHandler
- type UnimplementedLabelServiceHandler
- func (UnimplementedLabelServiceHandler) ArchiveLabels(context.Context, *connect.Request[v1beta1.ArchiveLabelsRequest]) (*connect.Response[v1beta1.ArchiveLabelsResponse], error)
- func (UnimplementedLabelServiceHandler) CreateOrUpdateLabels(context.Context, *connect.Request[v1beta1.CreateOrUpdateLabelsRequest]) (*connect.Response[v1beta1.CreateOrUpdateLabelsResponse], error)
- func (UnimplementedLabelServiceHandler) GetLabels(context.Context, *connect.Request[v1beta1.GetLabelsRequest]) (*connect.Response[v1beta1.GetLabelsResponse], error)
- func (UnimplementedLabelServiceHandler) ListLabelHistory(context.Context, *connect.Request[v1beta1.ListLabelHistoryRequest]) (*connect.Response[v1beta1.ListLabelHistoryResponse], error)
- func (UnimplementedLabelServiceHandler) ListLabels(context.Context, *connect.Request[v1beta1.ListLabelsRequest]) (*connect.Response[v1beta1.ListLabelsResponse], error)
- func (UnimplementedLabelServiceHandler) UnarchiveLabels(context.Context, *connect.Request[v1beta1.UnarchiveLabelsRequest]) (*connect.Response[v1beta1.UnarchiveLabelsResponse], error)
- type UnimplementedPluginServiceHandler
- func (UnimplementedPluginServiceHandler) CreatePlugins(context.Context, *connect.Request[v1beta1.CreatePluginsRequest]) (*connect.Response[v1beta1.CreatePluginsResponse], error)
- func (UnimplementedPluginServiceHandler) DeletePlugins(context.Context, *connect.Request[v1beta1.DeletePluginsRequest]) (*connect.Response[v1beta1.DeletePluginsResponse], error)
- func (UnimplementedPluginServiceHandler) GetPlugins(context.Context, *connect.Request[v1beta1.GetPluginsRequest]) (*connect.Response[v1beta1.GetPluginsResponse], error)
- func (UnimplementedPluginServiceHandler) ListPlugins(context.Context, *connect.Request[v1beta1.ListPluginsRequest]) (*connect.Response[v1beta1.ListPluginsResponse], error)
- func (UnimplementedPluginServiceHandler) UpdatePlugins(context.Context, *connect.Request[v1beta1.UpdatePluginsRequest]) (*connect.Response[v1beta1.UpdatePluginsResponse], error)
- type UnimplementedResourceServiceHandler
- type UnimplementedUploadServiceHandler
- type UploadServiceClient
- type UploadServiceHandler
Constants ¶
const ( // CheckServiceListRulesProcedure is the fully-qualified name of the CheckService's ListRules RPC. CheckServiceListRulesProcedure = "/buf.registry.plugin.v1beta1.CheckService/ListRules" // CheckServiceListCategoriesProcedure is the fully-qualified name of the CheckService's // ListCategories RPC. CheckServiceListCategoriesProcedure = "/buf.registry.plugin.v1beta1.CheckService/ListCategories" )
These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.
Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.
const ( // CollectionServiceGetCollectionsProcedure is the fully-qualified name of the CollectionService's // GetCollections RPC. CollectionServiceGetCollectionsProcedure = "/buf.registry.plugin.v1beta1.CollectionService/GetCollections" // CollectionServiceListCollectionsProcedure is the fully-qualified name of the CollectionService's // ListCollections RPC. CollectionServiceListCollectionsProcedure = "/buf.registry.plugin.v1beta1.CollectionService/ListCollections" // CollectionServiceGetPluginCollectionAssociationsProcedure is the fully-qualified name of the // CollectionService's GetPluginCollectionAssociations RPC. CollectionServiceGetPluginCollectionAssociationsProcedure = "/buf.registry.plugin.v1beta1.CollectionService/GetPluginCollectionAssociations" )
These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.
Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.
const ( // CommitServiceGetCommitsProcedure is the fully-qualified name of the CommitService's GetCommits // RPC. CommitServiceGetCommitsProcedure = "/buf.registry.plugin.v1beta1.CommitService/GetCommits" // CommitServiceListCommitsProcedure is the fully-qualified name of the CommitService's ListCommits // RPC. CommitServiceListCommitsProcedure = "/buf.registry.plugin.v1beta1.CommitService/ListCommits" )
These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.
Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.
const ( // LabelServiceGetLabelsProcedure is the fully-qualified name of the LabelService's GetLabels RPC. LabelServiceGetLabelsProcedure = "/buf.registry.plugin.v1beta1.LabelService/GetLabels" // LabelServiceListLabelsProcedure is the fully-qualified name of the LabelService's ListLabels RPC. LabelServiceListLabelsProcedure = "/buf.registry.plugin.v1beta1.LabelService/ListLabels" // LabelServiceListLabelHistoryProcedure is the fully-qualified name of the LabelService's // ListLabelHistory RPC. LabelServiceListLabelHistoryProcedure = "/buf.registry.plugin.v1beta1.LabelService/ListLabelHistory" // LabelServiceCreateOrUpdateLabelsProcedure is the fully-qualified name of the LabelService's // CreateOrUpdateLabels RPC. LabelServiceCreateOrUpdateLabelsProcedure = "/buf.registry.plugin.v1beta1.LabelService/CreateOrUpdateLabels" // LabelServiceArchiveLabelsProcedure is the fully-qualified name of the LabelService's // ArchiveLabels RPC. LabelServiceArchiveLabelsProcedure = "/buf.registry.plugin.v1beta1.LabelService/ArchiveLabels" // LabelServiceUnarchiveLabelsProcedure is the fully-qualified name of the LabelService's // UnarchiveLabels RPC. LabelServiceUnarchiveLabelsProcedure = "/buf.registry.plugin.v1beta1.LabelService/UnarchiveLabels" )
These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.
Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.
const ( // PluginServiceGetPluginsProcedure is the fully-qualified name of the PluginService's GetPlugins // RPC. PluginServiceGetPluginsProcedure = "/buf.registry.plugin.v1beta1.PluginService/GetPlugins" // PluginServiceListPluginsProcedure is the fully-qualified name of the PluginService's ListPlugins // RPC. PluginServiceListPluginsProcedure = "/buf.registry.plugin.v1beta1.PluginService/ListPlugins" // PluginServiceCreatePluginsProcedure is the fully-qualified name of the PluginService's // CreatePlugins RPC. PluginServiceCreatePluginsProcedure = "/buf.registry.plugin.v1beta1.PluginService/CreatePlugins" // PluginServiceUpdatePluginsProcedure is the fully-qualified name of the PluginService's // UpdatePlugins RPC. PluginServiceUpdatePluginsProcedure = "/buf.registry.plugin.v1beta1.PluginService/UpdatePlugins" // PluginServiceDeletePluginsProcedure is the fully-qualified name of the PluginService's // DeletePlugins RPC. PluginServiceDeletePluginsProcedure = "/buf.registry.plugin.v1beta1.PluginService/DeletePlugins" )
These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.
Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.
const (
// CheckServiceName is the fully-qualified name of the CheckService service.
CheckServiceName = "buf.registry.plugin.v1beta1.CheckService"
)
const (
// CollectionServiceName is the fully-qualified name of the CollectionService service.
CollectionServiceName = "buf.registry.plugin.v1beta1.CollectionService"
)
const (
// CommitServiceName is the fully-qualified name of the CommitService service.
CommitServiceName = "buf.registry.plugin.v1beta1.CommitService"
)
const ( // DownloadServiceDownloadProcedure is the fully-qualified name of the DownloadService's Download // RPC. DownloadServiceDownloadProcedure = "/buf.registry.plugin.v1beta1.DownloadService/Download" )
These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.
Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.
const (
// DownloadServiceName is the fully-qualified name of the DownloadService service.
DownloadServiceName = "buf.registry.plugin.v1beta1.DownloadService"
)
const (
// LabelServiceName is the fully-qualified name of the LabelService service.
LabelServiceName = "buf.registry.plugin.v1beta1.LabelService"
)
const (
// PluginServiceName is the fully-qualified name of the PluginService service.
PluginServiceName = "buf.registry.plugin.v1beta1.PluginService"
)
const ( // ResourceServiceGetResourcesProcedure is the fully-qualified name of the ResourceService's // GetResources RPC. ResourceServiceGetResourcesProcedure = "/buf.registry.plugin.v1beta1.ResourceService/GetResources" )
These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.
Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.
const (
// ResourceServiceName is the fully-qualified name of the ResourceService service.
ResourceServiceName = "buf.registry.plugin.v1beta1.ResourceService"
)
const (
// UploadServiceName is the fully-qualified name of the UploadService service.
UploadServiceName = "buf.registry.plugin.v1beta1.UploadService"
)
const (
// UploadServiceUploadProcedure is the fully-qualified name of the UploadService's Upload RPC.
UploadServiceUploadProcedure = "/buf.registry.plugin.v1beta1.UploadService/Upload"
)
These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.
Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.
Variables ¶
This section is empty.
Functions ¶
func NewCheckServiceHandler ¶
func NewCheckServiceHandler(svc CheckServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
NewCheckServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.
By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.
func NewCollectionServiceHandler ¶
func NewCollectionServiceHandler(svc CollectionServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
NewCollectionServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.
By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.
func NewCommitServiceHandler ¶
func NewCommitServiceHandler(svc CommitServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
NewCommitServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.
By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.
func NewDownloadServiceHandler ¶
func NewDownloadServiceHandler(svc DownloadServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
NewDownloadServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.
By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.
func NewLabelServiceHandler ¶
func NewLabelServiceHandler(svc LabelServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
NewLabelServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.
By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.
func NewPluginServiceHandler ¶
func NewPluginServiceHandler(svc PluginServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
NewPluginServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.
By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.
func NewResourceServiceHandler ¶
func NewResourceServiceHandler(svc ResourceServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
NewResourceServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.
By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.
func NewUploadServiceHandler ¶
func NewUploadServiceHandler(svc UploadServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
NewUploadServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.
By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.
Types ¶
type CheckServiceClient ¶
type CheckServiceClient interface {
// List Rules for a given Plugin, Label, or Commit.
ListRules(context.Context, *connect.Request[v1beta1.ListRulesRequest]) (*connect.Response[v1beta1.ListRulesResponse], error)
// List Categories for a given Plugin, Label, or Commit.
ListCategories(context.Context, *connect.Request[v1beta1.ListCategoriesRequest]) (*connect.Response[v1beta1.ListCategoriesResponse], error)
}
CheckServiceClient is a client for the buf.registry.plugin.v1beta1.CheckService service.
func NewCheckServiceClient ¶
func NewCheckServiceClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) CheckServiceClient
NewCheckServiceClient constructs a client for the buf.registry.plugin.v1beta1.CheckService service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.
The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).
type CheckServiceHandler ¶
type CheckServiceHandler interface {
// List Rules for a given Plugin, Label, or Commit.
ListRules(context.Context, *connect.Request[v1beta1.ListRulesRequest]) (*connect.Response[v1beta1.ListRulesResponse], error)
// List Categories for a given Plugin, Label, or Commit.
ListCategories(context.Context, *connect.Request[v1beta1.ListCategoriesRequest]) (*connect.Response[v1beta1.ListCategoriesResponse], error)
}
CheckServiceHandler is an implementation of the buf.registry.plugin.v1beta1.CheckService service.
type CollectionServiceClient ¶
type CollectionServiceClient interface {
// Get Collections.
GetCollections(context.Context, *connect.Request[v1beta1.GetCollectionsRequest]) (*connect.Response[v1beta1.GetCollectionsResponse], error)
// List Collections for a given Plugin.
ListCollections(context.Context, *connect.Request[v1beta1.ListCollectionsRequest]) (*connect.Response[v1beta1.ListCollectionsResponse], error)
// Get the Collections for the given Plugins.
GetPluginCollectionAssociations(context.Context, *connect.Request[v1beta1.GetPluginCollectionAssociationsRequest]) (*connect.Response[v1beta1.GetPluginCollectionAssociationsResponse], error)
}
CollectionServiceClient is a client for the buf.registry.plugin.v1beta1.CollectionService service.
func NewCollectionServiceClient ¶
func NewCollectionServiceClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) CollectionServiceClient
NewCollectionServiceClient constructs a client for the buf.registry.plugin.v1beta1.CollectionService service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.
The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).
type CollectionServiceHandler ¶
type CollectionServiceHandler interface {
// Get Collections.
GetCollections(context.Context, *connect.Request[v1beta1.GetCollectionsRequest]) (*connect.Response[v1beta1.GetCollectionsResponse], error)
// List Collections for a given Plugin.
ListCollections(context.Context, *connect.Request[v1beta1.ListCollectionsRequest]) (*connect.Response[v1beta1.ListCollectionsResponse], error)
// Get the Collections for the given Plugins.
GetPluginCollectionAssociations(context.Context, *connect.Request[v1beta1.GetPluginCollectionAssociationsRequest]) (*connect.Response[v1beta1.GetPluginCollectionAssociationsResponse], error)
}
CollectionServiceHandler is an implementation of the buf.registry.plugin.v1beta1.CollectionService service.
type CommitServiceClient ¶
type CommitServiceClient interface {
// Get Commits.
GetCommits(context.Context, *connect.Request[v1beta1.GetCommitsRequest]) (*connect.Response[v1beta1.GetCommitsResponse], error)
// List Commits for a given Plugin, Label, or Commit.
ListCommits(context.Context, *connect.Request[v1beta1.ListCommitsRequest]) (*connect.Response[v1beta1.ListCommitsResponse], error)
}
CommitServiceClient is a client for the buf.registry.plugin.v1beta1.CommitService service.
func NewCommitServiceClient ¶
func NewCommitServiceClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) CommitServiceClient
NewCommitServiceClient constructs a client for the buf.registry.plugin.v1beta1.CommitService service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.
The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).
type CommitServiceHandler ¶
type CommitServiceHandler interface {
// Get Commits.
GetCommits(context.Context, *connect.Request[v1beta1.GetCommitsRequest]) (*connect.Response[v1beta1.GetCommitsResponse], error)
// List Commits for a given Plugin, Label, or Commit.
ListCommits(context.Context, *connect.Request[v1beta1.ListCommitsRequest]) (*connect.Response[v1beta1.ListCommitsResponse], error)
}
CommitServiceHandler is an implementation of the buf.registry.plugin.v1beta1.CommitService service.
type DownloadServiceClient ¶
type DownloadServiceClient interface {
// Download contents for given set of Plugins.
//
// Contents are WASM modules that are compiled and executed within a suitable runtime.
Download(context.Context, *connect.Request[v1beta1.DownloadRequest]) (*connect.Response[v1beta1.DownloadResponse], error)
}
DownloadServiceClient is a client for the buf.registry.plugin.v1beta1.DownloadService service.
func NewDownloadServiceClient ¶
func NewDownloadServiceClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) DownloadServiceClient
NewDownloadServiceClient constructs a client for the buf.registry.plugin.v1beta1.DownloadService service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.
The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).
type DownloadServiceHandler ¶
type DownloadServiceHandler interface {
// Download contents for given set of Plugins.
//
// Contents are WASM modules that are compiled and executed within a suitable runtime.
Download(context.Context, *connect.Request[v1beta1.DownloadRequest]) (*connect.Response[v1beta1.DownloadResponse], error)
}
DownloadServiceHandler is an implementation of the buf.registry.plugin.v1beta1.DownloadService service.
type LabelServiceClient ¶
type LabelServiceClient interface {
// Get Labels by id or name.
GetLabels(context.Context, *connect.Request[v1beta1.GetLabelsRequest]) (*connect.Response[v1beta1.GetLabelsResponse], error)
// List Labels for a given Plugin, Commit or Label.
ListLabels(context.Context, *connect.Request[v1beta1.ListLabelsRequest]) (*connect.Response[v1beta1.ListLabelsResponse], error)
// List the history of a Label.
ListLabelHistory(context.Context, *connect.Request[v1beta1.ListLabelHistoryRequest]) (*connect.Response[v1beta1.ListLabelHistoryResponse], error)
// Create or update Labels on a Plugin.
//
// If the Label does not exist, it will be created. If the Label was archived, it will be
// unarchived. If the Label already existed, the Commit in the request has to be newer than the
// Commit that the Label is currently pointing to, otherwise an error is returned.
//
// This operation is atomic. Either all Labels are created/updated or an error is returned.
CreateOrUpdateLabels(context.Context, *connect.Request[v1beta1.CreateOrUpdateLabelsRequest]) (*connect.Response[v1beta1.CreateOrUpdateLabelsResponse], error)
// Archive existing Labels.
//
// This operation is atomic. Either all Labels are archived or an error is returned.
ArchiveLabels(context.Context, *connect.Request[v1beta1.ArchiveLabelsRequest]) (*connect.Response[v1beta1.ArchiveLabelsResponse], error)
// Unarchive existing Labels.
//
// This operation is atomic. Either all Labels are unarchived or an error is returned.
UnarchiveLabels(context.Context, *connect.Request[v1beta1.UnarchiveLabelsRequest]) (*connect.Response[v1beta1.UnarchiveLabelsResponse], error)
}
LabelServiceClient is a client for the buf.registry.plugin.v1beta1.LabelService service.
func NewLabelServiceClient ¶
func NewLabelServiceClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) LabelServiceClient
NewLabelServiceClient constructs a client for the buf.registry.plugin.v1beta1.LabelService service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.
The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).
type LabelServiceHandler ¶
type LabelServiceHandler interface {
// Get Labels by id or name.
GetLabels(context.Context, *connect.Request[v1beta1.GetLabelsRequest]) (*connect.Response[v1beta1.GetLabelsResponse], error)
// List Labels for a given Plugin, Commit or Label.
ListLabels(context.Context, *connect.Request[v1beta1.ListLabelsRequest]) (*connect.Response[v1beta1.ListLabelsResponse], error)
// List the history of a Label.
ListLabelHistory(context.Context, *connect.Request[v1beta1.ListLabelHistoryRequest]) (*connect.Response[v1beta1.ListLabelHistoryResponse], error)
// Create or update Labels on a Plugin.
//
// If the Label does not exist, it will be created. If the Label was archived, it will be
// unarchived. If the Label already existed, the Commit in the request has to be newer than the
// Commit that the Label is currently pointing to, otherwise an error is returned.
//
// This operation is atomic. Either all Labels are created/updated or an error is returned.
CreateOrUpdateLabels(context.Context, *connect.Request[v1beta1.CreateOrUpdateLabelsRequest]) (*connect.Response[v1beta1.CreateOrUpdateLabelsResponse], error)
// Archive existing Labels.
//
// This operation is atomic. Either all Labels are archived or an error is returned.
ArchiveLabels(context.Context, *connect.Request[v1beta1.ArchiveLabelsRequest]) (*connect.Response[v1beta1.ArchiveLabelsResponse], error)
// Unarchive existing Labels.
//
// This operation is atomic. Either all Labels are unarchived or an error is returned.
UnarchiveLabels(context.Context, *connect.Request[v1beta1.UnarchiveLabelsRequest]) (*connect.Response[v1beta1.UnarchiveLabelsResponse], error)
}
LabelServiceHandler is an implementation of the buf.registry.plugin.v1beta1.LabelService service.
type PluginServiceClient ¶
type PluginServiceClient interface {
// Get Plugins by id or name.
GetPlugins(context.Context, *connect.Request[v1beta1.GetPluginsRequest]) (*connect.Response[v1beta1.GetPluginsResponse], error)
// List Plugins, usually for a specific Organization.
ListPlugins(context.Context, *connect.Request[v1beta1.ListPluginsRequest]) (*connect.Response[v1beta1.ListPluginsResponse], error)
// Create new Plugins.
//
// This operation is atomic. Either all Plugins are created or an error is returned.
CreatePlugins(context.Context, *connect.Request[v1beta1.CreatePluginsRequest]) (*connect.Response[v1beta1.CreatePluginsResponse], error)
// Update existing Plugins.
//
// This operation is atomic. Either all Plugins are updated or an error is returned.
UpdatePlugins(context.Context, *connect.Request[v1beta1.UpdatePluginsRequest]) (*connect.Response[v1beta1.UpdatePluginsResponse], error)
// Delete existing Plugins.
//
// This operation is atomic. Either all Plugins are deleted or an error is returned.
DeletePlugins(context.Context, *connect.Request[v1beta1.DeletePluginsRequest]) (*connect.Response[v1beta1.DeletePluginsResponse], error)
}
PluginServiceClient is a client for the buf.registry.plugin.v1beta1.PluginService service.
func NewPluginServiceClient ¶
func NewPluginServiceClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) PluginServiceClient
NewPluginServiceClient constructs a client for the buf.registry.plugin.v1beta1.PluginService service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.
The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).
type PluginServiceHandler ¶
type PluginServiceHandler interface {
// Get Plugins by id or name.
GetPlugins(context.Context, *connect.Request[v1beta1.GetPluginsRequest]) (*connect.Response[v1beta1.GetPluginsResponse], error)
// List Plugins, usually for a specific Organization.
ListPlugins(context.Context, *connect.Request[v1beta1.ListPluginsRequest]) (*connect.Response[v1beta1.ListPluginsResponse], error)
// Create new Plugins.
//
// This operation is atomic. Either all Plugins are created or an error is returned.
CreatePlugins(context.Context, *connect.Request[v1beta1.CreatePluginsRequest]) (*connect.Response[v1beta1.CreatePluginsResponse], error)
// Update existing Plugins.
//
// This operation is atomic. Either all Plugins are updated or an error is returned.
UpdatePlugins(context.Context, *connect.Request[v1beta1.UpdatePluginsRequest]) (*connect.Response[v1beta1.UpdatePluginsResponse], error)
// Delete existing Plugins.
//
// This operation is atomic. Either all Plugins are deleted or an error is returned.
DeletePlugins(context.Context, *connect.Request[v1beta1.DeletePluginsRequest]) (*connect.Response[v1beta1.DeletePluginsResponse], error)
}
PluginServiceHandler is an implementation of the buf.registry.plugin.v1beta1.PluginService service.
type ResourceServiceClient ¶
type ResourceServiceClient interface {
// Get Resources.
GetResources(context.Context, *connect.Request[v1beta1.GetResourcesRequest]) (*connect.Response[v1beta1.GetResourcesResponse], error)
}
ResourceServiceClient is a client for the buf.registry.plugin.v1beta1.ResourceService service.
func NewResourceServiceClient ¶
func NewResourceServiceClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) ResourceServiceClient
NewResourceServiceClient constructs a client for the buf.registry.plugin.v1beta1.ResourceService service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.
The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).
type ResourceServiceHandler ¶
type ResourceServiceHandler interface {
// Get Resources.
GetResources(context.Context, *connect.Request[v1beta1.GetResourcesRequest]) (*connect.Response[v1beta1.GetResourcesResponse], error)
}
ResourceServiceHandler is an implementation of the buf.registry.plugin.v1beta1.ResourceService service.
type UnimplementedCheckServiceHandler ¶
type UnimplementedCheckServiceHandler struct{}
UnimplementedCheckServiceHandler returns CodeUnimplemented from all methods.
func (UnimplementedCheckServiceHandler) ListCategories ¶
func (UnimplementedCheckServiceHandler) ListCategories(context.Context, *connect.Request[v1beta1.ListCategoriesRequest]) (*connect.Response[v1beta1.ListCategoriesResponse], error)
func (UnimplementedCheckServiceHandler) ListRules ¶
func (UnimplementedCheckServiceHandler) ListRules(context.Context, *connect.Request[v1beta1.ListRulesRequest]) (*connect.Response[v1beta1.ListRulesResponse], error)
type UnimplementedCollectionServiceHandler ¶
type UnimplementedCollectionServiceHandler struct{}
UnimplementedCollectionServiceHandler returns CodeUnimplemented from all methods.
func (UnimplementedCollectionServiceHandler) GetCollections ¶
func (UnimplementedCollectionServiceHandler) GetCollections(context.Context, *connect.Request[v1beta1.GetCollectionsRequest]) (*connect.Response[v1beta1.GetCollectionsResponse], error)
func (UnimplementedCollectionServiceHandler) GetPluginCollectionAssociations ¶
func (UnimplementedCollectionServiceHandler) GetPluginCollectionAssociations(context.Context, *connect.Request[v1beta1.GetPluginCollectionAssociationsRequest]) (*connect.Response[v1beta1.GetPluginCollectionAssociationsResponse], error)
func (UnimplementedCollectionServiceHandler) ListCollections ¶
func (UnimplementedCollectionServiceHandler) ListCollections(context.Context, *connect.Request[v1beta1.ListCollectionsRequest]) (*connect.Response[v1beta1.ListCollectionsResponse], error)
type UnimplementedCommitServiceHandler ¶
type UnimplementedCommitServiceHandler struct{}
UnimplementedCommitServiceHandler returns CodeUnimplemented from all methods.
func (UnimplementedCommitServiceHandler) GetCommits ¶
func (UnimplementedCommitServiceHandler) GetCommits(context.Context, *connect.Request[v1beta1.GetCommitsRequest]) (*connect.Response[v1beta1.GetCommitsResponse], error)
func (UnimplementedCommitServiceHandler) ListCommits ¶
func (UnimplementedCommitServiceHandler) ListCommits(context.Context, *connect.Request[v1beta1.ListCommitsRequest]) (*connect.Response[v1beta1.ListCommitsResponse], error)
type UnimplementedDownloadServiceHandler ¶
type UnimplementedDownloadServiceHandler struct{}
UnimplementedDownloadServiceHandler returns CodeUnimplemented from all methods.
func (UnimplementedDownloadServiceHandler) Download ¶
func (UnimplementedDownloadServiceHandler) Download(context.Context, *connect.Request[v1beta1.DownloadRequest]) (*connect.Response[v1beta1.DownloadResponse], error)
type UnimplementedLabelServiceHandler ¶
type UnimplementedLabelServiceHandler struct{}
UnimplementedLabelServiceHandler returns CodeUnimplemented from all methods.
func (UnimplementedLabelServiceHandler) ArchiveLabels ¶
func (UnimplementedLabelServiceHandler) ArchiveLabels(context.Context, *connect.Request[v1beta1.ArchiveLabelsRequest]) (*connect.Response[v1beta1.ArchiveLabelsResponse], error)
func (UnimplementedLabelServiceHandler) CreateOrUpdateLabels ¶
func (UnimplementedLabelServiceHandler) CreateOrUpdateLabels(context.Context, *connect.Request[v1beta1.CreateOrUpdateLabelsRequest]) (*connect.Response[v1beta1.CreateOrUpdateLabelsResponse], error)
func (UnimplementedLabelServiceHandler) GetLabels ¶
func (UnimplementedLabelServiceHandler) GetLabels(context.Context, *connect.Request[v1beta1.GetLabelsRequest]) (*connect.Response[v1beta1.GetLabelsResponse], error)
func (UnimplementedLabelServiceHandler) ListLabelHistory ¶
func (UnimplementedLabelServiceHandler) ListLabelHistory(context.Context, *connect.Request[v1beta1.ListLabelHistoryRequest]) (*connect.Response[v1beta1.ListLabelHistoryResponse], error)
func (UnimplementedLabelServiceHandler) ListLabels ¶
func (UnimplementedLabelServiceHandler) ListLabels(context.Context, *connect.Request[v1beta1.ListLabelsRequest]) (*connect.Response[v1beta1.ListLabelsResponse], error)
func (UnimplementedLabelServiceHandler) UnarchiveLabels ¶
func (UnimplementedLabelServiceHandler) UnarchiveLabels(context.Context, *connect.Request[v1beta1.UnarchiveLabelsRequest]) (*connect.Response[v1beta1.UnarchiveLabelsResponse], error)
type UnimplementedPluginServiceHandler ¶
type UnimplementedPluginServiceHandler struct{}
UnimplementedPluginServiceHandler returns CodeUnimplemented from all methods.
func (UnimplementedPluginServiceHandler) CreatePlugins ¶
func (UnimplementedPluginServiceHandler) CreatePlugins(context.Context, *connect.Request[v1beta1.CreatePluginsRequest]) (*connect.Response[v1beta1.CreatePluginsResponse], error)
func (UnimplementedPluginServiceHandler) DeletePlugins ¶
func (UnimplementedPluginServiceHandler) DeletePlugins(context.Context, *connect.Request[v1beta1.DeletePluginsRequest]) (*connect.Response[v1beta1.DeletePluginsResponse], error)
func (UnimplementedPluginServiceHandler) GetPlugins ¶
func (UnimplementedPluginServiceHandler) GetPlugins(context.Context, *connect.Request[v1beta1.GetPluginsRequest]) (*connect.Response[v1beta1.GetPluginsResponse], error)
func (UnimplementedPluginServiceHandler) ListPlugins ¶
func (UnimplementedPluginServiceHandler) ListPlugins(context.Context, *connect.Request[v1beta1.ListPluginsRequest]) (*connect.Response[v1beta1.ListPluginsResponse], error)
func (UnimplementedPluginServiceHandler) UpdatePlugins ¶
func (UnimplementedPluginServiceHandler) UpdatePlugins(context.Context, *connect.Request[v1beta1.UpdatePluginsRequest]) (*connect.Response[v1beta1.UpdatePluginsResponse], error)
type UnimplementedResourceServiceHandler ¶
type UnimplementedResourceServiceHandler struct{}
UnimplementedResourceServiceHandler returns CodeUnimplemented from all methods.
func (UnimplementedResourceServiceHandler) GetResources ¶
func (UnimplementedResourceServiceHandler) GetResources(context.Context, *connect.Request[v1beta1.GetResourcesRequest]) (*connect.Response[v1beta1.GetResourcesResponse], error)
type UnimplementedUploadServiceHandler ¶
type UnimplementedUploadServiceHandler struct{}
UnimplementedUploadServiceHandler returns CodeUnimplemented from all methods.
func (UnimplementedUploadServiceHandler) Upload ¶
func (UnimplementedUploadServiceHandler) Upload(context.Context, *connect.Request[v1beta1.UploadRequest]) (*connect.Response[v1beta1.UploadResponse], error)
type UploadServiceClient ¶
type UploadServiceClient interface {
// Upload contents for given set of Plugins.
//
// Contents are expected to be WASM modules.
Upload(context.Context, *connect.Request[v1beta1.UploadRequest]) (*connect.Response[v1beta1.UploadResponse], error)
}
UploadServiceClient is a client for the buf.registry.plugin.v1beta1.UploadService service.
func NewUploadServiceClient ¶
func NewUploadServiceClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) UploadServiceClient
NewUploadServiceClient constructs a client for the buf.registry.plugin.v1beta1.UploadService service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.
The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).
type UploadServiceHandler ¶
type UploadServiceHandler interface {
// Upload contents for given set of Plugins.
//
// Contents are expected to be WASM modules.
Upload(context.Context, *connect.Request[v1beta1.UploadRequest]) (*connect.Response[v1beta1.UploadResponse], error)
}
UploadServiceHandler is an implementation of the buf.registry.plugin.v1beta1.UploadService service.
Source Files
¶
- check_service.connect.go
- collection_service.connect.go
- commit_service.connect.go
- download_service.connect.go
- label_service.connect.go
- plugin_service.connect.go
- resource_service.connect.go
- upload_service.connect.go