Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterCheckServiceServer(s grpc.ServiceRegistrar, srv CheckServiceServer)
- func RegisterCollectionServiceServer(s grpc.ServiceRegistrar, srv CollectionServiceServer)
- func RegisterCommitServiceServer(s grpc.ServiceRegistrar, srv CommitServiceServer)
- func RegisterDownloadServiceServer(s grpc.ServiceRegistrar, srv DownloadServiceServer)
- func RegisterLabelServiceServer(s grpc.ServiceRegistrar, srv LabelServiceServer)
- func RegisterPluginServiceServer(s grpc.ServiceRegistrar, srv PluginServiceServer)
- func RegisterResourceServiceServer(s grpc.ServiceRegistrar, srv ResourceServiceServer)
- func RegisterUploadServiceServer(s grpc.ServiceRegistrar, srv UploadServiceServer)
- type CheckServiceClient
- type CheckServiceServer
- type CollectionServiceClient
- type CollectionServiceServer
- type CommitServiceClient
- type CommitServiceServer
- type DownloadServiceClient
- type DownloadServiceServer
- type LabelServiceClient
- type LabelServiceServer
- type PluginServiceClient
- type PluginServiceServer
- type ResourceServiceClient
- type ResourceServiceServer
- type UnimplementedCheckServiceServer
- type UnimplementedCollectionServiceServer
- func (UnimplementedCollectionServiceServer) GetCollections(context.Context, *v1beta1.GetCollectionsRequest) (*v1beta1.GetCollectionsResponse, error)
- func (UnimplementedCollectionServiceServer) GetPluginCollectionAssociations(context.Context, *v1beta1.GetPluginCollectionAssociationsRequest) (*v1beta1.GetPluginCollectionAssociationsResponse, error)
- func (UnimplementedCollectionServiceServer) ListCollections(context.Context, *v1beta1.ListCollectionsRequest) (*v1beta1.ListCollectionsResponse, error)
- type UnimplementedCommitServiceServer
- type UnimplementedDownloadServiceServer
- type UnimplementedLabelServiceServer
- func (UnimplementedLabelServiceServer) ArchiveLabels(context.Context, *v1beta1.ArchiveLabelsRequest) (*v1beta1.ArchiveLabelsResponse, error)
- func (UnimplementedLabelServiceServer) CreateOrUpdateLabels(context.Context, *v1beta1.CreateOrUpdateLabelsRequest) (*v1beta1.CreateOrUpdateLabelsResponse, error)
- func (UnimplementedLabelServiceServer) GetLabels(context.Context, *v1beta1.GetLabelsRequest) (*v1beta1.GetLabelsResponse, error)
- func (UnimplementedLabelServiceServer) ListLabelHistory(context.Context, *v1beta1.ListLabelHistoryRequest) (*v1beta1.ListLabelHistoryResponse, error)
- func (UnimplementedLabelServiceServer) ListLabels(context.Context, *v1beta1.ListLabelsRequest) (*v1beta1.ListLabelsResponse, error)
- func (UnimplementedLabelServiceServer) UnarchiveLabels(context.Context, *v1beta1.UnarchiveLabelsRequest) (*v1beta1.UnarchiveLabelsResponse, error)
- type UnimplementedPluginServiceServer
- func (UnimplementedPluginServiceServer) CreatePlugins(context.Context, *v1beta1.CreatePluginsRequest) (*v1beta1.CreatePluginsResponse, error)
- func (UnimplementedPluginServiceServer) DeletePlugins(context.Context, *v1beta1.DeletePluginsRequest) (*v1beta1.DeletePluginsResponse, error)
- func (UnimplementedPluginServiceServer) GetPlugins(context.Context, *v1beta1.GetPluginsRequest) (*v1beta1.GetPluginsResponse, error)
- func (UnimplementedPluginServiceServer) ListPlugins(context.Context, *v1beta1.ListPluginsRequest) (*v1beta1.ListPluginsResponse, error)
- func (UnimplementedPluginServiceServer) UpdatePlugins(context.Context, *v1beta1.UpdatePluginsRequest) (*v1beta1.UpdatePluginsResponse, error)
- type UnimplementedResourceServiceServer
- type UnimplementedUploadServiceServer
- type UnsafeCheckServiceServer
- type UnsafeCollectionServiceServer
- type UnsafeCommitServiceServer
- type UnsafeDownloadServiceServer
- type UnsafeLabelServiceServer
- type UnsafePluginServiceServer
- type UnsafeResourceServiceServer
- type UnsafeUploadServiceServer
- type UploadServiceClient
- type UploadServiceServer
Constants ¶
const ( CheckService_ListRules_FullMethodName = "/buf.registry.plugin.v1beta1.CheckService/ListRules" CheckService_ListCategories_FullMethodName = "/buf.registry.plugin.v1beta1.CheckService/ListCategories" )
const ( CollectionService_GetCollections_FullMethodName = "/buf.registry.plugin.v1beta1.CollectionService/GetCollections" CollectionService_ListCollections_FullMethodName = "/buf.registry.plugin.v1beta1.CollectionService/ListCollections" CollectionService_GetPluginCollectionAssociations_FullMethodName = "/buf.registry.plugin.v1beta1.CollectionService/GetPluginCollectionAssociations" )
const ( CommitService_GetCommits_FullMethodName = "/buf.registry.plugin.v1beta1.CommitService/GetCommits" CommitService_ListCommits_FullMethodName = "/buf.registry.plugin.v1beta1.CommitService/ListCommits" )
const ( LabelService_GetLabels_FullMethodName = "/buf.registry.plugin.v1beta1.LabelService/GetLabels" LabelService_ListLabels_FullMethodName = "/buf.registry.plugin.v1beta1.LabelService/ListLabels" LabelService_ListLabelHistory_FullMethodName = "/buf.registry.plugin.v1beta1.LabelService/ListLabelHistory" LabelService_CreateOrUpdateLabels_FullMethodName = "/buf.registry.plugin.v1beta1.LabelService/CreateOrUpdateLabels" LabelService_ArchiveLabels_FullMethodName = "/buf.registry.plugin.v1beta1.LabelService/ArchiveLabels" LabelService_UnarchiveLabels_FullMethodName = "/buf.registry.plugin.v1beta1.LabelService/UnarchiveLabels" )
const ( PluginService_GetPlugins_FullMethodName = "/buf.registry.plugin.v1beta1.PluginService/GetPlugins" PluginService_ListPlugins_FullMethodName = "/buf.registry.plugin.v1beta1.PluginService/ListPlugins" PluginService_CreatePlugins_FullMethodName = "/buf.registry.plugin.v1beta1.PluginService/CreatePlugins" PluginService_UpdatePlugins_FullMethodName = "/buf.registry.plugin.v1beta1.PluginService/UpdatePlugins" PluginService_DeletePlugins_FullMethodName = "/buf.registry.plugin.v1beta1.PluginService/DeletePlugins" )
const (
DownloadService_Download_FullMethodName = "/buf.registry.plugin.v1beta1.DownloadService/Download"
)
const (
ResourceService_GetResources_FullMethodName = "/buf.registry.plugin.v1beta1.ResourceService/GetResources"
)
const (
UploadService_Upload_FullMethodName = "/buf.registry.plugin.v1beta1.UploadService/Upload"
)
Variables ¶
var CheckService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "buf.registry.plugin.v1beta1.CheckService", HandlerType: (*CheckServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "ListRules", Handler: _CheckService_ListRules_Handler, }, { MethodName: "ListCategories", Handler: _CheckService_ListCategories_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "buf/registry/plugin/v1beta1/check_service.proto", }
CheckService_ServiceDesc is the grpc.ServiceDesc for CheckService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var CollectionService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "buf.registry.plugin.v1beta1.CollectionService", HandlerType: (*CollectionServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "GetCollections", Handler: _CollectionService_GetCollections_Handler, }, { MethodName: "ListCollections", Handler: _CollectionService_ListCollections_Handler, }, { MethodName: "GetPluginCollectionAssociations", Handler: _CollectionService_GetPluginCollectionAssociations_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "buf/registry/plugin/v1beta1/collection_service.proto", }
CollectionService_ServiceDesc is the grpc.ServiceDesc for CollectionService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var CommitService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "buf.registry.plugin.v1beta1.CommitService", HandlerType: (*CommitServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "GetCommits", Handler: _CommitService_GetCommits_Handler, }, { MethodName: "ListCommits", Handler: _CommitService_ListCommits_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "buf/registry/plugin/v1beta1/commit_service.proto", }
CommitService_ServiceDesc is the grpc.ServiceDesc for CommitService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var DownloadService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "buf.registry.plugin.v1beta1.DownloadService", HandlerType: (*DownloadServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "Download", Handler: _DownloadService_Download_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "buf/registry/plugin/v1beta1/download_service.proto", }
DownloadService_ServiceDesc is the grpc.ServiceDesc for DownloadService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var LabelService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "buf.registry.plugin.v1beta1.LabelService", HandlerType: (*LabelServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "GetLabels", Handler: _LabelService_GetLabels_Handler, }, { MethodName: "ListLabels", Handler: _LabelService_ListLabels_Handler, }, { MethodName: "ListLabelHistory", Handler: _LabelService_ListLabelHistory_Handler, }, { MethodName: "CreateOrUpdateLabels", Handler: _LabelService_CreateOrUpdateLabels_Handler, }, { MethodName: "ArchiveLabels", Handler: _LabelService_ArchiveLabels_Handler, }, { MethodName: "UnarchiveLabels", Handler: _LabelService_UnarchiveLabels_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "buf/registry/plugin/v1beta1/label_service.proto", }
LabelService_ServiceDesc is the grpc.ServiceDesc for LabelService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var PluginService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "buf.registry.plugin.v1beta1.PluginService", HandlerType: (*PluginServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "GetPlugins", Handler: _PluginService_GetPlugins_Handler, }, { MethodName: "ListPlugins", Handler: _PluginService_ListPlugins_Handler, }, { MethodName: "CreatePlugins", Handler: _PluginService_CreatePlugins_Handler, }, { MethodName: "UpdatePlugins", Handler: _PluginService_UpdatePlugins_Handler, }, { MethodName: "DeletePlugins", Handler: _PluginService_DeletePlugins_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "buf/registry/plugin/v1beta1/plugin_service.proto", }
PluginService_ServiceDesc is the grpc.ServiceDesc for PluginService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var ResourceService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "buf.registry.plugin.v1beta1.ResourceService", HandlerType: (*ResourceServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "GetResources", Handler: _ResourceService_GetResources_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "buf/registry/plugin/v1beta1/resource_service.proto", }
ResourceService_ServiceDesc is the grpc.ServiceDesc for ResourceService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var UploadService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "buf.registry.plugin.v1beta1.UploadService", HandlerType: (*UploadServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "Upload", Handler: _UploadService_Upload_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "buf/registry/plugin/v1beta1/upload_service.proto", }
UploadService_ServiceDesc is the grpc.ServiceDesc for UploadService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterCheckServiceServer ¶
func RegisterCheckServiceServer(s grpc.ServiceRegistrar, srv CheckServiceServer)
func RegisterCollectionServiceServer ¶
func RegisterCollectionServiceServer(s grpc.ServiceRegistrar, srv CollectionServiceServer)
func RegisterCommitServiceServer ¶
func RegisterCommitServiceServer(s grpc.ServiceRegistrar, srv CommitServiceServer)
func RegisterDownloadServiceServer ¶
func RegisterDownloadServiceServer(s grpc.ServiceRegistrar, srv DownloadServiceServer)
func RegisterLabelServiceServer ¶
func RegisterLabelServiceServer(s grpc.ServiceRegistrar, srv LabelServiceServer)
func RegisterPluginServiceServer ¶
func RegisterPluginServiceServer(s grpc.ServiceRegistrar, srv PluginServiceServer)
func RegisterResourceServiceServer ¶
func RegisterResourceServiceServer(s grpc.ServiceRegistrar, srv ResourceServiceServer)
func RegisterUploadServiceServer ¶
func RegisterUploadServiceServer(s grpc.ServiceRegistrar, srv UploadServiceServer)
Types ¶
type CheckServiceClient ¶
type CheckServiceClient interface {
// List Rules for a given Plugin, Label, or Commit.
ListRules(ctx context.Context, in *v1beta1.ListRulesRequest, opts ...grpc.CallOption) (*v1beta1.ListRulesResponse, error)
// List Categories for a given Plugin, Label, or Commit.
ListCategories(ctx context.Context, in *v1beta1.ListCategoriesRequest, opts ...grpc.CallOption) (*v1beta1.ListCategoriesResponse, error)
}
CheckServiceClient is the client API for CheckService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
Operate on Check plugins.
func NewCheckServiceClient ¶
func NewCheckServiceClient(cc grpc.ClientConnInterface) CheckServiceClient
type CheckServiceServer ¶
type CheckServiceServer interface {
// List Rules for a given Plugin, Label, or Commit.
ListRules(context.Context, *v1beta1.ListRulesRequest) (*v1beta1.ListRulesResponse, error)
// List Categories for a given Plugin, Label, or Commit.
ListCategories(context.Context, *v1beta1.ListCategoriesRequest) (*v1beta1.ListCategoriesResponse, error)
}
CheckServiceServer is the server API for CheckService service. All implementations should embed UnimplementedCheckServiceServer for forward compatibility.
Operate on Check plugins.
type CollectionServiceClient ¶
type CollectionServiceClient interface {
// Get Collections.
GetCollections(ctx context.Context, in *v1beta1.GetCollectionsRequest, opts ...grpc.CallOption) (*v1beta1.GetCollectionsResponse, error)
// List Collections for a given Plugin.
ListCollections(ctx context.Context, in *v1beta1.ListCollectionsRequest, opts ...grpc.CallOption) (*v1beta1.ListCollectionsResponse, error)
// Get the Collections for the given Plugins.
GetPluginCollectionAssociations(ctx context.Context, in *v1beta1.GetPluginCollectionAssociationsRequest, opts ...grpc.CallOption) (*v1beta1.GetPluginCollectionAssociationsResponse, error)
}
CollectionServiceClient is the client API for CollectionService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
Operate on Collections.
func NewCollectionServiceClient ¶
func NewCollectionServiceClient(cc grpc.ClientConnInterface) CollectionServiceClient
type CollectionServiceServer ¶
type CollectionServiceServer interface {
// Get Collections.
GetCollections(context.Context, *v1beta1.GetCollectionsRequest) (*v1beta1.GetCollectionsResponse, error)
// List Collections for a given Plugin.
ListCollections(context.Context, *v1beta1.ListCollectionsRequest) (*v1beta1.ListCollectionsResponse, error)
// Get the Collections for the given Plugins.
GetPluginCollectionAssociations(context.Context, *v1beta1.GetPluginCollectionAssociationsRequest) (*v1beta1.GetPluginCollectionAssociationsResponse, error)
}
CollectionServiceServer is the server API for CollectionService service. All implementations should embed UnimplementedCollectionServiceServer for forward compatibility.
Operate on Collections.
type CommitServiceClient ¶
type CommitServiceClient interface {
// Get Commits.
GetCommits(ctx context.Context, in *v1beta1.GetCommitsRequest, opts ...grpc.CallOption) (*v1beta1.GetCommitsResponse, error)
// List Commits for a given Plugin, Label, or Commit.
ListCommits(ctx context.Context, in *v1beta1.ListCommitsRequest, opts ...grpc.CallOption) (*v1beta1.ListCommitsResponse, error)
}
CommitServiceClient is the client API for CommitService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
Operate on Commits.
func NewCommitServiceClient ¶
func NewCommitServiceClient(cc grpc.ClientConnInterface) CommitServiceClient
type CommitServiceServer ¶
type CommitServiceServer interface {
// Get Commits.
GetCommits(context.Context, *v1beta1.GetCommitsRequest) (*v1beta1.GetCommitsResponse, error)
// List Commits for a given Plugin, Label, or Commit.
ListCommits(context.Context, *v1beta1.ListCommitsRequest) (*v1beta1.ListCommitsResponse, error)
}
CommitServiceServer is the server API for CommitService service. All implementations should embed UnimplementedCommitServiceServer for forward compatibility.
Operate on Commits.
type DownloadServiceClient ¶
type DownloadServiceClient interface {
// Download contents for given set of Plugins.
//
// Contents are WASM modules that are compiled and executed within a suitable runtime.
Download(ctx context.Context, in *v1beta1.DownloadRequest, opts ...grpc.CallOption) (*v1beta1.DownloadResponse, error)
}
DownloadServiceClient is the client API for DownloadService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
Download contents.
func NewDownloadServiceClient ¶
func NewDownloadServiceClient(cc grpc.ClientConnInterface) DownloadServiceClient
type DownloadServiceServer ¶
type DownloadServiceServer interface {
// Download contents for given set of Plugins.
//
// Contents are WASM modules that are compiled and executed within a suitable runtime.
Download(context.Context, *v1beta1.DownloadRequest) (*v1beta1.DownloadResponse, error)
}
DownloadServiceServer is the server API for DownloadService service. All implementations should embed UnimplementedDownloadServiceServer for forward compatibility.
Download contents.
type LabelServiceClient ¶
type LabelServiceClient interface {
// Get Labels by id or name.
GetLabels(ctx context.Context, in *v1beta1.GetLabelsRequest, opts ...grpc.CallOption) (*v1beta1.GetLabelsResponse, error)
// List Labels for a given Plugin, Commit or Label.
ListLabels(ctx context.Context, in *v1beta1.ListLabelsRequest, opts ...grpc.CallOption) (*v1beta1.ListLabelsResponse, error)
// List the history of a Label.
ListLabelHistory(ctx context.Context, in *v1beta1.ListLabelHistoryRequest, opts ...grpc.CallOption) (*v1beta1.ListLabelHistoryResponse, error)
// Create or update Labels on a Plugin.
//
// If the Label does not exist, it will be created. If the Label was archived, it will be
// unarchived. If the Label already existed, the Commit in the request has to be newer than the
// Commit that the Label is currently pointing to, otherwise an error is returned.
//
// This operation is atomic. Either all Labels are created/updated or an error is returned.
CreateOrUpdateLabels(ctx context.Context, in *v1beta1.CreateOrUpdateLabelsRequest, opts ...grpc.CallOption) (*v1beta1.CreateOrUpdateLabelsResponse, error)
// Archive existing Labels.
//
// This operation is atomic. Either all Labels are archived or an error is returned.
ArchiveLabels(ctx context.Context, in *v1beta1.ArchiveLabelsRequest, opts ...grpc.CallOption) (*v1beta1.ArchiveLabelsResponse, error)
// Unarchive existing Labels.
//
// This operation is atomic. Either all Labels are unarchived or an error is returned.
UnarchiveLabels(ctx context.Context, in *v1beta1.UnarchiveLabelsRequest, opts ...grpc.CallOption) (*v1beta1.UnarchiveLabelsResponse, error)
}
LabelServiceClient is the client API for LabelService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
Operate on Labels.
func NewLabelServiceClient ¶
func NewLabelServiceClient(cc grpc.ClientConnInterface) LabelServiceClient
type LabelServiceServer ¶
type LabelServiceServer interface {
// Get Labels by id or name.
GetLabels(context.Context, *v1beta1.GetLabelsRequest) (*v1beta1.GetLabelsResponse, error)
// List Labels for a given Plugin, Commit or Label.
ListLabels(context.Context, *v1beta1.ListLabelsRequest) (*v1beta1.ListLabelsResponse, error)
// List the history of a Label.
ListLabelHistory(context.Context, *v1beta1.ListLabelHistoryRequest) (*v1beta1.ListLabelHistoryResponse, error)
// Create or update Labels on a Plugin.
//
// If the Label does not exist, it will be created. If the Label was archived, it will be
// unarchived. If the Label already existed, the Commit in the request has to be newer than the
// Commit that the Label is currently pointing to, otherwise an error is returned.
//
// This operation is atomic. Either all Labels are created/updated or an error is returned.
CreateOrUpdateLabels(context.Context, *v1beta1.CreateOrUpdateLabelsRequest) (*v1beta1.CreateOrUpdateLabelsResponse, error)
// Archive existing Labels.
//
// This operation is atomic. Either all Labels are archived or an error is returned.
ArchiveLabels(context.Context, *v1beta1.ArchiveLabelsRequest) (*v1beta1.ArchiveLabelsResponse, error)
// Unarchive existing Labels.
//
// This operation is atomic. Either all Labels are unarchived or an error is returned.
UnarchiveLabels(context.Context, *v1beta1.UnarchiveLabelsRequest) (*v1beta1.UnarchiveLabelsResponse, error)
}
LabelServiceServer is the server API for LabelService service. All implementations should embed UnimplementedLabelServiceServer for forward compatibility.
Operate on Labels.
type PluginServiceClient ¶
type PluginServiceClient interface {
// Get Plugins by id or name.
GetPlugins(ctx context.Context, in *v1beta1.GetPluginsRequest, opts ...grpc.CallOption) (*v1beta1.GetPluginsResponse, error)
// List Plugins, usually for a specific Organization.
ListPlugins(ctx context.Context, in *v1beta1.ListPluginsRequest, opts ...grpc.CallOption) (*v1beta1.ListPluginsResponse, error)
// Create new Plugins.
//
// This operation is atomic. Either all Plugins are created or an error is returned.
CreatePlugins(ctx context.Context, in *v1beta1.CreatePluginsRequest, opts ...grpc.CallOption) (*v1beta1.CreatePluginsResponse, error)
// Update existing Plugins.
//
// This operation is atomic. Either all Plugins are updated or an error is returned.
UpdatePlugins(ctx context.Context, in *v1beta1.UpdatePluginsRequest, opts ...grpc.CallOption) (*v1beta1.UpdatePluginsResponse, error)
// Delete existing Plugins.
//
// This operation is atomic. Either all Plugins are deleted or an error is returned.
DeletePlugins(ctx context.Context, in *v1beta1.DeletePluginsRequest, opts ...grpc.CallOption) (*v1beta1.DeletePluginsResponse, error)
}
PluginServiceClient is the client API for PluginService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
Operate on Plugins.
func NewPluginServiceClient ¶
func NewPluginServiceClient(cc grpc.ClientConnInterface) PluginServiceClient
type PluginServiceServer ¶
type PluginServiceServer interface {
// Get Plugins by id or name.
GetPlugins(context.Context, *v1beta1.GetPluginsRequest) (*v1beta1.GetPluginsResponse, error)
// List Plugins, usually for a specific Organization.
ListPlugins(context.Context, *v1beta1.ListPluginsRequest) (*v1beta1.ListPluginsResponse, error)
// Create new Plugins.
//
// This operation is atomic. Either all Plugins are created or an error is returned.
CreatePlugins(context.Context, *v1beta1.CreatePluginsRequest) (*v1beta1.CreatePluginsResponse, error)
// Update existing Plugins.
//
// This operation is atomic. Either all Plugins are updated or an error is returned.
UpdatePlugins(context.Context, *v1beta1.UpdatePluginsRequest) (*v1beta1.UpdatePluginsResponse, error)
// Delete existing Plugins.
//
// This operation is atomic. Either all Plugins are deleted or an error is returned.
DeletePlugins(context.Context, *v1beta1.DeletePluginsRequest) (*v1beta1.DeletePluginsResponse, error)
}
PluginServiceServer is the server API for PluginService service. All implementations should embed UnimplementedPluginServiceServer for forward compatibility.
Operate on Plugins.
type ResourceServiceClient ¶
type ResourceServiceClient interface {
// Get Resources.
GetResources(ctx context.Context, in *v1beta1.GetResourcesRequest, opts ...grpc.CallOption) (*v1beta1.GetResourcesResponse, error)
}
ResourceServiceClient is the client API for ResourceService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
Operate on Resources.
func NewResourceServiceClient ¶
func NewResourceServiceClient(cc grpc.ClientConnInterface) ResourceServiceClient
type ResourceServiceServer ¶
type ResourceServiceServer interface {
// Get Resources.
GetResources(context.Context, *v1beta1.GetResourcesRequest) (*v1beta1.GetResourcesResponse, error)
}
ResourceServiceServer is the server API for ResourceService service. All implementations should embed UnimplementedResourceServiceServer for forward compatibility.
Operate on Resources.
type UnimplementedCheckServiceServer ¶
type UnimplementedCheckServiceServer struct{}
UnimplementedCheckServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedCheckServiceServer) ListCategories ¶
func (UnimplementedCheckServiceServer) ListCategories(context.Context, *v1beta1.ListCategoriesRequest) (*v1beta1.ListCategoriesResponse, error)
func (UnimplementedCheckServiceServer) ListRules ¶
func (UnimplementedCheckServiceServer) ListRules(context.Context, *v1beta1.ListRulesRequest) (*v1beta1.ListRulesResponse, error)
type UnimplementedCollectionServiceServer ¶
type UnimplementedCollectionServiceServer struct{}
UnimplementedCollectionServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedCollectionServiceServer) GetCollections ¶
func (UnimplementedCollectionServiceServer) GetCollections(context.Context, *v1beta1.GetCollectionsRequest) (*v1beta1.GetCollectionsResponse, error)
func (UnimplementedCollectionServiceServer) GetPluginCollectionAssociations ¶
func (UnimplementedCollectionServiceServer) GetPluginCollectionAssociations(context.Context, *v1beta1.GetPluginCollectionAssociationsRequest) (*v1beta1.GetPluginCollectionAssociationsResponse, error)
func (UnimplementedCollectionServiceServer) ListCollections ¶
func (UnimplementedCollectionServiceServer) ListCollections(context.Context, *v1beta1.ListCollectionsRequest) (*v1beta1.ListCollectionsResponse, error)
type UnimplementedCommitServiceServer ¶
type UnimplementedCommitServiceServer struct{}
UnimplementedCommitServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedCommitServiceServer) GetCommits ¶
func (UnimplementedCommitServiceServer) GetCommits(context.Context, *v1beta1.GetCommitsRequest) (*v1beta1.GetCommitsResponse, error)
func (UnimplementedCommitServiceServer) ListCommits ¶
func (UnimplementedCommitServiceServer) ListCommits(context.Context, *v1beta1.ListCommitsRequest) (*v1beta1.ListCommitsResponse, error)
type UnimplementedDownloadServiceServer ¶
type UnimplementedDownloadServiceServer struct{}
UnimplementedDownloadServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedDownloadServiceServer) Download ¶
func (UnimplementedDownloadServiceServer) Download(context.Context, *v1beta1.DownloadRequest) (*v1beta1.DownloadResponse, error)
type UnimplementedLabelServiceServer ¶
type UnimplementedLabelServiceServer struct{}
UnimplementedLabelServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedLabelServiceServer) ArchiveLabels ¶
func (UnimplementedLabelServiceServer) ArchiveLabels(context.Context, *v1beta1.ArchiveLabelsRequest) (*v1beta1.ArchiveLabelsResponse, error)
func (UnimplementedLabelServiceServer) CreateOrUpdateLabels ¶
func (UnimplementedLabelServiceServer) CreateOrUpdateLabels(context.Context, *v1beta1.CreateOrUpdateLabelsRequest) (*v1beta1.CreateOrUpdateLabelsResponse, error)
func (UnimplementedLabelServiceServer) GetLabels ¶
func (UnimplementedLabelServiceServer) GetLabels(context.Context, *v1beta1.GetLabelsRequest) (*v1beta1.GetLabelsResponse, error)
func (UnimplementedLabelServiceServer) ListLabelHistory ¶
func (UnimplementedLabelServiceServer) ListLabelHistory(context.Context, *v1beta1.ListLabelHistoryRequest) (*v1beta1.ListLabelHistoryResponse, error)
func (UnimplementedLabelServiceServer) ListLabels ¶
func (UnimplementedLabelServiceServer) ListLabels(context.Context, *v1beta1.ListLabelsRequest) (*v1beta1.ListLabelsResponse, error)
func (UnimplementedLabelServiceServer) UnarchiveLabels ¶
func (UnimplementedLabelServiceServer) UnarchiveLabels(context.Context, *v1beta1.UnarchiveLabelsRequest) (*v1beta1.UnarchiveLabelsResponse, error)
type UnimplementedPluginServiceServer ¶
type UnimplementedPluginServiceServer struct{}
UnimplementedPluginServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedPluginServiceServer) CreatePlugins ¶
func (UnimplementedPluginServiceServer) CreatePlugins(context.Context, *v1beta1.CreatePluginsRequest) (*v1beta1.CreatePluginsResponse, error)
func (UnimplementedPluginServiceServer) DeletePlugins ¶
func (UnimplementedPluginServiceServer) DeletePlugins(context.Context, *v1beta1.DeletePluginsRequest) (*v1beta1.DeletePluginsResponse, error)
func (UnimplementedPluginServiceServer) GetPlugins ¶
func (UnimplementedPluginServiceServer) GetPlugins(context.Context, *v1beta1.GetPluginsRequest) (*v1beta1.GetPluginsResponse, error)
func (UnimplementedPluginServiceServer) ListPlugins ¶
func (UnimplementedPluginServiceServer) ListPlugins(context.Context, *v1beta1.ListPluginsRequest) (*v1beta1.ListPluginsResponse, error)
func (UnimplementedPluginServiceServer) UpdatePlugins ¶
func (UnimplementedPluginServiceServer) UpdatePlugins(context.Context, *v1beta1.UpdatePluginsRequest) (*v1beta1.UpdatePluginsResponse, error)
type UnimplementedResourceServiceServer ¶
type UnimplementedResourceServiceServer struct{}
UnimplementedResourceServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedResourceServiceServer) GetResources ¶
func (UnimplementedResourceServiceServer) GetResources(context.Context, *v1beta1.GetResourcesRequest) (*v1beta1.GetResourcesResponse, error)
type UnimplementedUploadServiceServer ¶
type UnimplementedUploadServiceServer struct{}
UnimplementedUploadServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedUploadServiceServer) Upload ¶
func (UnimplementedUploadServiceServer) Upload(context.Context, *v1beta1.UploadRequest) (*v1beta1.UploadResponse, error)
type UnsafeCheckServiceServer ¶
type UnsafeCheckServiceServer interface {
// contains filtered or unexported methods
}
UnsafeCheckServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to CheckServiceServer will result in compilation errors.
type UnsafeCollectionServiceServer ¶
type UnsafeCollectionServiceServer interface {
// contains filtered or unexported methods
}
UnsafeCollectionServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to CollectionServiceServer will result in compilation errors.
type UnsafeCommitServiceServer ¶
type UnsafeCommitServiceServer interface {
// contains filtered or unexported methods
}
UnsafeCommitServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to CommitServiceServer will result in compilation errors.
type UnsafeDownloadServiceServer ¶
type UnsafeDownloadServiceServer interface {
// contains filtered or unexported methods
}
UnsafeDownloadServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to DownloadServiceServer will result in compilation errors.
type UnsafeLabelServiceServer ¶
type UnsafeLabelServiceServer interface {
// contains filtered or unexported methods
}
UnsafeLabelServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to LabelServiceServer will result in compilation errors.
type UnsafePluginServiceServer ¶
type UnsafePluginServiceServer interface {
// contains filtered or unexported methods
}
UnsafePluginServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to PluginServiceServer will result in compilation errors.
type UnsafeResourceServiceServer ¶
type UnsafeResourceServiceServer interface {
// contains filtered or unexported methods
}
UnsafeResourceServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ResourceServiceServer will result in compilation errors.
type UnsafeUploadServiceServer ¶
type UnsafeUploadServiceServer interface {
// contains filtered or unexported methods
}
UnsafeUploadServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to UploadServiceServer will result in compilation errors.
type UploadServiceClient ¶
type UploadServiceClient interface {
// Upload contents for given set of Plugins.
//
// Contents are expected to be WASM modules.
Upload(ctx context.Context, in *v1beta1.UploadRequest, opts ...grpc.CallOption) (*v1beta1.UploadResponse, error)
}
UploadServiceClient is the client API for UploadService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
Upload contents.
func NewUploadServiceClient ¶
func NewUploadServiceClient(cc grpc.ClientConnInterface) UploadServiceClient
type UploadServiceServer ¶
type UploadServiceServer interface {
// Upload contents for given set of Plugins.
//
// Contents are expected to be WASM modules.
Upload(context.Context, *v1beta1.UploadRequest) (*v1beta1.UploadResponse, error)
}
UploadServiceServer is the server API for UploadService service. All implementations should embed UnimplementedUploadServiceServer for forward compatibility.
Upload contents.
Source Files
¶
- check_service_grpc.pb.go
- collection_service_grpc.pb.go
- commit_service_grpc.pb.go
- download_service_grpc.pb.go
- label_service_grpc.pb.go
- plugin_service_grpc.pb.go
- resource_service_grpc.pb.go
- upload_service_grpc.pb.go