Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterCommitServiceServer(s grpc.ServiceRegistrar, srv CommitServiceServer)
- func RegisterDownloadServiceServer(s grpc.ServiceRegistrar, srv DownloadServiceServer)
- func RegisterLabelServiceServer(s grpc.ServiceRegistrar, srv LabelServiceServer)
- func RegisterPolicyServiceServer(s grpc.ServiceRegistrar, srv PolicyServiceServer)
- func RegisterResourceServiceServer(s grpc.ServiceRegistrar, srv ResourceServiceServer)
- func RegisterUploadServiceServer(s grpc.ServiceRegistrar, srv UploadServiceServer)
- type CommitServiceClient
- type CommitServiceServer
- type DownloadServiceClient
- type DownloadServiceServer
- type LabelServiceClient
- type LabelServiceServer
- type PolicyServiceClient
- type PolicyServiceServer
- type ResourceServiceClient
- type ResourceServiceServer
- type UnimplementedCommitServiceServer
- type UnimplementedDownloadServiceServer
- type UnimplementedLabelServiceServer
- func (UnimplementedLabelServiceServer) ArchiveLabels(context.Context, *v1beta1.ArchiveLabelsRequest) (*v1beta1.ArchiveLabelsResponse, error)
- func (UnimplementedLabelServiceServer) CreateOrUpdateLabels(context.Context, *v1beta1.CreateOrUpdateLabelsRequest) (*v1beta1.CreateOrUpdateLabelsResponse, error)
- func (UnimplementedLabelServiceServer) GetLabels(context.Context, *v1beta1.GetLabelsRequest) (*v1beta1.GetLabelsResponse, error)
- func (UnimplementedLabelServiceServer) ListLabelHistory(context.Context, *v1beta1.ListLabelHistoryRequest) (*v1beta1.ListLabelHistoryResponse, error)
- func (UnimplementedLabelServiceServer) ListLabels(context.Context, *v1beta1.ListLabelsRequest) (*v1beta1.ListLabelsResponse, error)
- func (UnimplementedLabelServiceServer) UnarchiveLabels(context.Context, *v1beta1.UnarchiveLabelsRequest) (*v1beta1.UnarchiveLabelsResponse, error)
- type UnimplementedPolicyServiceServer
- func (UnimplementedPolicyServiceServer) CreatePolicies(context.Context, *v1beta1.CreatePoliciesRequest) (*v1beta1.CreatePoliciesResponse, error)
- func (UnimplementedPolicyServiceServer) DeletePolicies(context.Context, *v1beta1.DeletePoliciesRequest) (*v1beta1.DeletePoliciesResponse, error)
- func (UnimplementedPolicyServiceServer) GetPolicies(context.Context, *v1beta1.GetPoliciesRequest) (*v1beta1.GetPoliciesResponse, error)
- func (UnimplementedPolicyServiceServer) ListPolicies(context.Context, *v1beta1.ListPoliciesRequest) (*v1beta1.ListPoliciesResponse, error)
- func (UnimplementedPolicyServiceServer) UpdatePolicies(context.Context, *v1beta1.UpdatePoliciesRequest) (*v1beta1.UpdatePoliciesResponse, error)
- type UnimplementedResourceServiceServer
- type UnimplementedUploadServiceServer
- type UnsafeCommitServiceServer
- type UnsafeDownloadServiceServer
- type UnsafeLabelServiceServer
- type UnsafePolicyServiceServer
- type UnsafeResourceServiceServer
- type UnsafeUploadServiceServer
- type UploadServiceClient
- type UploadServiceServer
Constants ¶
const ( CommitService_GetCommits_FullMethodName = "/buf.registry.policy.v1beta1.CommitService/GetCommits" CommitService_ListCommits_FullMethodName = "/buf.registry.policy.v1beta1.CommitService/ListCommits" )
const ( LabelService_GetLabels_FullMethodName = "/buf.registry.policy.v1beta1.LabelService/GetLabels" LabelService_ListLabels_FullMethodName = "/buf.registry.policy.v1beta1.LabelService/ListLabels" LabelService_ListLabelHistory_FullMethodName = "/buf.registry.policy.v1beta1.LabelService/ListLabelHistory" LabelService_CreateOrUpdateLabels_FullMethodName = "/buf.registry.policy.v1beta1.LabelService/CreateOrUpdateLabels" LabelService_ArchiveLabels_FullMethodName = "/buf.registry.policy.v1beta1.LabelService/ArchiveLabels" LabelService_UnarchiveLabels_FullMethodName = "/buf.registry.policy.v1beta1.LabelService/UnarchiveLabels" )
const ( PolicyService_GetPolicies_FullMethodName = "/buf.registry.policy.v1beta1.PolicyService/GetPolicies" PolicyService_ListPolicies_FullMethodName = "/buf.registry.policy.v1beta1.PolicyService/ListPolicies" PolicyService_CreatePolicies_FullMethodName = "/buf.registry.policy.v1beta1.PolicyService/CreatePolicies" PolicyService_UpdatePolicies_FullMethodName = "/buf.registry.policy.v1beta1.PolicyService/UpdatePolicies" PolicyService_DeletePolicies_FullMethodName = "/buf.registry.policy.v1beta1.PolicyService/DeletePolicies" )
const (
DownloadService_Download_FullMethodName = "/buf.registry.policy.v1beta1.DownloadService/Download"
)
const (
ResourceService_GetResources_FullMethodName = "/buf.registry.policy.v1beta1.ResourceService/GetResources"
)
const (
UploadService_Upload_FullMethodName = "/buf.registry.policy.v1beta1.UploadService/Upload"
)
Variables ¶
var CommitService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "buf.registry.policy.v1beta1.CommitService", HandlerType: (*CommitServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "GetCommits", Handler: _CommitService_GetCommits_Handler, }, { MethodName: "ListCommits", Handler: _CommitService_ListCommits_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "buf/registry/policy/v1beta1/commit_service.proto", }
CommitService_ServiceDesc is the grpc.ServiceDesc for CommitService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var DownloadService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "buf.registry.policy.v1beta1.DownloadService", HandlerType: (*DownloadServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "Download", Handler: _DownloadService_Download_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "buf/registry/policy/v1beta1/download_service.proto", }
DownloadService_ServiceDesc is the grpc.ServiceDesc for DownloadService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var LabelService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "buf.registry.policy.v1beta1.LabelService", HandlerType: (*LabelServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "GetLabels", Handler: _LabelService_GetLabels_Handler, }, { MethodName: "ListLabels", Handler: _LabelService_ListLabels_Handler, }, { MethodName: "ListLabelHistory", Handler: _LabelService_ListLabelHistory_Handler, }, { MethodName: "CreateOrUpdateLabels", Handler: _LabelService_CreateOrUpdateLabels_Handler, }, { MethodName: "ArchiveLabels", Handler: _LabelService_ArchiveLabels_Handler, }, { MethodName: "UnarchiveLabels", Handler: _LabelService_UnarchiveLabels_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "buf/registry/policy/v1beta1/label_service.proto", }
LabelService_ServiceDesc is the grpc.ServiceDesc for LabelService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var PolicyService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "buf.registry.policy.v1beta1.PolicyService", HandlerType: (*PolicyServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "GetPolicies", Handler: _PolicyService_GetPolicies_Handler, }, { MethodName: "ListPolicies", Handler: _PolicyService_ListPolicies_Handler, }, { MethodName: "CreatePolicies", Handler: _PolicyService_CreatePolicies_Handler, }, { MethodName: "UpdatePolicies", Handler: _PolicyService_UpdatePolicies_Handler, }, { MethodName: "DeletePolicies", Handler: _PolicyService_DeletePolicies_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "buf/registry/policy/v1beta1/policy_service.proto", }
PolicyService_ServiceDesc is the grpc.ServiceDesc for PolicyService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var ResourceService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "buf.registry.policy.v1beta1.ResourceService", HandlerType: (*ResourceServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "GetResources", Handler: _ResourceService_GetResources_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "buf/registry/policy/v1beta1/resource_service.proto", }
ResourceService_ServiceDesc is the grpc.ServiceDesc for ResourceService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var UploadService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "buf.registry.policy.v1beta1.UploadService", HandlerType: (*UploadServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "Upload", Handler: _UploadService_Upload_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "buf/registry/policy/v1beta1/upload_service.proto", }
UploadService_ServiceDesc is the grpc.ServiceDesc for UploadService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterCommitServiceServer ¶
func RegisterCommitServiceServer(s grpc.ServiceRegistrar, srv CommitServiceServer)
func RegisterDownloadServiceServer ¶
func RegisterDownloadServiceServer(s grpc.ServiceRegistrar, srv DownloadServiceServer)
func RegisterLabelServiceServer ¶
func RegisterLabelServiceServer(s grpc.ServiceRegistrar, srv LabelServiceServer)
func RegisterPolicyServiceServer ¶
func RegisterPolicyServiceServer(s grpc.ServiceRegistrar, srv PolicyServiceServer)
func RegisterResourceServiceServer ¶
func RegisterResourceServiceServer(s grpc.ServiceRegistrar, srv ResourceServiceServer)
func RegisterUploadServiceServer ¶
func RegisterUploadServiceServer(s grpc.ServiceRegistrar, srv UploadServiceServer)
Types ¶
type CommitServiceClient ¶
type CommitServiceClient interface {
// Get Commits.
GetCommits(ctx context.Context, in *v1beta1.GetCommitsRequest, opts ...grpc.CallOption) (*v1beta1.GetCommitsResponse, error)
// List Commits for a given Policy.
ListCommits(ctx context.Context, in *v1beta1.ListCommitsRequest, opts ...grpc.CallOption) (*v1beta1.ListCommitsResponse, error)
}
CommitServiceClient is the client API for CommitService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewCommitServiceClient ¶
func NewCommitServiceClient(cc grpc.ClientConnInterface) CommitServiceClient
type CommitServiceServer ¶
type CommitServiceServer interface {
// Get Commits.
GetCommits(context.Context, *v1beta1.GetCommitsRequest) (*v1beta1.GetCommitsResponse, error)
// List Commits for a given Policy.
ListCommits(context.Context, *v1beta1.ListCommitsRequest) (*v1beta1.ListCommitsResponse, error)
}
CommitServiceServer is the server API for CommitService service. All implementations should embed UnimplementedCommitServiceServer for forward compatibility.
type DownloadServiceClient ¶
type DownloadServiceClient interface {
// Download contents for given set of Policies.
//
// Contents are a single YAML file.
Download(ctx context.Context, in *v1beta1.DownloadRequest, opts ...grpc.CallOption) (*v1beta1.DownloadResponse, error)
}
DownloadServiceClient is the client API for DownloadService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
Download contents.
func NewDownloadServiceClient ¶
func NewDownloadServiceClient(cc grpc.ClientConnInterface) DownloadServiceClient
type DownloadServiceServer ¶
type DownloadServiceServer interface {
// Download contents for given set of Policies.
//
// Contents are a single YAML file.
Download(context.Context, *v1beta1.DownloadRequest) (*v1beta1.DownloadResponse, error)
}
DownloadServiceServer is the server API for DownloadService service. All implementations should embed UnimplementedDownloadServiceServer for forward compatibility.
Download contents.
type LabelServiceClient ¶
type LabelServiceClient interface {
// Get Labels by id or name.
GetLabels(ctx context.Context, in *v1beta1.GetLabelsRequest, opts ...grpc.CallOption) (*v1beta1.GetLabelsResponse, error)
// List Labels for a given Policy, Commit or Label.
ListLabels(ctx context.Context, in *v1beta1.ListLabelsRequest, opts ...grpc.CallOption) (*v1beta1.ListLabelsResponse, error)
// List the history of a Label.
ListLabelHistory(ctx context.Context, in *v1beta1.ListLabelHistoryRequest, opts ...grpc.CallOption) (*v1beta1.ListLabelHistoryResponse, error)
// Create or update Labels on a Policy.
//
// If the Label does not exist, it will be created. If the Label was archived, it will be
// unarchived. If the Label already existed, the Commit in the request has to be newer than the
// Commit that the Label is currently pointing to, otherwise an error is returned.
//
// This operation is atomic. Either all Labels are created/updated or an error is returned.
CreateOrUpdateLabels(ctx context.Context, in *v1beta1.CreateOrUpdateLabelsRequest, opts ...grpc.CallOption) (*v1beta1.CreateOrUpdateLabelsResponse, error)
// Archive existing Labels.
//
// This operation is atomic. Either all Labels are archived or an error is returned.
ArchiveLabels(ctx context.Context, in *v1beta1.ArchiveLabelsRequest, opts ...grpc.CallOption) (*v1beta1.ArchiveLabelsResponse, error)
// Unarchive existing Labels.
//
// This operation is atomic. Either all Labels are unarchived or an error is returned.
UnarchiveLabels(ctx context.Context, in *v1beta1.UnarchiveLabelsRequest, opts ...grpc.CallOption) (*v1beta1.UnarchiveLabelsResponse, error)
}
LabelServiceClient is the client API for LabelService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
Operate on Labels
func NewLabelServiceClient ¶
func NewLabelServiceClient(cc grpc.ClientConnInterface) LabelServiceClient
type LabelServiceServer ¶
type LabelServiceServer interface {
// Get Labels by id or name.
GetLabels(context.Context, *v1beta1.GetLabelsRequest) (*v1beta1.GetLabelsResponse, error)
// List Labels for a given Policy, Commit or Label.
ListLabels(context.Context, *v1beta1.ListLabelsRequest) (*v1beta1.ListLabelsResponse, error)
// List the history of a Label.
ListLabelHistory(context.Context, *v1beta1.ListLabelHistoryRequest) (*v1beta1.ListLabelHistoryResponse, error)
// Create or update Labels on a Policy.
//
// If the Label does not exist, it will be created. If the Label was archived, it will be
// unarchived. If the Label already existed, the Commit in the request has to be newer than the
// Commit that the Label is currently pointing to, otherwise an error is returned.
//
// This operation is atomic. Either all Labels are created/updated or an error is returned.
CreateOrUpdateLabels(context.Context, *v1beta1.CreateOrUpdateLabelsRequest) (*v1beta1.CreateOrUpdateLabelsResponse, error)
// Archive existing Labels.
//
// This operation is atomic. Either all Labels are archived or an error is returned.
ArchiveLabels(context.Context, *v1beta1.ArchiveLabelsRequest) (*v1beta1.ArchiveLabelsResponse, error)
// Unarchive existing Labels.
//
// This operation is atomic. Either all Labels are unarchived or an error is returned.
UnarchiveLabels(context.Context, *v1beta1.UnarchiveLabelsRequest) (*v1beta1.UnarchiveLabelsResponse, error)
}
LabelServiceServer is the server API for LabelService service. All implementations should embed UnimplementedLabelServiceServer for forward compatibility.
Operate on Labels
type PolicyServiceClient ¶
type PolicyServiceClient interface {
// Get Policies by id or name.
GetPolicies(ctx context.Context, in *v1beta1.GetPoliciesRequest, opts ...grpc.CallOption) (*v1beta1.GetPoliciesResponse, error)
// List Policies, usually for a specific User or Organization.
ListPolicies(ctx context.Context, in *v1beta1.ListPoliciesRequest, opts ...grpc.CallOption) (*v1beta1.ListPoliciesResponse, error)
// Create new Policies.
//
// This operation is atomic. Either all Policies are created or an error is returned.
CreatePolicies(ctx context.Context, in *v1beta1.CreatePoliciesRequest, opts ...grpc.CallOption) (*v1beta1.CreatePoliciesResponse, error)
// Update exiting Policies.
//
// This operation is atomic. Either all Policies are updated or an error is returned.
UpdatePolicies(ctx context.Context, in *v1beta1.UpdatePoliciesRequest, opts ...grpc.CallOption) (*v1beta1.UpdatePoliciesResponse, error)
// Delete existing Policies.
//
// This operation is atomic. Either all Policies are deleted or an error is returned.
DeletePolicies(ctx context.Context, in *v1beta1.DeletePoliciesRequest, opts ...grpc.CallOption) (*v1beta1.DeletePoliciesResponse, error)
}
PolicyServiceClient is the client API for PolicyService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
Operate on Policies.
func NewPolicyServiceClient ¶
func NewPolicyServiceClient(cc grpc.ClientConnInterface) PolicyServiceClient
type PolicyServiceServer ¶
type PolicyServiceServer interface {
// Get Policies by id or name.
GetPolicies(context.Context, *v1beta1.GetPoliciesRequest) (*v1beta1.GetPoliciesResponse, error)
// List Policies, usually for a specific User or Organization.
ListPolicies(context.Context, *v1beta1.ListPoliciesRequest) (*v1beta1.ListPoliciesResponse, error)
// Create new Policies.
//
// This operation is atomic. Either all Policies are created or an error is returned.
CreatePolicies(context.Context, *v1beta1.CreatePoliciesRequest) (*v1beta1.CreatePoliciesResponse, error)
// Update exiting Policies.
//
// This operation is atomic. Either all Policies are updated or an error is returned.
UpdatePolicies(context.Context, *v1beta1.UpdatePoliciesRequest) (*v1beta1.UpdatePoliciesResponse, error)
// Delete existing Policies.
//
// This operation is atomic. Either all Policies are deleted or an error is returned.
DeletePolicies(context.Context, *v1beta1.DeletePoliciesRequest) (*v1beta1.DeletePoliciesResponse, error)
}
PolicyServiceServer is the server API for PolicyService service. All implementations should embed UnimplementedPolicyServiceServer for forward compatibility.
Operate on Policies.
type ResourceServiceClient ¶
type ResourceServiceClient interface {
// Get Resources.
GetResources(ctx context.Context, in *v1beta1.GetResourcesRequest, opts ...grpc.CallOption) (*v1beta1.GetResourcesResponse, error)
}
ResourceServiceClient is the client API for ResourceService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewResourceServiceClient ¶
func NewResourceServiceClient(cc grpc.ClientConnInterface) ResourceServiceClient
type ResourceServiceServer ¶
type ResourceServiceServer interface {
// Get Resources.
GetResources(context.Context, *v1beta1.GetResourcesRequest) (*v1beta1.GetResourcesResponse, error)
}
ResourceServiceServer is the server API for ResourceService service. All implementations should embed UnimplementedResourceServiceServer for forward compatibility.
type UnimplementedCommitServiceServer ¶
type UnimplementedCommitServiceServer struct{}
UnimplementedCommitServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedCommitServiceServer) GetCommits ¶
func (UnimplementedCommitServiceServer) GetCommits(context.Context, *v1beta1.GetCommitsRequest) (*v1beta1.GetCommitsResponse, error)
func (UnimplementedCommitServiceServer) ListCommits ¶
func (UnimplementedCommitServiceServer) ListCommits(context.Context, *v1beta1.ListCommitsRequest) (*v1beta1.ListCommitsResponse, error)
type UnimplementedDownloadServiceServer ¶
type UnimplementedDownloadServiceServer struct{}
UnimplementedDownloadServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedDownloadServiceServer) Download ¶
func (UnimplementedDownloadServiceServer) Download(context.Context, *v1beta1.DownloadRequest) (*v1beta1.DownloadResponse, error)
type UnimplementedLabelServiceServer ¶
type UnimplementedLabelServiceServer struct{}
UnimplementedLabelServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedLabelServiceServer) ArchiveLabels ¶
func (UnimplementedLabelServiceServer) ArchiveLabels(context.Context, *v1beta1.ArchiveLabelsRequest) (*v1beta1.ArchiveLabelsResponse, error)
func (UnimplementedLabelServiceServer) CreateOrUpdateLabels ¶
func (UnimplementedLabelServiceServer) CreateOrUpdateLabels(context.Context, *v1beta1.CreateOrUpdateLabelsRequest) (*v1beta1.CreateOrUpdateLabelsResponse, error)
func (UnimplementedLabelServiceServer) GetLabels ¶
func (UnimplementedLabelServiceServer) GetLabels(context.Context, *v1beta1.GetLabelsRequest) (*v1beta1.GetLabelsResponse, error)
func (UnimplementedLabelServiceServer) ListLabelHistory ¶
func (UnimplementedLabelServiceServer) ListLabelHistory(context.Context, *v1beta1.ListLabelHistoryRequest) (*v1beta1.ListLabelHistoryResponse, error)
func (UnimplementedLabelServiceServer) ListLabels ¶
func (UnimplementedLabelServiceServer) ListLabels(context.Context, *v1beta1.ListLabelsRequest) (*v1beta1.ListLabelsResponse, error)
func (UnimplementedLabelServiceServer) UnarchiveLabels ¶
func (UnimplementedLabelServiceServer) UnarchiveLabels(context.Context, *v1beta1.UnarchiveLabelsRequest) (*v1beta1.UnarchiveLabelsResponse, error)
type UnimplementedPolicyServiceServer ¶
type UnimplementedPolicyServiceServer struct{}
UnimplementedPolicyServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedPolicyServiceServer) CreatePolicies ¶
func (UnimplementedPolicyServiceServer) CreatePolicies(context.Context, *v1beta1.CreatePoliciesRequest) (*v1beta1.CreatePoliciesResponse, error)
func (UnimplementedPolicyServiceServer) DeletePolicies ¶
func (UnimplementedPolicyServiceServer) DeletePolicies(context.Context, *v1beta1.DeletePoliciesRequest) (*v1beta1.DeletePoliciesResponse, error)
func (UnimplementedPolicyServiceServer) GetPolicies ¶
func (UnimplementedPolicyServiceServer) GetPolicies(context.Context, *v1beta1.GetPoliciesRequest) (*v1beta1.GetPoliciesResponse, error)
func (UnimplementedPolicyServiceServer) ListPolicies ¶
func (UnimplementedPolicyServiceServer) ListPolicies(context.Context, *v1beta1.ListPoliciesRequest) (*v1beta1.ListPoliciesResponse, error)
func (UnimplementedPolicyServiceServer) UpdatePolicies ¶
func (UnimplementedPolicyServiceServer) UpdatePolicies(context.Context, *v1beta1.UpdatePoliciesRequest) (*v1beta1.UpdatePoliciesResponse, error)
type UnimplementedResourceServiceServer ¶
type UnimplementedResourceServiceServer struct{}
UnimplementedResourceServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedResourceServiceServer) GetResources ¶
func (UnimplementedResourceServiceServer) GetResources(context.Context, *v1beta1.GetResourcesRequest) (*v1beta1.GetResourcesResponse, error)
type UnimplementedUploadServiceServer ¶
type UnimplementedUploadServiceServer struct{}
UnimplementedUploadServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedUploadServiceServer) Upload ¶
func (UnimplementedUploadServiceServer) Upload(context.Context, *v1beta1.UploadRequest) (*v1beta1.UploadResponse, error)
type UnsafeCommitServiceServer ¶
type UnsafeCommitServiceServer interface {
// contains filtered or unexported methods
}
UnsafeCommitServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to CommitServiceServer will result in compilation errors.
type UnsafeDownloadServiceServer ¶
type UnsafeDownloadServiceServer interface {
// contains filtered or unexported methods
}
UnsafeDownloadServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to DownloadServiceServer will result in compilation errors.
type UnsafeLabelServiceServer ¶
type UnsafeLabelServiceServer interface {
// contains filtered or unexported methods
}
UnsafeLabelServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to LabelServiceServer will result in compilation errors.
type UnsafePolicyServiceServer ¶
type UnsafePolicyServiceServer interface {
// contains filtered or unexported methods
}
UnsafePolicyServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to PolicyServiceServer will result in compilation errors.
type UnsafeResourceServiceServer ¶
type UnsafeResourceServiceServer interface {
// contains filtered or unexported methods
}
UnsafeResourceServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ResourceServiceServer will result in compilation errors.
type UnsafeUploadServiceServer ¶
type UnsafeUploadServiceServer interface {
// contains filtered or unexported methods
}
UnsafeUploadServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to UploadServiceServer will result in compilation errors.
type UploadServiceClient ¶
type UploadServiceClient interface {
// Upload contents for given set of Policies.
//
// Contents are expected to be a single YAML file.
Upload(ctx context.Context, in *v1beta1.UploadRequest, opts ...grpc.CallOption) (*v1beta1.UploadResponse, error)
}
UploadServiceClient is the client API for UploadService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
Upload contents.
func NewUploadServiceClient ¶
func NewUploadServiceClient(cc grpc.ClientConnInterface) UploadServiceClient
type UploadServiceServer ¶
type UploadServiceServer interface {
// Upload contents for given set of Policies.
//
// Contents are expected to be a single YAML file.
Upload(context.Context, *v1beta1.UploadRequest) (*v1beta1.UploadResponse, error)
}
UploadServiceServer is the server API for UploadService service. All implementations should embed UnimplementedUploadServiceServer for forward compatibility.
Upload contents.
Source Files
¶
- commit_service_grpc.pb.go
- download_service_grpc.pb.go
- label_service_grpc.pb.go
- policy_service_grpc.pb.go
- resource_service_grpc.pb.go
- upload_service_grpc.pb.go