Documentation
¶
Index ¶
- Variables
- type AttachReq
- type AttachReq_builder
- type AttachResp
- type AttachResp_builder
- type DumpReq
- func (x *DumpReq) GetDir() string
- func (x *DumpReq) GetLeaveRunning() bool
- func (x *DumpReq) GetStream() bool
- func (*DumpReq) ProtoMessage()
- func (x *DumpReq) ProtoReflect() protoreflect.Message
- func (x *DumpReq) Reset()
- func (x *DumpReq) SetDir(v string)
- func (x *DumpReq) SetLeaveRunning(v bool)
- func (x *DumpReq) SetStream(v bool)
- func (x *DumpReq) String() string
- type DumpReq_builder
- type DumpResp
- type DumpResp_builder
- type FreezeReq
- type FreezeReq_builder
- type FreezeResp
- type FreezeResp_builder
- type HealthCheckComponent
- func (x *HealthCheckComponent) GetData() string
- func (x *HealthCheckComponent) GetErrors() []string
- func (x *HealthCheckComponent) GetName() string
- func (x *HealthCheckComponent) GetWarnings() []string
- func (*HealthCheckComponent) ProtoMessage()
- func (x *HealthCheckComponent) ProtoReflect() protoreflect.Message
- func (x *HealthCheckComponent) Reset()
- func (x *HealthCheckComponent) SetData(v string)
- func (x *HealthCheckComponent) SetErrors(v []string)
- func (x *HealthCheckComponent) SetName(v string)
- func (x *HealthCheckComponent) SetWarnings(v []string)
- func (x *HealthCheckComponent) String() string
- type HealthCheckComponent_builder
- type HealthCheckReq
- type HealthCheckReq_builder
- type HealthCheckResp
- func (x *HealthCheckResp) GetComponents() []*HealthCheckComponent
- func (*HealthCheckResp) ProtoMessage()
- func (x *HealthCheckResp) ProtoReflect() protoreflect.Message
- func (x *HealthCheckResp) Reset()
- func (x *HealthCheckResp) SetComponents(v []*HealthCheckComponent)
- func (x *HealthCheckResp) String() string
- type HealthCheckResp_builder
- type InfoReq
- type InfoReq_builder
- type InfoResp
- func (x *InfoResp) GetAttachedPID() uint32
- func (x *InfoResp) GetPID() uint32
- func (x *InfoResp) GetShmName() string
- func (x *InfoResp) GetShmSize() uint64
- func (x *InfoResp) GetVersion() string
- func (*InfoResp) ProtoMessage()
- func (x *InfoResp) ProtoReflect() protoreflect.Message
- func (x *InfoResp) Reset()
- func (x *InfoResp) SetAttachedPID(v uint32)
- func (x *InfoResp) SetPID(v uint32)
- func (x *InfoResp) SetShmName(v string)
- func (x *InfoResp) SetShmSize(v uint64)
- func (x *InfoResp) SetVersion(v string)
- func (x *InfoResp) String() string
- type InfoResp_builder
- type RestoreReq
- func (x *RestoreReq) GetDir() string
- func (x *RestoreReq) GetStream() bool
- func (*RestoreReq) ProtoMessage()
- func (x *RestoreReq) ProtoReflect() protoreflect.Message
- func (x *RestoreReq) Reset()
- func (x *RestoreReq) SetDir(v string)
- func (x *RestoreReq) SetStream(v bool)
- func (x *RestoreReq) String() string
- type RestoreReq_builder
- type RestoreResp
- func (x *RestoreResp) ClearRestoreStats()
- func (x *RestoreResp) GetRestoreStats() *RestoreStats
- func (x *RestoreResp) HasRestoreStats() bool
- func (*RestoreResp) ProtoMessage()
- func (x *RestoreResp) ProtoReflect() protoreflect.Message
- func (x *RestoreResp) Reset()
- func (x *RestoreResp) SetRestoreStats(v *RestoreStats)
- func (x *RestoreResp) String() string
- type RestoreResp_builder
- type RestoreStats
- func (x *RestoreStats) GetCopyHostMemTime() int64
- func (x *RestoreStats) GetCopyMemTime() int64
- func (x *RestoreStats) GetReplayCallsTime() int64
- func (*RestoreStats) ProtoMessage()
- func (x *RestoreStats) ProtoReflect() protoreflect.Message
- func (x *RestoreStats) Reset()
- func (x *RestoreStats) SetCopyHostMemTime(v int64)
- func (x *RestoreStats) SetCopyMemTime(v int64)
- func (x *RestoreStats) SetReplayCallsTime(v int64)
- func (x *RestoreStats) String() string
- type RestoreStats_builder
- type UnfreezeReq
- type UnfreezeReq_builder
- type UnfreezeResp
- type UnfreezeResp_builder
Constants ¶
This section is empty.
Variables ¶
var File_gpu_controller_proto protoreflect.FileDescriptor
var File_gpu_health_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type AttachReq ¶
type AttachReq struct {
PID uint32 `protobuf:"varint,1,opt,name=PID,proto3" json:"PID,omitempty"` // PID of the process to forcefully attach to the controller
// contains filtered or unexported fields
}
func (*AttachReq) ProtoReflect ¶
func (x *AttachReq) ProtoReflect() protoreflect.Message
type AttachReq_builder ¶
type AttachReq_builder struct {
PID uint32
// contains filtered or unexported fields
}
func (AttachReq_builder) Build ¶
func (b0 AttachReq_builder) Build() *AttachReq
type AttachResp ¶
type AttachResp struct {
// contains filtered or unexported fields
}
func (*AttachResp) ProtoMessage ¶
func (*AttachResp) ProtoMessage()
func (*AttachResp) ProtoReflect ¶
func (x *AttachResp) ProtoReflect() protoreflect.Message
func (*AttachResp) Reset ¶
func (x *AttachResp) Reset()
func (*AttachResp) String ¶
func (x *AttachResp) String() string
type AttachResp_builder ¶
type AttachResp_builder struct {
// contains filtered or unexported fields
}
func (AttachResp_builder) Build ¶
func (b0 AttachResp_builder) Build() *AttachResp
type DumpReq ¶
type DumpReq struct {
Dir string `protobuf:"bytes,1,opt,name=Dir,proto3" json:"Dir,omitempty"`
Stream bool `protobuf:"varint,2,opt,name=Stream,proto3" json:"Stream,omitempty"`
LeaveRunning bool `protobuf:"varint,3,opt,name=LeaveRunning,proto3" json:"LeaveRunning,omitempty"`
// contains filtered or unexported fields
}
func (*DumpReq) ProtoReflect ¶
func (x *DumpReq) ProtoReflect() protoreflect.Message
type DumpReq_builder ¶
type DumpReq_builder struct {
Dir string
Stream bool
LeaveRunning bool
// contains filtered or unexported fields
}
func (DumpReq_builder) Build ¶
func (b0 DumpReq_builder) Build() *DumpReq
type DumpResp ¶
type DumpResp struct {
// contains filtered or unexported fields
}
func (*DumpResp) ProtoReflect ¶
func (x *DumpResp) ProtoReflect() protoreflect.Message
type DumpResp_builder ¶
type DumpResp_builder struct {
// contains filtered or unexported fields
}
func (DumpResp_builder) Build ¶
func (b0 DumpResp_builder) Build() *DumpResp
type FreezeReq ¶
type FreezeReq struct {
// contains filtered or unexported fields
}
func (*FreezeReq) ProtoReflect ¶
func (x *FreezeReq) ProtoReflect() protoreflect.Message
type FreezeReq_builder ¶
type FreezeReq_builder struct {
// contains filtered or unexported fields
}
func (FreezeReq_builder) Build ¶
func (b0 FreezeReq_builder) Build() *FreezeReq
type FreezeResp ¶
type FreezeResp struct {
// contains filtered or unexported fields
}
func (*FreezeResp) ProtoMessage ¶
func (*FreezeResp) ProtoMessage()
func (*FreezeResp) ProtoReflect ¶
func (x *FreezeResp) ProtoReflect() protoreflect.Message
func (*FreezeResp) Reset ¶
func (x *FreezeResp) Reset()
func (*FreezeResp) String ¶
func (x *FreezeResp) String() string
type FreezeResp_builder ¶
type FreezeResp_builder struct {
// contains filtered or unexported fields
}
func (FreezeResp_builder) Build ¶
func (b0 FreezeResp_builder) Build() *FreezeResp
type HealthCheckComponent ¶
type HealthCheckComponent struct {
Name string `protobuf:"bytes,1,opt,name=Name,proto3" json:"Name,omitempty"`
Data string `protobuf:"bytes,2,opt,name=Data,proto3" json:"Data,omitempty"`
Errors []string `protobuf:"bytes,3,rep,name=Errors,proto3" json:"Errors,omitempty"`
Warnings []string `protobuf:"bytes,4,rep,name=Warnings,proto3" json:"Warnings,omitempty"`
// contains filtered or unexported fields
}
func (*HealthCheckComponent) GetData ¶
func (x *HealthCheckComponent) GetData() string
func (*HealthCheckComponent) GetErrors ¶
func (x *HealthCheckComponent) GetErrors() []string
func (*HealthCheckComponent) GetName ¶
func (x *HealthCheckComponent) GetName() string
func (*HealthCheckComponent) GetWarnings ¶
func (x *HealthCheckComponent) GetWarnings() []string
func (*HealthCheckComponent) ProtoMessage ¶
func (*HealthCheckComponent) ProtoMessage()
func (*HealthCheckComponent) ProtoReflect ¶
func (x *HealthCheckComponent) ProtoReflect() protoreflect.Message
func (*HealthCheckComponent) Reset ¶
func (x *HealthCheckComponent) Reset()
func (*HealthCheckComponent) SetData ¶
func (x *HealthCheckComponent) SetData(v string)
func (*HealthCheckComponent) SetErrors ¶
func (x *HealthCheckComponent) SetErrors(v []string)
func (*HealthCheckComponent) SetName ¶
func (x *HealthCheckComponent) SetName(v string)
func (*HealthCheckComponent) SetWarnings ¶
func (x *HealthCheckComponent) SetWarnings(v []string)
func (*HealthCheckComponent) String ¶
func (x *HealthCheckComponent) String() string
type HealthCheckComponent_builder ¶
type HealthCheckComponent_builder struct {
Name string
Data string
Errors []string
Warnings []string
// contains filtered or unexported fields
}
func (HealthCheckComponent_builder) Build ¶
func (b0 HealthCheckComponent_builder) Build() *HealthCheckComponent
type HealthCheckReq ¶
type HealthCheckReq struct {
// contains filtered or unexported fields
}
func (*HealthCheckReq) ProtoMessage ¶
func (*HealthCheckReq) ProtoMessage()
func (*HealthCheckReq) ProtoReflect ¶
func (x *HealthCheckReq) ProtoReflect() protoreflect.Message
func (*HealthCheckReq) Reset ¶
func (x *HealthCheckReq) Reset()
func (*HealthCheckReq) String ¶
func (x *HealthCheckReq) String() string
type HealthCheckReq_builder ¶
type HealthCheckReq_builder struct {
// contains filtered or unexported fields
}
func (HealthCheckReq_builder) Build ¶
func (b0 HealthCheckReq_builder) Build() *HealthCheckReq
type HealthCheckResp ¶
type HealthCheckResp struct {
Components []*HealthCheckComponent `protobuf:"bytes,1,rep,name=Components,proto3" json:"Components,omitempty"`
// contains filtered or unexported fields
}
func (*HealthCheckResp) GetComponents ¶
func (x *HealthCheckResp) GetComponents() []*HealthCheckComponent
func (*HealthCheckResp) ProtoMessage ¶
func (*HealthCheckResp) ProtoMessage()
func (*HealthCheckResp) ProtoReflect ¶
func (x *HealthCheckResp) ProtoReflect() protoreflect.Message
func (*HealthCheckResp) Reset ¶
func (x *HealthCheckResp) Reset()
func (*HealthCheckResp) SetComponents ¶
func (x *HealthCheckResp) SetComponents(v []*HealthCheckComponent)
func (*HealthCheckResp) String ¶
func (x *HealthCheckResp) String() string
type HealthCheckResp_builder ¶
type HealthCheckResp_builder struct {
Components []*HealthCheckComponent
// contains filtered or unexported fields
}
func (HealthCheckResp_builder) Build ¶
func (b0 HealthCheckResp_builder) Build() *HealthCheckResp
type InfoReq ¶
type InfoReq struct {
// contains filtered or unexported fields
}
func (*InfoReq) ProtoReflect ¶
func (x *InfoReq) ProtoReflect() protoreflect.Message
type InfoReq_builder ¶
type InfoReq_builder struct {
// contains filtered or unexported fields
}
func (InfoReq_builder) Build ¶
func (b0 InfoReq_builder) Build() *InfoReq
type InfoResp ¶
type InfoResp struct {
PID uint32 `protobuf:"varint,1,opt,name=PID,proto3" json:"PID,omitempty"` // PID of the controller process
AttachedPID uint32 `protobuf:"varint,2,opt,name=AttachedPID,proto3" json:"AttachedPID,omitempty"` // PID of the process that is attached to the controller, 0 if none attached
ShmSize uint64 `protobuf:"varint,3,opt,name=ShmSize,proto3" json:"ShmSize,omitempty"` // Size of the shared memory segment used for IPC
ShmName string `protobuf:"bytes,4,opt,name=ShmName,proto3" json:"ShmName,omitempty"` // Name of the shared memory segment used for IPC
Version string `protobuf:"bytes,5,opt,name=Version,proto3" json:"Version,omitempty"` // Version of the controller
// contains filtered or unexported fields
}
func (*InfoResp) ProtoReflect ¶
func (x *InfoResp) ProtoReflect() protoreflect.Message
type InfoResp_builder ¶
type InfoResp_builder struct {
PID uint32
AttachedPID uint32
ShmSize uint64
ShmName string
Version string
// contains filtered or unexported fields
}
func (InfoResp_builder) Build ¶
func (b0 InfoResp_builder) Build() *InfoResp
type RestoreReq ¶
type RestoreReq struct {
Dir string `protobuf:"bytes,1,opt,name=Dir,proto3" json:"Dir,omitempty"`
Stream bool `protobuf:"varint,2,opt,name=Stream,proto3" json:"Stream,omitempty"`
// contains filtered or unexported fields
}
func (*RestoreReq) GetDir ¶
func (x *RestoreReq) GetDir() string
func (*RestoreReq) GetStream ¶
func (x *RestoreReq) GetStream() bool
func (*RestoreReq) ProtoMessage ¶
func (*RestoreReq) ProtoMessage()
func (*RestoreReq) ProtoReflect ¶
func (x *RestoreReq) ProtoReflect() protoreflect.Message
func (*RestoreReq) Reset ¶
func (x *RestoreReq) Reset()
func (*RestoreReq) SetDir ¶
func (x *RestoreReq) SetDir(v string)
func (*RestoreReq) SetStream ¶
func (x *RestoreReq) SetStream(v bool)
func (*RestoreReq) String ¶
func (x *RestoreReq) String() string
type RestoreReq_builder ¶
func (RestoreReq_builder) Build ¶
func (b0 RestoreReq_builder) Build() *RestoreReq
type RestoreResp ¶
type RestoreResp struct {
RestoreStats *RestoreStats `protobuf:"bytes,1,opt,name=RestoreStats,proto3" json:"RestoreStats,omitempty"`
// contains filtered or unexported fields
}
func (*RestoreResp) ClearRestoreStats ¶
func (x *RestoreResp) ClearRestoreStats()
func (*RestoreResp) GetRestoreStats ¶
func (x *RestoreResp) GetRestoreStats() *RestoreStats
func (*RestoreResp) HasRestoreStats ¶
func (x *RestoreResp) HasRestoreStats() bool
func (*RestoreResp) ProtoMessage ¶
func (*RestoreResp) ProtoMessage()
func (*RestoreResp) ProtoReflect ¶
func (x *RestoreResp) ProtoReflect() protoreflect.Message
func (*RestoreResp) Reset ¶
func (x *RestoreResp) Reset()
func (*RestoreResp) SetRestoreStats ¶
func (x *RestoreResp) SetRestoreStats(v *RestoreStats)
func (*RestoreResp) String ¶
func (x *RestoreResp) String() string
type RestoreResp_builder ¶
type RestoreResp_builder struct {
RestoreStats *RestoreStats
// contains filtered or unexported fields
}
func (RestoreResp_builder) Build ¶
func (b0 RestoreResp_builder) Build() *RestoreResp
type RestoreStats ¶
type RestoreStats struct {
CopyMemTime int64 `protobuf:"varint,1,opt,name=CopyMemTime,proto3" json:"CopyMemTime,omitempty"` // in milliseconds
ReplayCallsTime int64 `protobuf:"varint,2,opt,name=ReplayCallsTime,proto3" json:"ReplayCallsTime,omitempty"` // in milliseconds
CopyHostMemTime int64 `protobuf:"varint,3,opt,name=CopyHostMemTime,proto3" json:"CopyHostMemTime,omitempty"` // in milliseconds
// contains filtered or unexported fields
}
func (*RestoreStats) GetCopyHostMemTime ¶
func (x *RestoreStats) GetCopyHostMemTime() int64
func (*RestoreStats) GetCopyMemTime ¶
func (x *RestoreStats) GetCopyMemTime() int64
func (*RestoreStats) GetReplayCallsTime ¶
func (x *RestoreStats) GetReplayCallsTime() int64
func (*RestoreStats) ProtoMessage ¶
func (*RestoreStats) ProtoMessage()
func (*RestoreStats) ProtoReflect ¶
func (x *RestoreStats) ProtoReflect() protoreflect.Message
func (*RestoreStats) Reset ¶
func (x *RestoreStats) Reset()
func (*RestoreStats) SetCopyHostMemTime ¶
func (x *RestoreStats) SetCopyHostMemTime(v int64)
func (*RestoreStats) SetCopyMemTime ¶
func (x *RestoreStats) SetCopyMemTime(v int64)
func (*RestoreStats) SetReplayCallsTime ¶
func (x *RestoreStats) SetReplayCallsTime(v int64)
func (*RestoreStats) String ¶
func (x *RestoreStats) String() string
type RestoreStats_builder ¶
type RestoreStats_builder struct {
CopyMemTime int64
ReplayCallsTime int64
CopyHostMemTime int64
// contains filtered or unexported fields
}
func (RestoreStats_builder) Build ¶
func (b0 RestoreStats_builder) Build() *RestoreStats
type UnfreezeReq ¶
type UnfreezeReq struct {
// contains filtered or unexported fields
}
func (*UnfreezeReq) ProtoMessage ¶
func (*UnfreezeReq) ProtoMessage()
func (*UnfreezeReq) ProtoReflect ¶
func (x *UnfreezeReq) ProtoReflect() protoreflect.Message
func (*UnfreezeReq) Reset ¶
func (x *UnfreezeReq) Reset()
func (*UnfreezeReq) String ¶
func (x *UnfreezeReq) String() string
type UnfreezeReq_builder ¶
type UnfreezeReq_builder struct {
// contains filtered or unexported fields
}
func (UnfreezeReq_builder) Build ¶
func (b0 UnfreezeReq_builder) Build() *UnfreezeReq
type UnfreezeResp ¶
type UnfreezeResp struct {
// contains filtered or unexported fields
}
func (*UnfreezeResp) ProtoMessage ¶
func (*UnfreezeResp) ProtoMessage()
func (*UnfreezeResp) ProtoReflect ¶
func (x *UnfreezeResp) ProtoReflect() protoreflect.Message
func (*UnfreezeResp) Reset ¶
func (x *UnfreezeResp) Reset()
func (*UnfreezeResp) String ¶
func (x *UnfreezeResp) String() string
type UnfreezeResp_builder ¶
type UnfreezeResp_builder struct {
// contains filtered or unexported fields
}
func (UnfreezeResp_builder) Build ¶
func (b0 UnfreezeResp_builder) Build() *UnfreezeResp
Source Files
¶
- controller.pb.go
- health.pb.go
Click to show internal directories.
Click to hide internal directories.