Documentation
¶
Index ¶
- Constants
- Variables
- type FileStatus
- type ImgStreamerListReplyEntry
- func (x *ImgStreamerListReplyEntry) GetFilenames() []string
- func (*ImgStreamerListReplyEntry) ProtoMessage()
- func (x *ImgStreamerListReplyEntry) ProtoReflect() protoreflect.Message
- func (x *ImgStreamerListReplyEntry) Reset()
- func (x *ImgStreamerListReplyEntry) SetFilenames(v []string)
- func (x *ImgStreamerListReplyEntry) String() string
- type ImgStreamerListReplyEntry_builder
- type ImgStreamerReplyEntry
- func (x *ImgStreamerReplyEntry) ClearStatus()
- func (x *ImgStreamerReplyEntry) GetExists() bool
- func (x *ImgStreamerReplyEntry) GetStatus() FileStatus
- func (x *ImgStreamerReplyEntry) HasStatus() bool
- func (*ImgStreamerReplyEntry) ProtoMessage()
- func (x *ImgStreamerReplyEntry) ProtoReflect() protoreflect.Message
- func (x *ImgStreamerReplyEntry) Reset()
- func (x *ImgStreamerReplyEntry) SetExists(v bool)
- func (x *ImgStreamerReplyEntry) SetStatus(v FileStatus)
- func (x *ImgStreamerReplyEntry) String() string
- type ImgStreamerReplyEntry_builder
- type ImgStreamerRequestEntry
- func (x *ImgStreamerRequestEntry) GetFilename() string
- func (*ImgStreamerRequestEntry) ProtoMessage()
- func (x *ImgStreamerRequestEntry) ProtoReflect() protoreflect.Message
- func (x *ImgStreamerRequestEntry) Reset()
- func (x *ImgStreamerRequestEntry) SetFilename(v string)
- func (x *ImgStreamerRequestEntry) String() string
- type ImgStreamerRequestEntry_builder
- type Marker
- func (x *Marker) ClearBody()
- func (x *Marker) ClearFileData()
- func (x *Marker) ClearFileEof()
- func (x *Marker) ClearFilename()
- func (x *Marker) ClearImageEof()
- func (x *Marker) GetBody() isMarker_Body
- func (x *Marker) GetFileData() uint32
- func (x *Marker) GetFileEof() bool
- func (x *Marker) GetFilename() string
- func (x *Marker) GetImageEof() bool
- func (x *Marker) GetSeq() uint64
- func (x *Marker) HasBody() bool
- func (x *Marker) HasFileData() bool
- func (x *Marker) HasFileEof() bool
- func (x *Marker) HasFilename() bool
- func (x *Marker) HasImageEof() bool
- func (*Marker) ProtoMessage()
- func (x *Marker) ProtoReflect() protoreflect.Message
- func (x *Marker) Reset()
- func (x *Marker) SetFileData(v uint32)
- func (x *Marker) SetFileEof(v bool)
- func (x *Marker) SetFilename(v string)
- func (x *Marker) SetImageEof(v bool)
- func (x *Marker) SetSeq(v uint64)
- func (x *Marker) String() string
- func (x *Marker) WhichBody() case_Marker_Body
- type Marker_FileData
- type Marker_FileEof
- type Marker_Filename
- type Marker_ImageEof
- type Marker_builder
Constants ¶
const Marker_Body_not_set_case case_Marker_Body = 0
const Marker_FileData_case case_Marker_Body = 3
const Marker_FileEof_case case_Marker_Body = 4
const Marker_Filename_case case_Marker_Body = 2
const Marker_ImageEof_case case_Marker_Body = 5
Variables ¶
var ( FileStatus_name = map[int32]string{ 0: "DOES_NOT_EXIST", 1: "NOT_READY", 2: "READY", } FileStatus_value = map[string]int32{ "DOES_NOT_EXIST": 0, "NOT_READY": 1, "READY": 2, } )
Enum value maps for FileStatus.
var File_img_streamer_img_streamer_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type FileStatus ¶
type FileStatus int32
const ( FileStatus_DOES_NOT_EXIST FileStatus = 0 FileStatus_NOT_READY FileStatus = 1 FileStatus_READY FileStatus = 2 )
func (FileStatus) Descriptor ¶
func (FileStatus) Descriptor() protoreflect.EnumDescriptor
func (FileStatus) Enum ¶
func (x FileStatus) Enum() *FileStatus
func (FileStatus) Number ¶
func (x FileStatus) Number() protoreflect.EnumNumber
func (FileStatus) String ¶
func (x FileStatus) String() string
func (FileStatus) Type ¶
func (FileStatus) Type() protoreflect.EnumType
type ImgStreamerListReplyEntry ¶
type ImgStreamerListReplyEntry struct {
Filenames []string `protobuf:"bytes,1,rep,name=filenames,proto3" json:"filenames,omitempty"`
// contains filtered or unexported fields
}
This message is sent from the streamer to CRIU for listing all image files
func (*ImgStreamerListReplyEntry) GetFilenames ¶
func (x *ImgStreamerListReplyEntry) GetFilenames() []string
func (*ImgStreamerListReplyEntry) ProtoMessage ¶
func (*ImgStreamerListReplyEntry) ProtoMessage()
func (*ImgStreamerListReplyEntry) ProtoReflect ¶
func (x *ImgStreamerListReplyEntry) ProtoReflect() protoreflect.Message
func (*ImgStreamerListReplyEntry) Reset ¶
func (x *ImgStreamerListReplyEntry) Reset()
func (*ImgStreamerListReplyEntry) SetFilenames ¶
func (x *ImgStreamerListReplyEntry) SetFilenames(v []string)
func (*ImgStreamerListReplyEntry) String ¶
func (x *ImgStreamerListReplyEntry) String() string
type ImgStreamerListReplyEntry_builder ¶
type ImgStreamerListReplyEntry_builder struct {
Filenames []string
// contains filtered or unexported fields
}
func (ImgStreamerListReplyEntry_builder) Build ¶
func (b0 ImgStreamerListReplyEntry_builder) Build() *ImgStreamerListReplyEntry
type ImgStreamerReplyEntry ¶
type ImgStreamerReplyEntry struct {
// for backwards compatibilty, in case clients can't read status
Exists bool `protobuf:"varint,1,opt,name=exists,proto3" json:"exists,omitempty"`
Status *FileStatus `protobuf:"varint,2,opt,name=status,proto3,enum=img_streamer.FileStatus,oneof" json:"status,omitempty"`
// contains filtered or unexported fields
}
This message is sent from the streamer to CRIU. It is only used during restore to report whether the requested file exists, or is ready or not.
func (*ImgStreamerReplyEntry) ClearStatus ¶
func (x *ImgStreamerReplyEntry) ClearStatus()
func (*ImgStreamerReplyEntry) GetExists ¶
func (x *ImgStreamerReplyEntry) GetExists() bool
func (*ImgStreamerReplyEntry) GetStatus ¶
func (x *ImgStreamerReplyEntry) GetStatus() FileStatus
func (*ImgStreamerReplyEntry) HasStatus ¶
func (x *ImgStreamerReplyEntry) HasStatus() bool
func (*ImgStreamerReplyEntry) ProtoMessage ¶
func (*ImgStreamerReplyEntry) ProtoMessage()
func (*ImgStreamerReplyEntry) ProtoReflect ¶
func (x *ImgStreamerReplyEntry) ProtoReflect() protoreflect.Message
func (*ImgStreamerReplyEntry) Reset ¶
func (x *ImgStreamerReplyEntry) Reset()
func (*ImgStreamerReplyEntry) SetExists ¶
func (x *ImgStreamerReplyEntry) SetExists(v bool)
func (*ImgStreamerReplyEntry) SetStatus ¶
func (x *ImgStreamerReplyEntry) SetStatus(v FileStatus)
func (*ImgStreamerReplyEntry) String ¶
func (x *ImgStreamerReplyEntry) String() string
type ImgStreamerReplyEntry_builder ¶
type ImgStreamerReplyEntry_builder struct {
// for backwards compatibilty, in case clients can't read status
Exists bool
Status *FileStatus
// contains filtered or unexported fields
}
func (ImgStreamerReplyEntry_builder) Build ¶
func (b0 ImgStreamerReplyEntry_builder) Build() *ImgStreamerReplyEntry
type ImgStreamerRequestEntry ¶
type ImgStreamerRequestEntry struct {
Filename string `protobuf:"bytes,1,opt,name=filename,proto3" json:"filename,omitempty"`
// contains filtered or unexported fields
}
This message is sent from CRIU to the streamer.
- During dump, it communicates the name of the file that is about to be sent to the streamer.
- During restore, CRIU requests image files from the streamer. The message is used to communicate the name of the desired file.
func (*ImgStreamerRequestEntry) GetFilename ¶
func (x *ImgStreamerRequestEntry) GetFilename() string
func (*ImgStreamerRequestEntry) ProtoMessage ¶
func (*ImgStreamerRequestEntry) ProtoMessage()
func (*ImgStreamerRequestEntry) ProtoReflect ¶
func (x *ImgStreamerRequestEntry) ProtoReflect() protoreflect.Message
func (*ImgStreamerRequestEntry) Reset ¶
func (x *ImgStreamerRequestEntry) Reset()
func (*ImgStreamerRequestEntry) SetFilename ¶
func (x *ImgStreamerRequestEntry) SetFilename(v string)
func (*ImgStreamerRequestEntry) String ¶
func (x *ImgStreamerRequestEntry) String() string
type ImgStreamerRequestEntry_builder ¶
type ImgStreamerRequestEntry_builder struct {
Filename string
// contains filtered or unexported fields
}
func (ImgStreamerRequestEntry_builder) Build ¶
func (b0 ImgStreamerRequestEntry_builder) Build() *ImgStreamerRequestEntry
type Marker ¶
type Marker struct {
Seq uint64 `protobuf:"varint,1,opt,name=seq,proto3" json:"seq,omitempty"`
// Types that are valid to be assigned to Body:
//
// *Marker_Filename
// *Marker_FileData
// *Marker_FileEof
// *Marker_ImageEof
Body isMarker_Body `protobuf_oneof:"body"`
// contains filtered or unexported fields
}
func (*Marker) ProtoReflect ¶
func (x *Marker) ProtoReflect() protoreflect.Message
type Marker_FileData ¶
type Marker_FileData struct {
// Incoming data for the current file
FileData uint32 `protobuf:"varint,3,opt,name=file_data,json=fileData,proto3,oneof"`
}
type Marker_FileEof ¶
type Marker_FileEof struct {
// EOF of current file is reached
FileEof bool `protobuf:"varint,4,opt,name=file_eof,json=fileEof,proto3,oneof"`
}
type Marker_Filename ¶
type Marker_Filename struct {
// Denotes the filename of the next upcoming markers (denoted as current file)
Filename string `protobuf:"bytes,2,opt,name=filename,proto3,oneof"`
}
type Marker_ImageEof ¶
type Marker_ImageEof struct {
// EOF of image is reached
ImageEof bool `protobuf:"varint,5,opt,name=image_eof,json=imageEof,proto3,oneof"`
}
type Marker_builder ¶
type Marker_builder struct {
Seq uint64
// Fields of oneof Body:
// Denotes the filename of the next upcoming markers (denoted as current file)
Filename *string
// Incoming data for the current file
FileData *uint32
// EOF of current file is reached
FileEof *bool
// EOF of image is reached
ImageEof *bool
// contains filtered or unexported fields
}
func (Marker_builder) Build ¶
func (b0 Marker_builder) Build() *Marker
Source Files
¶
- img-streamer.pb.go
Click to show internal directories.
Click to hide internal directories.