Documentation
¶
Index ¶
- Constants
- Variables
- type AccessLogEntry
- func (x *AccessLogEntry) ClearPeer()
- func (x *AccessLogEntry) ClearPolicySource()
- func (x *AccessLogEntry) ClearRequestContext()
- func (x *AccessLogEntry) ClearTimestamp()
- func (x *AccessLogEntry) GetCallId() string
- func (x *AccessLogEntry) GetMetadata() map[string]*MetaValues
- func (x *AccessLogEntry) GetMethod() string
- func (x *AccessLogEntry) GetOversized() bool
- func (x *AccessLogEntry) GetPeer() *Peer
- func (x *AccessLogEntry) GetPolicySource() *PolicySource
- func (x *AccessLogEntry) GetRequestContext() *RequestContext
- func (x *AccessLogEntry) GetStatusCode() uint32
- func (x *AccessLogEntry) GetTimestamp() *timestamppb.Timestamp
- func (x *AccessLogEntry) HasPeer() bool
- func (x *AccessLogEntry) HasPolicySource() bool
- func (x *AccessLogEntry) HasRequestContext() bool
- func (x *AccessLogEntry) HasTimestamp() bool
- func (*AccessLogEntry) ProtoMessage()
- func (x *AccessLogEntry) ProtoReflect() protoreflect.Message
- func (x *AccessLogEntry) Reset()
- func (x *AccessLogEntry) SetCallId(v string)
- func (x *AccessLogEntry) SetMetadata(v map[string]*MetaValues)
- func (x *AccessLogEntry) SetMethod(v string)
- func (x *AccessLogEntry) SetOversized(v bool)
- func (x *AccessLogEntry) SetPeer(v *Peer)
- func (x *AccessLogEntry) SetPolicySource(v *PolicySource)
- func (x *AccessLogEntry) SetRequestContext(v *RequestContext)
- func (x *AccessLogEntry) SetStatusCode(v uint32)
- func (x *AccessLogEntry) SetTimestamp(v *timestamppb.Timestamp)
- func (x *AccessLogEntry) String() string
- type AccessLogEntry_builder
- type AuditTrail
- func (x *AuditTrail) GetEffectivePolicies() map[string]*v11.SourceAttributes
- func (*AuditTrail) ProtoMessage()
- func (x *AuditTrail) ProtoReflect() protoreflect.Message
- func (x *AuditTrail) Reset()
- func (x *AuditTrail) SetEffectivePolicies(v map[string]*v11.SourceAttributes)
- func (x *AuditTrail) String() string
- type AuditTrail_builder
- type DecisionLogEntry
- func (x *DecisionLogEntry) ClearAuditTrail()
- func (x *DecisionLogEntry) ClearCheckResources()
- func (x *DecisionLogEntry) ClearMethod()
- func (x *DecisionLogEntry) ClearPeer()
- func (x *DecisionLogEntry) ClearPlanResources()
- func (x *DecisionLogEntry) ClearPolicySource()
- func (x *DecisionLogEntry) ClearRequestContext()
- func (x *DecisionLogEntry) ClearTimestamp()
- func (x *DecisionLogEntry) GetAuditTrail() *AuditTrail
- func (x *DecisionLogEntry) GetCallId() string
- func (x *DecisionLogEntry) GetCheckResources() *DecisionLogEntry_CheckResources
- func (x *DecisionLogEntry) GetError() stringdeprecated
- func (x *DecisionLogEntry) GetInputs() []*v1.CheckInputdeprecated
- func (x *DecisionLogEntry) GetMetadata() map[string]*MetaValues
- func (x *DecisionLogEntry) GetMethod() isDecisionLogEntry_Method
- func (x *DecisionLogEntry) GetOutputs() []*v1.CheckOutputdeprecated
- func (x *DecisionLogEntry) GetOversized() bool
- func (x *DecisionLogEntry) GetPeer() *Peer
- func (x *DecisionLogEntry) GetPlanResources() *DecisionLogEntry_PlanResources
- func (x *DecisionLogEntry) GetPolicySource() *PolicySource
- func (x *DecisionLogEntry) GetRequestContext() *RequestContext
- func (x *DecisionLogEntry) GetTimestamp() *timestamppb.Timestamp
- func (x *DecisionLogEntry) HasAuditTrail() bool
- func (x *DecisionLogEntry) HasCheckResources() bool
- func (x *DecisionLogEntry) HasMethod() bool
- func (x *DecisionLogEntry) HasPeer() bool
- func (x *DecisionLogEntry) HasPlanResources() bool
- func (x *DecisionLogEntry) HasPolicySource() bool
- func (x *DecisionLogEntry) HasRequestContext() bool
- func (x *DecisionLogEntry) HasTimestamp() bool
- func (*DecisionLogEntry) ProtoMessage()
- func (x *DecisionLogEntry) ProtoReflect() protoreflect.Message
- func (x *DecisionLogEntry) Reset()
- func (x *DecisionLogEntry) SetAuditTrail(v *AuditTrail)
- func (x *DecisionLogEntry) SetCallId(v string)
- func (x *DecisionLogEntry) SetCheckResources(v *DecisionLogEntry_CheckResources)
- func (x *DecisionLogEntry) SetError(v string)deprecated
- func (x *DecisionLogEntry) SetInputs(v []*v1.CheckInput)deprecated
- func (x *DecisionLogEntry) SetMetadata(v map[string]*MetaValues)
- func (x *DecisionLogEntry) SetOutputs(v []*v1.CheckOutput)deprecated
- func (x *DecisionLogEntry) SetOversized(v bool)
- func (x *DecisionLogEntry) SetPeer(v *Peer)
- func (x *DecisionLogEntry) SetPlanResources(v *DecisionLogEntry_PlanResources)
- func (x *DecisionLogEntry) SetPolicySource(v *PolicySource)
- func (x *DecisionLogEntry) SetRequestContext(v *RequestContext)
- func (x *DecisionLogEntry) SetTimestamp(v *timestamppb.Timestamp)
- func (x *DecisionLogEntry) String() string
- func (x *DecisionLogEntry) WhichMethod() case_DecisionLogEntry_Method
- type DecisionLogEntry_CheckResources
- func (x *DecisionLogEntry_CheckResources) GetError() string
- func (x *DecisionLogEntry_CheckResources) GetInputs() []*v1.CheckInput
- func (x *DecisionLogEntry_CheckResources) GetOutputs() []*v1.CheckOutput
- func (*DecisionLogEntry_CheckResources) ProtoMessage()
- func (x *DecisionLogEntry_CheckResources) ProtoReflect() protoreflect.Message
- func (x *DecisionLogEntry_CheckResources) Reset()
- func (x *DecisionLogEntry_CheckResources) SetError(v string)
- func (x *DecisionLogEntry_CheckResources) SetInputs(v []*v1.CheckInput)
- func (x *DecisionLogEntry_CheckResources) SetOutputs(v []*v1.CheckOutput)
- func (x *DecisionLogEntry_CheckResources) String() string
- type DecisionLogEntry_CheckResources_
- type DecisionLogEntry_CheckResources_builder
- type DecisionLogEntry_PlanResources
- func (x *DecisionLogEntry_PlanResources) ClearInput()
- func (x *DecisionLogEntry_PlanResources) ClearOutput()
- func (x *DecisionLogEntry_PlanResources) GetError() string
- func (x *DecisionLogEntry_PlanResources) GetInput() *v1.PlanResourcesInput
- func (x *DecisionLogEntry_PlanResources) GetOutput() *v1.PlanResourcesOutput
- func (x *DecisionLogEntry_PlanResources) HasInput() bool
- func (x *DecisionLogEntry_PlanResources) HasOutput() bool
- func (*DecisionLogEntry_PlanResources) ProtoMessage()
- func (x *DecisionLogEntry_PlanResources) ProtoReflect() protoreflect.Message
- func (x *DecisionLogEntry_PlanResources) Reset()
- func (x *DecisionLogEntry_PlanResources) SetError(v string)
- func (x *DecisionLogEntry_PlanResources) SetInput(v *v1.PlanResourcesInput)
- func (x *DecisionLogEntry_PlanResources) SetOutput(v *v1.PlanResourcesOutput)
- func (x *DecisionLogEntry_PlanResources) String() string
- type DecisionLogEntry_PlanResources_
- type DecisionLogEntry_PlanResources_builder
- type DecisionLogEntry_builder
- type MetaValues
- type MetaValues_builder
- type Peer
- func (x *Peer) GetAddress() string
- func (x *Peer) GetAuthInfo() string
- func (x *Peer) GetForwardedFor() string
- func (x *Peer) GetUserAgent() string
- func (*Peer) ProtoMessage()
- func (x *Peer) ProtoReflect() protoreflect.Message
- func (x *Peer) Reset()
- func (x *Peer) SetAddress(v string)
- func (x *Peer) SetAuthInfo(v string)
- func (x *Peer) SetForwardedFor(v string)
- func (x *Peer) SetUserAgent(v string)
- func (x *Peer) String() string
- type Peer_builder
- type PolicySource
- func (x *PolicySource) ClearBlob()
- func (x *PolicySource) ClearDatabase()
- func (x *PolicySource) ClearDisk()
- func (x *PolicySource) ClearEmbeddedPdp()
- func (x *PolicySource) ClearGit()
- func (x *PolicySource) ClearHub()
- func (x *PolicySource) ClearSource()
- func (x *PolicySource) GetBlob() *PolicySource_Blob
- func (x *PolicySource) GetDatabase() *PolicySource_Database
- func (x *PolicySource) GetDisk() *PolicySource_Disk
- func (x *PolicySource) GetEmbeddedPdp() *PolicySource_EmbeddedPDP
- func (x *PolicySource) GetGit() *PolicySource_Git
- func (x *PolicySource) GetHub() *PolicySource_Hub
- func (x *PolicySource) GetSource() isPolicySource_Source
- func (x *PolicySource) HasBlob() bool
- func (x *PolicySource) HasDatabase() bool
- func (x *PolicySource) HasDisk() bool
- func (x *PolicySource) HasEmbeddedPdp() bool
- func (x *PolicySource) HasGit() bool
- func (x *PolicySource) HasHub() bool
- func (x *PolicySource) HasSource() bool
- func (*PolicySource) ProtoMessage()
- func (x *PolicySource) ProtoReflect() protoreflect.Message
- func (x *PolicySource) Reset()
- func (x *PolicySource) SetBlob(v *PolicySource_Blob)
- func (x *PolicySource) SetDatabase(v *PolicySource_Database)
- func (x *PolicySource) SetDisk(v *PolicySource_Disk)
- func (x *PolicySource) SetEmbeddedPdp(v *PolicySource_EmbeddedPDP)
- func (x *PolicySource) SetGit(v *PolicySource_Git)
- func (x *PolicySource) SetHub(v *PolicySource_Hub)
- func (x *PolicySource) String() string
- func (x *PolicySource) WhichSource() case_PolicySource_Source
- type PolicySource_Blob
- func (x *PolicySource_Blob) GetBucketUrl() string
- func (x *PolicySource_Blob) GetPrefix() string
- func (*PolicySource_Blob) ProtoMessage()
- func (x *PolicySource_Blob) ProtoReflect() protoreflect.Message
- func (x *PolicySource_Blob) Reset()
- func (x *PolicySource_Blob) SetBucketUrl(v string)
- func (x *PolicySource_Blob) SetPrefix(v string)
- func (x *PolicySource_Blob) String() string
- type PolicySource_Blob_
- type PolicySource_Blob_builder
- type PolicySource_Database
- func (x *PolicySource_Database) GetDriver() PolicySource_Database_Driver
- func (*PolicySource_Database) ProtoMessage()
- func (x *PolicySource_Database) ProtoReflect() protoreflect.Message
- func (x *PolicySource_Database) Reset()
- func (x *PolicySource_Database) SetDriver(v PolicySource_Database_Driver)
- func (x *PolicySource_Database) String() string
- type PolicySource_Database_
- type PolicySource_Database_Driver
- func (PolicySource_Database_Driver) Descriptor() protoreflect.EnumDescriptor
- func (x PolicySource_Database_Driver) Enum() *PolicySource_Database_Driver
- func (x PolicySource_Database_Driver) Number() protoreflect.EnumNumber
- func (x PolicySource_Database_Driver) String() string
- func (PolicySource_Database_Driver) Type() protoreflect.EnumType
- type PolicySource_Database_builder
- type PolicySource_Disk
- type PolicySource_Disk_
- type PolicySource_Disk_builder
- type PolicySource_EmbeddedPDP
- func (x *PolicySource_EmbeddedPDP) ClearBuiltAt()
- func (x *PolicySource_EmbeddedPDP) GetBuiltAt() *timestamppb.Timestamp
- func (x *PolicySource_EmbeddedPDP) GetCommitHash() string
- func (x *PolicySource_EmbeddedPDP) GetUrl() string
- func (x *PolicySource_EmbeddedPDP) HasBuiltAt() bool
- func (*PolicySource_EmbeddedPDP) ProtoMessage()
- func (x *PolicySource_EmbeddedPDP) ProtoReflect() protoreflect.Message
- func (x *PolicySource_EmbeddedPDP) Reset()
- func (x *PolicySource_EmbeddedPDP) SetBuiltAt(v *timestamppb.Timestamp)
- func (x *PolicySource_EmbeddedPDP) SetCommitHash(v string)
- func (x *PolicySource_EmbeddedPDP) SetUrl(v string)
- func (x *PolicySource_EmbeddedPDP) String() string
- type PolicySource_EmbeddedPDP_builder
- type PolicySource_EmbeddedPdp
- type PolicySource_Git
- func (x *PolicySource_Git) GetBranch() string
- func (x *PolicySource_Git) GetRepositoryUrl() string
- func (x *PolicySource_Git) GetSubdirectory() string
- func (*PolicySource_Git) ProtoMessage()
- func (x *PolicySource_Git) ProtoReflect() protoreflect.Message
- func (x *PolicySource_Git) Reset()
- func (x *PolicySource_Git) SetBranch(v string)
- func (x *PolicySource_Git) SetRepositoryUrl(v string)
- func (x *PolicySource_Git) SetSubdirectory(v string)
- func (x *PolicySource_Git) String() string
- type PolicySource_Git_
- type PolicySource_Git_builder
- type PolicySource_Hub
- func (x *PolicySource_Hub) ClearDeploymentId()
- func (x *PolicySource_Hub) ClearEmbeddedBundle()
- func (x *PolicySource_Hub) ClearLabel()
- func (x *PolicySource_Hub) ClearLocalBundle()
- func (x *PolicySource_Hub) ClearPlaygroundId()
- func (x *PolicySource_Hub) ClearSource()
- func (x *PolicySource_Hub) GetDeploymentId() string
- func (x *PolicySource_Hub) GetEmbeddedBundle() *PolicySource_Hub_EmbeddedBundle
- func (x *PolicySource_Hub) GetLabel() string
- func (x *PolicySource_Hub) GetLocalBundle() *PolicySource_Hub_LocalBundle
- func (x *PolicySource_Hub) GetPlaygroundId() string
- func (x *PolicySource_Hub) GetSource() isPolicySource_Hub_Source
- func (x *PolicySource_Hub) HasDeploymentId() bool
- func (x *PolicySource_Hub) HasEmbeddedBundle() bool
- func (x *PolicySource_Hub) HasLabel() bool
- func (x *PolicySource_Hub) HasLocalBundle() bool
- func (x *PolicySource_Hub) HasPlaygroundId() bool
- func (x *PolicySource_Hub) HasSource() bool
- func (*PolicySource_Hub) ProtoMessage()
- func (x *PolicySource_Hub) ProtoReflect() protoreflect.Message
- func (x *PolicySource_Hub) Reset()
- func (x *PolicySource_Hub) SetDeploymentId(v string)
- func (x *PolicySource_Hub) SetEmbeddedBundle(v *PolicySource_Hub_EmbeddedBundle)
- func (x *PolicySource_Hub) SetLabel(v string)
- func (x *PolicySource_Hub) SetLocalBundle(v *PolicySource_Hub_LocalBundle)
- func (x *PolicySource_Hub) SetPlaygroundId(v string)
- func (x *PolicySource_Hub) String() string
- func (x *PolicySource_Hub) WhichSource() case_PolicySource_Hub_Source
- type PolicySource_Hub_
- type PolicySource_Hub_DeploymentId
- type PolicySource_Hub_EmbeddedBundle
- func (x *PolicySource_Hub_EmbeddedBundle) GetRuleId() string
- func (x *PolicySource_Hub_EmbeddedBundle) GetScopes() []string
- func (*PolicySource_Hub_EmbeddedBundle) ProtoMessage()
- func (x *PolicySource_Hub_EmbeddedBundle) ProtoReflect() protoreflect.Message
- func (x *PolicySource_Hub_EmbeddedBundle) Reset()
- func (x *PolicySource_Hub_EmbeddedBundle) SetRuleId(v string)
- func (x *PolicySource_Hub_EmbeddedBundle) SetScopes(v []string)
- func (x *PolicySource_Hub_EmbeddedBundle) String() string
- type PolicySource_Hub_EmbeddedBundle_
- type PolicySource_Hub_EmbeddedBundle_builder
- type PolicySource_Hub_Label
- type PolicySource_Hub_LocalBundle
- func (x *PolicySource_Hub_LocalBundle) GetPath() string
- func (*PolicySource_Hub_LocalBundle) ProtoMessage()
- func (x *PolicySource_Hub_LocalBundle) ProtoReflect() protoreflect.Message
- func (x *PolicySource_Hub_LocalBundle) Reset()
- func (x *PolicySource_Hub_LocalBundle) SetPath(v string)
- func (x *PolicySource_Hub_LocalBundle) String() string
- type PolicySource_Hub_LocalBundle_
- type PolicySource_Hub_LocalBundle_builder
- type PolicySource_Hub_PlaygroundId
- type PolicySource_Hub_builder
- type PolicySource_builder
- type RequestContext
- func (x *RequestContext) GetAnnotations() map[string]*structpb.Value
- func (*RequestContext) ProtoMessage()
- func (x *RequestContext) ProtoReflect() protoreflect.Message
- func (x *RequestContext) Reset()
- func (x *RequestContext) SetAnnotations(v map[string]*structpb.Value)
- func (x *RequestContext) String() string
- type RequestContext_builder
Constants ¶
const DecisionLogEntry_CheckResources_case case_DecisionLogEntry_Method = 7
const DecisionLogEntry_Method_not_set_case case_DecisionLogEntry_Method = 0
const DecisionLogEntry_PlanResources_case case_DecisionLogEntry_Method = 8
const PolicySource_Blob_case case_PolicySource_Source = 1
const PolicySource_Database_case case_PolicySource_Source = 2
const PolicySource_Disk_case case_PolicySource_Source = 3
const PolicySource_EmbeddedPdp_case case_PolicySource_Source = 6
const PolicySource_Git_case case_PolicySource_Source = 4
const PolicySource_Hub_DeploymentId_case case_PolicySource_Hub_Source = 2
const PolicySource_Hub_EmbeddedBundle_case case_PolicySource_Hub_Source = 5
const PolicySource_Hub_Label_case case_PolicySource_Hub_Source = 1
const PolicySource_Hub_LocalBundle_case case_PolicySource_Hub_Source = 4
const PolicySource_Hub_PlaygroundId_case case_PolicySource_Hub_Source = 3
const PolicySource_Hub_Source_not_set_case case_PolicySource_Hub_Source = 0
const PolicySource_Hub_case case_PolicySource_Source = 5
const PolicySource_Source_not_set_case case_PolicySource_Source = 0
Variables ¶
var ( PolicySource_Database_Driver_name = map[int32]string{ 0: "DRIVER_UNSPECIFIED", 1: "DRIVER_MYSQL", 2: "DRIVER_POSTGRES", 3: "DRIVER_SQLITE3", } PolicySource_Database_Driver_value = map[string]int32{ "DRIVER_UNSPECIFIED": 0, "DRIVER_MYSQL": 1, "DRIVER_POSTGRES": 2, "DRIVER_SQLITE3": 3, } )
Enum value maps for PolicySource_Database_Driver.
var File_cerbos_audit_v1_audit_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type AccessLogEntry ¶
type AccessLogEntry struct {
CallId string `protobuf:"bytes,1,opt,name=call_id,json=callId,proto3" json:"call_id,omitempty"`
Timestamp *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=timestamp,proto3" json:"timestamp,omitempty"`
Peer *Peer `protobuf:"bytes,3,opt,name=peer,proto3" json:"peer,omitempty"`
Metadata map[string]*MetaValues `` /* 143-byte string literal not displayed */
Method string `protobuf:"bytes,5,opt,name=method,proto3" json:"method,omitempty"`
StatusCode uint32 `protobuf:"varint,6,opt,name=status_code,json=statusCode,proto3" json:"status_code,omitempty"`
Oversized bool `protobuf:"varint,7,opt,name=oversized,proto3" json:"oversized,omitempty"`
PolicySource *PolicySource `protobuf:"bytes,8,opt,name=policy_source,json=policySource,proto3" json:"policy_source,omitempty"`
RequestContext *RequestContext `protobuf:"bytes,9,opt,name=request_context,json=requestContext,proto3,oneof" json:"request_context,omitempty"`
// contains filtered or unexported fields
}
func (*AccessLogEntry) ClearPeer ¶
func (x *AccessLogEntry) ClearPeer()
func (*AccessLogEntry) ClearPolicySource ¶
func (x *AccessLogEntry) ClearPolicySource()
func (*AccessLogEntry) ClearRequestContext ¶
func (x *AccessLogEntry) ClearRequestContext()
func (*AccessLogEntry) ClearTimestamp ¶
func (x *AccessLogEntry) ClearTimestamp()
func (*AccessLogEntry) GetCallId ¶
func (x *AccessLogEntry) GetCallId() string
func (*AccessLogEntry) GetMetadata ¶
func (x *AccessLogEntry) GetMetadata() map[string]*MetaValues
func (*AccessLogEntry) GetMethod ¶
func (x *AccessLogEntry) GetMethod() string
func (*AccessLogEntry) GetOversized ¶
func (x *AccessLogEntry) GetOversized() bool
func (*AccessLogEntry) GetPeer ¶
func (x *AccessLogEntry) GetPeer() *Peer
func (*AccessLogEntry) GetPolicySource ¶
func (x *AccessLogEntry) GetPolicySource() *PolicySource
func (*AccessLogEntry) GetRequestContext ¶
func (x *AccessLogEntry) GetRequestContext() *RequestContext
func (*AccessLogEntry) GetStatusCode ¶
func (x *AccessLogEntry) GetStatusCode() uint32
func (*AccessLogEntry) GetTimestamp ¶
func (x *AccessLogEntry) GetTimestamp() *timestamppb.Timestamp
func (*AccessLogEntry) HasPeer ¶
func (x *AccessLogEntry) HasPeer() bool
func (*AccessLogEntry) HasPolicySource ¶
func (x *AccessLogEntry) HasPolicySource() bool
func (*AccessLogEntry) HasRequestContext ¶
func (x *AccessLogEntry) HasRequestContext() bool
func (*AccessLogEntry) HasTimestamp ¶
func (x *AccessLogEntry) HasTimestamp() bool
func (*AccessLogEntry) ProtoMessage ¶
func (*AccessLogEntry) ProtoMessage()
func (*AccessLogEntry) ProtoReflect ¶
func (x *AccessLogEntry) ProtoReflect() protoreflect.Message
func (*AccessLogEntry) Reset ¶
func (x *AccessLogEntry) Reset()
func (*AccessLogEntry) SetCallId ¶
func (x *AccessLogEntry) SetCallId(v string)
func (*AccessLogEntry) SetMetadata ¶
func (x *AccessLogEntry) SetMetadata(v map[string]*MetaValues)
func (*AccessLogEntry) SetMethod ¶
func (x *AccessLogEntry) SetMethod(v string)
func (*AccessLogEntry) SetOversized ¶
func (x *AccessLogEntry) SetOversized(v bool)
func (*AccessLogEntry) SetPeer ¶
func (x *AccessLogEntry) SetPeer(v *Peer)
func (*AccessLogEntry) SetPolicySource ¶
func (x *AccessLogEntry) SetPolicySource(v *PolicySource)
func (*AccessLogEntry) SetRequestContext ¶
func (x *AccessLogEntry) SetRequestContext(v *RequestContext)
func (*AccessLogEntry) SetStatusCode ¶
func (x *AccessLogEntry) SetStatusCode(v uint32)
func (*AccessLogEntry) SetTimestamp ¶
func (x *AccessLogEntry) SetTimestamp(v *timestamppb.Timestamp)
func (*AccessLogEntry) String ¶
func (x *AccessLogEntry) String() string
type AccessLogEntry_builder ¶
type AccessLogEntry_builder struct {
CallId string
Timestamp *timestamppb.Timestamp
Peer *Peer
Metadata map[string]*MetaValues
Method string
StatusCode uint32
Oversized bool
PolicySource *PolicySource
RequestContext *RequestContext
// contains filtered or unexported fields
}
func (AccessLogEntry_builder) Build ¶
func (b0 AccessLogEntry_builder) Build() *AccessLogEntry
type AuditTrail ¶
type AuditTrail struct {
EffectivePolicies map[string]*v11.SourceAttributes `` /* 186-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*AuditTrail) GetEffectivePolicies ¶
func (x *AuditTrail) GetEffectivePolicies() map[string]*v11.SourceAttributes
func (*AuditTrail) ProtoMessage ¶
func (*AuditTrail) ProtoMessage()
func (*AuditTrail) ProtoReflect ¶
func (x *AuditTrail) ProtoReflect() protoreflect.Message
func (*AuditTrail) Reset ¶
func (x *AuditTrail) Reset()
func (*AuditTrail) SetEffectivePolicies ¶
func (x *AuditTrail) SetEffectivePolicies(v map[string]*v11.SourceAttributes)
func (*AuditTrail) String ¶
func (x *AuditTrail) String() string
type AuditTrail_builder ¶
type AuditTrail_builder struct {
EffectivePolicies map[string]*v11.SourceAttributes
// contains filtered or unexported fields
}
func (AuditTrail_builder) Build ¶
func (b0 AuditTrail_builder) Build() *AuditTrail
type DecisionLogEntry ¶
type DecisionLogEntry struct {
CallId string `protobuf:"bytes,1,opt,name=call_id,json=callId,proto3" json:"call_id,omitempty"`
Timestamp *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=timestamp,proto3" json:"timestamp,omitempty"`
Peer *Peer `protobuf:"bytes,3,opt,name=peer,proto3" json:"peer,omitempty"`
// Deprecated. Use method.check_resources.inputs instead.
//
// Deprecated: Marked as deprecated in cerbos/audit/v1/audit.proto.
Inputs []*v1.CheckInput `protobuf:"bytes,4,rep,name=inputs,proto3" json:"inputs,omitempty"`
// Deprecated. Use method.check_resources.outputs instead.
//
// Deprecated: Marked as deprecated in cerbos/audit/v1/audit.proto.
Outputs []*v1.CheckOutput `protobuf:"bytes,5,rep,name=outputs,proto3" json:"outputs,omitempty"`
// Deprecated. Use method.check_resources.error instead.
//
// Deprecated: Marked as deprecated in cerbos/audit/v1/audit.proto.
Error string `protobuf:"bytes,6,opt,name=error,proto3" json:"error,omitempty"`
// Types that are valid to be assigned to Method:
//
// *DecisionLogEntry_CheckResources_
// *DecisionLogEntry_PlanResources_
Method isDecisionLogEntry_Method `protobuf_oneof:"method"`
Metadata map[string]*MetaValues `` /* 144-byte string literal not displayed */
AuditTrail *AuditTrail `protobuf:"bytes,16,opt,name=audit_trail,json=auditTrail,proto3" json:"audit_trail,omitempty"`
Oversized bool `protobuf:"varint,17,opt,name=oversized,proto3" json:"oversized,omitempty"`
PolicySource *PolicySource `protobuf:"bytes,18,opt,name=policy_source,json=policySource,proto3" json:"policy_source,omitempty"`
RequestContext *RequestContext `protobuf:"bytes,19,opt,name=request_context,json=requestContext,proto3,oneof" json:"request_context,omitempty"`
// contains filtered or unexported fields
}
func (*DecisionLogEntry) ClearAuditTrail ¶
func (x *DecisionLogEntry) ClearAuditTrail()
func (*DecisionLogEntry) ClearCheckResources ¶
func (x *DecisionLogEntry) ClearCheckResources()
func (*DecisionLogEntry) ClearMethod ¶
func (x *DecisionLogEntry) ClearMethod()
func (*DecisionLogEntry) ClearPeer ¶
func (x *DecisionLogEntry) ClearPeer()
func (*DecisionLogEntry) ClearPlanResources ¶
func (x *DecisionLogEntry) ClearPlanResources()
func (*DecisionLogEntry) ClearPolicySource ¶
func (x *DecisionLogEntry) ClearPolicySource()
func (*DecisionLogEntry) ClearRequestContext ¶
func (x *DecisionLogEntry) ClearRequestContext()
func (*DecisionLogEntry) ClearTimestamp ¶
func (x *DecisionLogEntry) ClearTimestamp()
func (*DecisionLogEntry) GetAuditTrail ¶
func (x *DecisionLogEntry) GetAuditTrail() *AuditTrail
func (*DecisionLogEntry) GetCallId ¶
func (x *DecisionLogEntry) GetCallId() string
func (*DecisionLogEntry) GetCheckResources ¶
func (x *DecisionLogEntry) GetCheckResources() *DecisionLogEntry_CheckResources
func (*DecisionLogEntry) GetError
deprecated
func (x *DecisionLogEntry) GetError() string
Deprecated: Marked as deprecated in cerbos/audit/v1/audit.proto.
func (*DecisionLogEntry) GetInputs
deprecated
func (x *DecisionLogEntry) GetInputs() []*v1.CheckInput
Deprecated: Marked as deprecated in cerbos/audit/v1/audit.proto.
func (*DecisionLogEntry) GetMetadata ¶
func (x *DecisionLogEntry) GetMetadata() map[string]*MetaValues
func (*DecisionLogEntry) GetMethod ¶
func (x *DecisionLogEntry) GetMethod() isDecisionLogEntry_Method
func (*DecisionLogEntry) GetOutputs
deprecated
func (x *DecisionLogEntry) GetOutputs() []*v1.CheckOutput
Deprecated: Marked as deprecated in cerbos/audit/v1/audit.proto.
func (*DecisionLogEntry) GetOversized ¶
func (x *DecisionLogEntry) GetOversized() bool
func (*DecisionLogEntry) GetPeer ¶
func (x *DecisionLogEntry) GetPeer() *Peer
func (*DecisionLogEntry) GetPlanResources ¶
func (x *DecisionLogEntry) GetPlanResources() *DecisionLogEntry_PlanResources
func (*DecisionLogEntry) GetPolicySource ¶
func (x *DecisionLogEntry) GetPolicySource() *PolicySource
func (*DecisionLogEntry) GetRequestContext ¶
func (x *DecisionLogEntry) GetRequestContext() *RequestContext
func (*DecisionLogEntry) GetTimestamp ¶
func (x *DecisionLogEntry) GetTimestamp() *timestamppb.Timestamp
func (*DecisionLogEntry) HasAuditTrail ¶
func (x *DecisionLogEntry) HasAuditTrail() bool
func (*DecisionLogEntry) HasCheckResources ¶
func (x *DecisionLogEntry) HasCheckResources() bool
func (*DecisionLogEntry) HasMethod ¶
func (x *DecisionLogEntry) HasMethod() bool
func (*DecisionLogEntry) HasPeer ¶
func (x *DecisionLogEntry) HasPeer() bool
func (*DecisionLogEntry) HasPlanResources ¶
func (x *DecisionLogEntry) HasPlanResources() bool
func (*DecisionLogEntry) HasPolicySource ¶
func (x *DecisionLogEntry) HasPolicySource() bool
func (*DecisionLogEntry) HasRequestContext ¶
func (x *DecisionLogEntry) HasRequestContext() bool
func (*DecisionLogEntry) HasTimestamp ¶
func (x *DecisionLogEntry) HasTimestamp() bool
func (*DecisionLogEntry) ProtoMessage ¶
func (*DecisionLogEntry) ProtoMessage()
func (*DecisionLogEntry) ProtoReflect ¶
func (x *DecisionLogEntry) ProtoReflect() protoreflect.Message
func (*DecisionLogEntry) Reset ¶
func (x *DecisionLogEntry) Reset()
func (*DecisionLogEntry) SetAuditTrail ¶
func (x *DecisionLogEntry) SetAuditTrail(v *AuditTrail)
func (*DecisionLogEntry) SetCallId ¶
func (x *DecisionLogEntry) SetCallId(v string)
func (*DecisionLogEntry) SetCheckResources ¶
func (x *DecisionLogEntry) SetCheckResources(v *DecisionLogEntry_CheckResources)
func (*DecisionLogEntry) SetError
deprecated
func (x *DecisionLogEntry) SetError(v string)
Deprecated: Marked as deprecated in cerbos/audit/v1/audit.proto.
func (*DecisionLogEntry) SetInputs
deprecated
func (x *DecisionLogEntry) SetInputs(v []*v1.CheckInput)
Deprecated: Marked as deprecated in cerbos/audit/v1/audit.proto.
func (*DecisionLogEntry) SetMetadata ¶
func (x *DecisionLogEntry) SetMetadata(v map[string]*MetaValues)
func (*DecisionLogEntry) SetOutputs
deprecated
func (x *DecisionLogEntry) SetOutputs(v []*v1.CheckOutput)
Deprecated: Marked as deprecated in cerbos/audit/v1/audit.proto.
func (*DecisionLogEntry) SetOversized ¶
func (x *DecisionLogEntry) SetOversized(v bool)
func (*DecisionLogEntry) SetPeer ¶
func (x *DecisionLogEntry) SetPeer(v *Peer)
func (*DecisionLogEntry) SetPlanResources ¶
func (x *DecisionLogEntry) SetPlanResources(v *DecisionLogEntry_PlanResources)
func (*DecisionLogEntry) SetPolicySource ¶
func (x *DecisionLogEntry) SetPolicySource(v *PolicySource)
func (*DecisionLogEntry) SetRequestContext ¶
func (x *DecisionLogEntry) SetRequestContext(v *RequestContext)
func (*DecisionLogEntry) SetTimestamp ¶
func (x *DecisionLogEntry) SetTimestamp(v *timestamppb.Timestamp)
func (*DecisionLogEntry) String ¶
func (x *DecisionLogEntry) String() string
func (*DecisionLogEntry) WhichMethod ¶
func (x *DecisionLogEntry) WhichMethod() case_DecisionLogEntry_Method
type DecisionLogEntry_CheckResources ¶
type DecisionLogEntry_CheckResources struct {
Inputs []*v1.CheckInput `protobuf:"bytes,1,rep,name=inputs,proto3" json:"inputs,omitempty"`
Outputs []*v1.CheckOutput `protobuf:"bytes,2,rep,name=outputs,proto3" json:"outputs,omitempty"`
Error string `protobuf:"bytes,3,opt,name=error,proto3" json:"error,omitempty"`
// contains filtered or unexported fields
}
func (*DecisionLogEntry_CheckResources) GetError ¶
func (x *DecisionLogEntry_CheckResources) GetError() string
func (*DecisionLogEntry_CheckResources) GetInputs ¶
func (x *DecisionLogEntry_CheckResources) GetInputs() []*v1.CheckInput
func (*DecisionLogEntry_CheckResources) GetOutputs ¶
func (x *DecisionLogEntry_CheckResources) GetOutputs() []*v1.CheckOutput
func (*DecisionLogEntry_CheckResources) ProtoMessage ¶
func (*DecisionLogEntry_CheckResources) ProtoMessage()
func (*DecisionLogEntry_CheckResources) ProtoReflect ¶
func (x *DecisionLogEntry_CheckResources) ProtoReflect() protoreflect.Message
func (*DecisionLogEntry_CheckResources) Reset ¶
func (x *DecisionLogEntry_CheckResources) Reset()
func (*DecisionLogEntry_CheckResources) SetError ¶
func (x *DecisionLogEntry_CheckResources) SetError(v string)
func (*DecisionLogEntry_CheckResources) SetInputs ¶
func (x *DecisionLogEntry_CheckResources) SetInputs(v []*v1.CheckInput)
func (*DecisionLogEntry_CheckResources) SetOutputs ¶
func (x *DecisionLogEntry_CheckResources) SetOutputs(v []*v1.CheckOutput)
func (*DecisionLogEntry_CheckResources) String ¶
func (x *DecisionLogEntry_CheckResources) String() string
type DecisionLogEntry_CheckResources_ ¶
type DecisionLogEntry_CheckResources_ struct {
CheckResources *DecisionLogEntry_CheckResources `protobuf:"bytes,7,opt,name=check_resources,json=checkResources,proto3,oneof"`
}
type DecisionLogEntry_CheckResources_builder ¶
type DecisionLogEntry_CheckResources_builder struct {
Inputs []*v1.CheckInput
Outputs []*v1.CheckOutput
Error string
// contains filtered or unexported fields
}
func (DecisionLogEntry_CheckResources_builder) Build ¶
func (b0 DecisionLogEntry_CheckResources_builder) Build() *DecisionLogEntry_CheckResources
type DecisionLogEntry_PlanResources ¶
type DecisionLogEntry_PlanResources struct {
Input *v1.PlanResourcesInput `protobuf:"bytes,1,opt,name=input,proto3" json:"input,omitempty"`
Output *v1.PlanResourcesOutput `protobuf:"bytes,2,opt,name=output,proto3" json:"output,omitempty"`
Error string `protobuf:"bytes,3,opt,name=error,proto3" json:"error,omitempty"`
// contains filtered or unexported fields
}
func (*DecisionLogEntry_PlanResources) ClearInput ¶
func (x *DecisionLogEntry_PlanResources) ClearInput()
func (*DecisionLogEntry_PlanResources) ClearOutput ¶
func (x *DecisionLogEntry_PlanResources) ClearOutput()
func (*DecisionLogEntry_PlanResources) GetError ¶
func (x *DecisionLogEntry_PlanResources) GetError() string
func (*DecisionLogEntry_PlanResources) GetInput ¶
func (x *DecisionLogEntry_PlanResources) GetInput() *v1.PlanResourcesInput
func (*DecisionLogEntry_PlanResources) GetOutput ¶
func (x *DecisionLogEntry_PlanResources) GetOutput() *v1.PlanResourcesOutput
func (*DecisionLogEntry_PlanResources) HasInput ¶
func (x *DecisionLogEntry_PlanResources) HasInput() bool
func (*DecisionLogEntry_PlanResources) HasOutput ¶
func (x *DecisionLogEntry_PlanResources) HasOutput() bool
func (*DecisionLogEntry_PlanResources) ProtoMessage ¶
func (*DecisionLogEntry_PlanResources) ProtoMessage()
func (*DecisionLogEntry_PlanResources) ProtoReflect ¶
func (x *DecisionLogEntry_PlanResources) ProtoReflect() protoreflect.Message
func (*DecisionLogEntry_PlanResources) Reset ¶
func (x *DecisionLogEntry_PlanResources) Reset()
func (*DecisionLogEntry_PlanResources) SetError ¶
func (x *DecisionLogEntry_PlanResources) SetError(v string)
func (*DecisionLogEntry_PlanResources) SetInput ¶
func (x *DecisionLogEntry_PlanResources) SetInput(v *v1.PlanResourcesInput)
func (*DecisionLogEntry_PlanResources) SetOutput ¶
func (x *DecisionLogEntry_PlanResources) SetOutput(v *v1.PlanResourcesOutput)
func (*DecisionLogEntry_PlanResources) String ¶
func (x *DecisionLogEntry_PlanResources) String() string
type DecisionLogEntry_PlanResources_ ¶
type DecisionLogEntry_PlanResources_ struct {
PlanResources *DecisionLogEntry_PlanResources `protobuf:"bytes,8,opt,name=plan_resources,json=planResources,proto3,oneof"`
}
type DecisionLogEntry_PlanResources_builder ¶
type DecisionLogEntry_PlanResources_builder struct {
Input *v1.PlanResourcesInput
Output *v1.PlanResourcesOutput
Error string
// contains filtered or unexported fields
}
func (DecisionLogEntry_PlanResources_builder) Build ¶
func (b0 DecisionLogEntry_PlanResources_builder) Build() *DecisionLogEntry_PlanResources
type DecisionLogEntry_builder ¶
type DecisionLogEntry_builder struct {
CallId string
Timestamp *timestamppb.Timestamp
Peer *Peer
// Deprecated. Use method.check_resources.inputs instead.
//
// Deprecated: Marked as deprecated in cerbos/audit/v1/audit.proto.
Inputs []*v1.CheckInput
// Deprecated. Use method.check_resources.outputs instead.
//
// Deprecated: Marked as deprecated in cerbos/audit/v1/audit.proto.
Outputs []*v1.CheckOutput
// Deprecated. Use method.check_resources.error instead.
//
// Deprecated: Marked as deprecated in cerbos/audit/v1/audit.proto.
Error string
// Fields of oneof Method:
CheckResources *DecisionLogEntry_CheckResources
PlanResources *DecisionLogEntry_PlanResources
// -- end of Method
Metadata map[string]*MetaValues
AuditTrail *AuditTrail
Oversized bool
PolicySource *PolicySource
RequestContext *RequestContext
// contains filtered or unexported fields
}
func (DecisionLogEntry_builder) Build ¶
func (b0 DecisionLogEntry_builder) Build() *DecisionLogEntry
type MetaValues ¶
type MetaValues struct {
Values []string `protobuf:"bytes,1,rep,name=values,proto3" json:"values,omitempty"`
// contains filtered or unexported fields
}
func (*MetaValues) GetValues ¶
func (x *MetaValues) GetValues() []string
func (*MetaValues) ProtoMessage ¶
func (*MetaValues) ProtoMessage()
func (*MetaValues) ProtoReflect ¶
func (x *MetaValues) ProtoReflect() protoreflect.Message
func (*MetaValues) Reset ¶
func (x *MetaValues) Reset()
func (*MetaValues) SetValues ¶
func (x *MetaValues) SetValues(v []string)
func (*MetaValues) String ¶
func (x *MetaValues) String() string
type MetaValues_builder ¶
type MetaValues_builder struct {
Values []string
// contains filtered or unexported fields
}
func (MetaValues_builder) Build ¶
func (b0 MetaValues_builder) Build() *MetaValues
type Peer ¶
type Peer struct {
Address string `protobuf:"bytes,1,opt,name=address,proto3" json:"address,omitempty"`
AuthInfo string `protobuf:"bytes,2,opt,name=auth_info,json=authInfo,proto3" json:"auth_info,omitempty"`
UserAgent string `protobuf:"bytes,3,opt,name=user_agent,json=userAgent,proto3" json:"user_agent,omitempty"`
ForwardedFor string `protobuf:"bytes,4,opt,name=forwarded_for,json=forwardedFor,proto3" json:"forwarded_for,omitempty"`
// contains filtered or unexported fields
}
func (*Peer) ProtoReflect ¶
func (x *Peer) ProtoReflect() protoreflect.Message
type Peer_builder ¶
type Peer_builder struct {
Address string
AuthInfo string
UserAgent string
ForwardedFor string
// contains filtered or unexported fields
}
func (Peer_builder) Build ¶
func (b0 Peer_builder) Build() *Peer
type PolicySource ¶
type PolicySource struct {
// Types that are valid to be assigned to Source:
//
// *PolicySource_Blob_
// *PolicySource_Database_
// *PolicySource_Disk_
// *PolicySource_Git_
// *PolicySource_Hub_
// *PolicySource_EmbeddedPdp
Source isPolicySource_Source `protobuf_oneof:"source"`
// contains filtered or unexported fields
}
func (*PolicySource) ClearBlob ¶
func (x *PolicySource) ClearBlob()
func (*PolicySource) ClearDatabase ¶
func (x *PolicySource) ClearDatabase()
func (*PolicySource) ClearDisk ¶
func (x *PolicySource) ClearDisk()
func (*PolicySource) ClearEmbeddedPdp ¶
func (x *PolicySource) ClearEmbeddedPdp()
func (*PolicySource) ClearGit ¶
func (x *PolicySource) ClearGit()
func (*PolicySource) ClearHub ¶
func (x *PolicySource) ClearHub()
func (*PolicySource) ClearSource ¶
func (x *PolicySource) ClearSource()
func (*PolicySource) GetBlob ¶
func (x *PolicySource) GetBlob() *PolicySource_Blob
func (*PolicySource) GetDatabase ¶
func (x *PolicySource) GetDatabase() *PolicySource_Database
func (*PolicySource) GetDisk ¶
func (x *PolicySource) GetDisk() *PolicySource_Disk
func (*PolicySource) GetEmbeddedPdp ¶
func (x *PolicySource) GetEmbeddedPdp() *PolicySource_EmbeddedPDP
func (*PolicySource) GetGit ¶
func (x *PolicySource) GetGit() *PolicySource_Git
func (*PolicySource) GetHub ¶
func (x *PolicySource) GetHub() *PolicySource_Hub
func (*PolicySource) GetSource ¶
func (x *PolicySource) GetSource() isPolicySource_Source
func (*PolicySource) HasBlob ¶
func (x *PolicySource) HasBlob() bool
func (*PolicySource) HasDatabase ¶
func (x *PolicySource) HasDatabase() bool
func (*PolicySource) HasDisk ¶
func (x *PolicySource) HasDisk() bool
func (*PolicySource) HasEmbeddedPdp ¶
func (x *PolicySource) HasEmbeddedPdp() bool
func (*PolicySource) HasGit ¶
func (x *PolicySource) HasGit() bool
func (*PolicySource) HasHub ¶
func (x *PolicySource) HasHub() bool
func (*PolicySource) HasSource ¶
func (x *PolicySource) HasSource() bool
func (*PolicySource) ProtoMessage ¶
func (*PolicySource) ProtoMessage()
func (*PolicySource) ProtoReflect ¶
func (x *PolicySource) ProtoReflect() protoreflect.Message
func (*PolicySource) Reset ¶
func (x *PolicySource) Reset()
func (*PolicySource) SetBlob ¶
func (x *PolicySource) SetBlob(v *PolicySource_Blob)
func (*PolicySource) SetDatabase ¶
func (x *PolicySource) SetDatabase(v *PolicySource_Database)
func (*PolicySource) SetDisk ¶
func (x *PolicySource) SetDisk(v *PolicySource_Disk)
func (*PolicySource) SetEmbeddedPdp ¶
func (x *PolicySource) SetEmbeddedPdp(v *PolicySource_EmbeddedPDP)
func (*PolicySource) SetGit ¶
func (x *PolicySource) SetGit(v *PolicySource_Git)
func (*PolicySource) SetHub ¶
func (x *PolicySource) SetHub(v *PolicySource_Hub)
func (*PolicySource) String ¶
func (x *PolicySource) String() string
func (*PolicySource) WhichSource ¶
func (x *PolicySource) WhichSource() case_PolicySource_Source
type PolicySource_Blob ¶
type PolicySource_Blob struct {
BucketUrl string `protobuf:"bytes,1,opt,name=bucket_url,json=bucketUrl,proto3" json:"bucket_url,omitempty"`
Prefix string `protobuf:"bytes,2,opt,name=prefix,proto3" json:"prefix,omitempty"`
// contains filtered or unexported fields
}
func (*PolicySource_Blob) GetBucketUrl ¶
func (x *PolicySource_Blob) GetBucketUrl() string
func (*PolicySource_Blob) GetPrefix ¶
func (x *PolicySource_Blob) GetPrefix() string
func (*PolicySource_Blob) ProtoMessage ¶
func (*PolicySource_Blob) ProtoMessage()
func (*PolicySource_Blob) ProtoReflect ¶
func (x *PolicySource_Blob) ProtoReflect() protoreflect.Message
func (*PolicySource_Blob) Reset ¶
func (x *PolicySource_Blob) Reset()
func (*PolicySource_Blob) SetBucketUrl ¶
func (x *PolicySource_Blob) SetBucketUrl(v string)
func (*PolicySource_Blob) SetPrefix ¶
func (x *PolicySource_Blob) SetPrefix(v string)
func (*PolicySource_Blob) String ¶
func (x *PolicySource_Blob) String() string
type PolicySource_Blob_ ¶
type PolicySource_Blob_ struct {
Blob *PolicySource_Blob `protobuf:"bytes,1,opt,name=blob,proto3,oneof"`
}
type PolicySource_Blob_builder ¶
type PolicySource_Blob_builder struct {
BucketUrl string
Prefix string
// contains filtered or unexported fields
}
func (PolicySource_Blob_builder) Build ¶
func (b0 PolicySource_Blob_builder) Build() *PolicySource_Blob
type PolicySource_Database ¶
type PolicySource_Database struct {
Driver PolicySource_Database_Driver `protobuf:"varint,1,opt,name=driver,proto3,enum=cerbos.audit.v1.PolicySource_Database_Driver" json:"driver,omitempty"`
// contains filtered or unexported fields
}
func (*PolicySource_Database) GetDriver ¶
func (x *PolicySource_Database) GetDriver() PolicySource_Database_Driver
func (*PolicySource_Database) ProtoMessage ¶
func (*PolicySource_Database) ProtoMessage()
func (*PolicySource_Database) ProtoReflect ¶
func (x *PolicySource_Database) ProtoReflect() protoreflect.Message
func (*PolicySource_Database) Reset ¶
func (x *PolicySource_Database) Reset()
func (*PolicySource_Database) SetDriver ¶
func (x *PolicySource_Database) SetDriver(v PolicySource_Database_Driver)
func (*PolicySource_Database) String ¶
func (x *PolicySource_Database) String() string
type PolicySource_Database_ ¶
type PolicySource_Database_ struct {
Database *PolicySource_Database `protobuf:"bytes,2,opt,name=database,proto3,oneof"`
}
type PolicySource_Database_Driver ¶
type PolicySource_Database_Driver int32
const ( PolicySource_Database_DRIVER_UNSPECIFIED PolicySource_Database_Driver = 0 PolicySource_Database_DRIVER_MYSQL PolicySource_Database_Driver = 1 PolicySource_Database_DRIVER_POSTGRES PolicySource_Database_Driver = 2 PolicySource_Database_DRIVER_SQLITE3 PolicySource_Database_Driver = 3 )
func (PolicySource_Database_Driver) Descriptor ¶
func (PolicySource_Database_Driver) Descriptor() protoreflect.EnumDescriptor
func (PolicySource_Database_Driver) Enum ¶
func (x PolicySource_Database_Driver) Enum() *PolicySource_Database_Driver
func (PolicySource_Database_Driver) Number ¶
func (x PolicySource_Database_Driver) Number() protoreflect.EnumNumber
func (PolicySource_Database_Driver) String ¶
func (x PolicySource_Database_Driver) String() string
func (PolicySource_Database_Driver) Type ¶
func (PolicySource_Database_Driver) Type() protoreflect.EnumType
type PolicySource_Database_builder ¶
type PolicySource_Database_builder struct {
Driver PolicySource_Database_Driver
// contains filtered or unexported fields
}
func (PolicySource_Database_builder) Build ¶
func (b0 PolicySource_Database_builder) Build() *PolicySource_Database
type PolicySource_Disk ¶
type PolicySource_Disk struct {
Directory string `protobuf:"bytes,1,opt,name=directory,proto3" json:"directory,omitempty"`
// contains filtered or unexported fields
}
func (*PolicySource_Disk) GetDirectory ¶
func (x *PolicySource_Disk) GetDirectory() string
func (*PolicySource_Disk) ProtoMessage ¶
func (*PolicySource_Disk) ProtoMessage()
func (*PolicySource_Disk) ProtoReflect ¶
func (x *PolicySource_Disk) ProtoReflect() protoreflect.Message
func (*PolicySource_Disk) Reset ¶
func (x *PolicySource_Disk) Reset()
func (*PolicySource_Disk) SetDirectory ¶
func (x *PolicySource_Disk) SetDirectory(v string)
func (*PolicySource_Disk) String ¶
func (x *PolicySource_Disk) String() string
type PolicySource_Disk_ ¶
type PolicySource_Disk_ struct {
Disk *PolicySource_Disk `protobuf:"bytes,3,opt,name=disk,proto3,oneof"`
}
type PolicySource_Disk_builder ¶
type PolicySource_Disk_builder struct {
Directory string
// contains filtered or unexported fields
}
func (PolicySource_Disk_builder) Build ¶
func (b0 PolicySource_Disk_builder) Build() *PolicySource_Disk
type PolicySource_EmbeddedPDP ¶
type PolicySource_EmbeddedPDP struct {
Url string `protobuf:"bytes,1,opt,name=url,proto3" json:"url,omitempty"`
CommitHash string `protobuf:"bytes,2,opt,name=commit_hash,json=commitHash,proto3" json:"commit_hash,omitempty"`
BuiltAt *timestamppb.Timestamp `protobuf:"bytes,3,opt,name=built_at,json=builtAt,proto3" json:"built_at,omitempty"`
// contains filtered or unexported fields
}
func (*PolicySource_EmbeddedPDP) ClearBuiltAt ¶
func (x *PolicySource_EmbeddedPDP) ClearBuiltAt()
func (*PolicySource_EmbeddedPDP) GetBuiltAt ¶
func (x *PolicySource_EmbeddedPDP) GetBuiltAt() *timestamppb.Timestamp
func (*PolicySource_EmbeddedPDP) GetCommitHash ¶
func (x *PolicySource_EmbeddedPDP) GetCommitHash() string
func (*PolicySource_EmbeddedPDP) GetUrl ¶
func (x *PolicySource_EmbeddedPDP) GetUrl() string
func (*PolicySource_EmbeddedPDP) HasBuiltAt ¶
func (x *PolicySource_EmbeddedPDP) HasBuiltAt() bool
func (*PolicySource_EmbeddedPDP) ProtoMessage ¶
func (*PolicySource_EmbeddedPDP) ProtoMessage()
func (*PolicySource_EmbeddedPDP) ProtoReflect ¶
func (x *PolicySource_EmbeddedPDP) ProtoReflect() protoreflect.Message
func (*PolicySource_EmbeddedPDP) Reset ¶
func (x *PolicySource_EmbeddedPDP) Reset()
func (*PolicySource_EmbeddedPDP) SetBuiltAt ¶
func (x *PolicySource_EmbeddedPDP) SetBuiltAt(v *timestamppb.Timestamp)
func (*PolicySource_EmbeddedPDP) SetCommitHash ¶
func (x *PolicySource_EmbeddedPDP) SetCommitHash(v string)
func (*PolicySource_EmbeddedPDP) SetUrl ¶
func (x *PolicySource_EmbeddedPDP) SetUrl(v string)
func (*PolicySource_EmbeddedPDP) String ¶
func (x *PolicySource_EmbeddedPDP) String() string
type PolicySource_EmbeddedPDP_builder ¶
type PolicySource_EmbeddedPDP_builder struct {
Url string
CommitHash string
BuiltAt *timestamppb.Timestamp
// contains filtered or unexported fields
}
func (PolicySource_EmbeddedPDP_builder) Build ¶
func (b0 PolicySource_EmbeddedPDP_builder) Build() *PolicySource_EmbeddedPDP
type PolicySource_EmbeddedPdp ¶
type PolicySource_EmbeddedPdp struct {
EmbeddedPdp *PolicySource_EmbeddedPDP `protobuf:"bytes,6,opt,name=embedded_pdp,json=embeddedPdp,proto3,oneof"`
}
type PolicySource_Git ¶
type PolicySource_Git struct {
RepositoryUrl string `protobuf:"bytes,1,opt,name=repository_url,json=repositoryUrl,proto3" json:"repository_url,omitempty"`
Branch string `protobuf:"bytes,2,opt,name=branch,proto3" json:"branch,omitempty"`
Subdirectory string `protobuf:"bytes,3,opt,name=subdirectory,proto3" json:"subdirectory,omitempty"`
// contains filtered or unexported fields
}
func (*PolicySource_Git) GetBranch ¶
func (x *PolicySource_Git) GetBranch() string
func (*PolicySource_Git) GetRepositoryUrl ¶
func (x *PolicySource_Git) GetRepositoryUrl() string
func (*PolicySource_Git) GetSubdirectory ¶
func (x *PolicySource_Git) GetSubdirectory() string
func (*PolicySource_Git) ProtoMessage ¶
func (*PolicySource_Git) ProtoMessage()
func (*PolicySource_Git) ProtoReflect ¶
func (x *PolicySource_Git) ProtoReflect() protoreflect.Message
func (*PolicySource_Git) Reset ¶
func (x *PolicySource_Git) Reset()
func (*PolicySource_Git) SetBranch ¶
func (x *PolicySource_Git) SetBranch(v string)
func (*PolicySource_Git) SetRepositoryUrl ¶
func (x *PolicySource_Git) SetRepositoryUrl(v string)
func (*PolicySource_Git) SetSubdirectory ¶
func (x *PolicySource_Git) SetSubdirectory(v string)
func (*PolicySource_Git) String ¶
func (x *PolicySource_Git) String() string
type PolicySource_Git_ ¶
type PolicySource_Git_ struct {
Git *PolicySource_Git `protobuf:"bytes,4,opt,name=git,proto3,oneof"`
}
type PolicySource_Git_builder ¶
type PolicySource_Git_builder struct {
RepositoryUrl string
Branch string
Subdirectory string
// contains filtered or unexported fields
}
func (PolicySource_Git_builder) Build ¶
func (b0 PolicySource_Git_builder) Build() *PolicySource_Git
type PolicySource_Hub ¶
type PolicySource_Hub struct {
// Types that are valid to be assigned to Source:
//
// *PolicySource_Hub_Label
// *PolicySource_Hub_DeploymentId
// *PolicySource_Hub_PlaygroundId
// *PolicySource_Hub_LocalBundle_
// *PolicySource_Hub_EmbeddedBundle_
Source isPolicySource_Hub_Source `protobuf_oneof:"source"`
// contains filtered or unexported fields
}
func (*PolicySource_Hub) ClearDeploymentId ¶
func (x *PolicySource_Hub) ClearDeploymentId()
func (*PolicySource_Hub) ClearEmbeddedBundle ¶
func (x *PolicySource_Hub) ClearEmbeddedBundle()
func (*PolicySource_Hub) ClearLabel ¶
func (x *PolicySource_Hub) ClearLabel()
func (*PolicySource_Hub) ClearLocalBundle ¶
func (x *PolicySource_Hub) ClearLocalBundle()
func (*PolicySource_Hub) ClearPlaygroundId ¶
func (x *PolicySource_Hub) ClearPlaygroundId()
func (*PolicySource_Hub) ClearSource ¶
func (x *PolicySource_Hub) ClearSource()
func (*PolicySource_Hub) GetDeploymentId ¶
func (x *PolicySource_Hub) GetDeploymentId() string
func (*PolicySource_Hub) GetEmbeddedBundle ¶
func (x *PolicySource_Hub) GetEmbeddedBundle() *PolicySource_Hub_EmbeddedBundle
func (*PolicySource_Hub) GetLabel ¶
func (x *PolicySource_Hub) GetLabel() string
func (*PolicySource_Hub) GetLocalBundle ¶
func (x *PolicySource_Hub) GetLocalBundle() *PolicySource_Hub_LocalBundle
func (*PolicySource_Hub) GetPlaygroundId ¶
func (x *PolicySource_Hub) GetPlaygroundId() string
func (*PolicySource_Hub) GetSource ¶
func (x *PolicySource_Hub) GetSource() isPolicySource_Hub_Source
func (*PolicySource_Hub) HasDeploymentId ¶
func (x *PolicySource_Hub) HasDeploymentId() bool
func (*PolicySource_Hub) HasEmbeddedBundle ¶
func (x *PolicySource_Hub) HasEmbeddedBundle() bool
func (*PolicySource_Hub) HasLabel ¶
func (x *PolicySource_Hub) HasLabel() bool
func (*PolicySource_Hub) HasLocalBundle ¶
func (x *PolicySource_Hub) HasLocalBundle() bool
func (*PolicySource_Hub) HasPlaygroundId ¶
func (x *PolicySource_Hub) HasPlaygroundId() bool
func (*PolicySource_Hub) HasSource ¶
func (x *PolicySource_Hub) HasSource() bool
func (*PolicySource_Hub) ProtoMessage ¶
func (*PolicySource_Hub) ProtoMessage()
func (*PolicySource_Hub) ProtoReflect ¶
func (x *PolicySource_Hub) ProtoReflect() protoreflect.Message
func (*PolicySource_Hub) Reset ¶
func (x *PolicySource_Hub) Reset()
func (*PolicySource_Hub) SetDeploymentId ¶
func (x *PolicySource_Hub) SetDeploymentId(v string)
func (*PolicySource_Hub) SetEmbeddedBundle ¶
func (x *PolicySource_Hub) SetEmbeddedBundle(v *PolicySource_Hub_EmbeddedBundle)
func (*PolicySource_Hub) SetLabel ¶
func (x *PolicySource_Hub) SetLabel(v string)
func (*PolicySource_Hub) SetLocalBundle ¶
func (x *PolicySource_Hub) SetLocalBundle(v *PolicySource_Hub_LocalBundle)
func (*PolicySource_Hub) SetPlaygroundId ¶
func (x *PolicySource_Hub) SetPlaygroundId(v string)
func (*PolicySource_Hub) String ¶
func (x *PolicySource_Hub) String() string
func (*PolicySource_Hub) WhichSource ¶
func (x *PolicySource_Hub) WhichSource() case_PolicySource_Hub_Source
type PolicySource_Hub_ ¶
type PolicySource_Hub_ struct {
Hub *PolicySource_Hub `protobuf:"bytes,5,opt,name=hub,proto3,oneof"`
}
type PolicySource_Hub_DeploymentId ¶
type PolicySource_Hub_DeploymentId struct {
DeploymentId string `protobuf:"bytes,2,opt,name=deployment_id,json=deploymentId,proto3,oneof"`
}
type PolicySource_Hub_EmbeddedBundle ¶
type PolicySource_Hub_EmbeddedBundle struct {
RuleId string `protobuf:"bytes,1,opt,name=rule_id,json=ruleId,proto3" json:"rule_id,omitempty"`
Scopes []string `protobuf:"bytes,2,rep,name=scopes,proto3" json:"scopes,omitempty"`
// contains filtered or unexported fields
}
func (*PolicySource_Hub_EmbeddedBundle) GetRuleId ¶
func (x *PolicySource_Hub_EmbeddedBundle) GetRuleId() string
func (*PolicySource_Hub_EmbeddedBundle) GetScopes ¶
func (x *PolicySource_Hub_EmbeddedBundle) GetScopes() []string
func (*PolicySource_Hub_EmbeddedBundle) ProtoMessage ¶
func (*PolicySource_Hub_EmbeddedBundle) ProtoMessage()
func (*PolicySource_Hub_EmbeddedBundle) ProtoReflect ¶
func (x *PolicySource_Hub_EmbeddedBundle) ProtoReflect() protoreflect.Message
func (*PolicySource_Hub_EmbeddedBundle) Reset ¶
func (x *PolicySource_Hub_EmbeddedBundle) Reset()
func (*PolicySource_Hub_EmbeddedBundle) SetRuleId ¶
func (x *PolicySource_Hub_EmbeddedBundle) SetRuleId(v string)
func (*PolicySource_Hub_EmbeddedBundle) SetScopes ¶
func (x *PolicySource_Hub_EmbeddedBundle) SetScopes(v []string)
func (*PolicySource_Hub_EmbeddedBundle) String ¶
func (x *PolicySource_Hub_EmbeddedBundle) String() string
type PolicySource_Hub_EmbeddedBundle_ ¶
type PolicySource_Hub_EmbeddedBundle_ struct {
EmbeddedBundle *PolicySource_Hub_EmbeddedBundle `protobuf:"bytes,5,opt,name=embedded_bundle,json=embeddedBundle,proto3,oneof"`
}
type PolicySource_Hub_EmbeddedBundle_builder ¶
type PolicySource_Hub_EmbeddedBundle_builder struct {
RuleId string
Scopes []string
// contains filtered or unexported fields
}
func (PolicySource_Hub_EmbeddedBundle_builder) Build ¶
func (b0 PolicySource_Hub_EmbeddedBundle_builder) Build() *PolicySource_Hub_EmbeddedBundle
type PolicySource_Hub_Label ¶
type PolicySource_Hub_Label struct {
Label string `protobuf:"bytes,1,opt,name=label,proto3,oneof"`
}
type PolicySource_Hub_LocalBundle ¶
type PolicySource_Hub_LocalBundle struct {
Path string `protobuf:"bytes,1,opt,name=path,proto3" json:"path,omitempty"`
// contains filtered or unexported fields
}
func (*PolicySource_Hub_LocalBundle) GetPath ¶
func (x *PolicySource_Hub_LocalBundle) GetPath() string
func (*PolicySource_Hub_LocalBundle) ProtoMessage ¶
func (*PolicySource_Hub_LocalBundle) ProtoMessage()
func (*PolicySource_Hub_LocalBundle) ProtoReflect ¶
func (x *PolicySource_Hub_LocalBundle) ProtoReflect() protoreflect.Message
func (*PolicySource_Hub_LocalBundle) Reset ¶
func (x *PolicySource_Hub_LocalBundle) Reset()
func (*PolicySource_Hub_LocalBundle) SetPath ¶
func (x *PolicySource_Hub_LocalBundle) SetPath(v string)
func (*PolicySource_Hub_LocalBundle) String ¶
func (x *PolicySource_Hub_LocalBundle) String() string
type PolicySource_Hub_LocalBundle_ ¶
type PolicySource_Hub_LocalBundle_ struct {
LocalBundle *PolicySource_Hub_LocalBundle `protobuf:"bytes,4,opt,name=local_bundle,json=localBundle,proto3,oneof"`
}
type PolicySource_Hub_LocalBundle_builder ¶
type PolicySource_Hub_LocalBundle_builder struct {
Path string
// contains filtered or unexported fields
}
func (PolicySource_Hub_LocalBundle_builder) Build ¶
func (b0 PolicySource_Hub_LocalBundle_builder) Build() *PolicySource_Hub_LocalBundle
type PolicySource_Hub_PlaygroundId ¶
type PolicySource_Hub_PlaygroundId struct {
PlaygroundId string `protobuf:"bytes,3,opt,name=playground_id,json=playgroundId,proto3,oneof"`
}
type PolicySource_Hub_builder ¶
type PolicySource_Hub_builder struct {
// Fields of oneof Source:
Label *string
DeploymentId *string
PlaygroundId *string
LocalBundle *PolicySource_Hub_LocalBundle
EmbeddedBundle *PolicySource_Hub_EmbeddedBundle
// contains filtered or unexported fields
}
func (PolicySource_Hub_builder) Build ¶
func (b0 PolicySource_Hub_builder) Build() *PolicySource_Hub
type PolicySource_builder ¶
type PolicySource_builder struct {
// Fields of oneof Source:
Blob *PolicySource_Blob
Database *PolicySource_Database
Disk *PolicySource_Disk
Git *PolicySource_Git
Hub *PolicySource_Hub
EmbeddedPdp *PolicySource_EmbeddedPDP
// contains filtered or unexported fields
}
func (PolicySource_builder) Build ¶
func (b0 PolicySource_builder) Build() *PolicySource
type RequestContext ¶
type RequestContext struct {
Annotations map[string]*structpb.Value `` /* 149-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*RequestContext) GetAnnotations ¶
func (x *RequestContext) GetAnnotations() map[string]*structpb.Value
func (*RequestContext) ProtoMessage ¶
func (*RequestContext) ProtoMessage()
func (*RequestContext) ProtoReflect ¶
func (x *RequestContext) ProtoReflect() protoreflect.Message
func (*RequestContext) Reset ¶
func (x *RequestContext) Reset()
func (*RequestContext) SetAnnotations ¶
func (x *RequestContext) SetAnnotations(v map[string]*structpb.Value)
func (*RequestContext) String ¶
func (x *RequestContext) String() string
type RequestContext_builder ¶
type RequestContext_builder struct {
Annotations map[string]*structpb.Value
// contains filtered or unexported fields
}
func (RequestContext_builder) Build ¶
func (b0 RequestContext_builder) Build() *RequestContext
Source Files
¶
- audit.pb.go
Click to show internal directories.
Click to hide internal directories.