Documentation
¶
Index ¶
- Constants
- func NewSchedulerServiceHandler(svc SchedulerServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
- type SchedulerServiceClient
- type SchedulerServiceHandler
- type UnimplementedSchedulerServiceHandler
- func (UnimplementedSchedulerServiceHandler) CancelJob(context.Context, *connect.Request[v1alpha1.CancelJobRequest]) (*connect.Response[v1alpha1.CancelJobResponse], error)
- func (UnimplementedSchedulerServiceHandler) CreateContinuousJob(context.Context, *connect.Request[v1alpha1.CreateContinuousJobRequest]) (*connect.Response[v1alpha1.CreateContinuousJobResponse], error)
- func (UnimplementedSchedulerServiceHandler) CreateOneShotJob(context.Context, *connect.Request[v1alpha1.CreateOneShotJobRequest]) (*connect.Response[v1alpha1.CreateOneShotJobResponse], error)
- func (UnimplementedSchedulerServiceHandler) CreateQueuedJob(context.Context, *connect.Request[v1alpha1.CreateQueuedJobRequest]) (*connect.Response[v1alpha1.CreateQueuedJobResponse], error)
- func (UnimplementedSchedulerServiceHandler) CreateRecurringJob(context.Context, *connect.Request[v1alpha1.CreateRecurringJobRequest]) (*connect.Response[v1alpha1.CreateRecurringJobResponse], error)
- func (UnimplementedSchedulerServiceHandler) DeleteJob(context.Context, *connect.Request[v1alpha1.DeleteJobRequest]) (*connect.Response[v1alpha1.DeleteJobResponse], error)
- func (UnimplementedSchedulerServiceHandler) GetJob(context.Context, *connect.Request[v1alpha1.GetJobRequest]) (*connect.Response[v1alpha1.GetJobResponse], error)
- func (UnimplementedSchedulerServiceHandler) ListJobHistory(context.Context, *connect.Request[v1alpha1.ListJobHistoryRequest]) (*connect.Response[v1alpha1.ListJobHistoryResponse], error)
- func (UnimplementedSchedulerServiceHandler) ListJobs(context.Context, *connect.Request[v1alpha1.ListJobsRequest]) (*connect.Response[v1alpha1.ListJobsResponse], error)
- func (UnimplementedSchedulerServiceHandler) ListWorkers(context.Context, *connect.Request[v1alpha1.ListWorkersRequest]) (*connect.Response[v1alpha1.ListWorkersResponse], error)
Constants ¶
const ( // SchedulerServiceCancelJobProcedure is the fully-qualified name of the SchedulerService's // CancelJob RPC. SchedulerServiceCancelJobProcedure = "/dendra.job.scheduler.v1alpha1.SchedulerService/CancelJob" // SchedulerServiceCreateContinuousJobProcedure is the fully-qualified name of the // SchedulerService's CreateContinuousJob RPC. SchedulerServiceCreateContinuousJobProcedure = "/dendra.job.scheduler.v1alpha1.SchedulerService/CreateContinuousJob" // SchedulerServiceCreateOneShotJobProcedure is the fully-qualified name of the SchedulerService's // CreateOneShotJob RPC. SchedulerServiceCreateOneShotJobProcedure = "/dendra.job.scheduler.v1alpha1.SchedulerService/CreateOneShotJob" // SchedulerServiceCreateQueuedJobProcedure is the fully-qualified name of the SchedulerService's // CreateQueuedJob RPC. SchedulerServiceCreateQueuedJobProcedure = "/dendra.job.scheduler.v1alpha1.SchedulerService/CreateQueuedJob" // SchedulerServiceCreateRecurringJobProcedure is the fully-qualified name of the SchedulerService's // CreateRecurringJob RPC. SchedulerServiceCreateRecurringJobProcedure = "/dendra.job.scheduler.v1alpha1.SchedulerService/CreateRecurringJob" // SchedulerServiceDeleteJobProcedure is the fully-qualified name of the SchedulerService's // DeleteJob RPC. SchedulerServiceDeleteJobProcedure = "/dendra.job.scheduler.v1alpha1.SchedulerService/DeleteJob" // SchedulerServiceGetJobProcedure is the fully-qualified name of the SchedulerService's GetJob RPC. SchedulerServiceGetJobProcedure = "/dendra.job.scheduler.v1alpha1.SchedulerService/GetJob" // SchedulerServiceListJobsProcedure is the fully-qualified name of the SchedulerService's ListJobs // RPC. SchedulerServiceListJobsProcedure = "/dendra.job.scheduler.v1alpha1.SchedulerService/ListJobs" // SchedulerServiceListJobHistoryProcedure is the fully-qualified name of the SchedulerService's // ListJobHistory RPC. SchedulerServiceListJobHistoryProcedure = "/dendra.job.scheduler.v1alpha1.SchedulerService/ListJobHistory" // SchedulerServiceListWorkersProcedure is the fully-qualified name of the SchedulerService's // ListWorkers RPC. SchedulerServiceListWorkersProcedure = "/dendra.job.scheduler.v1alpha1.SchedulerService/ListWorkers" )
These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.
Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.
const (
// SchedulerServiceName is the fully-qualified name of the SchedulerService service.
SchedulerServiceName = "dendra.job.scheduler.v1alpha1.SchedulerService"
)
Variables ¶
This section is empty.
Functions ¶
func NewSchedulerServiceHandler ¶
func NewSchedulerServiceHandler(svc SchedulerServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
NewSchedulerServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.
By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.
Types ¶
type SchedulerServiceClient ¶
type SchedulerServiceClient interface {
CancelJob(context.Context, *connect.Request[v1alpha1.CancelJobRequest]) (*connect.Response[v1alpha1.CancelJobResponse], error)
CreateContinuousJob(context.Context, *connect.Request[v1alpha1.CreateContinuousJobRequest]) (*connect.Response[v1alpha1.CreateContinuousJobResponse], error)
CreateOneShotJob(context.Context, *connect.Request[v1alpha1.CreateOneShotJobRequest]) (*connect.Response[v1alpha1.CreateOneShotJobResponse], error)
CreateQueuedJob(context.Context, *connect.Request[v1alpha1.CreateQueuedJobRequest]) (*connect.Response[v1alpha1.CreateQueuedJobResponse], error)
CreateRecurringJob(context.Context, *connect.Request[v1alpha1.CreateRecurringJobRequest]) (*connect.Response[v1alpha1.CreateRecurringJobResponse], error)
DeleteJob(context.Context, *connect.Request[v1alpha1.DeleteJobRequest]) (*connect.Response[v1alpha1.DeleteJobResponse], error)
GetJob(context.Context, *connect.Request[v1alpha1.GetJobRequest]) (*connect.Response[v1alpha1.GetJobResponse], error)
ListJobs(context.Context, *connect.Request[v1alpha1.ListJobsRequest]) (*connect.Response[v1alpha1.ListJobsResponse], error)
ListJobHistory(context.Context, *connect.Request[v1alpha1.ListJobHistoryRequest]) (*connect.Response[v1alpha1.ListJobHistoryResponse], error)
ListWorkers(context.Context, *connect.Request[v1alpha1.ListWorkersRequest]) (*connect.Response[v1alpha1.ListWorkersResponse], error)
}
SchedulerServiceClient is a client for the dendra.job.scheduler.v1alpha1.SchedulerService service.
func NewSchedulerServiceClient ¶
func NewSchedulerServiceClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) SchedulerServiceClient
NewSchedulerServiceClient constructs a client for the dendra.job.scheduler.v1alpha1.SchedulerService service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.
The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).
type SchedulerServiceHandler ¶
type SchedulerServiceHandler interface {
CancelJob(context.Context, *connect.Request[v1alpha1.CancelJobRequest]) (*connect.Response[v1alpha1.CancelJobResponse], error)
CreateContinuousJob(context.Context, *connect.Request[v1alpha1.CreateContinuousJobRequest]) (*connect.Response[v1alpha1.CreateContinuousJobResponse], error)
CreateOneShotJob(context.Context, *connect.Request[v1alpha1.CreateOneShotJobRequest]) (*connect.Response[v1alpha1.CreateOneShotJobResponse], error)
CreateQueuedJob(context.Context, *connect.Request[v1alpha1.CreateQueuedJobRequest]) (*connect.Response[v1alpha1.CreateQueuedJobResponse], error)
CreateRecurringJob(context.Context, *connect.Request[v1alpha1.CreateRecurringJobRequest]) (*connect.Response[v1alpha1.CreateRecurringJobResponse], error)
DeleteJob(context.Context, *connect.Request[v1alpha1.DeleteJobRequest]) (*connect.Response[v1alpha1.DeleteJobResponse], error)
GetJob(context.Context, *connect.Request[v1alpha1.GetJobRequest]) (*connect.Response[v1alpha1.GetJobResponse], error)
ListJobs(context.Context, *connect.Request[v1alpha1.ListJobsRequest]) (*connect.Response[v1alpha1.ListJobsResponse], error)
ListJobHistory(context.Context, *connect.Request[v1alpha1.ListJobHistoryRequest]) (*connect.Response[v1alpha1.ListJobHistoryResponse], error)
ListWorkers(context.Context, *connect.Request[v1alpha1.ListWorkersRequest]) (*connect.Response[v1alpha1.ListWorkersResponse], error)
}
SchedulerServiceHandler is an implementation of the dendra.job.scheduler.v1alpha1.SchedulerService service.
type UnimplementedSchedulerServiceHandler ¶
type UnimplementedSchedulerServiceHandler struct{}
UnimplementedSchedulerServiceHandler returns CodeUnimplemented from all methods.
func (UnimplementedSchedulerServiceHandler) CancelJob ¶
func (UnimplementedSchedulerServiceHandler) CancelJob(context.Context, *connect.Request[v1alpha1.CancelJobRequest]) (*connect.Response[v1alpha1.CancelJobResponse], error)
func (UnimplementedSchedulerServiceHandler) CreateContinuousJob ¶
func (UnimplementedSchedulerServiceHandler) CreateContinuousJob(context.Context, *connect.Request[v1alpha1.CreateContinuousJobRequest]) (*connect.Response[v1alpha1.CreateContinuousJobResponse], error)
func (UnimplementedSchedulerServiceHandler) CreateOneShotJob ¶
func (UnimplementedSchedulerServiceHandler) CreateOneShotJob(context.Context, *connect.Request[v1alpha1.CreateOneShotJobRequest]) (*connect.Response[v1alpha1.CreateOneShotJobResponse], error)
func (UnimplementedSchedulerServiceHandler) CreateQueuedJob ¶
func (UnimplementedSchedulerServiceHandler) CreateQueuedJob(context.Context, *connect.Request[v1alpha1.CreateQueuedJobRequest]) (*connect.Response[v1alpha1.CreateQueuedJobResponse], error)
func (UnimplementedSchedulerServiceHandler) CreateRecurringJob ¶
func (UnimplementedSchedulerServiceHandler) CreateRecurringJob(context.Context, *connect.Request[v1alpha1.CreateRecurringJobRequest]) (*connect.Response[v1alpha1.CreateRecurringJobResponse], error)
func (UnimplementedSchedulerServiceHandler) DeleteJob ¶
func (UnimplementedSchedulerServiceHandler) DeleteJob(context.Context, *connect.Request[v1alpha1.DeleteJobRequest]) (*connect.Response[v1alpha1.DeleteJobResponse], error)
func (UnimplementedSchedulerServiceHandler) GetJob ¶
func (UnimplementedSchedulerServiceHandler) GetJob(context.Context, *connect.Request[v1alpha1.GetJobRequest]) (*connect.Response[v1alpha1.GetJobResponse], error)
func (UnimplementedSchedulerServiceHandler) ListJobHistory ¶
func (UnimplementedSchedulerServiceHandler) ListJobHistory(context.Context, *connect.Request[v1alpha1.ListJobHistoryRequest]) (*connect.Response[v1alpha1.ListJobHistoryResponse], error)
func (UnimplementedSchedulerServiceHandler) ListJobs ¶
func (UnimplementedSchedulerServiceHandler) ListJobs(context.Context, *connect.Request[v1alpha1.ListJobsRequest]) (*connect.Response[v1alpha1.ListJobsResponse], error)
func (UnimplementedSchedulerServiceHandler) ListWorkers ¶
func (UnimplementedSchedulerServiceHandler) ListWorkers(context.Context, *connect.Request[v1alpha1.ListWorkersRequest]) (*connect.Response[v1alpha1.ListWorkersResponse], error)
Source Files
¶
- service.connect.go