Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterCustomerBillingAccountTransactionServiceServer(s grpc.ServiceRegistrar, srv CustomerBillingAccountTransactionServiceServer)
- type CustomerBillingAccountTransactionServiceClient
- type CustomerBillingAccountTransactionServiceServer
- type CustomerBillingAccountTransactionService_ListBillingAccountTransactionsClient
- type CustomerBillingAccountTransactionService_ListBillingAccountTransactionsServer
- type UnimplementedCustomerBillingAccountTransactionServiceServer
- func (UnimplementedCustomerBillingAccountTransactionServiceServer) CreateBillingAccountTransaction(context.Context, *v1beta1.CreateBillingAccountTransactionRequest) (*v1beta1.CreateBillingAccountTransactionResponse, error)
- func (UnimplementedCustomerBillingAccountTransactionServiceServer) DeleteBillingAccountTransaction(context.Context, *v1beta1.DeleteBillingAccountTransactionRequest) (*v1beta1.DeleteBillingAccountTransactionResponse, error)
- func (UnimplementedCustomerBillingAccountTransactionServiceServer) ListBillingAccountTransactions(*v1beta1.ListBillingAccountTransactionsRequest, ...) error
- type UnsafeCustomerBillingAccountTransactionServiceServer
Constants ¶
const ( CustomerBillingAccountTransactionService_ListBillingAccountTransactions_FullMethodName = "" /* 126-byte string literal not displayed */ CustomerBillingAccountTransactionService_CreateBillingAccountTransaction_FullMethodName = "" /* 127-byte string literal not displayed */ CustomerBillingAccountTransactionService_DeleteBillingAccountTransaction_FullMethodName = "" /* 127-byte string literal not displayed */ )
Variables ¶
var CustomerBillingAccountTransactionService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "stargate.customer.billing.account.transaction.v1beta1.CustomerBillingAccountTransactionService", HandlerType: (*CustomerBillingAccountTransactionServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "CreateBillingAccountTransaction", Handler: _CustomerBillingAccountTransactionService_CreateBillingAccountTransaction_Handler, }, { MethodName: "DeleteBillingAccountTransaction", Handler: _CustomerBillingAccountTransactionService_DeleteBillingAccountTransaction_Handler, }, }, Streams: []grpc.StreamDesc{ { StreamName: "ListBillingAccountTransactions", Handler: _CustomerBillingAccountTransactionService_ListBillingAccountTransactions_Handler, ServerStreams: true, }, }, Metadata: "stargate/customer/billing/account/transaction/v1beta1/customer_billing_account_transaction_service.proto", }
CustomerBillingAccountTransactionService_ServiceDesc is the grpc.ServiceDesc for CustomerBillingAccountTransactionService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterCustomerBillingAccountTransactionServiceServer ¶
func RegisterCustomerBillingAccountTransactionServiceServer(s grpc.ServiceRegistrar, srv CustomerBillingAccountTransactionServiceServer)
Types ¶
type CustomerBillingAccountTransactionServiceClient ¶
type CustomerBillingAccountTransactionServiceClient interface {
ListBillingAccountTransactions(ctx context.Context, in *v1beta1.ListBillingAccountTransactionsRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[v1beta1.ListBillingAccountTransactionsResponse], error)
CreateBillingAccountTransaction(ctx context.Context, in *v1beta1.CreateBillingAccountTransactionRequest, opts ...grpc.CallOption) (*v1beta1.CreateBillingAccountTransactionResponse, error)
DeleteBillingAccountTransaction(ctx context.Context, in *v1beta1.DeleteBillingAccountTransactionRequest, opts ...grpc.CallOption) (*v1beta1.DeleteBillingAccountTransactionResponse, error)
}
CustomerBillingAccountTransactionServiceClient is the client API for CustomerBillingAccountTransactionService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewCustomerBillingAccountTransactionServiceClient ¶
func NewCustomerBillingAccountTransactionServiceClient(cc grpc.ClientConnInterface) CustomerBillingAccountTransactionServiceClient
type CustomerBillingAccountTransactionServiceServer ¶
type CustomerBillingAccountTransactionServiceServer interface {
ListBillingAccountTransactions(*v1beta1.ListBillingAccountTransactionsRequest, grpc.ServerStreamingServer[v1beta1.ListBillingAccountTransactionsResponse]) error
CreateBillingAccountTransaction(context.Context, *v1beta1.CreateBillingAccountTransactionRequest) (*v1beta1.CreateBillingAccountTransactionResponse, error)
DeleteBillingAccountTransaction(context.Context, *v1beta1.DeleteBillingAccountTransactionRequest) (*v1beta1.DeleteBillingAccountTransactionResponse, error)
}
CustomerBillingAccountTransactionServiceServer is the server API for CustomerBillingAccountTransactionService service. All implementations should embed UnimplementedCustomerBillingAccountTransactionServiceServer for forward compatibility.
type CustomerBillingAccountTransactionService_ListBillingAccountTransactionsClient ¶
type CustomerBillingAccountTransactionService_ListBillingAccountTransactionsClient = grpc.ServerStreamingClient[v1beta1.ListBillingAccountTransactionsResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type CustomerBillingAccountTransactionService_ListBillingAccountTransactionsServer ¶
type CustomerBillingAccountTransactionService_ListBillingAccountTransactionsServer = grpc.ServerStreamingServer[v1beta1.ListBillingAccountTransactionsResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type UnimplementedCustomerBillingAccountTransactionServiceServer ¶
type UnimplementedCustomerBillingAccountTransactionServiceServer struct{}
UnimplementedCustomerBillingAccountTransactionServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedCustomerBillingAccountTransactionServiceServer) CreateBillingAccountTransaction ¶
func (UnimplementedCustomerBillingAccountTransactionServiceServer) CreateBillingAccountTransaction(context.Context, *v1beta1.CreateBillingAccountTransactionRequest) (*v1beta1.CreateBillingAccountTransactionResponse, error)
func (UnimplementedCustomerBillingAccountTransactionServiceServer) DeleteBillingAccountTransaction ¶
func (UnimplementedCustomerBillingAccountTransactionServiceServer) DeleteBillingAccountTransaction(context.Context, *v1beta1.DeleteBillingAccountTransactionRequest) (*v1beta1.DeleteBillingAccountTransactionResponse, error)
func (UnimplementedCustomerBillingAccountTransactionServiceServer) ListBillingAccountTransactions ¶
func (UnimplementedCustomerBillingAccountTransactionServiceServer) ListBillingAccountTransactions(*v1beta1.ListBillingAccountTransactionsRequest, grpc.ServerStreamingServer[v1beta1.ListBillingAccountTransactionsResponse]) error
type UnsafeCustomerBillingAccountTransactionServiceServer ¶
type UnsafeCustomerBillingAccountTransactionServiceServer interface {
// contains filtered or unexported methods
}
UnsafeCustomerBillingAccountTransactionServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to CustomerBillingAccountTransactionServiceServer will result in compilation errors.
Source Files
¶
- customer_billing_account_transaction_service_grpc.pb.go