Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterCustomerBillingAccountServiceServer(s grpc.ServiceRegistrar, srv CustomerBillingAccountServiceServer)
- type CustomerBillingAccountServiceClient
- type CustomerBillingAccountServiceServer
- type CustomerBillingAccountService_ListBillingAccountsClient
- type CustomerBillingAccountService_ListBillingAccountsServer
- type UnimplementedCustomerBillingAccountServiceServer
- type UnsafeCustomerBillingAccountServiceServer
Constants ¶
const (
CustomerBillingAccountService_ListBillingAccounts_FullMethodName = "/stargate.customer.billing.account.v1beta3.CustomerBillingAccountService/ListBillingAccounts"
)
Variables ¶
var CustomerBillingAccountService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "stargate.customer.billing.account.v1beta3.CustomerBillingAccountService", HandlerType: (*CustomerBillingAccountServiceServer)(nil), Methods: []grpc.MethodDesc{}, Streams: []grpc.StreamDesc{ { StreamName: "ListBillingAccounts", Handler: _CustomerBillingAccountService_ListBillingAccounts_Handler, ServerStreams: true, }, }, Metadata: "stargate/customer/billing/account/v1beta3/customer_billing_account_service.proto", }
CustomerBillingAccountService_ServiceDesc is the grpc.ServiceDesc for CustomerBillingAccountService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterCustomerBillingAccountServiceServer ¶
func RegisterCustomerBillingAccountServiceServer(s grpc.ServiceRegistrar, srv CustomerBillingAccountServiceServer)
Types ¶
type CustomerBillingAccountServiceClient ¶
type CustomerBillingAccountServiceClient interface {
ListBillingAccounts(ctx context.Context, in *v1beta3.ListBillingAccountsRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[v1beta3.ListBillingAccountsResponse], error)
}
CustomerBillingAccountServiceClient is the client API for CustomerBillingAccountService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewCustomerBillingAccountServiceClient ¶
func NewCustomerBillingAccountServiceClient(cc grpc.ClientConnInterface) CustomerBillingAccountServiceClient
type CustomerBillingAccountServiceServer ¶
type CustomerBillingAccountServiceServer interface {
ListBillingAccounts(*v1beta3.ListBillingAccountsRequest, grpc.ServerStreamingServer[v1beta3.ListBillingAccountsResponse]) error
}
CustomerBillingAccountServiceServer is the server API for CustomerBillingAccountService service. All implementations should embed UnimplementedCustomerBillingAccountServiceServer for forward compatibility.
type CustomerBillingAccountService_ListBillingAccountsClient ¶
type CustomerBillingAccountService_ListBillingAccountsClient = grpc.ServerStreamingClient[v1beta3.ListBillingAccountsResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type CustomerBillingAccountService_ListBillingAccountsServer ¶
type CustomerBillingAccountService_ListBillingAccountsServer = grpc.ServerStreamingServer[v1beta3.ListBillingAccountsResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type UnimplementedCustomerBillingAccountServiceServer ¶
type UnimplementedCustomerBillingAccountServiceServer struct{}
UnimplementedCustomerBillingAccountServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedCustomerBillingAccountServiceServer) ListBillingAccounts ¶
func (UnimplementedCustomerBillingAccountServiceServer) ListBillingAccounts(*v1beta3.ListBillingAccountsRequest, grpc.ServerStreamingServer[v1beta3.ListBillingAccountsResponse]) error
type UnsafeCustomerBillingAccountServiceServer ¶
type UnsafeCustomerBillingAccountServiceServer interface {
// contains filtered or unexported methods
}
UnsafeCustomerBillingAccountServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to CustomerBillingAccountServiceServer will result in compilation errors.
Source Files
¶
- customer_billing_account_service_grpc.pb.go