Documentation
¶
Index ¶
Constants ¶
const (
ItemService_UpdateItems_FullMethodName = "/stargate.item.v1beta1.ItemService/UpdateItems"
)
Variables ¶
var ItemService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "stargate.item.v1beta1.ItemService", HandlerType: (*ItemServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "UpdateItems", Handler: _ItemService_UpdateItems_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "stargate/item/v1beta1/item_service.proto", }
ItemService_ServiceDesc is the grpc.ServiceDesc for ItemService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterItemServiceServer ¶
func RegisterItemServiceServer(s grpc.ServiceRegistrar, srv ItemServiceServer)
Types ¶
type ItemServiceClient ¶
type ItemServiceClient interface {
UpdateItems(ctx context.Context, in *v1beta1.UpdateItemsRequest, opts ...grpc.CallOption) (*v1beta1.UpdateItemsResponse, error)
}
ItemServiceClient is the client API for ItemService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewItemServiceClient ¶
func NewItemServiceClient(cc grpc.ClientConnInterface) ItemServiceClient
type ItemServiceServer ¶
type ItemServiceServer interface {
UpdateItems(context.Context, *v1beta1.UpdateItemsRequest) (*v1beta1.UpdateItemsResponse, error)
}
ItemServiceServer is the server API for ItemService service. All implementations should embed UnimplementedItemServiceServer for forward compatibility.
type UnimplementedItemServiceServer ¶
type UnimplementedItemServiceServer struct{}
UnimplementedItemServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedItemServiceServer) UpdateItems ¶
func (UnimplementedItemServiceServer) UpdateItems(context.Context, *v1beta1.UpdateItemsRequest) (*v1beta1.UpdateItemsResponse, error)
type UnsafeItemServiceServer ¶
type UnsafeItemServiceServer interface {
// contains filtered or unexported methods
}
UnsafeItemServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ItemServiceServer will result in compilation errors.
Source Files
¶
- item_service_grpc.pb.go