Documentation
¶
Index ¶
- Variables
- type AcceptLatestTermsAndConditionsRequest
- func (x *AcceptLatestTermsAndConditionsRequest) ClearContactUuid()
- func (x *AcceptLatestTermsAndConditionsRequest) GetContactUuid() *v1.UUID
- func (x *AcceptLatestTermsAndConditionsRequest) HasContactUuid() bool
- func (*AcceptLatestTermsAndConditionsRequest) ProtoMessage()
- func (x *AcceptLatestTermsAndConditionsRequest) ProtoReflect() protoreflect.Message
- func (x *AcceptLatestTermsAndConditionsRequest) Reset()
- func (x *AcceptLatestTermsAndConditionsRequest) SetContactUuid(v *v1.UUID)
- func (x *AcceptLatestTermsAndConditionsRequest) String() string
- type AcceptLatestTermsAndConditionsRequest_builder
- type AcceptLatestTermsAndConditionsResponse
- type AcceptLatestTermsAndConditionsResponse_builder
- type GetAdvertisingInterestsRequest
- func (x *GetAdvertisingInterestsRequest) ClearContactUuid()
- func (x *GetAdvertisingInterestsRequest) GetContactUuid() *v1.UUID
- func (x *GetAdvertisingInterestsRequest) HasContactUuid() bool
- func (*GetAdvertisingInterestsRequest) ProtoMessage()
- func (x *GetAdvertisingInterestsRequest) ProtoReflect() protoreflect.Message
- func (x *GetAdvertisingInterestsRequest) Reset()
- func (x *GetAdvertisingInterestsRequest) SetContactUuid(v *v1.UUID)
- func (x *GetAdvertisingInterestsRequest) String() string
- type GetAdvertisingInterestsRequest_builder
- type GetAdvertisingInterestsResponse
- func (x *GetAdvertisingInterestsResponse) GetInterestUuid() []*v1.UUID
- func (*GetAdvertisingInterestsResponse) ProtoMessage()
- func (x *GetAdvertisingInterestsResponse) ProtoReflect() protoreflect.Message
- func (x *GetAdvertisingInterestsResponse) Reset()
- func (x *GetAdvertisingInterestsResponse) SetInterestUuid(v []*v1.UUID)
- func (x *GetAdvertisingInterestsResponse) String() string
- type GetAdvertisingInterestsResponse_builder
- type HasAcceptedLatestTermsAndConditionsRequest
- func (x *HasAcceptedLatestTermsAndConditionsRequest) ClearContactUuid()
- func (x *HasAcceptedLatestTermsAndConditionsRequest) GetContactUuid() *v1.UUID
- func (x *HasAcceptedLatestTermsAndConditionsRequest) HasContactUuid() bool
- func (*HasAcceptedLatestTermsAndConditionsRequest) ProtoMessage()
- func (x *HasAcceptedLatestTermsAndConditionsRequest) ProtoReflect() protoreflect.Message
- func (x *HasAcceptedLatestTermsAndConditionsRequest) Reset()
- func (x *HasAcceptedLatestTermsAndConditionsRequest) SetContactUuid(v *v1.UUID)
- func (x *HasAcceptedLatestTermsAndConditionsRequest) String() string
- type HasAcceptedLatestTermsAndConditionsRequest_builder
- type HasAcceptedLatestTermsAndConditionsResponse
- func (x *HasAcceptedLatestTermsAndConditionsResponse) GetAccepted() bool
- func (*HasAcceptedLatestTermsAndConditionsResponse) ProtoMessage()
- func (x *HasAcceptedLatestTermsAndConditionsResponse) ProtoReflect() protoreflect.Message
- func (x *HasAcceptedLatestTermsAndConditionsResponse) Reset()
- func (x *HasAcceptedLatestTermsAndConditionsResponse) SetAccepted(v bool)
- func (x *HasAcceptedLatestTermsAndConditionsResponse) String() string
- type HasAcceptedLatestTermsAndConditionsResponse_builder
- type UpdateAdvertisingInterestsRequest
- func (x *UpdateAdvertisingInterestsRequest) ClearContactUuid()
- func (x *UpdateAdvertisingInterestsRequest) GetContactUuid() *v1.UUID
- func (x *UpdateAdvertisingInterestsRequest) GetInterestUuid() []*v1.UUID
- func (x *UpdateAdvertisingInterestsRequest) HasContactUuid() bool
- func (*UpdateAdvertisingInterestsRequest) ProtoMessage()
- func (x *UpdateAdvertisingInterestsRequest) ProtoReflect() protoreflect.Message
- func (x *UpdateAdvertisingInterestsRequest) Reset()
- func (x *UpdateAdvertisingInterestsRequest) SetContactUuid(v *v1.UUID)
- func (x *UpdateAdvertisingInterestsRequest) SetInterestUuid(v []*v1.UUID)
- func (x *UpdateAdvertisingInterestsRequest) String() string
- type UpdateAdvertisingInterestsRequest_builder
- type UpdateAdvertisingInterestsResponse
- type UpdateAdvertisingInterestsResponse_builder
Constants ¶
This section is empty.
Variables ¶
var File_stargate_customer_contact_v1_customer_contact_service_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type AcceptLatestTermsAndConditionsRequest ¶
type AcceptLatestTermsAndConditionsRequest struct {
ContactUuid *v1.UUID `protobuf:"bytes,1,opt,name=contact_uuid,json=contactUuid,proto3,oneof" json:"contact_uuid,omitempty"`
// contains filtered or unexported fields
}
func (*AcceptLatestTermsAndConditionsRequest) ClearContactUuid ¶
func (x *AcceptLatestTermsAndConditionsRequest) ClearContactUuid()
func (*AcceptLatestTermsAndConditionsRequest) GetContactUuid ¶
func (x *AcceptLatestTermsAndConditionsRequest) GetContactUuid() *v1.UUID
func (*AcceptLatestTermsAndConditionsRequest) HasContactUuid ¶
func (x *AcceptLatestTermsAndConditionsRequest) HasContactUuid() bool
func (*AcceptLatestTermsAndConditionsRequest) ProtoMessage ¶
func (*AcceptLatestTermsAndConditionsRequest) ProtoMessage()
func (*AcceptLatestTermsAndConditionsRequest) ProtoReflect ¶
func (x *AcceptLatestTermsAndConditionsRequest) ProtoReflect() protoreflect.Message
func (*AcceptLatestTermsAndConditionsRequest) Reset ¶
func (x *AcceptLatestTermsAndConditionsRequest) Reset()
func (*AcceptLatestTermsAndConditionsRequest) SetContactUuid ¶
func (x *AcceptLatestTermsAndConditionsRequest) SetContactUuid(v *v1.UUID)
func (*AcceptLatestTermsAndConditionsRequest) String ¶
func (x *AcceptLatestTermsAndConditionsRequest) String() string
type AcceptLatestTermsAndConditionsRequest_builder ¶
type AcceptLatestTermsAndConditionsRequest_builder struct {
ContactUuid *v1.UUID
// contains filtered or unexported fields
}
func (AcceptLatestTermsAndConditionsRequest_builder) Build ¶
type AcceptLatestTermsAndConditionsResponse ¶
type AcceptLatestTermsAndConditionsResponse struct {
// contains filtered or unexported fields
}
func (*AcceptLatestTermsAndConditionsResponse) ProtoMessage ¶
func (*AcceptLatestTermsAndConditionsResponse) ProtoMessage()
func (*AcceptLatestTermsAndConditionsResponse) ProtoReflect ¶
func (x *AcceptLatestTermsAndConditionsResponse) ProtoReflect() protoreflect.Message
func (*AcceptLatestTermsAndConditionsResponse) Reset ¶
func (x *AcceptLatestTermsAndConditionsResponse) Reset()
func (*AcceptLatestTermsAndConditionsResponse) String ¶
func (x *AcceptLatestTermsAndConditionsResponse) String() string
type AcceptLatestTermsAndConditionsResponse_builder ¶
type AcceptLatestTermsAndConditionsResponse_builder struct {
// contains filtered or unexported fields
}
func (AcceptLatestTermsAndConditionsResponse_builder) Build ¶
type GetAdvertisingInterestsRequest ¶
type GetAdvertisingInterestsRequest struct {
// Unique identifier for customer contact.
ContactUuid *v1.UUID `protobuf:"bytes,1,opt,name=contact_uuid,json=contactUuid,proto3" json:"contact_uuid,omitempty"`
// contains filtered or unexported fields
}
func (*GetAdvertisingInterestsRequest) ClearContactUuid ¶
func (x *GetAdvertisingInterestsRequest) ClearContactUuid()
func (*GetAdvertisingInterestsRequest) GetContactUuid ¶
func (x *GetAdvertisingInterestsRequest) GetContactUuid() *v1.UUID
func (*GetAdvertisingInterestsRequest) HasContactUuid ¶
func (x *GetAdvertisingInterestsRequest) HasContactUuid() bool
func (*GetAdvertisingInterestsRequest) ProtoMessage ¶
func (*GetAdvertisingInterestsRequest) ProtoMessage()
func (*GetAdvertisingInterestsRequest) ProtoReflect ¶
func (x *GetAdvertisingInterestsRequest) ProtoReflect() protoreflect.Message
func (*GetAdvertisingInterestsRequest) Reset ¶
func (x *GetAdvertisingInterestsRequest) Reset()
func (*GetAdvertisingInterestsRequest) SetContactUuid ¶
func (x *GetAdvertisingInterestsRequest) SetContactUuid(v *v1.UUID)
func (*GetAdvertisingInterestsRequest) String ¶
func (x *GetAdvertisingInterestsRequest) String() string
type GetAdvertisingInterestsRequest_builder ¶
type GetAdvertisingInterestsRequest_builder struct {
// Unique identifier for customer contact.
ContactUuid *v1.UUID
// contains filtered or unexported fields
}
func (GetAdvertisingInterestsRequest_builder) Build ¶
func (b0 GetAdvertisingInterestsRequest_builder) Build() *GetAdvertisingInterestsRequest
type GetAdvertisingInterestsResponse ¶
type GetAdvertisingInterestsResponse struct {
// List of unique identifier for customer contact advertising interests currently present on the customer contact.
InterestUuid []*v1.UUID `protobuf:"bytes,1,rep,name=interest_uuid,json=interestUuid,proto3" json:"interest_uuid,omitempty"`
// contains filtered or unexported fields
}
func (*GetAdvertisingInterestsResponse) GetInterestUuid ¶
func (x *GetAdvertisingInterestsResponse) GetInterestUuid() []*v1.UUID
func (*GetAdvertisingInterestsResponse) ProtoMessage ¶
func (*GetAdvertisingInterestsResponse) ProtoMessage()
func (*GetAdvertisingInterestsResponse) ProtoReflect ¶
func (x *GetAdvertisingInterestsResponse) ProtoReflect() protoreflect.Message
func (*GetAdvertisingInterestsResponse) Reset ¶
func (x *GetAdvertisingInterestsResponse) Reset()
func (*GetAdvertisingInterestsResponse) SetInterestUuid ¶
func (x *GetAdvertisingInterestsResponse) SetInterestUuid(v []*v1.UUID)
func (*GetAdvertisingInterestsResponse) String ¶
func (x *GetAdvertisingInterestsResponse) String() string
type GetAdvertisingInterestsResponse_builder ¶
type GetAdvertisingInterestsResponse_builder struct {
// List of unique identifier for customer contact advertising interests currently present on the customer contact.
InterestUuid []*v1.UUID
// contains filtered or unexported fields
}
func (GetAdvertisingInterestsResponse_builder) Build ¶
func (b0 GetAdvertisingInterestsResponse_builder) Build() *GetAdvertisingInterestsResponse
type HasAcceptedLatestTermsAndConditionsRequest ¶
type HasAcceptedLatestTermsAndConditionsRequest struct {
ContactUuid *v1.UUID `protobuf:"bytes,1,opt,name=contact_uuid,json=contactUuid,proto3" json:"contact_uuid,omitempty"`
// contains filtered or unexported fields
}
func (*HasAcceptedLatestTermsAndConditionsRequest) ClearContactUuid ¶
func (x *HasAcceptedLatestTermsAndConditionsRequest) ClearContactUuid()
func (*HasAcceptedLatestTermsAndConditionsRequest) GetContactUuid ¶
func (x *HasAcceptedLatestTermsAndConditionsRequest) GetContactUuid() *v1.UUID
func (*HasAcceptedLatestTermsAndConditionsRequest) HasContactUuid ¶
func (x *HasAcceptedLatestTermsAndConditionsRequest) HasContactUuid() bool
func (*HasAcceptedLatestTermsAndConditionsRequest) ProtoMessage ¶
func (*HasAcceptedLatestTermsAndConditionsRequest) ProtoMessage()
func (*HasAcceptedLatestTermsAndConditionsRequest) ProtoReflect ¶
func (x *HasAcceptedLatestTermsAndConditionsRequest) ProtoReflect() protoreflect.Message
func (*HasAcceptedLatestTermsAndConditionsRequest) Reset ¶
func (x *HasAcceptedLatestTermsAndConditionsRequest) Reset()
func (*HasAcceptedLatestTermsAndConditionsRequest) SetContactUuid ¶
func (x *HasAcceptedLatestTermsAndConditionsRequest) SetContactUuid(v *v1.UUID)
func (*HasAcceptedLatestTermsAndConditionsRequest) String ¶
func (x *HasAcceptedLatestTermsAndConditionsRequest) String() string
type HasAcceptedLatestTermsAndConditionsRequest_builder ¶
type HasAcceptedLatestTermsAndConditionsRequest_builder struct {
ContactUuid *v1.UUID
// contains filtered or unexported fields
}
func (HasAcceptedLatestTermsAndConditionsRequest_builder) Build ¶
type HasAcceptedLatestTermsAndConditionsResponse ¶
type HasAcceptedLatestTermsAndConditionsResponse struct {
Accepted bool `protobuf:"varint,1,opt,name=accepted,proto3" json:"accepted,omitempty"`
// contains filtered or unexported fields
}
func (*HasAcceptedLatestTermsAndConditionsResponse) GetAccepted ¶
func (x *HasAcceptedLatestTermsAndConditionsResponse) GetAccepted() bool
func (*HasAcceptedLatestTermsAndConditionsResponse) ProtoMessage ¶
func (*HasAcceptedLatestTermsAndConditionsResponse) ProtoMessage()
func (*HasAcceptedLatestTermsAndConditionsResponse) ProtoReflect ¶
func (x *HasAcceptedLatestTermsAndConditionsResponse) ProtoReflect() protoreflect.Message
func (*HasAcceptedLatestTermsAndConditionsResponse) Reset ¶
func (x *HasAcceptedLatestTermsAndConditionsResponse) Reset()
func (*HasAcceptedLatestTermsAndConditionsResponse) SetAccepted ¶
func (x *HasAcceptedLatestTermsAndConditionsResponse) SetAccepted(v bool)
func (*HasAcceptedLatestTermsAndConditionsResponse) String ¶
func (x *HasAcceptedLatestTermsAndConditionsResponse) String() string
type HasAcceptedLatestTermsAndConditionsResponse_builder ¶
type HasAcceptedLatestTermsAndConditionsResponse_builder struct {
Accepted bool
// contains filtered or unexported fields
}
func (HasAcceptedLatestTermsAndConditionsResponse_builder) Build ¶
type UpdateAdvertisingInterestsRequest ¶
type UpdateAdvertisingInterestsRequest struct {
// Unique identifier for customer contact.
ContactUuid *v1.UUID `protobuf:"bytes,1,opt,name=contact_uuid,json=contactUuid,proto3" json:"contact_uuid,omitempty"`
// List of unique identifier for customer contact advertising interests.
// Existing customer contact advertising interests will be replaced with the provided list.
InterestUuid []*v1.UUID `protobuf:"bytes,2,rep,name=interest_uuid,json=interestUuid,proto3" json:"interest_uuid,omitempty"`
// contains filtered or unexported fields
}
func (*UpdateAdvertisingInterestsRequest) ClearContactUuid ¶
func (x *UpdateAdvertisingInterestsRequest) ClearContactUuid()
func (*UpdateAdvertisingInterestsRequest) GetContactUuid ¶
func (x *UpdateAdvertisingInterestsRequest) GetContactUuid() *v1.UUID
func (*UpdateAdvertisingInterestsRequest) GetInterestUuid ¶
func (x *UpdateAdvertisingInterestsRequest) GetInterestUuid() []*v1.UUID
func (*UpdateAdvertisingInterestsRequest) HasContactUuid ¶
func (x *UpdateAdvertisingInterestsRequest) HasContactUuid() bool
func (*UpdateAdvertisingInterestsRequest) ProtoMessage ¶
func (*UpdateAdvertisingInterestsRequest) ProtoMessage()
func (*UpdateAdvertisingInterestsRequest) ProtoReflect ¶
func (x *UpdateAdvertisingInterestsRequest) ProtoReflect() protoreflect.Message
func (*UpdateAdvertisingInterestsRequest) Reset ¶
func (x *UpdateAdvertisingInterestsRequest) Reset()
func (*UpdateAdvertisingInterestsRequest) SetContactUuid ¶
func (x *UpdateAdvertisingInterestsRequest) SetContactUuid(v *v1.UUID)
func (*UpdateAdvertisingInterestsRequest) SetInterestUuid ¶
func (x *UpdateAdvertisingInterestsRequest) SetInterestUuid(v []*v1.UUID)
func (*UpdateAdvertisingInterestsRequest) String ¶
func (x *UpdateAdvertisingInterestsRequest) String() string
type UpdateAdvertisingInterestsRequest_builder ¶
type UpdateAdvertisingInterestsRequest_builder struct {
// Unique identifier for customer contact.
ContactUuid *v1.UUID
// List of unique identifier for customer contact advertising interests.
// Existing customer contact advertising interests will be replaced with the provided list.
InterestUuid []*v1.UUID
// contains filtered or unexported fields
}
func (UpdateAdvertisingInterestsRequest_builder) Build ¶
func (b0 UpdateAdvertisingInterestsRequest_builder) Build() *UpdateAdvertisingInterestsRequest
type UpdateAdvertisingInterestsResponse ¶
type UpdateAdvertisingInterestsResponse struct {
// contains filtered or unexported fields
}
func (*UpdateAdvertisingInterestsResponse) ProtoMessage ¶
func (*UpdateAdvertisingInterestsResponse) ProtoMessage()
func (*UpdateAdvertisingInterestsResponse) ProtoReflect ¶
func (x *UpdateAdvertisingInterestsResponse) ProtoReflect() protoreflect.Message
func (*UpdateAdvertisingInterestsResponse) Reset ¶
func (x *UpdateAdvertisingInterestsResponse) Reset()
func (*UpdateAdvertisingInterestsResponse) String ¶
func (x *UpdateAdvertisingInterestsResponse) String() string
type UpdateAdvertisingInterestsResponse_builder ¶
type UpdateAdvertisingInterestsResponse_builder struct {
// contains filtered or unexported fields
}
func (UpdateAdvertisingInterestsResponse_builder) Build ¶
func (b0 UpdateAdvertisingInterestsResponse_builder) Build() *UpdateAdvertisingInterestsResponse
Source Files
¶
- customer_contact_service.pb.go
Click to show internal directories.
Click to hide internal directories.