Documentation
¶
Overview ¶
Package routev3gateway is a reverse proxy.
It translates gRPC into RESTful JSON APIs.
Package routev3gateway is a reverse proxy.
It translates gRPC into RESTful JSON APIs.
Index ¶
- func RegisterRouteDiscoveryServiceHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error
- func RegisterRouteDiscoveryServiceHandlerClient(ctx context.Context, mux *runtime.ServeMux, ...) error
- func RegisterRouteDiscoveryServiceHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, ...) (err error)
- func RegisterRouteDiscoveryServiceHandlerServer(ctx context.Context, mux *runtime.ServeMux, ...) error
- func RegisterScopedRoutesDiscoveryServiceHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error
- func RegisterScopedRoutesDiscoveryServiceHandlerClient(ctx context.Context, mux *runtime.ServeMux, ...) error
- func RegisterScopedRoutesDiscoveryServiceHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, ...) (err error)
- func RegisterScopedRoutesDiscoveryServiceHandlerServer(ctx context.Context, mux *runtime.ServeMux, ...) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func RegisterRouteDiscoveryServiceHandler ¶
func RegisterRouteDiscoveryServiceHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error
RegisterRouteDiscoveryServiceHandler registers the http handlers for service RouteDiscoveryService to "mux". The handlers forward requests to the grpc endpoint over "conn".
func RegisterRouteDiscoveryServiceHandlerClient ¶
func RegisterRouteDiscoveryServiceHandlerClient(ctx context.Context, mux *runtime.ServeMux, client routev3grpc.RouteDiscoveryServiceClient) error
RegisterRouteDiscoveryServiceHandlerClient registers the http handlers for service RouteDiscoveryService to "mux". The handlers forward requests to the grpc endpoint over the given implementation of "routev3grpc.RouteDiscoveryServiceClient". Note: the gRPC framework executes interceptors within the gRPC handler. If the passed in "routev3grpc.RouteDiscoveryServiceClient" doesn't go through the normal gRPC flow (creating a gRPC client etc.) then it will be up to the passed in "routev3grpc.RouteDiscoveryServiceClient" to call the correct interceptors. This client ignores the HTTP middlewares.
func RegisterRouteDiscoveryServiceHandlerFromEndpoint ¶
func RegisterRouteDiscoveryServiceHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, opts []grpc.DialOption) (err error)
RegisterRouteDiscoveryServiceHandlerFromEndpoint is same as RegisterRouteDiscoveryServiceHandler but automatically dials to "endpoint" and closes the connection when "ctx" gets done.
func RegisterRouteDiscoveryServiceHandlerServer ¶
func RegisterRouteDiscoveryServiceHandlerServer(ctx context.Context, mux *runtime.ServeMux, server routev3grpc.RouteDiscoveryServiceServer) error
RegisterRouteDiscoveryServiceHandlerServer registers the http handlers for service RouteDiscoveryService to "mux". UnaryRPC :call RouteDiscoveryServiceServer directly. StreamingRPC :currently unsupported pending https://github.com/grpc/grpc-go/issues/906. Note that using this registration option will cause many gRPC library features to stop working. Consider using RegisterRouteDiscoveryServiceHandlerFromEndpoint instead. GRPC interceptors will not work for this type of registration. To use interceptors, you must use the "runtime.WithMiddlewares" option in the "runtime.NewServeMux" call.
func RegisterScopedRoutesDiscoveryServiceHandler ¶
func RegisterScopedRoutesDiscoveryServiceHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error
RegisterScopedRoutesDiscoveryServiceHandler registers the http handlers for service ScopedRoutesDiscoveryService to "mux". The handlers forward requests to the grpc endpoint over "conn".
func RegisterScopedRoutesDiscoveryServiceHandlerClient ¶
func RegisterScopedRoutesDiscoveryServiceHandlerClient(ctx context.Context, mux *runtime.ServeMux, client routev3grpc.ScopedRoutesDiscoveryServiceClient) error
RegisterScopedRoutesDiscoveryServiceHandlerClient registers the http handlers for service ScopedRoutesDiscoveryService to "mux". The handlers forward requests to the grpc endpoint over the given implementation of "routev3grpc.ScopedRoutesDiscoveryServiceClient". Note: the gRPC framework executes interceptors within the gRPC handler. If the passed in "routev3grpc.ScopedRoutesDiscoveryServiceClient" doesn't go through the normal gRPC flow (creating a gRPC client etc.) then it will be up to the passed in "routev3grpc.ScopedRoutesDiscoveryServiceClient" to call the correct interceptors. This client ignores the HTTP middlewares.
func RegisterScopedRoutesDiscoveryServiceHandlerFromEndpoint ¶
func RegisterScopedRoutesDiscoveryServiceHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, opts []grpc.DialOption) (err error)
RegisterScopedRoutesDiscoveryServiceHandlerFromEndpoint is same as RegisterScopedRoutesDiscoveryServiceHandler but automatically dials to "endpoint" and closes the connection when "ctx" gets done.
func RegisterScopedRoutesDiscoveryServiceHandlerServer ¶
func RegisterScopedRoutesDiscoveryServiceHandlerServer(ctx context.Context, mux *runtime.ServeMux, server routev3grpc.ScopedRoutesDiscoveryServiceServer) error
RegisterScopedRoutesDiscoveryServiceHandlerServer registers the http handlers for service ScopedRoutesDiscoveryService to "mux". UnaryRPC :call ScopedRoutesDiscoveryServiceServer directly. StreamingRPC :currently unsupported pending https://github.com/grpc/grpc-go/issues/906. Note that using this registration option will cause many gRPC library features to stop working. Consider using RegisterScopedRoutesDiscoveryServiceHandlerFromEndpoint instead. GRPC interceptors will not work for this type of registration. To use interceptors, you must use the "runtime.WithMiddlewares" option in the "runtime.NewServeMux" call.
Types ¶
This section is empty.
Source Files
¶
- rds.pb.gw.go
- srds.pb.gw.go