Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterRuntimeDiscoveryServiceServer(s grpc.ServiceRegistrar, srv RuntimeDiscoveryServiceServer)
- type RuntimeDiscoveryServiceClient
- type RuntimeDiscoveryServiceServer
- type RuntimeDiscoveryService_DeltaRuntimeClient
- type RuntimeDiscoveryService_DeltaRuntimeServer
- type RuntimeDiscoveryService_StreamRuntimeClient
- type RuntimeDiscoveryService_StreamRuntimeServer
- type UnimplementedRuntimeDiscoveryServiceServer
- func (UnimplementedRuntimeDiscoveryServiceServer) DeltaRuntime(grpc.BidiStreamingServer[v3.DeltaDiscoveryRequest, v3.DeltaDiscoveryResponse]) error
- func (UnimplementedRuntimeDiscoveryServiceServer) FetchRuntime(context.Context, *v3.DiscoveryRequest) (*v3.DiscoveryResponse, error)
- func (UnimplementedRuntimeDiscoveryServiceServer) StreamRuntime(grpc.BidiStreamingServer[v3.DiscoveryRequest, v3.DiscoveryResponse]) error
- type UnsafeRuntimeDiscoveryServiceServer
Constants ¶
const ( RuntimeDiscoveryService_StreamRuntime_FullMethodName = "/envoy.service.runtime.v3.RuntimeDiscoveryService/StreamRuntime" RuntimeDiscoveryService_DeltaRuntime_FullMethodName = "/envoy.service.runtime.v3.RuntimeDiscoveryService/DeltaRuntime" RuntimeDiscoveryService_FetchRuntime_FullMethodName = "/envoy.service.runtime.v3.RuntimeDiscoveryService/FetchRuntime" )
Variables ¶
var RuntimeDiscoveryService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "envoy.service.runtime.v3.RuntimeDiscoveryService", HandlerType: (*RuntimeDiscoveryServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "FetchRuntime", Handler: _RuntimeDiscoveryService_FetchRuntime_Handler, }, }, Streams: []grpc.StreamDesc{ { StreamName: "StreamRuntime", Handler: _RuntimeDiscoveryService_StreamRuntime_Handler, ServerStreams: true, ClientStreams: true, }, { StreamName: "DeltaRuntime", Handler: _RuntimeDiscoveryService_DeltaRuntime_Handler, ServerStreams: true, ClientStreams: true, }, }, Metadata: "envoy/service/runtime/v3/rtds.proto", }
RuntimeDiscoveryService_ServiceDesc is the grpc.ServiceDesc for RuntimeDiscoveryService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterRuntimeDiscoveryServiceServer ¶
func RegisterRuntimeDiscoveryServiceServer(s grpc.ServiceRegistrar, srv RuntimeDiscoveryServiceServer)
Types ¶
type RuntimeDiscoveryServiceClient ¶
type RuntimeDiscoveryServiceClient interface {
StreamRuntime(ctx context.Context, opts ...grpc.CallOption) (grpc.BidiStreamingClient[v3.DiscoveryRequest, v3.DiscoveryResponse], error)
DeltaRuntime(ctx context.Context, opts ...grpc.CallOption) (grpc.BidiStreamingClient[v3.DeltaDiscoveryRequest, v3.DeltaDiscoveryResponse], error)
FetchRuntime(ctx context.Context, in *v3.DiscoveryRequest, opts ...grpc.CallOption) (*v3.DiscoveryResponse, error)
}
RuntimeDiscoveryServiceClient is the client API for RuntimeDiscoveryService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
Discovery service for Runtime resources.
func NewRuntimeDiscoveryServiceClient ¶
func NewRuntimeDiscoveryServiceClient(cc grpc.ClientConnInterface) RuntimeDiscoveryServiceClient
type RuntimeDiscoveryServiceServer ¶
type RuntimeDiscoveryServiceServer interface {
StreamRuntime(grpc.BidiStreamingServer[v3.DiscoveryRequest, v3.DiscoveryResponse]) error
DeltaRuntime(grpc.BidiStreamingServer[v3.DeltaDiscoveryRequest, v3.DeltaDiscoveryResponse]) error
FetchRuntime(context.Context, *v3.DiscoveryRequest) (*v3.DiscoveryResponse, error)
}
RuntimeDiscoveryServiceServer is the server API for RuntimeDiscoveryService service. All implementations should embed UnimplementedRuntimeDiscoveryServiceServer for forward compatibility.
Discovery service for Runtime resources.
type RuntimeDiscoveryService_DeltaRuntimeClient ¶
type RuntimeDiscoveryService_DeltaRuntimeClient = grpc.BidiStreamingClient[v3.DeltaDiscoveryRequest, v3.DeltaDiscoveryResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type RuntimeDiscoveryService_DeltaRuntimeServer ¶
type RuntimeDiscoveryService_DeltaRuntimeServer = grpc.BidiStreamingServer[v3.DeltaDiscoveryRequest, v3.DeltaDiscoveryResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type RuntimeDiscoveryService_StreamRuntimeClient ¶
type RuntimeDiscoveryService_StreamRuntimeClient = grpc.BidiStreamingClient[v3.DiscoveryRequest, v3.DiscoveryResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type RuntimeDiscoveryService_StreamRuntimeServer ¶
type RuntimeDiscoveryService_StreamRuntimeServer = grpc.BidiStreamingServer[v3.DiscoveryRequest, v3.DiscoveryResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type UnimplementedRuntimeDiscoveryServiceServer ¶
type UnimplementedRuntimeDiscoveryServiceServer struct{}
UnimplementedRuntimeDiscoveryServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedRuntimeDiscoveryServiceServer) DeltaRuntime ¶
func (UnimplementedRuntimeDiscoveryServiceServer) DeltaRuntime(grpc.BidiStreamingServer[v3.DeltaDiscoveryRequest, v3.DeltaDiscoveryResponse]) error
func (UnimplementedRuntimeDiscoveryServiceServer) FetchRuntime ¶
func (UnimplementedRuntimeDiscoveryServiceServer) FetchRuntime(context.Context, *v3.DiscoveryRequest) (*v3.DiscoveryResponse, error)
func (UnimplementedRuntimeDiscoveryServiceServer) StreamRuntime ¶
func (UnimplementedRuntimeDiscoveryServiceServer) StreamRuntime(grpc.BidiStreamingServer[v3.DiscoveryRequest, v3.DiscoveryResponse]) error
type UnsafeRuntimeDiscoveryServiceServer ¶
type UnsafeRuntimeDiscoveryServiceServer interface {
// contains filtered or unexported methods
}
UnsafeRuntimeDiscoveryServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to RuntimeDiscoveryServiceServer will result in compilation errors.
Source Files
¶
- rtds_grpc.pb.go