Documentation
¶
Index ¶
- Constants
- Variables
- type Buffer
- func (x *Buffer) ClearMaxRequestBytes()
- func (x *Buffer) GetMaxRequestBytes() *wrapperspb.UInt32Value
- func (x *Buffer) HasMaxRequestBytes() bool
- func (*Buffer) ProtoMessage()
- func (x *Buffer) ProtoReflect() protoreflect.Message
- func (x *Buffer) Reset()
- func (x *Buffer) SetMaxRequestBytes(v *wrapperspb.UInt32Value)
- func (x *Buffer) String() string
- type BufferPerRoute
- func (x *BufferPerRoute) ClearBuffer()
- func (x *BufferPerRoute) ClearDisabled()
- func (x *BufferPerRoute) ClearOverride()
- func (x *BufferPerRoute) GetBuffer() *Buffer
- func (x *BufferPerRoute) GetDisabled() bool
- func (x *BufferPerRoute) GetOverride() isBufferPerRoute_Override
- func (x *BufferPerRoute) HasBuffer() bool
- func (x *BufferPerRoute) HasDisabled() bool
- func (x *BufferPerRoute) HasOverride() bool
- func (*BufferPerRoute) ProtoMessage()
- func (x *BufferPerRoute) ProtoReflect() protoreflect.Message
- func (x *BufferPerRoute) Reset()
- func (x *BufferPerRoute) SetBuffer(v *Buffer)
- func (x *BufferPerRoute) SetDisabled(v bool)
- func (x *BufferPerRoute) String() string
- func (x *BufferPerRoute) WhichOverride() case_BufferPerRoute_Override
- type BufferPerRoute_Buffer
- type BufferPerRoute_Disabled
- type BufferPerRoute_builder
- type Buffer_builder
Constants ¶
const BufferPerRoute_Buffer_case case_BufferPerRoute_Override = 2
const BufferPerRoute_Disabled_case case_BufferPerRoute_Override = 1
const BufferPerRoute_Override_not_set_case case_BufferPerRoute_Override = 0
Variables ¶
var File_envoy_config_filter_http_buffer_v2_buffer_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Buffer ¶
type Buffer struct {
// The maximum request size that the filter will buffer before the connection
// manager will stop buffering and return a 413 response.
MaxRequestBytes *wrapperspb.UInt32Value `protobuf:"bytes,1,opt,name=max_request_bytes,json=maxRequestBytes,proto3" json:"max_request_bytes,omitempty"`
// contains filtered or unexported fields
}
func (*Buffer) GetMaxRequestBytes ¶
func (x *Buffer) GetMaxRequestBytes() *wrapperspb.UInt32Value
func (*Buffer) ProtoReflect ¶
func (x *Buffer) ProtoReflect() protoreflect.Message
func (*Buffer) SetMaxRequestBytes ¶
func (x *Buffer) SetMaxRequestBytes(v *wrapperspb.UInt32Value)
type BufferPerRoute ¶
type BufferPerRoute struct {
// Types that are valid to be assigned to Override:
//
// *BufferPerRoute_Disabled
// *BufferPerRoute_Buffer
Override isBufferPerRoute_Override `protobuf_oneof:"override"`
// contains filtered or unexported fields
}
func (*BufferPerRoute) ClearBuffer ¶
func (x *BufferPerRoute) ClearBuffer()
func (*BufferPerRoute) ClearDisabled ¶
func (x *BufferPerRoute) ClearDisabled()
func (*BufferPerRoute) ClearOverride ¶
func (x *BufferPerRoute) ClearOverride()
func (*BufferPerRoute) GetBuffer ¶
func (x *BufferPerRoute) GetBuffer() *Buffer
func (*BufferPerRoute) GetDisabled ¶
func (x *BufferPerRoute) GetDisabled() bool
func (*BufferPerRoute) GetOverride ¶
func (x *BufferPerRoute) GetOverride() isBufferPerRoute_Override
func (*BufferPerRoute) HasBuffer ¶
func (x *BufferPerRoute) HasBuffer() bool
func (*BufferPerRoute) HasDisabled ¶
func (x *BufferPerRoute) HasDisabled() bool
func (*BufferPerRoute) HasOverride ¶
func (x *BufferPerRoute) HasOverride() bool
func (*BufferPerRoute) ProtoMessage ¶
func (*BufferPerRoute) ProtoMessage()
func (*BufferPerRoute) ProtoReflect ¶
func (x *BufferPerRoute) ProtoReflect() protoreflect.Message
func (*BufferPerRoute) Reset ¶
func (x *BufferPerRoute) Reset()
func (*BufferPerRoute) SetBuffer ¶
func (x *BufferPerRoute) SetBuffer(v *Buffer)
func (*BufferPerRoute) SetDisabled ¶
func (x *BufferPerRoute) SetDisabled(v bool)
func (*BufferPerRoute) String ¶
func (x *BufferPerRoute) String() string
func (*BufferPerRoute) WhichOverride ¶
func (x *BufferPerRoute) WhichOverride() case_BufferPerRoute_Override
type BufferPerRoute_Buffer ¶
type BufferPerRoute_Buffer struct {
// Override the global configuration of the filter with this new config.
Buffer *Buffer `protobuf:"bytes,2,opt,name=buffer,proto3,oneof"`
}
type BufferPerRoute_Disabled ¶
type BufferPerRoute_Disabled struct {
// Disable the buffer filter for this particular vhost or route.
Disabled bool `protobuf:"varint,1,opt,name=disabled,proto3,oneof"`
}
type BufferPerRoute_builder ¶
type BufferPerRoute_builder struct {
// Fields of oneof Override:
// Disable the buffer filter for this particular vhost or route.
Disabled *bool
// Override the global configuration of the filter with this new config.
Buffer *Buffer
// contains filtered or unexported fields
}
func (BufferPerRoute_builder) Build ¶
func (b0 BufferPerRoute_builder) Build() *BufferPerRoute
type Buffer_builder ¶
type Buffer_builder struct {
// The maximum request size that the filter will buffer before the connection
// manager will stop buffering and return a 413 response.
MaxRequestBytes *wrapperspb.UInt32Value
// contains filtered or unexported fields
}
func (Buffer_builder) Build ¶
func (b0 Buffer_builder) Build() *Buffer
Source Files
¶
- buffer.pb.go
Click to show internal directories.
Click to hide internal directories.