Documentation
¶
Index ¶
- Constants
- Variables
- type DubboFilter
- func (x *DubboFilter) ClearConfig()
- func (x *DubboFilter) GetConfig() *anypb.Any
- func (x *DubboFilter) GetName() string
- func (x *DubboFilter) HasConfig() bool
- func (*DubboFilter) ProtoMessage()
- func (x *DubboFilter) ProtoReflect() protoreflect.Message
- func (x *DubboFilter) Reset()
- func (x *DubboFilter) SetConfig(v *anypb.Any)
- func (x *DubboFilter) SetName(v string)
- func (x *DubboFilter) String() string
- type DubboFilter_builder
- type DubboProxy
- func (x *DubboProxy) GetDubboFilters() []*DubboFilter
- func (x *DubboProxy) GetProtocolType() ProtocolType
- func (x *DubboProxy) GetRouteConfig() []*RouteConfiguration
- func (x *DubboProxy) GetSerializationType() SerializationType
- func (x *DubboProxy) GetStatPrefix() string
- func (*DubboProxy) ProtoMessage()
- func (x *DubboProxy) ProtoReflect() protoreflect.Message
- func (x *DubboProxy) Reset()
- func (x *DubboProxy) SetDubboFilters(v []*DubboFilter)
- func (x *DubboProxy) SetProtocolType(v ProtocolType)
- func (x *DubboProxy) SetRouteConfig(v []*RouteConfiguration)
- func (x *DubboProxy) SetSerializationType(v SerializationType)
- func (x *DubboProxy) SetStatPrefix(v string)
- func (x *DubboProxy) String() string
- type DubboProxy_builder
- type MethodMatch
- func (x *MethodMatch) ClearName()
- func (x *MethodMatch) GetName() *matcher.StringMatcher
- func (x *MethodMatch) GetParamsMatch() map[uint32]*MethodMatch_ParameterMatchSpecifier
- func (x *MethodMatch) HasName() bool
- func (*MethodMatch) ProtoMessage()
- func (x *MethodMatch) ProtoReflect() protoreflect.Message
- func (x *MethodMatch) Reset()
- func (x *MethodMatch) SetName(v *matcher.StringMatcher)
- func (x *MethodMatch) SetParamsMatch(v map[uint32]*MethodMatch_ParameterMatchSpecifier)
- func (x *MethodMatch) String() string
- type MethodMatch_ParameterMatchSpecifier
- func (x *MethodMatch_ParameterMatchSpecifier) ClearExactMatch()
- func (x *MethodMatch_ParameterMatchSpecifier) ClearParameterMatchSpecifier()
- func (x *MethodMatch_ParameterMatchSpecifier) ClearRangeMatch()
- func (x *MethodMatch_ParameterMatchSpecifier) GetExactMatch() string
- func (x *MethodMatch_ParameterMatchSpecifier) GetParameterMatchSpecifier() isMethodMatch_ParameterMatchSpecifier_ParameterMatchSpecifier
- func (x *MethodMatch_ParameterMatchSpecifier) GetRangeMatch() *_type.Int64Range
- func (x *MethodMatch_ParameterMatchSpecifier) HasExactMatch() bool
- func (x *MethodMatch_ParameterMatchSpecifier) HasParameterMatchSpecifier() bool
- func (x *MethodMatch_ParameterMatchSpecifier) HasRangeMatch() bool
- func (*MethodMatch_ParameterMatchSpecifier) ProtoMessage()
- func (x *MethodMatch_ParameterMatchSpecifier) ProtoReflect() protoreflect.Message
- func (x *MethodMatch_ParameterMatchSpecifier) Reset()
- func (x *MethodMatch_ParameterMatchSpecifier) SetExactMatch(v string)
- func (x *MethodMatch_ParameterMatchSpecifier) SetRangeMatch(v *_type.Int64Range)
- func (x *MethodMatch_ParameterMatchSpecifier) String() string
- func (x *MethodMatch_ParameterMatchSpecifier) WhichParameterMatchSpecifier() case_MethodMatch_ParameterMatchSpecifier_ParameterMatchSpecifier
- type MethodMatch_ParameterMatchSpecifier_ExactMatch
- type MethodMatch_ParameterMatchSpecifier_RangeMatch
- type MethodMatch_ParameterMatchSpecifier_builder
- type MethodMatch_builder
- type ProtocolType
- type Route
- func (x *Route) ClearMatch()
- func (x *Route) ClearRoute()
- func (x *Route) GetMatch() *RouteMatch
- func (x *Route) GetRoute() *RouteAction
- func (x *Route) HasMatch() bool
- func (x *Route) HasRoute() bool
- func (*Route) ProtoMessage()
- func (x *Route) ProtoReflect() protoreflect.Message
- func (x *Route) Reset()
- func (x *Route) SetMatch(v *RouteMatch)
- func (x *Route) SetRoute(v *RouteAction)
- func (x *Route) String() string
- type RouteAction
- func (x *RouteAction) ClearCluster()
- func (x *RouteAction) ClearClusterSpecifier()
- func (x *RouteAction) ClearWeightedClusters()
- func (x *RouteAction) GetCluster() string
- func (x *RouteAction) GetClusterSpecifier() isRouteAction_ClusterSpecifier
- func (x *RouteAction) GetWeightedClusters() *route.WeightedCluster
- func (x *RouteAction) HasCluster() bool
- func (x *RouteAction) HasClusterSpecifier() bool
- func (x *RouteAction) HasWeightedClusters() bool
- func (*RouteAction) ProtoMessage()
- func (x *RouteAction) ProtoReflect() protoreflect.Message
- func (x *RouteAction) Reset()
- func (x *RouteAction) SetCluster(v string)
- func (x *RouteAction) SetWeightedClusters(v *route.WeightedCluster)
- func (x *RouteAction) String() string
- func (x *RouteAction) WhichClusterSpecifier() case_RouteAction_ClusterSpecifier
- type RouteAction_Cluster
- type RouteAction_WeightedClusters
- type RouteAction_builder
- type RouteConfiguration
- func (x *RouteConfiguration) GetGroup() string
- func (x *RouteConfiguration) GetInterface() string
- func (x *RouteConfiguration) GetName() string
- func (x *RouteConfiguration) GetRoutes() []*Route
- func (x *RouteConfiguration) GetVersion() string
- func (*RouteConfiguration) ProtoMessage()
- func (x *RouteConfiguration) ProtoReflect() protoreflect.Message
- func (x *RouteConfiguration) Reset()
- func (x *RouteConfiguration) SetGroup(v string)
- func (x *RouteConfiguration) SetInterface(v string)
- func (x *RouteConfiguration) SetName(v string)
- func (x *RouteConfiguration) SetRoutes(v []*Route)
- func (x *RouteConfiguration) SetVersion(v string)
- func (x *RouteConfiguration) String() string
- type RouteConfiguration_builder
- type RouteMatch
- func (x *RouteMatch) ClearMethod()
- func (x *RouteMatch) GetHeaders() []*route.HeaderMatcher
- func (x *RouteMatch) GetMethod() *MethodMatch
- func (x *RouteMatch) HasMethod() bool
- func (*RouteMatch) ProtoMessage()
- func (x *RouteMatch) ProtoReflect() protoreflect.Message
- func (x *RouteMatch) Reset()
- func (x *RouteMatch) SetHeaders(v []*route.HeaderMatcher)
- func (x *RouteMatch) SetMethod(v *MethodMatch)
- func (x *RouteMatch) String() string
- type RouteMatch_builder
- type Route_builder
- type SerializationType
Constants ¶
const MethodMatch_ParameterMatchSpecifier_ExactMatch_case case_MethodMatch_ParameterMatchSpecifier_ParameterMatchSpecifier = 3
const MethodMatch_ParameterMatchSpecifier_ParameterMatchSpecifier_not_set_case case_MethodMatch_ParameterMatchSpecifier_ParameterMatchSpecifier = 0
const MethodMatch_ParameterMatchSpecifier_RangeMatch_case case_MethodMatch_ParameterMatchSpecifier_ParameterMatchSpecifier = 4
const RouteAction_ClusterSpecifier_not_set_case case_RouteAction_ClusterSpecifier = 0
const RouteAction_Cluster_case case_RouteAction_ClusterSpecifier = 1
const RouteAction_WeightedClusters_case case_RouteAction_ClusterSpecifier = 2
Variables ¶
var ( ProtocolType_name = map[int32]string{ 0: "Dubbo", } ProtocolType_value = map[string]int32{ "Dubbo": 0, } )
Enum value maps for ProtocolType.
var ( SerializationType_name = map[int32]string{ 0: "Hessian2", } SerializationType_value = map[string]int32{ "Hessian2": 0, } )
Enum value maps for SerializationType.
var File_envoy_config_filter_network_dubbo_proxy_v2alpha1_dubbo_proxy_proto protoreflect.FileDescriptor
var File_envoy_config_filter_network_dubbo_proxy_v2alpha1_route_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type DubboFilter ¶
type DubboFilter struct {
// The name of the filter to instantiate. The name must match a supported
// filter.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// Filter specific configuration which depends on the filter being
// instantiated. See the supported filters for further documentation.
Config *anypb.Any `protobuf:"bytes,2,opt,name=config,proto3" json:"config,omitempty"`
// contains filtered or unexported fields
}
DubboFilter configures a Dubbo filter.
func (*DubboFilter) ClearConfig ¶
func (x *DubboFilter) ClearConfig()
func (*DubboFilter) GetConfig ¶
func (x *DubboFilter) GetConfig() *anypb.Any
func (*DubboFilter) GetName ¶
func (x *DubboFilter) GetName() string
func (*DubboFilter) HasConfig ¶
func (x *DubboFilter) HasConfig() bool
func (*DubboFilter) ProtoMessage ¶
func (*DubboFilter) ProtoMessage()
func (*DubboFilter) ProtoReflect ¶
func (x *DubboFilter) ProtoReflect() protoreflect.Message
func (*DubboFilter) Reset ¶
func (x *DubboFilter) Reset()
func (*DubboFilter) SetConfig ¶
func (x *DubboFilter) SetConfig(v *anypb.Any)
func (*DubboFilter) SetName ¶
func (x *DubboFilter) SetName(v string)
func (*DubboFilter) String ¶
func (x *DubboFilter) String() string
type DubboFilter_builder ¶
type DubboFilter_builder struct {
// The name of the filter to instantiate. The name must match a supported
// filter.
Name string
// Filter specific configuration which depends on the filter being
// instantiated. See the supported filters for further documentation.
Config *anypb.Any
// contains filtered or unexported fields
}
func (DubboFilter_builder) Build ¶
func (b0 DubboFilter_builder) Build() *DubboFilter
type DubboProxy ¶
type DubboProxy struct {
// The human readable prefix to use when emitting statistics.
StatPrefix string `protobuf:"bytes,1,opt,name=stat_prefix,json=statPrefix,proto3" json:"stat_prefix,omitempty"`
// Configure the protocol used.
ProtocolType ProtocolType `` /* 165-byte string literal not displayed */
// Configure the serialization protocol used.
SerializationType SerializationType `` /* 185-byte string literal not displayed */
// The route table for the connection manager is static and is specified in this property.
RouteConfig []*RouteConfiguration `protobuf:"bytes,4,rep,name=route_config,json=routeConfig,proto3" json:"route_config,omitempty"`
// A list of individual Dubbo filters that make up the filter chain for requests made to the
// Dubbo proxy. Order matters as the filters are processed sequentially. For backwards
// compatibility, if no dubbo_filters are specified, a default Dubbo router filter
// (`envoy.filters.dubbo.router`) is used.
DubboFilters []*DubboFilter `protobuf:"bytes,5,rep,name=dubbo_filters,json=dubboFilters,proto3" json:"dubbo_filters,omitempty"`
// contains filtered or unexported fields
}
[#next-free-field: 6]
func (*DubboProxy) GetDubboFilters ¶
func (x *DubboProxy) GetDubboFilters() []*DubboFilter
func (*DubboProxy) GetProtocolType ¶
func (x *DubboProxy) GetProtocolType() ProtocolType
func (*DubboProxy) GetRouteConfig ¶
func (x *DubboProxy) GetRouteConfig() []*RouteConfiguration
func (*DubboProxy) GetSerializationType ¶
func (x *DubboProxy) GetSerializationType() SerializationType
func (*DubboProxy) GetStatPrefix ¶
func (x *DubboProxy) GetStatPrefix() string
func (*DubboProxy) ProtoMessage ¶
func (*DubboProxy) ProtoMessage()
func (*DubboProxy) ProtoReflect ¶
func (x *DubboProxy) ProtoReflect() protoreflect.Message
func (*DubboProxy) Reset ¶
func (x *DubboProxy) Reset()
func (*DubboProxy) SetDubboFilters ¶
func (x *DubboProxy) SetDubboFilters(v []*DubboFilter)
func (*DubboProxy) SetProtocolType ¶
func (x *DubboProxy) SetProtocolType(v ProtocolType)
func (*DubboProxy) SetRouteConfig ¶
func (x *DubboProxy) SetRouteConfig(v []*RouteConfiguration)
func (*DubboProxy) SetSerializationType ¶
func (x *DubboProxy) SetSerializationType(v SerializationType)
func (*DubboProxy) SetStatPrefix ¶
func (x *DubboProxy) SetStatPrefix(v string)
func (*DubboProxy) String ¶
func (x *DubboProxy) String() string
type DubboProxy_builder ¶
type DubboProxy_builder struct {
// The human readable prefix to use when emitting statistics.
StatPrefix string
// Configure the protocol used.
ProtocolType ProtocolType
// Configure the serialization protocol used.
SerializationType SerializationType
// The route table for the connection manager is static and is specified in this property.
RouteConfig []*RouteConfiguration
// A list of individual Dubbo filters that make up the filter chain for requests made to the
// Dubbo proxy. Order matters as the filters are processed sequentially. For backwards
// compatibility, if no dubbo_filters are specified, a default Dubbo router filter
// (`envoy.filters.dubbo.router`) is used.
DubboFilters []*DubboFilter
// contains filtered or unexported fields
}
func (DubboProxy_builder) Build ¶
func (b0 DubboProxy_builder) Build() *DubboProxy
type MethodMatch ¶
type MethodMatch struct {
// The name of the method.
Name *matcher.StringMatcher `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// Method parameter definition.
// The key is the parameter index, starting from 0.
// The value is the parameter matching type.
ParamsMatch map[uint32]*MethodMatch_ParameterMatchSpecifier `` /* 169-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*MethodMatch) ClearName ¶
func (x *MethodMatch) ClearName()
func (*MethodMatch) GetName ¶
func (x *MethodMatch) GetName() *matcher.StringMatcher
func (*MethodMatch) GetParamsMatch ¶
func (x *MethodMatch) GetParamsMatch() map[uint32]*MethodMatch_ParameterMatchSpecifier
func (*MethodMatch) HasName ¶
func (x *MethodMatch) HasName() bool
func (*MethodMatch) ProtoMessage ¶
func (*MethodMatch) ProtoMessage()
func (*MethodMatch) ProtoReflect ¶
func (x *MethodMatch) ProtoReflect() protoreflect.Message
func (*MethodMatch) Reset ¶
func (x *MethodMatch) Reset()
func (*MethodMatch) SetName ¶
func (x *MethodMatch) SetName(v *matcher.StringMatcher)
func (*MethodMatch) SetParamsMatch ¶
func (x *MethodMatch) SetParamsMatch(v map[uint32]*MethodMatch_ParameterMatchSpecifier)
func (*MethodMatch) String ¶
func (x *MethodMatch) String() string
type MethodMatch_ParameterMatchSpecifier ¶
type MethodMatch_ParameterMatchSpecifier struct {
// Types that are valid to be assigned to ParameterMatchSpecifier:
//
// *MethodMatch_ParameterMatchSpecifier_ExactMatch
// *MethodMatch_ParameterMatchSpecifier_RangeMatch
ParameterMatchSpecifier isMethodMatch_ParameterMatchSpecifier_ParameterMatchSpecifier `protobuf_oneof:"parameter_match_specifier"`
// contains filtered or unexported fields
}
The parameter matching type.
func (*MethodMatch_ParameterMatchSpecifier) ClearExactMatch ¶
func (x *MethodMatch_ParameterMatchSpecifier) ClearExactMatch()
func (*MethodMatch_ParameterMatchSpecifier) ClearParameterMatchSpecifier ¶
func (x *MethodMatch_ParameterMatchSpecifier) ClearParameterMatchSpecifier()
func (*MethodMatch_ParameterMatchSpecifier) ClearRangeMatch ¶
func (x *MethodMatch_ParameterMatchSpecifier) ClearRangeMatch()
func (*MethodMatch_ParameterMatchSpecifier) GetExactMatch ¶
func (x *MethodMatch_ParameterMatchSpecifier) GetExactMatch() string
func (*MethodMatch_ParameterMatchSpecifier) GetParameterMatchSpecifier ¶
func (x *MethodMatch_ParameterMatchSpecifier) GetParameterMatchSpecifier() isMethodMatch_ParameterMatchSpecifier_ParameterMatchSpecifier
func (*MethodMatch_ParameterMatchSpecifier) GetRangeMatch ¶
func (x *MethodMatch_ParameterMatchSpecifier) GetRangeMatch() *_type.Int64Range
func (*MethodMatch_ParameterMatchSpecifier) HasExactMatch ¶
func (x *MethodMatch_ParameterMatchSpecifier) HasExactMatch() bool
func (*MethodMatch_ParameterMatchSpecifier) HasParameterMatchSpecifier ¶
func (x *MethodMatch_ParameterMatchSpecifier) HasParameterMatchSpecifier() bool
func (*MethodMatch_ParameterMatchSpecifier) HasRangeMatch ¶
func (x *MethodMatch_ParameterMatchSpecifier) HasRangeMatch() bool
func (*MethodMatch_ParameterMatchSpecifier) ProtoMessage ¶
func (*MethodMatch_ParameterMatchSpecifier) ProtoMessage()
func (*MethodMatch_ParameterMatchSpecifier) ProtoReflect ¶
func (x *MethodMatch_ParameterMatchSpecifier) ProtoReflect() protoreflect.Message
func (*MethodMatch_ParameterMatchSpecifier) Reset ¶
func (x *MethodMatch_ParameterMatchSpecifier) Reset()
func (*MethodMatch_ParameterMatchSpecifier) SetExactMatch ¶
func (x *MethodMatch_ParameterMatchSpecifier) SetExactMatch(v string)
func (*MethodMatch_ParameterMatchSpecifier) SetRangeMatch ¶
func (x *MethodMatch_ParameterMatchSpecifier) SetRangeMatch(v *_type.Int64Range)
func (*MethodMatch_ParameterMatchSpecifier) String ¶
func (x *MethodMatch_ParameterMatchSpecifier) String() string
func (*MethodMatch_ParameterMatchSpecifier) WhichParameterMatchSpecifier ¶
func (x *MethodMatch_ParameterMatchSpecifier) WhichParameterMatchSpecifier() case_MethodMatch_ParameterMatchSpecifier_ParameterMatchSpecifier
type MethodMatch_ParameterMatchSpecifier_ExactMatch ¶
type MethodMatch_ParameterMatchSpecifier_ExactMatch struct {
// If specified, header match will be performed based on the value of the header.
ExactMatch string `protobuf:"bytes,3,opt,name=exact_match,json=exactMatch,proto3,oneof"`
}
type MethodMatch_ParameterMatchSpecifier_RangeMatch ¶
type MethodMatch_ParameterMatchSpecifier_RangeMatch struct {
// If specified, header match will be performed based on range.
// The rule will match if the request header value is within this range.
// The entire request header value must represent an integer in base 10 notation: consisting
// of an optional plus or minus sign followed by a sequence of digits. The rule will not match
// if the header value does not represent an integer. Match will fail for empty values,
// floating point numbers or if only a subsequence of the header value is an integer.
//
// Examples:
//
// - For range [-10,0), route will match for header value -1, but not for 0,
// "somestring", 10.9, "-1somestring"
RangeMatch *_type.Int64Range `protobuf:"bytes,4,opt,name=range_match,json=rangeMatch,proto3,oneof"`
}
type MethodMatch_ParameterMatchSpecifier_builder ¶
type MethodMatch_ParameterMatchSpecifier_builder struct {
// Fields of oneof ParameterMatchSpecifier:
// If specified, header match will be performed based on the value of the header.
ExactMatch *string
// If specified, header match will be performed based on range.
// The rule will match if the request header value is within this range.
// The entire request header value must represent an integer in base 10 notation: consisting
// of an optional plus or minus sign followed by a sequence of digits. The rule will not match
// if the header value does not represent an integer. Match will fail for empty values,
// floating point numbers or if only a subsequence of the header value is an integer.
//
// Examples:
//
// - For range [-10,0), route will match for header value -1, but not for 0,
// "somestring", 10.9, "-1somestring"
RangeMatch *_type.Int64Range
// contains filtered or unexported fields
}
func (MethodMatch_ParameterMatchSpecifier_builder) Build ¶
func (b0 MethodMatch_ParameterMatchSpecifier_builder) Build() *MethodMatch_ParameterMatchSpecifier
type MethodMatch_builder ¶
type MethodMatch_builder struct {
// The name of the method.
Name *matcher.StringMatcher
// Method parameter definition.
// The key is the parameter index, starting from 0.
// The value is the parameter matching type.
ParamsMatch map[uint32]*MethodMatch_ParameterMatchSpecifier
// contains filtered or unexported fields
}
func (MethodMatch_builder) Build ¶
func (b0 MethodMatch_builder) Build() *MethodMatch
type ProtocolType ¶
type ProtocolType int32
Dubbo Protocol types supported by Envoy.
const ( // the default protocol. ProtocolType_Dubbo ProtocolType = 0 )
func (ProtocolType) Descriptor ¶
func (ProtocolType) Descriptor() protoreflect.EnumDescriptor
func (ProtocolType) Enum ¶
func (x ProtocolType) Enum() *ProtocolType
func (ProtocolType) Number ¶
func (x ProtocolType) Number() protoreflect.EnumNumber
func (ProtocolType) String ¶
func (x ProtocolType) String() string
func (ProtocolType) Type ¶
func (ProtocolType) Type() protoreflect.EnumType
type Route ¶
type Route struct {
// Route matching parameters.
Match *RouteMatch `protobuf:"bytes,1,opt,name=match,proto3" json:"match,omitempty"`
// Route request to some upstream cluster.
Route *RouteAction `protobuf:"bytes,2,opt,name=route,proto3" json:"route,omitempty"`
// contains filtered or unexported fields
}
func (*Route) GetMatch ¶
func (x *Route) GetMatch() *RouteMatch
func (*Route) GetRoute ¶
func (x *Route) GetRoute() *RouteAction
func (*Route) ProtoReflect ¶
func (x *Route) ProtoReflect() protoreflect.Message
func (*Route) SetMatch ¶
func (x *Route) SetMatch(v *RouteMatch)
func (*Route) SetRoute ¶
func (x *Route) SetRoute(v *RouteAction)
type RouteAction ¶
type RouteAction struct {
// Types that are valid to be assigned to ClusterSpecifier:
//
// *RouteAction_Cluster
// *RouteAction_WeightedClusters
ClusterSpecifier isRouteAction_ClusterSpecifier `protobuf_oneof:"cluster_specifier"`
// contains filtered or unexported fields
}
func (*RouteAction) ClearCluster ¶
func (x *RouteAction) ClearCluster()
func (*RouteAction) ClearClusterSpecifier ¶
func (x *RouteAction) ClearClusterSpecifier()
func (*RouteAction) ClearWeightedClusters ¶
func (x *RouteAction) ClearWeightedClusters()
func (*RouteAction) GetCluster ¶
func (x *RouteAction) GetCluster() string
func (*RouteAction) GetClusterSpecifier ¶
func (x *RouteAction) GetClusterSpecifier() isRouteAction_ClusterSpecifier
func (*RouteAction) GetWeightedClusters ¶
func (x *RouteAction) GetWeightedClusters() *route.WeightedCluster
func (*RouteAction) HasCluster ¶
func (x *RouteAction) HasCluster() bool
func (*RouteAction) HasClusterSpecifier ¶
func (x *RouteAction) HasClusterSpecifier() bool
func (*RouteAction) HasWeightedClusters ¶
func (x *RouteAction) HasWeightedClusters() bool
func (*RouteAction) ProtoMessage ¶
func (*RouteAction) ProtoMessage()
func (*RouteAction) ProtoReflect ¶
func (x *RouteAction) ProtoReflect() protoreflect.Message
func (*RouteAction) Reset ¶
func (x *RouteAction) Reset()
func (*RouteAction) SetCluster ¶
func (x *RouteAction) SetCluster(v string)
func (*RouteAction) SetWeightedClusters ¶
func (x *RouteAction) SetWeightedClusters(v *route.WeightedCluster)
func (*RouteAction) String ¶
func (x *RouteAction) String() string
func (*RouteAction) WhichClusterSpecifier ¶
func (x *RouteAction) WhichClusterSpecifier() case_RouteAction_ClusterSpecifier
type RouteAction_Cluster ¶
type RouteAction_Cluster struct {
// Indicates the upstream cluster to which the request should be routed.
Cluster string `protobuf:"bytes,1,opt,name=cluster,proto3,oneof"`
}
type RouteAction_WeightedClusters ¶
type RouteAction_WeightedClusters struct {
// Multiple upstream clusters can be specified for a given route. The
// request is routed to one of the upstream clusters based on weights
// assigned to each cluster.
// Currently ClusterWeight only supports the name and weight fields.
WeightedClusters *route.WeightedCluster `protobuf:"bytes,2,opt,name=weighted_clusters,json=weightedClusters,proto3,oneof"`
}
type RouteAction_builder ¶
type RouteAction_builder struct {
// Fields of oneof ClusterSpecifier:
// Indicates the upstream cluster to which the request should be routed.
Cluster *string
// Multiple upstream clusters can be specified for a given route. The
// request is routed to one of the upstream clusters based on weights
// assigned to each cluster.
// Currently ClusterWeight only supports the name and weight fields.
WeightedClusters *route.WeightedCluster
// contains filtered or unexported fields
}
func (RouteAction_builder) Build ¶
func (b0 RouteAction_builder) Build() *RouteAction
type RouteConfiguration ¶
type RouteConfiguration struct {
// The name of the route configuration. Reserved for future use in asynchronous route discovery.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// The interface name of the service.
Interface string `protobuf:"bytes,2,opt,name=interface,proto3" json:"interface,omitempty"`
// Which group does the interface belong to.
Group string `protobuf:"bytes,3,opt,name=group,proto3" json:"group,omitempty"`
// The version number of the interface.
Version string `protobuf:"bytes,4,opt,name=version,proto3" json:"version,omitempty"`
// The list of routes that will be matched, in order, against incoming requests. The first route
// that matches will be used.
Routes []*Route `protobuf:"bytes,5,rep,name=routes,proto3" json:"routes,omitempty"`
// contains filtered or unexported fields
}
[#next-free-field: 6]
func (*RouteConfiguration) GetGroup ¶
func (x *RouteConfiguration) GetGroup() string
func (*RouteConfiguration) GetInterface ¶
func (x *RouteConfiguration) GetInterface() string
func (*RouteConfiguration) GetName ¶
func (x *RouteConfiguration) GetName() string
func (*RouteConfiguration) GetRoutes ¶
func (x *RouteConfiguration) GetRoutes() []*Route
func (*RouteConfiguration) GetVersion ¶
func (x *RouteConfiguration) GetVersion() string
func (*RouteConfiguration) ProtoMessage ¶
func (*RouteConfiguration) ProtoMessage()
func (*RouteConfiguration) ProtoReflect ¶
func (x *RouteConfiguration) ProtoReflect() protoreflect.Message
func (*RouteConfiguration) Reset ¶
func (x *RouteConfiguration) Reset()
func (*RouteConfiguration) SetGroup ¶
func (x *RouteConfiguration) SetGroup(v string)
func (*RouteConfiguration) SetInterface ¶
func (x *RouteConfiguration) SetInterface(v string)
func (*RouteConfiguration) SetName ¶
func (x *RouteConfiguration) SetName(v string)
func (*RouteConfiguration) SetRoutes ¶
func (x *RouteConfiguration) SetRoutes(v []*Route)
func (*RouteConfiguration) SetVersion ¶
func (x *RouteConfiguration) SetVersion(v string)
func (*RouteConfiguration) String ¶
func (x *RouteConfiguration) String() string
type RouteConfiguration_builder ¶
type RouteConfiguration_builder struct {
// The name of the route configuration. Reserved for future use in asynchronous route discovery.
Name string
// The interface name of the service.
Interface string
// Which group does the interface belong to.
Group string
// The version number of the interface.
Version string
// The list of routes that will be matched, in order, against incoming requests. The first route
// that matches will be used.
Routes []*Route
// contains filtered or unexported fields
}
func (RouteConfiguration_builder) Build ¶
func (b0 RouteConfiguration_builder) Build() *RouteConfiguration
type RouteMatch ¶
type RouteMatch struct {
// Method level routing matching.
Method *MethodMatch `protobuf:"bytes,1,opt,name=method,proto3" json:"method,omitempty"`
// Specifies a set of headers that the route should match on. The router will check the request’s
// headers against all the specified headers in the route config. A match will happen if all the
// headers in the route are present in the request with the same values (or based on presence if
// the value field is not in the config).
Headers []*route.HeaderMatcher `protobuf:"bytes,2,rep,name=headers,proto3" json:"headers,omitempty"`
// contains filtered or unexported fields
}
func (*RouteMatch) ClearMethod ¶
func (x *RouteMatch) ClearMethod()
func (*RouteMatch) GetHeaders ¶
func (x *RouteMatch) GetHeaders() []*route.HeaderMatcher
func (*RouteMatch) GetMethod ¶
func (x *RouteMatch) GetMethod() *MethodMatch
func (*RouteMatch) HasMethod ¶
func (x *RouteMatch) HasMethod() bool
func (*RouteMatch) ProtoMessage ¶
func (*RouteMatch) ProtoMessage()
func (*RouteMatch) ProtoReflect ¶
func (x *RouteMatch) ProtoReflect() protoreflect.Message
func (*RouteMatch) Reset ¶
func (x *RouteMatch) Reset()
func (*RouteMatch) SetHeaders ¶
func (x *RouteMatch) SetHeaders(v []*route.HeaderMatcher)
func (*RouteMatch) SetMethod ¶
func (x *RouteMatch) SetMethod(v *MethodMatch)
func (*RouteMatch) String ¶
func (x *RouteMatch) String() string
type RouteMatch_builder ¶
type RouteMatch_builder struct {
// Method level routing matching.
Method *MethodMatch
// Specifies a set of headers that the route should match on. The router will check the request’s
// headers against all the specified headers in the route config. A match will happen if all the
// headers in the route are present in the request with the same values (or based on presence if
// the value field is not in the config).
Headers []*route.HeaderMatcher
// contains filtered or unexported fields
}
func (RouteMatch_builder) Build ¶
func (b0 RouteMatch_builder) Build() *RouteMatch
type Route_builder ¶
type Route_builder struct {
// Route matching parameters.
Match *RouteMatch
// Route request to some upstream cluster.
Route *RouteAction
// contains filtered or unexported fields
}
func (Route_builder) Build ¶
func (b0 Route_builder) Build() *Route
type SerializationType ¶
type SerializationType int32
Dubbo Serialization types supported by Envoy.
const ( // the default serialization protocol. SerializationType_Hessian2 SerializationType = 0 )
func (SerializationType) Descriptor ¶
func (SerializationType) Descriptor() protoreflect.EnumDescriptor
func (SerializationType) Enum ¶
func (x SerializationType) Enum() *SerializationType
func (SerializationType) Number ¶
func (x SerializationType) Number() protoreflect.EnumNumber
func (SerializationType) String ¶
func (x SerializationType) String() string
func (SerializationType) Type ¶
func (SerializationType) Type() protoreflect.EnumType
Source Files
¶
- dubbo_proxy.pb.go
- route.pb.go
Click to show internal directories.
Click to hide internal directories.