Documentation
¶
Index ¶
- Constants
- Variables
- type FilterStateValue
- func (x *FilterStateValue) ClearFormatString()
- func (x *FilterStateValue) ClearKey()
- func (x *FilterStateValue) ClearObjectKey()
- func (x *FilterStateValue) ClearValue()
- func (x *FilterStateValue) GetFactoryKey() string
- func (x *FilterStateValue) GetFormatString() *v3.SubstitutionFormatString
- func (x *FilterStateValue) GetKey() isFilterStateValue_Key
- func (x *FilterStateValue) GetObjectKey() string
- func (x *FilterStateValue) GetReadOnly() bool
- func (x *FilterStateValue) GetSharedWithUpstream() FilterStateValue_SharedWithUpstream
- func (x *FilterStateValue) GetSkipIfEmpty() bool
- func (x *FilterStateValue) GetValue() isFilterStateValue_Value
- func (x *FilterStateValue) HasFormatString() bool
- func (x *FilterStateValue) HasKey() bool
- func (x *FilterStateValue) HasObjectKey() bool
- func (x *FilterStateValue) HasValue() bool
- func (*FilterStateValue) ProtoMessage()
- func (x *FilterStateValue) ProtoReflect() protoreflect.Message
- func (x *FilterStateValue) Reset()
- func (x *FilterStateValue) SetFactoryKey(v string)
- func (x *FilterStateValue) SetFormatString(v *v3.SubstitutionFormatString)
- func (x *FilterStateValue) SetObjectKey(v string)
- func (x *FilterStateValue) SetReadOnly(v bool)
- func (x *FilterStateValue) SetSharedWithUpstream(v FilterStateValue_SharedWithUpstream)
- func (x *FilterStateValue) SetSkipIfEmpty(v bool)
- func (x *FilterStateValue) String() string
- func (x *FilterStateValue) WhichKey() case_FilterStateValue_Key
- func (x *FilterStateValue) WhichValue() case_FilterStateValue_Value
- type FilterStateValue_FormatString
- type FilterStateValue_ObjectKey
- type FilterStateValue_SharedWithUpstream
- func (FilterStateValue_SharedWithUpstream) Descriptor() protoreflect.EnumDescriptor
- func (x FilterStateValue_SharedWithUpstream) Enum() *FilterStateValue_SharedWithUpstream
- func (x FilterStateValue_SharedWithUpstream) Number() protoreflect.EnumNumber
- func (x FilterStateValue_SharedWithUpstream) String() string
- func (FilterStateValue_SharedWithUpstream) Type() protoreflect.EnumType
- type FilterStateValue_builder
Constants ¶
const FilterStateValue_FormatString_case case_FilterStateValue_Value = 2
const FilterStateValue_Key_not_set_case case_FilterStateValue_Key = 0
const FilterStateValue_ObjectKey_case case_FilterStateValue_Key = 1
const FilterStateValue_Value_not_set_case case_FilterStateValue_Value = 0
Variables ¶
var ( 0: "NONE", 1: "ONCE", 2: "TRANSITIVE", } "NONE": 0, "ONCE": 1, "TRANSITIVE": 2, } )
Enum value maps for FilterStateValue_SharedWithUpstream.
var File_envoy_extensions_filters_common_set_filter_state_v3_value_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type FilterStateValue ¶
type FilterStateValue struct {
// Types that are valid to be assigned to Key:
//
// *FilterStateValue_ObjectKey
Key isFilterStateValue_Key `protobuf_oneof:"key"`
// Specifies which registered factory should be used to create the filter state object from the
// provided value. This field is required when :ref:`object_key
// <envoy_v3_api_field_extensions.filters.common.set_filter_state.v3.FilterStateValue.object_key>`
// is a custom name not found in the :ref:`well-known filter state keys <well_known_filter_state>`.
//
// Each well-known key has a factory registered with the same name (e.g., the key
// “envoy.tcp_proxy.cluster“ has a factory also named “envoy.tcp_proxy.cluster“). For custom keys,
// use one of the following generic factories:
//
// - “envoy.string“: Creates a generic string object. Use this for arbitrary string values that
// will be accessed via “StringAccessor“.
//
// If not specified, defaults to the value of “object_key“.
FactoryKey string `protobuf:"bytes,6,opt,name=factory_key,json=factoryKey,proto3" json:"factory_key,omitempty"`
// Types that are valid to be assigned to Value:
//
// *FilterStateValue_FormatString
Value isFilterStateValue_Value `protobuf_oneof:"value"`
// If marked as read-only, the filter state key value is locked, and cannot
// be overridden by any filter, including this filter.
ReadOnly bool `protobuf:"varint,3,opt,name=read_only,json=readOnly,proto3" json:"read_only,omitempty"`
// transport <config_internal_upstream_transport>` for more details on the filter state sharing with
// the internal connections.
SharedWithUpstream FilterStateValue_SharedWithUpstream `` /* 211-byte string literal not displayed */
// Skip the update if the value evaluates to an empty string.
// This option can be used to supply multiple alternatives for the same filter state object key.
SkipIfEmpty bool `protobuf:"varint,5,opt,name=skip_if_empty,json=skipIfEmpty,proto3" json:"skip_if_empty,omitempty"`
// contains filtered or unexported fields
}
A filter state key and value pair. [#next-free-field: 7]
func (*FilterStateValue) ClearFormatString ¶
func (x *FilterStateValue) ClearFormatString()
func (*FilterStateValue) ClearKey ¶
func (x *FilterStateValue) ClearKey()
func (*FilterStateValue) ClearObjectKey ¶
func (x *FilterStateValue) ClearObjectKey()
func (*FilterStateValue) ClearValue ¶
func (x *FilterStateValue) ClearValue()
func (*FilterStateValue) GetFactoryKey ¶
func (x *FilterStateValue) GetFactoryKey() string
func (*FilterStateValue) GetFormatString ¶
func (x *FilterStateValue) GetFormatString() *v3.SubstitutionFormatString
func (*FilterStateValue) GetKey ¶
func (x *FilterStateValue) GetKey() isFilterStateValue_Key
func (*FilterStateValue) GetObjectKey ¶
func (x *FilterStateValue) GetObjectKey() string
func (*FilterStateValue) GetReadOnly ¶
func (x *FilterStateValue) GetReadOnly() bool
func (*FilterStateValue) GetSharedWithUpstream ¶
func (x *FilterStateValue) GetSharedWithUpstream() FilterStateValue_SharedWithUpstream
func (*FilterStateValue) GetSkipIfEmpty ¶
func (x *FilterStateValue) GetSkipIfEmpty() bool
func (*FilterStateValue) GetValue ¶
func (x *FilterStateValue) GetValue() isFilterStateValue_Value
func (*FilterStateValue) HasFormatString ¶
func (x *FilterStateValue) HasFormatString() bool
func (*FilterStateValue) HasKey ¶
func (x *FilterStateValue) HasKey() bool
func (*FilterStateValue) HasObjectKey ¶
func (x *FilterStateValue) HasObjectKey() bool
func (*FilterStateValue) HasValue ¶
func (x *FilterStateValue) HasValue() bool
func (*FilterStateValue) ProtoMessage ¶
func (*FilterStateValue) ProtoMessage()
func (*FilterStateValue) ProtoReflect ¶
func (x *FilterStateValue) ProtoReflect() protoreflect.Message
func (*FilterStateValue) Reset ¶
func (x *FilterStateValue) Reset()
func (*FilterStateValue) SetFactoryKey ¶
func (x *FilterStateValue) SetFactoryKey(v string)
func (*FilterStateValue) SetFormatString ¶
func (x *FilterStateValue) SetFormatString(v *v3.SubstitutionFormatString)
func (*FilterStateValue) SetObjectKey ¶
func (x *FilterStateValue) SetObjectKey(v string)
func (*FilterStateValue) SetReadOnly ¶
func (x *FilterStateValue) SetReadOnly(v bool)
func (*FilterStateValue) SetSharedWithUpstream ¶
func (x *FilterStateValue) SetSharedWithUpstream(v FilterStateValue_SharedWithUpstream)
func (*FilterStateValue) SetSkipIfEmpty ¶
func (x *FilterStateValue) SetSkipIfEmpty(v bool)
func (*FilterStateValue) String ¶
func (x *FilterStateValue) String() string
func (*FilterStateValue) WhichKey ¶
func (x *FilterStateValue) WhichKey() case_FilterStateValue_Key
func (*FilterStateValue) WhichValue ¶
func (x *FilterStateValue) WhichValue() case_FilterStateValue_Value
type FilterStateValue_FormatString ¶
type FilterStateValue_FormatString struct {
// Uses the :ref:`format string <config_access_log_format_strings>` to
// instantiate the filter state object value.
FormatString *v3.SubstitutionFormatString `protobuf:"bytes,2,opt,name=format_string,json=formatString,proto3,oneof"`
}
type FilterStateValue_ObjectKey ¶
type FilterStateValue_ObjectKey struct {
// The name under which the filter state object will be stored and can be retrieved.
//
// When using :ref:`well-known filter state keys <well_known_filter_state>` (e.g.,
// “envoy.network.upstream_server_name“, “envoy.tcp_proxy.cluster“), the object key serves
// dual purpose where it identifies both where the data is stored and which factory creates the
// object. In this case, :ref:`factory_key
// <envoy_v3_api_field_extensions.filters.common.set_filter_state.v3.FilterStateValue.factory_key>`
// is not needed.
//
// When using a custom key name which is not from the well-known list, you must also specify
// :ref:`factory_key
// <envoy_v3_api_field_extensions.filters.common.set_filter_state.v3.FilterStateValue.factory_key>`
// to indicate which factory should create the object from your value.
//
// Example using a well-known key where “factory_key“ is not needed:
//
// .. code-block:: yaml
//
// object_key: envoy.tcp_proxy.cluster
// format_string:
// text_format_source:
// inline_string: "my-cluster"
//
// Example using a custom key which requires a “factory_key“:
//
// .. code-block:: yaml
//
// object_key: my.custom.key
// factory_key: envoy.string
// format_string:
// text_format_source:
// inline_string: "my-value"
ObjectKey string `protobuf:"bytes,1,opt,name=object_key,json=objectKey,proto3,oneof"`
}
type FilterStateValue_SharedWithUpstream ¶
type FilterStateValue_SharedWithUpstream int32
const ( // Object is not shared with the upstream internal connections. FilterStateValue_NONE FilterStateValue_SharedWithUpstream = 0 // Object is shared with the upstream internal connection. FilterStateValue_ONCE FilterStateValue_SharedWithUpstream = 1 // Object is shared with the upstream internal connection and any internal connection upstream from it. FilterStateValue_TRANSITIVE FilterStateValue_SharedWithUpstream = 2 )
func (FilterStateValue_SharedWithUpstream) Descriptor ¶
func (FilterStateValue_SharedWithUpstream) Descriptor() protoreflect.EnumDescriptor
func (FilterStateValue_SharedWithUpstream) Enum ¶
func (x FilterStateValue_SharedWithUpstream) Enum() *FilterStateValue_SharedWithUpstream
func (FilterStateValue_SharedWithUpstream) Number ¶
func (x FilterStateValue_SharedWithUpstream) Number() protoreflect.EnumNumber
func (FilterStateValue_SharedWithUpstream) String ¶
func (x FilterStateValue_SharedWithUpstream) String() string
func (FilterStateValue_SharedWithUpstream) Type ¶
func (FilterStateValue_SharedWithUpstream) Type() protoreflect.EnumType
type FilterStateValue_builder ¶
type FilterStateValue_builder struct {
// Fields of oneof Key:
// The name under which the filter state object will be stored and can be retrieved.
//
// When using :ref:`well-known filter state keys <well_known_filter_state>` (e.g.,
// “envoy.network.upstream_server_name“, “envoy.tcp_proxy.cluster“), the object key serves
// dual purpose where it identifies both where the data is stored and which factory creates the
// object. In this case, :ref:`factory_key
// <envoy_v3_api_field_extensions.filters.common.set_filter_state.v3.FilterStateValue.factory_key>`
// is not needed.
//
// When using a custom key name which is not from the well-known list, you must also specify
// :ref:`factory_key
// <envoy_v3_api_field_extensions.filters.common.set_filter_state.v3.FilterStateValue.factory_key>`
// to indicate which factory should create the object from your value.
//
// Example using a well-known key where “factory_key“ is not needed:
//
// .. code-block:: yaml
//
// object_key: envoy.tcp_proxy.cluster
// format_string:
// text_format_source:
// inline_string: "my-cluster"
//
// Example using a custom key which requires a “factory_key“:
//
// .. code-block:: yaml
//
// object_key: my.custom.key
// factory_key: envoy.string
// format_string:
// text_format_source:
// inline_string: "my-value"
ObjectKey *string
// -- end of Key
// Specifies which registered factory should be used to create the filter state object from the
// provided value. This field is required when :ref:`object_key
// <envoy_v3_api_field_extensions.filters.common.set_filter_state.v3.FilterStateValue.object_key>`
// is a custom name not found in the :ref:`well-known filter state keys <well_known_filter_state>`.
//
// Each well-known key has a factory registered with the same name (e.g., the key
// “envoy.tcp_proxy.cluster“ has a factory also named “envoy.tcp_proxy.cluster“). For custom keys,
// use one of the following generic factories:
//
// - “envoy.string“: Creates a generic string object. Use this for arbitrary string values that
// will be accessed via “StringAccessor“.
//
// If not specified, defaults to the value of “object_key“.
FactoryKey string
// Fields of oneof Value:
// Uses the :ref:`format string <config_access_log_format_strings>` to
// instantiate the filter state object value.
FormatString *v3.SubstitutionFormatString
// -- end of Value
// If marked as read-only, the filter state key value is locked, and cannot
// be overridden by any filter, including this filter.
ReadOnly bool
// transport <config_internal_upstream_transport>` for more details on the filter state sharing with
// the internal connections.
SharedWithUpstream FilterStateValue_SharedWithUpstream
// Skip the update if the value evaluates to an empty string.
// This option can be used to supply multiple alternatives for the same filter state object key.
SkipIfEmpty bool
// contains filtered or unexported fields
}
func (FilterStateValue_builder) Build ¶
func (b0 FilterStateValue_builder) Build() *FilterStateValue
Source Files
¶
- value.pb.go
Click to show internal directories.
Click to hide internal directories.