Documentation
¶
Index ¶
- Variables
- type BasicAuth
- func (x *BasicAuth) ClearUsers()
- func (x *BasicAuth) GetAuthenticationHeader() string
- func (x *BasicAuth) GetForwardUsernameHeader() string
- func (x *BasicAuth) GetUsers() *v3.DataSource
- func (x *BasicAuth) HasUsers() bool
- func (*BasicAuth) ProtoMessage()
- func (x *BasicAuth) ProtoReflect() protoreflect.Message
- func (x *BasicAuth) Reset()
- func (x *BasicAuth) SetAuthenticationHeader(v string)
- func (x *BasicAuth) SetForwardUsernameHeader(v string)
- func (x *BasicAuth) SetUsers(v *v3.DataSource)
- func (x *BasicAuth) String() string
- type BasicAuthPerRoute
- func (x *BasicAuthPerRoute) ClearUsers()
- func (x *BasicAuthPerRoute) GetUsers() *v3.DataSource
- func (x *BasicAuthPerRoute) HasUsers() bool
- func (*BasicAuthPerRoute) ProtoMessage()
- func (x *BasicAuthPerRoute) ProtoReflect() protoreflect.Message
- func (x *BasicAuthPerRoute) Reset()
- func (x *BasicAuthPerRoute) SetUsers(v *v3.DataSource)
- func (x *BasicAuthPerRoute) String() string
- type BasicAuthPerRoute_builder
- type BasicAuth_builder
Constants ¶
This section is empty.
Variables ¶
var File_envoy_extensions_filters_http_basic_auth_v3_basic_auth_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type BasicAuth ¶
type BasicAuth struct {
// Username-password pairs used to verify user credentials in the "Authorization" header.
// The value needs to be the htpasswd format.
// Reference to https://httpd.apache.org/docs/2.4/programs/htpasswd.html
Users *v3.DataSource `protobuf:"bytes,1,opt,name=users,proto3" json:"users,omitempty"`
// This field specifies the header name to forward a successfully authenticated user to
// the backend. The header will be added to the request with the username as the value.
//
// If it is not specified, the username will not be forwarded.
ForwardUsernameHeader string `` /* 126-byte string literal not displayed */
// This field specifies the request header to load the basic credential from.
//
// If it is not specified, the filter loads the credential from the "Authorization" header.
AuthenticationHeader string `protobuf:"bytes,3,opt,name=authentication_header,json=authenticationHeader,proto3" json:"authentication_header,omitempty"`
// contains filtered or unexported fields
}
Basic HTTP authentication.
Example:
.. code-block:: yaml
users:
inline_string: |-
user1:{SHA}hashed_user1_password
user2:{SHA}hashed_user2_password
func (*BasicAuth) GetUsers ¶
func (x *BasicAuth) GetUsers() *v3.DataSource
func (*BasicAuth) ProtoReflect ¶
func (x *BasicAuth) ProtoReflect() protoreflect.Message
func (*BasicAuth) SetUsers ¶
func (x *BasicAuth) SetUsers(v *v3.DataSource)
type BasicAuthPerRoute ¶
type BasicAuthPerRoute struct {
// Username-password pairs for this route.
Users *v3.DataSource `protobuf:"bytes,1,opt,name=users,proto3" json:"users,omitempty"`
// contains filtered or unexported fields
}
Extra settings that may be added to per-route configuration for a virtual host or a cluster.
func (*BasicAuthPerRoute) ClearUsers ¶
func (x *BasicAuthPerRoute) ClearUsers()
func (*BasicAuthPerRoute) GetUsers ¶
func (x *BasicAuthPerRoute) GetUsers() *v3.DataSource
func (*BasicAuthPerRoute) HasUsers ¶
func (x *BasicAuthPerRoute) HasUsers() bool
func (*BasicAuthPerRoute) ProtoMessage ¶
func (*BasicAuthPerRoute) ProtoMessage()
func (*BasicAuthPerRoute) ProtoReflect ¶
func (x *BasicAuthPerRoute) ProtoReflect() protoreflect.Message
func (*BasicAuthPerRoute) Reset ¶
func (x *BasicAuthPerRoute) Reset()
func (*BasicAuthPerRoute) SetUsers ¶
func (x *BasicAuthPerRoute) SetUsers(v *v3.DataSource)
func (*BasicAuthPerRoute) String ¶
func (x *BasicAuthPerRoute) String() string
type BasicAuthPerRoute_builder ¶
type BasicAuthPerRoute_builder struct {
// Username-password pairs for this route.
Users *v3.DataSource
// contains filtered or unexported fields
}
func (BasicAuthPerRoute_builder) Build ¶
func (b0 BasicAuthPerRoute_builder) Build() *BasicAuthPerRoute
type BasicAuth_builder ¶
type BasicAuth_builder struct {
// Username-password pairs used to verify user credentials in the "Authorization" header.
// The value needs to be the htpasswd format.
// Reference to https://httpd.apache.org/docs/2.4/programs/htpasswd.html
Users *v3.DataSource
// This field specifies the header name to forward a successfully authenticated user to
// the backend. The header will be added to the request with the username as the value.
//
// If it is not specified, the username will not be forwarded.
ForwardUsernameHeader string
// This field specifies the request header to load the basic credential from.
//
// If it is not specified, the filter loads the credential from the "Authorization" header.
AuthenticationHeader string
// contains filtered or unexported fields
}
func (BasicAuth_builder) Build ¶
func (b0 BasicAuth_builder) Build() *BasicAuth
Source Files
¶
- basic_auth.pb.go
Click to show internal directories.
Click to hide internal directories.