Documentation
¶
Index ¶
- Variables
- type Geoip
- func (x *Geoip) ClearCustomHeaderConfig()
- func (x *Geoip) ClearProvider()
- func (x *Geoip) ClearXffConfig()
- func (x *Geoip) GetCustomHeaderConfig() *Geoip_CustomHeaderConfig
- func (x *Geoip) GetProvider() *v3.TypedExtensionConfig
- func (x *Geoip) GetXffConfig() *Geoip_XffConfig
- func (x *Geoip) HasCustomHeaderConfig() bool
- func (x *Geoip) HasProvider() bool
- func (x *Geoip) HasXffConfig() bool
- func (*Geoip) ProtoMessage()
- func (x *Geoip) ProtoReflect() protoreflect.Message
- func (x *Geoip) Reset()
- func (x *Geoip) SetCustomHeaderConfig(v *Geoip_CustomHeaderConfig)
- func (x *Geoip) SetProvider(v *v3.TypedExtensionConfig)
- func (x *Geoip) SetXffConfig(v *Geoip_XffConfig)
- func (x *Geoip) String() string
- type Geoip_CustomHeaderConfig
- func (x *Geoip_CustomHeaderConfig) GetHeaderName() string
- func (*Geoip_CustomHeaderConfig) ProtoMessage()
- func (x *Geoip_CustomHeaderConfig) ProtoReflect() protoreflect.Message
- func (x *Geoip_CustomHeaderConfig) Reset()
- func (x *Geoip_CustomHeaderConfig) SetHeaderName(v string)
- func (x *Geoip_CustomHeaderConfig) String() string
- type Geoip_CustomHeaderConfig_builder
- type Geoip_XffConfig
- type Geoip_XffConfig_builder
- type Geoip_builder
Constants ¶
This section is empty.
Variables ¶
var File_envoy_extensions_filters_http_geoip_v3_geoip_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Geoip ¶
type Geoip struct {
// Configuration for extracting the client IP address from the
// “x-forwarded-for“ header. If set, the
// :ref:`xff_num_trusted_hops <envoy_v3_api_field_extensions.filters.http.geoip.v3.Geoip.XffConfig.xff_num_trusted_hops>`
// field will be used to determine the trusted client address from the “x-forwarded-for“ header.
// If not set, the immediate downstream connection source address will be used.
//
// Only one of “xff_config“ or
// :ref:`custom_header_config <envoy_v3_api_field_extensions.filters.http.geoip.v3.Geoip.custom_header_config>`
// can be set.
XffConfig *Geoip_XffConfig `protobuf:"bytes,1,opt,name=xff_config,json=xffConfig,proto3" json:"xff_config,omitempty"`
// Configuration for extracting the client IP address from a custom request header.
//
// If set, the
// :ref:`header_name <envoy_v3_api_field_extensions.filters.http.geoip.v3.Geoip.CustomHeaderConfig.header_name>`
// field will be used to extract the client IP address from the specified request header.
//
// Only one of “custom_header_config“ or
// :ref:`xff_config <envoy_v3_api_field_extensions.filters.http.geoip.v3.Geoip.xff_config>`
// can be set.
CustomHeaderConfig *Geoip_CustomHeaderConfig `protobuf:"bytes,4,opt,name=custom_header_config,json=customHeaderConfig,proto3" json:"custom_header_config,omitempty"`
// Geoip driver specific configuration which depends on the driver being instantiated.
// See the geoip drivers for examples:
//
// - :ref:`MaxMindConfig <envoy_v3_api_msg_extensions.geoip_providers.maxmind.v3.MaxMindConfig>`
// [#extension-category: envoy.geoip_providers]
Provider *v3.TypedExtensionConfig `protobuf:"bytes,3,opt,name=provider,proto3" json:"provider,omitempty"`
// contains filtered or unexported fields
}
func (*Geoip) GetCustomHeaderConfig ¶
func (x *Geoip) GetCustomHeaderConfig() *Geoip_CustomHeaderConfig
func (*Geoip) GetProvider ¶
func (x *Geoip) GetProvider() *v3.TypedExtensionConfig
func (*Geoip) GetXffConfig ¶
func (x *Geoip) GetXffConfig() *Geoip_XffConfig
func (*Geoip) ProtoReflect ¶
func (x *Geoip) ProtoReflect() protoreflect.Message
func (*Geoip) SetCustomHeaderConfig ¶
func (x *Geoip) SetCustomHeaderConfig(v *Geoip_CustomHeaderConfig)
func (*Geoip) SetProvider ¶
func (x *Geoip) SetProvider(v *v3.TypedExtensionConfig)
func (*Geoip) SetXffConfig ¶
func (x *Geoip) SetXffConfig(v *Geoip_XffConfig)
type Geoip_CustomHeaderConfig ¶
type Geoip_CustomHeaderConfig struct {
// The name of the request header to extract the client IP address from.
// The header value must contain a valid IP address (IPv4 or IPv6).
//
// If the header is missing or contains an invalid IP address, the filter will fall back
// to using the immediate downstream connection source address.
HeaderName string `protobuf:"bytes,1,opt,name=header_name,json=headerName,proto3" json:"header_name,omitempty"`
// contains filtered or unexported fields
}
func (*Geoip_CustomHeaderConfig) GetHeaderName ¶
func (x *Geoip_CustomHeaderConfig) GetHeaderName() string
func (*Geoip_CustomHeaderConfig) ProtoMessage ¶
func (*Geoip_CustomHeaderConfig) ProtoMessage()
func (*Geoip_CustomHeaderConfig) ProtoReflect ¶
func (x *Geoip_CustomHeaderConfig) ProtoReflect() protoreflect.Message
func (*Geoip_CustomHeaderConfig) Reset ¶
func (x *Geoip_CustomHeaderConfig) Reset()
func (*Geoip_CustomHeaderConfig) SetHeaderName ¶
func (x *Geoip_CustomHeaderConfig) SetHeaderName(v string)
func (*Geoip_CustomHeaderConfig) String ¶
func (x *Geoip_CustomHeaderConfig) String() string
type Geoip_CustomHeaderConfig_builder ¶
type Geoip_CustomHeaderConfig_builder struct {
// The name of the request header to extract the client IP address from.
// The header value must contain a valid IP address (IPv4 or IPv6).
//
// If the header is missing or contains an invalid IP address, the filter will fall back
// to using the immediate downstream connection source address.
HeaderName string
// contains filtered or unexported fields
}
func (Geoip_CustomHeaderConfig_builder) Build ¶
func (b0 Geoip_CustomHeaderConfig_builder) Build() *Geoip_CustomHeaderConfig
type Geoip_XffConfig ¶
type Geoip_XffConfig struct {
// The number of additional ingress proxy hops from the right side of the
// :ref:`config_http_conn_man_headers_x-forwarded-for` HTTP header to trust when
// determining the origin client's IP address. See the documentation for
// :ref:`config_http_conn_man_headers_x-forwarded-for` for more information.
//
// Defaults to “0“.
XffNumTrustedHops uint32 `protobuf:"varint,1,opt,name=xff_num_trusted_hops,json=xffNumTrustedHops,proto3" json:"xff_num_trusted_hops,omitempty"`
// contains filtered or unexported fields
}
func (*Geoip_XffConfig) GetXffNumTrustedHops ¶
func (x *Geoip_XffConfig) GetXffNumTrustedHops() uint32
func (*Geoip_XffConfig) ProtoMessage ¶
func (*Geoip_XffConfig) ProtoMessage()
func (*Geoip_XffConfig) ProtoReflect ¶
func (x *Geoip_XffConfig) ProtoReflect() protoreflect.Message
func (*Geoip_XffConfig) Reset ¶
func (x *Geoip_XffConfig) Reset()
func (*Geoip_XffConfig) SetXffNumTrustedHops ¶
func (x *Geoip_XffConfig) SetXffNumTrustedHops(v uint32)
func (*Geoip_XffConfig) String ¶
func (x *Geoip_XffConfig) String() string
type Geoip_XffConfig_builder ¶
type Geoip_XffConfig_builder struct {
// The number of additional ingress proxy hops from the right side of the
// :ref:`config_http_conn_man_headers_x-forwarded-for` HTTP header to trust when
// determining the origin client's IP address. See the documentation for
// :ref:`config_http_conn_man_headers_x-forwarded-for` for more information.
//
// Defaults to “0“.
XffNumTrustedHops uint32
// contains filtered or unexported fields
}
func (Geoip_XffConfig_builder) Build ¶
func (b0 Geoip_XffConfig_builder) Build() *Geoip_XffConfig
type Geoip_builder ¶
type Geoip_builder struct {
// Configuration for extracting the client IP address from the
// “x-forwarded-for“ header. If set, the
// :ref:`xff_num_trusted_hops <envoy_v3_api_field_extensions.filters.http.geoip.v3.Geoip.XffConfig.xff_num_trusted_hops>`
// field will be used to determine the trusted client address from the “x-forwarded-for“ header.
// If not set, the immediate downstream connection source address will be used.
//
// Only one of “xff_config“ or
// :ref:`custom_header_config <envoy_v3_api_field_extensions.filters.http.geoip.v3.Geoip.custom_header_config>`
// can be set.
XffConfig *Geoip_XffConfig
// Configuration for extracting the client IP address from a custom request header.
//
// If set, the
// :ref:`header_name <envoy_v3_api_field_extensions.filters.http.geoip.v3.Geoip.CustomHeaderConfig.header_name>`
// field will be used to extract the client IP address from the specified request header.
//
// Only one of “custom_header_config“ or
// :ref:`xff_config <envoy_v3_api_field_extensions.filters.http.geoip.v3.Geoip.xff_config>`
// can be set.
CustomHeaderConfig *Geoip_CustomHeaderConfig
// Geoip driver specific configuration which depends on the driver being instantiated.
// See the geoip drivers for examples:
//
// - :ref:`MaxMindConfig <envoy_v3_api_msg_extensions.geoip_providers.maxmind.v3.MaxMindConfig>`
// [#extension-category: envoy.geoip_providers]
Provider *v3.TypedExtensionConfig
// contains filtered or unexported fields
}
func (Geoip_builder) Build ¶
func (b0 Geoip_builder) Build() *Geoip
Source Files
¶
- geoip.pb.go
Click to show internal directories.
Click to hide internal directories.