Documentation
¶
Index ¶
- Variables
- type OnDemand
- func (x *OnDemand) ClearOdcds()
- func (x *OnDemand) GetOdcds() *OnDemandCds
- func (x *OnDemand) HasOdcds() bool
- func (*OnDemand) ProtoMessage()
- func (x *OnDemand) ProtoReflect() protoreflect.Message
- func (x *OnDemand) Reset()
- func (x *OnDemand) SetOdcds(v *OnDemandCds)
- func (x *OnDemand) String() string
- type OnDemandCds
- func (x *OnDemandCds) ClearSource()
- func (x *OnDemandCds) ClearTimeout()
- func (x *OnDemandCds) GetResourcesLocator() string
- func (x *OnDemandCds) GetSource() *v3.ConfigSource
- func (x *OnDemandCds) GetTimeout() *durationpb.Duration
- func (x *OnDemandCds) HasSource() bool
- func (x *OnDemandCds) HasTimeout() bool
- func (*OnDemandCds) ProtoMessage()
- func (x *OnDemandCds) ProtoReflect() protoreflect.Message
- func (x *OnDemandCds) Reset()
- func (x *OnDemandCds) SetResourcesLocator(v string)
- func (x *OnDemandCds) SetSource(v *v3.ConfigSource)
- func (x *OnDemandCds) SetTimeout(v *durationpb.Duration)
- func (x *OnDemandCds) String() string
- type OnDemandCds_builder
- type OnDemand_builder
- type PerRouteConfig
- func (x *PerRouteConfig) ClearOdcds()
- func (x *PerRouteConfig) GetOdcds() *OnDemandCds
- func (x *PerRouteConfig) HasOdcds() bool
- func (*PerRouteConfig) ProtoMessage()
- func (x *PerRouteConfig) ProtoReflect() protoreflect.Message
- func (x *PerRouteConfig) Reset()
- func (x *PerRouteConfig) SetOdcds(v *OnDemandCds)
- func (x *PerRouteConfig) String() string
- type PerRouteConfig_builder
Constants ¶
This section is empty.
Variables ¶
var File_envoy_extensions_filters_http_on_demand_v3_on_demand_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type OnDemand ¶
type OnDemand struct {
// An optional configuration for on-demand cluster discovery
// service. If not specified, the on-demand cluster discovery will
// be disabled. When it's specified, the filter will pause the
// request to an unknown cluster and will begin a cluster discovery
// process. When the discovery is finished (successfully or not), the
// request will be resumed for further processing.
Odcds *OnDemandCds `protobuf:"bytes,1,opt,name=odcds,proto3" json:"odcds,omitempty"`
// contains filtered or unexported fields
}
On Demand Discovery filter config.
func (*OnDemand) GetOdcds ¶
func (x *OnDemand) GetOdcds() *OnDemandCds
func (*OnDemand) ProtoReflect ¶
func (x *OnDemand) ProtoReflect() protoreflect.Message
func (*OnDemand) SetOdcds ¶
func (x *OnDemand) SetOdcds(v *OnDemandCds)
type OnDemandCds ¶
type OnDemandCds struct {
// A configuration source for the service that will be used for
// on-demand cluster discovery.
Source *v3.ConfigSource `protobuf:"bytes,1,opt,name=source,proto3" json:"source,omitempty"`
// xdstp:// resource locator for on-demand cluster collection.
ResourcesLocator string `protobuf:"bytes,2,opt,name=resources_locator,json=resourcesLocator,proto3" json:"resources_locator,omitempty"`
// The timeout for on demand cluster lookup. If not set, defaults to 5 seconds.
Timeout *durationpb.Duration `protobuf:"bytes,3,opt,name=timeout,proto3" json:"timeout,omitempty"`
// contains filtered or unexported fields
}
Configuration of on-demand CDS.
func (*OnDemandCds) ClearSource ¶
func (x *OnDemandCds) ClearSource()
func (*OnDemandCds) ClearTimeout ¶
func (x *OnDemandCds) ClearTimeout()
func (*OnDemandCds) GetResourcesLocator ¶
func (x *OnDemandCds) GetResourcesLocator() string
func (*OnDemandCds) GetSource ¶
func (x *OnDemandCds) GetSource() *v3.ConfigSource
func (*OnDemandCds) GetTimeout ¶
func (x *OnDemandCds) GetTimeout() *durationpb.Duration
func (*OnDemandCds) HasSource ¶
func (x *OnDemandCds) HasSource() bool
func (*OnDemandCds) HasTimeout ¶
func (x *OnDemandCds) HasTimeout() bool
func (*OnDemandCds) ProtoMessage ¶
func (*OnDemandCds) ProtoMessage()
func (*OnDemandCds) ProtoReflect ¶
func (x *OnDemandCds) ProtoReflect() protoreflect.Message
func (*OnDemandCds) Reset ¶
func (x *OnDemandCds) Reset()
func (*OnDemandCds) SetResourcesLocator ¶
func (x *OnDemandCds) SetResourcesLocator(v string)
func (*OnDemandCds) SetSource ¶
func (x *OnDemandCds) SetSource(v *v3.ConfigSource)
func (*OnDemandCds) SetTimeout ¶
func (x *OnDemandCds) SetTimeout(v *durationpb.Duration)
func (*OnDemandCds) String ¶
func (x *OnDemandCds) String() string
type OnDemandCds_builder ¶
type OnDemandCds_builder struct {
// A configuration source for the service that will be used for
// on-demand cluster discovery.
Source *v3.ConfigSource
// xdstp:// resource locator for on-demand cluster collection.
ResourcesLocator string
// The timeout for on demand cluster lookup. If not set, defaults to 5 seconds.
Timeout *durationpb.Duration
// contains filtered or unexported fields
}
func (OnDemandCds_builder) Build ¶
func (b0 OnDemandCds_builder) Build() *OnDemandCds
type OnDemand_builder ¶
type OnDemand_builder struct {
// An optional configuration for on-demand cluster discovery
// service. If not specified, the on-demand cluster discovery will
// be disabled. When it's specified, the filter will pause the
// request to an unknown cluster and will begin a cluster discovery
// process. When the discovery is finished (successfully or not), the
// request will be resumed for further processing.
Odcds *OnDemandCds
// contains filtered or unexported fields
}
func (OnDemand_builder) Build ¶
func (b0 OnDemand_builder) Build() *OnDemand
type PerRouteConfig ¶
type PerRouteConfig struct {
// An optional configuration for on-demand cluster discovery
// service. If not specified, the on-demand cluster discovery will
// be disabled. When it's specified, the filter will pause the
// request to an unknown cluster and will begin a cluster discovery
// process. When the discovery is finished (successfully or not), the
// request will be resumed for further processing.
Odcds *OnDemandCds `protobuf:"bytes,1,opt,name=odcds,proto3" json:"odcds,omitempty"`
// contains filtered or unexported fields
}
Per-route configuration for On Demand Discovery.
func (*PerRouteConfig) ClearOdcds ¶
func (x *PerRouteConfig) ClearOdcds()
func (*PerRouteConfig) GetOdcds ¶
func (x *PerRouteConfig) GetOdcds() *OnDemandCds
func (*PerRouteConfig) HasOdcds ¶
func (x *PerRouteConfig) HasOdcds() bool
func (*PerRouteConfig) ProtoMessage ¶
func (*PerRouteConfig) ProtoMessage()
func (*PerRouteConfig) ProtoReflect ¶
func (x *PerRouteConfig) ProtoReflect() protoreflect.Message
func (*PerRouteConfig) Reset ¶
func (x *PerRouteConfig) Reset()
func (*PerRouteConfig) SetOdcds ¶
func (x *PerRouteConfig) SetOdcds(v *OnDemandCds)
func (*PerRouteConfig) String ¶
func (x *PerRouteConfig) String() string
type PerRouteConfig_builder ¶
type PerRouteConfig_builder struct {
// An optional configuration for on-demand cluster discovery
// service. If not specified, the on-demand cluster discovery will
// be disabled. When it's specified, the filter will pause the
// request to an unknown cluster and will begin a cluster discovery
// process. When the discovery is finished (successfully or not), the
// request will be resumed for further processing.
Odcds *OnDemandCds
// contains filtered or unexported fields
}
func (PerRouteConfig_builder) Build ¶
func (b0 PerRouteConfig_builder) Build() *PerRouteConfig
Source Files
¶
- on_demand.pb.go
Click to show internal directories.
Click to hide internal directories.