Documentation
¶
Index ¶
- Variables
- type Config
- func (x *Config) ClearValue()deprecated
- func (x *Config) GetMetadata() []*Metadata
- func (x *Config) GetMetadataNamespace() stringdeprecated
- func (x *Config) GetValue() *structpb.Structdeprecated
- func (x *Config) HasValue() booldeprecated
- func (*Config) ProtoMessage()
- func (x *Config) ProtoReflect() protoreflect.Message
- func (x *Config) Reset()
- func (x *Config) SetMetadata(v []*Metadata)
- func (x *Config) SetMetadataNamespace(v string)deprecated
- func (x *Config) SetValue(v *structpb.Struct)deprecated
- func (x *Config) String() string
- type Config_builder
- type Metadata
- func (x *Metadata) ClearTypedValue()
- func (x *Metadata) ClearValue()
- func (x *Metadata) GetAllowOverwrite() bool
- func (x *Metadata) GetMetadataNamespace() string
- func (x *Metadata) GetTypedValue() *anypb.Any
- func (x *Metadata) GetValue() *structpb.Struct
- func (x *Metadata) HasTypedValue() bool
- func (x *Metadata) HasValue() bool
- func (*Metadata) ProtoMessage()
- func (x *Metadata) ProtoReflect() protoreflect.Message
- func (x *Metadata) Reset()
- func (x *Metadata) SetAllowOverwrite(v bool)
- func (x *Metadata) SetMetadataNamespace(v string)
- func (x *Metadata) SetTypedValue(v *anypb.Any)
- func (x *Metadata) SetValue(v *structpb.Struct)
- func (x *Metadata) String() string
- type Metadata_builder
Constants ¶
This section is empty.
Variables ¶
var File_envoy_extensions_filters_http_set_metadata_v3_set_metadata_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
// The metadata namespace.
// This field is deprecated; please use “metadata“ as replacement.
//
// Deprecated: Marked as deprecated in envoy/extensions/filters/http/set_metadata/v3/set_metadata.proto.
MetadataNamespace string `protobuf:"bytes,1,opt,name=metadata_namespace,json=metadataNamespace,proto3" json:"metadata_namespace,omitempty"`
// The untyped value to update the dynamic metadata namespace with. See
// :ref:`the filter documentation <config_http_filters_set_metadata>` for
// more information on how this value is merged with potentially existing
// ones.
// This field is deprecated; please use “metadata“ as replacement.
//
// Deprecated: Marked as deprecated in envoy/extensions/filters/http/set_metadata/v3/set_metadata.proto.
Value *structpb.Struct `protobuf:"bytes,2,opt,name=value,proto3" json:"value,omitempty"`
// Defines changes to be made to dynamic metadata.
Metadata []*Metadata `protobuf:"bytes,3,rep,name=metadata,proto3" json:"metadata,omitempty"`
// contains filtered or unexported fields
}
func (*Config) ClearValue
deprecated
func (x *Config) ClearValue()
Deprecated: Marked as deprecated in envoy/extensions/filters/http/set_metadata/v3/set_metadata.proto.
func (*Config) ProtoReflect ¶
func (x *Config) ProtoReflect() protoreflect.Message
type Config_builder ¶
type Config_builder struct {
// The metadata namespace.
// This field is deprecated; please use “metadata“ as replacement.
//
// Deprecated: Marked as deprecated in envoy/extensions/filters/http/set_metadata/v3/set_metadata.proto.
MetadataNamespace string
// The untyped value to update the dynamic metadata namespace with. See
// :ref:`the filter documentation <config_http_filters_set_metadata>` for
// more information on how this value is merged with potentially existing
// ones.
// This field is deprecated; please use “metadata“ as replacement.
//
// Deprecated: Marked as deprecated in envoy/extensions/filters/http/set_metadata/v3/set_metadata.proto.
Value *structpb.Struct
// Defines changes to be made to dynamic metadata.
Metadata []*Metadata
// contains filtered or unexported fields
}
func (Config_builder) Build ¶
func (b0 Config_builder) Build() *Config
type Metadata ¶
type Metadata struct {
// The metadata namespace.
MetadataNamespace string `protobuf:"bytes,1,opt,name=metadata_namespace,json=metadataNamespace,proto3" json:"metadata_namespace,omitempty"`
// Allow the filter to overwrite or merge with an existing value in the namespace.
AllowOverwrite bool `protobuf:"varint,2,opt,name=allow_overwrite,json=allowOverwrite,proto3" json:"allow_overwrite,omitempty"`
// The value to place at the namespace. If “allow_overwrite“, this will
// overwrite or merge with any existing values in that namespace. See
// :ref:`the filter documentation <config_http_filters_set_metadata>` for
// more information on how this value is merged with potentially existing
// ones if “allow_overwrite“ is configured. Only one of “value“ and
// “typed_value“ may be set.
Value *structpb.Struct `protobuf:"bytes,3,opt,name=value,proto3" json:"value,omitempty"`
// The value to place at the namespace. If “allow_overwrite“, this will
// overwrite any existing values in that namespace. Only one of “value“ and
// “typed_value“ may be set.
TypedValue *anypb.Any `protobuf:"bytes,4,opt,name=typed_value,json=typedValue,proto3" json:"typed_value,omitempty"`
// contains filtered or unexported fields
}
func (*Metadata) ProtoReflect ¶
func (x *Metadata) ProtoReflect() protoreflect.Message
type Metadata_builder ¶
type Metadata_builder struct {
// The metadata namespace.
MetadataNamespace string
// Allow the filter to overwrite or merge with an existing value in the namespace.
AllowOverwrite bool
// The value to place at the namespace. If “allow_overwrite“, this will
// overwrite or merge with any existing values in that namespace. See
// :ref:`the filter documentation <config_http_filters_set_metadata>` for
// more information on how this value is merged with potentially existing
// ones if “allow_overwrite“ is configured. Only one of “value“ and
// “typed_value“ may be set.
Value *structpb.Struct
// The value to place at the namespace. If “allow_overwrite“, this will
// overwrite any existing values in that namespace. Only one of “value“ and
// “typed_value“ may be set.
TypedValue *anypb.Any
// contains filtered or unexported fields
}
func (Metadata_builder) Build ¶
func (b0 Metadata_builder) Build() *Metadata
Source Files
¶
- set_metadata.pb.go
Click to show internal directories.
Click to hide internal directories.