Documentation
¶
Index ¶
- Constants
- Variables
- type StatefulSession
- func (x *StatefulSession) ClearSessionState()
- func (x *StatefulSession) GetSessionState() *v3.TypedExtensionConfig
- func (x *StatefulSession) GetStatPrefix() string
- func (x *StatefulSession) GetStatusOnStrictDestinationNotFound() uint32
- func (x *StatefulSession) GetStrict() bool
- func (x *StatefulSession) HasSessionState() bool
- func (*StatefulSession) ProtoMessage()
- func (x *StatefulSession) ProtoReflect() protoreflect.Message
- func (x *StatefulSession) Reset()
- func (x *StatefulSession) SetSessionState(v *v3.TypedExtensionConfig)
- func (x *StatefulSession) SetStatPrefix(v string)
- func (x *StatefulSession) SetStatusOnStrictDestinationNotFound(v uint32)
- func (x *StatefulSession) SetStrict(v bool)
- func (x *StatefulSession) String() string
- type StatefulSessionPerRoute
- func (x *StatefulSessionPerRoute) ClearDisabled()
- func (x *StatefulSessionPerRoute) ClearOverride()
- func (x *StatefulSessionPerRoute) ClearStatefulSession()
- func (x *StatefulSessionPerRoute) GetDisabled() bool
- func (x *StatefulSessionPerRoute) GetOverride() isStatefulSessionPerRoute_Override
- func (x *StatefulSessionPerRoute) GetStatefulSession() *StatefulSession
- func (x *StatefulSessionPerRoute) HasDisabled() bool
- func (x *StatefulSessionPerRoute) HasOverride() bool
- func (x *StatefulSessionPerRoute) HasStatefulSession() bool
- func (*StatefulSessionPerRoute) ProtoMessage()
- func (x *StatefulSessionPerRoute) ProtoReflect() protoreflect.Message
- func (x *StatefulSessionPerRoute) Reset()
- func (x *StatefulSessionPerRoute) SetDisabled(v bool)
- func (x *StatefulSessionPerRoute) SetStatefulSession(v *StatefulSession)
- func (x *StatefulSessionPerRoute) String() string
- func (x *StatefulSessionPerRoute) WhichOverride() case_StatefulSessionPerRoute_Override
- type StatefulSessionPerRoute_Disabled
- type StatefulSessionPerRoute_StatefulSession
- type StatefulSessionPerRoute_builder
- type StatefulSession_builder
Constants ¶
const StatefulSessionPerRoute_Disabled_case case_StatefulSessionPerRoute_Override = 1
const StatefulSessionPerRoute_Override_not_set_case case_StatefulSessionPerRoute_Override = 0
const StatefulSessionPerRoute_StatefulSession_case case_StatefulSessionPerRoute_Override = 2
Variables ¶
var File_envoy_extensions_filters_http_stateful_session_v3_stateful_session_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type StatefulSession ¶
type StatefulSession struct {
// Specifies the implementation of session state. This session state is used to store and retrieve the address of the
// upstream host assigned to the session.
//
// [#extension-category: envoy.http.stateful_session]
SessionState *v3.TypedExtensionConfig `protobuf:"bytes,1,opt,name=session_state,json=sessionState,proto3" json:"session_state,omitempty"`
// Determines whether the HTTP request must be strictly routed to the requested destination. When set to “true“,
// if the requested destination is not found in the set of available endpoints, Envoy will return a status code
// determined by “status_on_strict_destination_not_found“. If the destination exists but is unhealthy, Envoy will
// always return “503“ regardless of “status_on_strict_destination_not_found“. The default value is “false“,
// which allows Envoy to fall back to its load balancing mechanism and route the request according to the load
// balancing algorithm.
Strict bool `protobuf:"varint,2,opt,name=strict,proto3" json:"strict,omitempty"`
// Optional stat prefix. If specified, the filter will emit statistics in the
// “http.<stat_prefix>.stateful_session.<stat_prefix>.“ namespace. If not specified, no statistics will be emitted.
//
// .. note::
//
// Per-route configuration overrides do not support statistics and will not emit stats even if this field is set
// in the per-route config.
StatPrefix string `protobuf:"bytes,3,opt,name=stat_prefix,json=statPrefix,proto3" json:"stat_prefix,omitempty"`
// The HTTP status code to return when “strict“ mode is enabled and the requested destination
// is not found in the set of available endpoints. This does not apply when the destination exists
// but is unhealthy. This field has no effect when “strict“ is set to “false“ and will be
// ignored. Defaults to “503“ (Service Unavailable) if not specified or set to “0“.
StatusOnStrictDestinationNotFound uint32 `` /* 169-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*StatefulSession) ClearSessionState ¶
func (x *StatefulSession) ClearSessionState()
func (*StatefulSession) GetSessionState ¶
func (x *StatefulSession) GetSessionState() *v3.TypedExtensionConfig
func (*StatefulSession) GetStatPrefix ¶
func (x *StatefulSession) GetStatPrefix() string
func (*StatefulSession) GetStatusOnStrictDestinationNotFound ¶
func (x *StatefulSession) GetStatusOnStrictDestinationNotFound() uint32
func (*StatefulSession) GetStrict ¶
func (x *StatefulSession) GetStrict() bool
func (*StatefulSession) HasSessionState ¶
func (x *StatefulSession) HasSessionState() bool
func (*StatefulSession) ProtoMessage ¶
func (*StatefulSession) ProtoMessage()
func (*StatefulSession) ProtoReflect ¶
func (x *StatefulSession) ProtoReflect() protoreflect.Message
func (*StatefulSession) Reset ¶
func (x *StatefulSession) Reset()
func (*StatefulSession) SetSessionState ¶
func (x *StatefulSession) SetSessionState(v *v3.TypedExtensionConfig)
func (*StatefulSession) SetStatPrefix ¶
func (x *StatefulSession) SetStatPrefix(v string)
func (*StatefulSession) SetStatusOnStrictDestinationNotFound ¶
func (x *StatefulSession) SetStatusOnStrictDestinationNotFound(v uint32)
func (*StatefulSession) SetStrict ¶
func (x *StatefulSession) SetStrict(v bool)
func (*StatefulSession) String ¶
func (x *StatefulSession) String() string
type StatefulSessionPerRoute ¶
type StatefulSessionPerRoute struct {
// Types that are valid to be assigned to Override:
//
// *StatefulSessionPerRoute_Disabled
// *StatefulSessionPerRoute_StatefulSession
Override isStatefulSessionPerRoute_Override `protobuf_oneof:"override"`
// contains filtered or unexported fields
}
func (*StatefulSessionPerRoute) ClearDisabled ¶
func (x *StatefulSessionPerRoute) ClearDisabled()
func (*StatefulSessionPerRoute) ClearOverride ¶
func (x *StatefulSessionPerRoute) ClearOverride()
func (*StatefulSessionPerRoute) ClearStatefulSession ¶
func (x *StatefulSessionPerRoute) ClearStatefulSession()
func (*StatefulSessionPerRoute) GetDisabled ¶
func (x *StatefulSessionPerRoute) GetDisabled() bool
func (*StatefulSessionPerRoute) GetOverride ¶
func (x *StatefulSessionPerRoute) GetOverride() isStatefulSessionPerRoute_Override
func (*StatefulSessionPerRoute) GetStatefulSession ¶
func (x *StatefulSessionPerRoute) GetStatefulSession() *StatefulSession
func (*StatefulSessionPerRoute) HasDisabled ¶
func (x *StatefulSessionPerRoute) HasDisabled() bool
func (*StatefulSessionPerRoute) HasOverride ¶
func (x *StatefulSessionPerRoute) HasOverride() bool
func (*StatefulSessionPerRoute) HasStatefulSession ¶
func (x *StatefulSessionPerRoute) HasStatefulSession() bool
func (*StatefulSessionPerRoute) ProtoMessage ¶
func (*StatefulSessionPerRoute) ProtoMessage()
func (*StatefulSessionPerRoute) ProtoReflect ¶
func (x *StatefulSessionPerRoute) ProtoReflect() protoreflect.Message
func (*StatefulSessionPerRoute) Reset ¶
func (x *StatefulSessionPerRoute) Reset()
func (*StatefulSessionPerRoute) SetDisabled ¶
func (x *StatefulSessionPerRoute) SetDisabled(v bool)
func (*StatefulSessionPerRoute) SetStatefulSession ¶
func (x *StatefulSessionPerRoute) SetStatefulSession(v *StatefulSession)
func (*StatefulSessionPerRoute) String ¶
func (x *StatefulSessionPerRoute) String() string
func (*StatefulSessionPerRoute) WhichOverride ¶
func (x *StatefulSessionPerRoute) WhichOverride() case_StatefulSessionPerRoute_Override
type StatefulSessionPerRoute_Disabled ¶
type StatefulSessionPerRoute_Disabled struct {
// Disable the stateful session filter for this particular vhost or route. If disabled is
// specified in multiple per-filter-configs, the most specific one will be used.
Disabled bool `protobuf:"varint,1,opt,name=disabled,proto3,oneof"`
}
type StatefulSessionPerRoute_StatefulSession ¶
type StatefulSessionPerRoute_StatefulSession struct {
// Per-route stateful session configuration that can be served by RDS or static route table.
StatefulSession *StatefulSession `protobuf:"bytes,2,opt,name=stateful_session,json=statefulSession,proto3,oneof"`
}
type StatefulSessionPerRoute_builder ¶
type StatefulSessionPerRoute_builder struct {
// Fields of oneof Override:
// Disable the stateful session filter for this particular vhost or route. If disabled is
// specified in multiple per-filter-configs, the most specific one will be used.
Disabled *bool
// Per-route stateful session configuration that can be served by RDS or static route table.
StatefulSession *StatefulSession
// contains filtered or unexported fields
}
func (StatefulSessionPerRoute_builder) Build ¶
func (b0 StatefulSessionPerRoute_builder) Build() *StatefulSessionPerRoute
type StatefulSession_builder ¶
type StatefulSession_builder struct {
// Specifies the implementation of session state. This session state is used to store and retrieve the address of the
// upstream host assigned to the session.
//
// [#extension-category: envoy.http.stateful_session]
SessionState *v3.TypedExtensionConfig
// Determines whether the HTTP request must be strictly routed to the requested destination. When set to “true“,
// if the requested destination is not found in the set of available endpoints, Envoy will return a status code
// determined by “status_on_strict_destination_not_found“. If the destination exists but is unhealthy, Envoy will
// always return “503“ regardless of “status_on_strict_destination_not_found“. The default value is “false“,
// which allows Envoy to fall back to its load balancing mechanism and route the request according to the load
// balancing algorithm.
Strict bool
// Optional stat prefix. If specified, the filter will emit statistics in the
// “http.<stat_prefix>.stateful_session.<stat_prefix>.“ namespace. If not specified, no statistics will be emitted.
//
// .. note::
//
// Per-route configuration overrides do not support statistics and will not emit stats even if this field is set
// in the per-route config.
StatPrefix string
// The HTTP status code to return when “strict“ mode is enabled and the requested destination
// is not found in the set of available endpoints. This does not apply when the destination exists
// but is unhealthy. This field has no effect when “strict“ is set to “false“ and will be
// ignored. Defaults to “503“ (Service Unavailable) if not specified or set to “0“.
StatusOnStrictDestinationNotFound uint32
// contains filtered or unexported fields
}
func (StatefulSession_builder) Build ¶
func (b0 StatefulSession_builder) Build() *StatefulSession
Source Files
¶
- stateful_session.pb.go
Click to show internal directories.
Click to hide internal directories.