Documentation
¶
Index ¶
- Variables
- type HostMatchInput
- type HostMatchInput_builder
- type KeyValueMatchEntry
- func (x *KeyValueMatchEntry) ClearStringMatch()
- func (x *KeyValueMatchEntry) GetName() string
- func (x *KeyValueMatchEntry) GetStringMatch() *v3.StringMatcher
- func (x *KeyValueMatchEntry) HasStringMatch() bool
- func (*KeyValueMatchEntry) ProtoMessage()
- func (x *KeyValueMatchEntry) ProtoReflect() protoreflect.Message
- func (x *KeyValueMatchEntry) Reset()
- func (x *KeyValueMatchEntry) SetName(v string)
- func (x *KeyValueMatchEntry) SetStringMatch(v *v3.StringMatcher)
- func (x *KeyValueMatchEntry) String() string
- type KeyValueMatchEntry_builder
- type MethodMatchInput
- type MethodMatchInput_builder
- type PathMatchInput
- type PathMatchInput_builder
- type PropertyMatchInput
- type PropertyMatchInput_builder
- type RequestMatchInput
- type RequestMatchInput_builder
- type RequestMatcher
- func (x *RequestMatcher) ClearHost()
- func (x *RequestMatcher) ClearMethod()
- func (x *RequestMatcher) ClearPath()
- func (x *RequestMatcher) GetHost() *v3.StringMatcher
- func (x *RequestMatcher) GetMethod() *v3.StringMatcher
- func (x *RequestMatcher) GetPath() *v3.StringMatcher
- func (x *RequestMatcher) GetProperties() []*KeyValueMatchEntry
- func (x *RequestMatcher) HasHost() bool
- func (x *RequestMatcher) HasMethod() bool
- func (x *RequestMatcher) HasPath() bool
- func (*RequestMatcher) ProtoMessage()
- func (x *RequestMatcher) ProtoReflect() protoreflect.Message
- func (x *RequestMatcher) Reset()
- func (x *RequestMatcher) SetHost(v *v3.StringMatcher)
- func (x *RequestMatcher) SetMethod(v *v3.StringMatcher)
- func (x *RequestMatcher) SetPath(v *v3.StringMatcher)
- func (x *RequestMatcher) SetProperties(v []*KeyValueMatchEntry)
- func (x *RequestMatcher) String() string
- type RequestMatcher_builder
- type ServiceMatchInput
- type ServiceMatchInput_builder
Constants ¶
This section is empty.
Variables ¶
var File_envoy_extensions_filters_network_generic_proxy_matcher_v3_matcher_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type HostMatchInput ¶
type HostMatchInput struct {
// contains filtered or unexported fields
}
Used to match request host of the generic downstream request. Only applicable if a host provided by the application protocol. This is same with the ServiceMatchInput and this should be preferred over ServiceMatchInput.
func (*HostMatchInput) ProtoMessage ¶
func (*HostMatchInput) ProtoMessage()
func (*HostMatchInput) ProtoReflect ¶
func (x *HostMatchInput) ProtoReflect() protoreflect.Message
func (*HostMatchInput) Reset ¶
func (x *HostMatchInput) Reset()
func (*HostMatchInput) String ¶
func (x *HostMatchInput) String() string
type HostMatchInput_builder ¶
type HostMatchInput_builder struct {
// contains filtered or unexported fields
}
func (HostMatchInput_builder) Build ¶
func (b0 HostMatchInput_builder) Build() *HostMatchInput
type KeyValueMatchEntry ¶
type KeyValueMatchEntry struct {
// The key name to match on.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// The key value pattern.
StringMatch *v3.StringMatcher `protobuf:"bytes,2,opt,name=string_match,json=stringMatch,proto3" json:"string_match,omitempty"`
// contains filtered or unexported fields
}
Used to match an arbitrary key-value pair for headers, trailers or properties.
func (*KeyValueMatchEntry) ClearStringMatch ¶
func (x *KeyValueMatchEntry) ClearStringMatch()
func (*KeyValueMatchEntry) GetName ¶
func (x *KeyValueMatchEntry) GetName() string
func (*KeyValueMatchEntry) GetStringMatch ¶
func (x *KeyValueMatchEntry) GetStringMatch() *v3.StringMatcher
func (*KeyValueMatchEntry) HasStringMatch ¶
func (x *KeyValueMatchEntry) HasStringMatch() bool
func (*KeyValueMatchEntry) ProtoMessage ¶
func (*KeyValueMatchEntry) ProtoMessage()
func (*KeyValueMatchEntry) ProtoReflect ¶
func (x *KeyValueMatchEntry) ProtoReflect() protoreflect.Message
func (*KeyValueMatchEntry) Reset ¶
func (x *KeyValueMatchEntry) Reset()
func (*KeyValueMatchEntry) SetName ¶
func (x *KeyValueMatchEntry) SetName(v string)
func (*KeyValueMatchEntry) SetStringMatch ¶
func (x *KeyValueMatchEntry) SetStringMatch(v *v3.StringMatcher)
func (*KeyValueMatchEntry) String ¶
func (x *KeyValueMatchEntry) String() string
type KeyValueMatchEntry_builder ¶
type KeyValueMatchEntry_builder struct {
// The key name to match on.
Name string
// The key value pattern.
StringMatch *v3.StringMatcher
// contains filtered or unexported fields
}
func (KeyValueMatchEntry_builder) Build ¶
func (b0 KeyValueMatchEntry_builder) Build() *KeyValueMatchEntry
type MethodMatchInput ¶
type MethodMatchInput struct {
// contains filtered or unexported fields
}
Used to match request method of the generic downstream request. Only applicable if a method provided by the application protocol.
func (*MethodMatchInput) ProtoMessage ¶
func (*MethodMatchInput) ProtoMessage()
func (*MethodMatchInput) ProtoReflect ¶
func (x *MethodMatchInput) ProtoReflect() protoreflect.Message
func (*MethodMatchInput) Reset ¶
func (x *MethodMatchInput) Reset()
func (*MethodMatchInput) String ¶
func (x *MethodMatchInput) String() string
type MethodMatchInput_builder ¶
type MethodMatchInput_builder struct {
// contains filtered or unexported fields
}
func (MethodMatchInput_builder) Build ¶
func (b0 MethodMatchInput_builder) Build() *MethodMatchInput
type PathMatchInput ¶
type PathMatchInput struct {
// contains filtered or unexported fields
}
Used to match request path of the generic downstream request. Only applicable if a path provided by the application protocol.
func (*PathMatchInput) ProtoMessage ¶
func (*PathMatchInput) ProtoMessage()
func (*PathMatchInput) ProtoReflect ¶
func (x *PathMatchInput) ProtoReflect() protoreflect.Message
func (*PathMatchInput) Reset ¶
func (x *PathMatchInput) Reset()
func (*PathMatchInput) String ¶
func (x *PathMatchInput) String() string
type PathMatchInput_builder ¶
type PathMatchInput_builder struct {
// contains filtered or unexported fields
}
func (PathMatchInput_builder) Build ¶
func (b0 PathMatchInput_builder) Build() *PathMatchInput
type PropertyMatchInput ¶
type PropertyMatchInput struct {
// The property name to match on.
PropertyName string `protobuf:"bytes,1,opt,name=property_name,json=propertyName,proto3" json:"property_name,omitempty"`
// contains filtered or unexported fields
}
Used to match an arbitrary property of the generic downstream request. These properties are populated by the codecs of application protocols.
func (*PropertyMatchInput) GetPropertyName ¶
func (x *PropertyMatchInput) GetPropertyName() string
func (*PropertyMatchInput) ProtoMessage ¶
func (*PropertyMatchInput) ProtoMessage()
func (*PropertyMatchInput) ProtoReflect ¶
func (x *PropertyMatchInput) ProtoReflect() protoreflect.Message
func (*PropertyMatchInput) Reset ¶
func (x *PropertyMatchInput) Reset()
func (*PropertyMatchInput) SetPropertyName ¶
func (x *PropertyMatchInput) SetPropertyName(v string)
func (*PropertyMatchInput) String ¶
func (x *PropertyMatchInput) String() string
type PropertyMatchInput_builder ¶
type PropertyMatchInput_builder struct {
// The property name to match on.
PropertyName string
// contains filtered or unexported fields
}
func (PropertyMatchInput_builder) Build ¶
func (b0 PropertyMatchInput_builder) Build() *PropertyMatchInput
type RequestMatchInput ¶
type RequestMatchInput struct {
// contains filtered or unexported fields
}
Used to match an whole generic downstream request.
func (*RequestMatchInput) ProtoMessage ¶
func (*RequestMatchInput) ProtoMessage()
func (*RequestMatchInput) ProtoReflect ¶
func (x *RequestMatchInput) ProtoReflect() protoreflect.Message
func (*RequestMatchInput) Reset ¶
func (x *RequestMatchInput) Reset()
func (*RequestMatchInput) String ¶
func (x *RequestMatchInput) String() string
type RequestMatchInput_builder ¶
type RequestMatchInput_builder struct {
// contains filtered or unexported fields
}
func (RequestMatchInput_builder) Build ¶
func (b0 RequestMatchInput_builder) Build() *RequestMatchInput
type RequestMatcher ¶
type RequestMatcher struct {
// Optional host pattern to match on. If not specified, any host will match.
Host *v3.StringMatcher `protobuf:"bytes,1,opt,name=host,proto3" json:"host,omitempty"`
// Optional path pattern to match on. If not specified, any path will match.
Path *v3.StringMatcher `protobuf:"bytes,2,opt,name=path,proto3" json:"path,omitempty"`
// Optional method pattern to match on. If not specified, any method will match.
Method *v3.StringMatcher `protobuf:"bytes,3,opt,name=method,proto3" json:"method,omitempty"`
// Optional arbitrary properties to match on. If not specified, any properties
// will match. The key is the property name and the value is the property value
// to match on.
Properties []*KeyValueMatchEntry `protobuf:"bytes,4,rep,name=properties,proto3" json:"properties,omitempty"`
// contains filtered or unexported fields
}
Custom matcher to match on the generic downstream request. This is used to match multiple fields of the downstream request and avoid complex combinations of HostMatchInput, PathMatchInput, MethodMatchInput and PropertyMatchInput.
func (*RequestMatcher) ClearHost ¶
func (x *RequestMatcher) ClearHost()
func (*RequestMatcher) ClearMethod ¶
func (x *RequestMatcher) ClearMethod()
func (*RequestMatcher) ClearPath ¶
func (x *RequestMatcher) ClearPath()
func (*RequestMatcher) GetHost ¶
func (x *RequestMatcher) GetHost() *v3.StringMatcher
func (*RequestMatcher) GetMethod ¶
func (x *RequestMatcher) GetMethod() *v3.StringMatcher
func (*RequestMatcher) GetPath ¶
func (x *RequestMatcher) GetPath() *v3.StringMatcher
func (*RequestMatcher) GetProperties ¶
func (x *RequestMatcher) GetProperties() []*KeyValueMatchEntry
func (*RequestMatcher) HasHost ¶
func (x *RequestMatcher) HasHost() bool
func (*RequestMatcher) HasMethod ¶
func (x *RequestMatcher) HasMethod() bool
func (*RequestMatcher) HasPath ¶
func (x *RequestMatcher) HasPath() bool
func (*RequestMatcher) ProtoMessage ¶
func (*RequestMatcher) ProtoMessage()
func (*RequestMatcher) ProtoReflect ¶
func (x *RequestMatcher) ProtoReflect() protoreflect.Message
func (*RequestMatcher) Reset ¶
func (x *RequestMatcher) Reset()
func (*RequestMatcher) SetHost ¶
func (x *RequestMatcher) SetHost(v *v3.StringMatcher)
func (*RequestMatcher) SetMethod ¶
func (x *RequestMatcher) SetMethod(v *v3.StringMatcher)
func (*RequestMatcher) SetPath ¶
func (x *RequestMatcher) SetPath(v *v3.StringMatcher)
func (*RequestMatcher) SetProperties ¶
func (x *RequestMatcher) SetProperties(v []*KeyValueMatchEntry)
func (*RequestMatcher) String ¶
func (x *RequestMatcher) String() string
type RequestMatcher_builder ¶
type RequestMatcher_builder struct {
// Optional host pattern to match on. If not specified, any host will match.
Host *v3.StringMatcher
// Optional path pattern to match on. If not specified, any path will match.
Path *v3.StringMatcher
// Optional method pattern to match on. If not specified, any method will match.
Method *v3.StringMatcher
// Optional arbitrary properties to match on. If not specified, any properties
// will match. The key is the property name and the value is the property value
// to match on.
Properties []*KeyValueMatchEntry
// contains filtered or unexported fields
}
func (RequestMatcher_builder) Build ¶
func (b0 RequestMatcher_builder) Build() *RequestMatcher
type ServiceMatchInput ¶
type ServiceMatchInput struct {
// contains filtered or unexported fields
}
Used to match request service of the downstream request. Only applicable if a service provided by the application protocol. This is deprecated and should be replaced by HostMatchInput. This is kept for backward compatibility.
func (*ServiceMatchInput) ProtoMessage ¶
func (*ServiceMatchInput) ProtoMessage()
func (*ServiceMatchInput) ProtoReflect ¶
func (x *ServiceMatchInput) ProtoReflect() protoreflect.Message
func (*ServiceMatchInput) Reset ¶
func (x *ServiceMatchInput) Reset()
func (*ServiceMatchInput) String ¶
func (x *ServiceMatchInput) String() string
type ServiceMatchInput_builder ¶
type ServiceMatchInput_builder struct {
// contains filtered or unexported fields
}
func (ServiceMatchInput_builder) Build ¶
func (b0 ServiceMatchInput_builder) Build() *ServiceMatchInput
Source Files
¶
- matcher.pb.go