Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var File_envoy_extensions_filters_network_set_filter_state_v3_set_filter_state_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
// A sequence of the filter state values to apply in the specified order
// when a new connection is received.
OnNewConnection []*v3.FilterStateValue `protobuf:"bytes,1,rep,name=on_new_connection,json=onNewConnection,proto3" json:"on_new_connection,omitempty"`
// contains filtered or unexported fields
}
func (*Config) GetOnNewConnection ¶
func (x *Config) GetOnNewConnection() []*v3.FilterStateValue
func (*Config) ProtoReflect ¶
func (x *Config) ProtoReflect() protoreflect.Message
func (*Config) SetOnNewConnection ¶
func (x *Config) SetOnNewConnection(v []*v3.FilterStateValue)
type Config_builder ¶
type Config_builder struct {
// A sequence of the filter state values to apply in the specified order
// when a new connection is received.
OnNewConnection []*v3.FilterStateValue
// contains filtered or unexported fields
}
func (Config_builder) Build ¶
func (b0 Config_builder) Build() *Config
Source Files
¶
- set_filter_state.pb.go
Click to show internal directories.
Click to hide internal directories.