Documentation
¶
Index ¶
- Constants
- Variables
- type FilterConfig
- func (x *FilterConfig) ClearDnsCacheConfig()
- func (x *FilterConfig) ClearPortSpecifier()
- func (x *FilterConfig) ClearPortValue()
- func (x *FilterConfig) GetDnsCacheConfig() *v3.DnsCacheConfig
- func (x *FilterConfig) GetPortSpecifier() isFilterConfig_PortSpecifier
- func (x *FilterConfig) GetPortValue() uint32
- func (x *FilterConfig) GetSaveUpstreamAddress() bool
- func (x *FilterConfig) HasDnsCacheConfig() bool
- func (x *FilterConfig) HasPortSpecifier() bool
- func (x *FilterConfig) HasPortValue() bool
- func (*FilterConfig) ProtoMessage()
- func (x *FilterConfig) ProtoReflect() protoreflect.Message
- func (x *FilterConfig) Reset()
- func (x *FilterConfig) SetDnsCacheConfig(v *v3.DnsCacheConfig)
- func (x *FilterConfig) SetPortValue(v uint32)
- func (x *FilterConfig) SetSaveUpstreamAddress(v bool)
- func (x *FilterConfig) String() string
- func (x *FilterConfig) WhichPortSpecifier() case_FilterConfig_PortSpecifier
- type FilterConfig_PortValue
- type FilterConfig_builder
Constants ¶
const FilterConfig_PortSpecifier_not_set_case case_FilterConfig_PortSpecifier = 0
const FilterConfig_PortValue_case case_FilterConfig_PortSpecifier = 2
Variables ¶
var File_envoy_extensions_filters_network_sni_dynamic_forward_proxy_v3_sni_dynamic_forward_proxy_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type FilterConfig ¶
type FilterConfig struct {
// The DNS cache configuration that the filter will attach to. Note this
// configuration must match that of associated :ref:`dynamic forward proxy
// cluster configuration
// <envoy_v3_api_field_extensions.clusters.dynamic_forward_proxy.v3.ClusterConfig.dns_cache_config>`.
DnsCacheConfig *v3.DnsCacheConfig `protobuf:"bytes,1,opt,name=dns_cache_config,json=dnsCacheConfig,proto3" json:"dns_cache_config,omitempty"`
// Types that are valid to be assigned to PortSpecifier:
//
// *FilterConfig_PortValue
PortSpecifier isFilterConfig_PortSpecifier `protobuf_oneof:"port_specifier"`
// When this flag is set, the filter will add the resolved upstream address in the filter
// state. The state should be saved with key
// “envoy.stream.upstream_address“ (See
// :repo:`upstream_address.h<source/common/stream_info/upstream_address.h>`).
SaveUpstreamAddress bool `protobuf:"varint,3,opt,name=save_upstream_address,json=saveUpstreamAddress,proto3" json:"save_upstream_address,omitempty"`
// contains filtered or unexported fields
}
Configuration for the SNI-based dynamic forward proxy filter. See the :ref:`architecture overview <arch_overview_http_dynamic_forward_proxy>` for more information. Note this filter must be configured along with :ref:`TLS inspector listener filter <config_listener_filters_tls_inspector>` to work. [#extension: envoy.filters.network.sni_dynamic_forward_proxy]
func (*FilterConfig) ClearDnsCacheConfig ¶
func (x *FilterConfig) ClearDnsCacheConfig()
func (*FilterConfig) ClearPortSpecifier ¶
func (x *FilterConfig) ClearPortSpecifier()
func (*FilterConfig) ClearPortValue ¶
func (x *FilterConfig) ClearPortValue()
func (*FilterConfig) GetDnsCacheConfig ¶
func (x *FilterConfig) GetDnsCacheConfig() *v3.DnsCacheConfig
func (*FilterConfig) GetPortSpecifier ¶
func (x *FilterConfig) GetPortSpecifier() isFilterConfig_PortSpecifier
func (*FilterConfig) GetPortValue ¶
func (x *FilterConfig) GetPortValue() uint32
func (*FilterConfig) GetSaveUpstreamAddress ¶
func (x *FilterConfig) GetSaveUpstreamAddress() bool
func (*FilterConfig) HasDnsCacheConfig ¶
func (x *FilterConfig) HasDnsCacheConfig() bool
func (*FilterConfig) HasPortSpecifier ¶
func (x *FilterConfig) HasPortSpecifier() bool
func (*FilterConfig) HasPortValue ¶
func (x *FilterConfig) HasPortValue() bool
func (*FilterConfig) ProtoMessage ¶
func (*FilterConfig) ProtoMessage()
func (*FilterConfig) ProtoReflect ¶
func (x *FilterConfig) ProtoReflect() protoreflect.Message
func (*FilterConfig) Reset ¶
func (x *FilterConfig) Reset()
func (*FilterConfig) SetDnsCacheConfig ¶
func (x *FilterConfig) SetDnsCacheConfig(v *v3.DnsCacheConfig)
func (*FilterConfig) SetPortValue ¶
func (x *FilterConfig) SetPortValue(v uint32)
func (*FilterConfig) SetSaveUpstreamAddress ¶
func (x *FilterConfig) SetSaveUpstreamAddress(v bool)
func (*FilterConfig) String ¶
func (x *FilterConfig) String() string
func (*FilterConfig) WhichPortSpecifier ¶
func (x *FilterConfig) WhichPortSpecifier() case_FilterConfig_PortSpecifier
type FilterConfig_PortValue ¶
type FilterConfig_PortValue struct {
// The port number to connect to the upstream.
PortValue uint32 `protobuf:"varint,2,opt,name=port_value,json=portValue,proto3,oneof"`
}
type FilterConfig_builder ¶
type FilterConfig_builder struct {
// The DNS cache configuration that the filter will attach to. Note this
// configuration must match that of associated :ref:`dynamic forward proxy
// cluster configuration
// <envoy_v3_api_field_extensions.clusters.dynamic_forward_proxy.v3.ClusterConfig.dns_cache_config>`.
DnsCacheConfig *v3.DnsCacheConfig
// Fields of oneof PortSpecifier:
// The port number to connect to the upstream.
PortValue *uint32
// -- end of PortSpecifier
// When this flag is set, the filter will add the resolved upstream address in the filter
// state. The state should be saved with key
// “envoy.stream.upstream_address“ (See
// :repo:`upstream_address.h<source/common/stream_info/upstream_address.h>`).
SaveUpstreamAddress bool
// contains filtered or unexported fields
}
func (FilterConfig_builder) Build ¶
func (b0 FilterConfig_builder) Build() *FilterConfig
Source Files
¶
- sni_dynamic_forward_proxy.pb.go
Click to show internal directories.
Click to hide internal directories.