Documentation
¶
Index ¶
- Variables
- type Router
- func (x *Router) ClearCloseDownstreamOnUpstreamError()
- func (x *Router) GetCloseDownstreamOnUpstreamError() *wrapperspb.BoolValue
- func (x *Router) HasCloseDownstreamOnUpstreamError() bool
- func (*Router) ProtoMessage()
- func (x *Router) ProtoReflect() protoreflect.Message
- func (x *Router) Reset()
- func (x *Router) SetCloseDownstreamOnUpstreamError(v *wrapperspb.BoolValue)
- func (x *Router) String() string
- type Router_builder
Constants ¶
This section is empty.
Variables ¶
var File_envoy_extensions_filters_network_thrift_proxy_router_v3_router_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Router ¶
type Router struct {
// Close downstream connection in case of routing or upstream connection problem. Default: true
CloseDownstreamOnUpstreamError *wrapperspb.BoolValue `` /* 157-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*Router) ClearCloseDownstreamOnUpstreamError ¶
func (x *Router) ClearCloseDownstreamOnUpstreamError()
func (*Router) GetCloseDownstreamOnUpstreamError ¶
func (x *Router) GetCloseDownstreamOnUpstreamError() *wrapperspb.BoolValue
func (*Router) HasCloseDownstreamOnUpstreamError ¶
func (*Router) ProtoReflect ¶
func (x *Router) ProtoReflect() protoreflect.Message
func (*Router) SetCloseDownstreamOnUpstreamError ¶
func (x *Router) SetCloseDownstreamOnUpstreamError(v *wrapperspb.BoolValue)
type Router_builder ¶
type Router_builder struct {
// Close downstream connection in case of routing or upstream connection problem. Default: true
CloseDownstreamOnUpstreamError *wrapperspb.BoolValue
// contains filtered or unexported fields
}
func (Router_builder) Build ¶
func (b0 Router_builder) Build() *Router
Source Files
¶
- router.pb.go
Click to show internal directories.
Click to hide internal directories.