Documentation
¶
Index ¶
- Variables
- type CommonGeoipProviderConfig
- func (x *CommonGeoipProviderConfig) ClearGeoFieldKeys()
- func (x *CommonGeoipProviderConfig) ClearGeoHeadersToAdd()deprecated
- func (x *CommonGeoipProviderConfig) GetGeoFieldKeys() *CommonGeoipProviderConfig_GeolocationFieldKeys
- func (x *CommonGeoipProviderConfig) GetGeoHeadersToAdd() *CommonGeoipProviderConfig_GeolocationHeadersToAdddeprecated
- func (x *CommonGeoipProviderConfig) HasGeoFieldKeys() bool
- func (x *CommonGeoipProviderConfig) HasGeoHeadersToAdd() booldeprecated
- func (*CommonGeoipProviderConfig) ProtoMessage()
- func (x *CommonGeoipProviderConfig) ProtoReflect() protoreflect.Message
- func (x *CommonGeoipProviderConfig) Reset()
- func (x *CommonGeoipProviderConfig) SetGeoFieldKeys(v *CommonGeoipProviderConfig_GeolocationFieldKeys)
- func (x *CommonGeoipProviderConfig) SetGeoHeadersToAdd(v *CommonGeoipProviderConfig_GeolocationHeadersToAdd)deprecated
- func (x *CommonGeoipProviderConfig) String() string
- type CommonGeoipProviderConfig_GeolocationFieldKeys
- func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) GetAnon() string
- func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) GetAnonHosting() string
- func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) GetAnonProxy() string
- func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) GetAnonTor() string
- func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) GetAnonVpn() string
- func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) GetApplePrivateRelay() string
- func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) GetAsn() string
- func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) GetCity() string
- func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) GetCountry() string
- func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) GetIsp() string
- func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) GetRegion() string
- func (*CommonGeoipProviderConfig_GeolocationFieldKeys) ProtoMessage()
- func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) ProtoReflect() protoreflect.Message
- func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) Reset()
- func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) SetAnon(v string)
- func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) SetAnonHosting(v string)
- func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) SetAnonProxy(v string)
- func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) SetAnonTor(v string)
- func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) SetAnonVpn(v string)
- func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) SetApplePrivateRelay(v string)
- func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) SetAsn(v string)
- func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) SetCity(v string)
- func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) SetCountry(v string)
- func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) SetIsp(v string)
- func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) SetRegion(v string)
- func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) String() string
- type CommonGeoipProviderConfig_GeolocationFieldKeys_builder
- type CommonGeoipProviderConfig_GeolocationHeadersToAdd
- func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) GetAnon() string
- func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) GetAnonHosting() string
- func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) GetAnonProxy() string
- func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) GetAnonTor() string
- func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) GetAnonVpn() string
- func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) GetApplePrivateRelay() string
- func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) GetAsn() string
- func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) GetCity() string
- func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) GetCountry() string
- func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) GetIsAnon() stringdeprecated
- func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) GetIsp() string
- func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) GetRegion() string
- func (*CommonGeoipProviderConfig_GeolocationHeadersToAdd) ProtoMessage()
- func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) ProtoReflect() protoreflect.Message
- func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) Reset()
- func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) SetAnon(v string)
- func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) SetAnonHosting(v string)
- func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) SetAnonProxy(v string)
- func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) SetAnonTor(v string)
- func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) SetAnonVpn(v string)
- func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) SetApplePrivateRelay(v string)
- func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) SetAsn(v string)
- func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) SetCity(v string)
- func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) SetCountry(v string)
- func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) SetIsAnon(v string)deprecated
- func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) SetIsp(v string)
- func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) SetRegion(v string)
- func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) String() string
- type CommonGeoipProviderConfig_GeolocationHeadersToAdd_builder
- type CommonGeoipProviderConfig_builder
Constants ¶
This section is empty.
Variables ¶
var File_envoy_extensions_geoip_providers_common_v3_common_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type CommonGeoipProviderConfig ¶
type CommonGeoipProviderConfig struct {
// Configuration for geolocation headers to add to HTTP requests.
// This field is deprecated in favor of “geo_field_keys“. If both are set, “geo_field_keys“
// takes precedence.
//
// Deprecated: Marked as deprecated in envoy/extensions/geoip_providers/common/v3/common.proto.
GeoHeadersToAdd *CommonGeoipProviderConfig_GeolocationHeadersToAdd `protobuf:"bytes,1,opt,name=geo_headers_to_add,json=geoHeadersToAdd,proto3" json:"geo_headers_to_add,omitempty"`
// Configuration for geolocation field keys.
// At least one of “geo_headers_to_add“ or “geo_field_keys“ must be set.
GeoFieldKeys *CommonGeoipProviderConfig_GeolocationFieldKeys `protobuf:"bytes,3,opt,name=geo_field_keys,json=geoFieldKeys,proto3" json:"geo_field_keys,omitempty"`
// contains filtered or unexported fields
}
func (*CommonGeoipProviderConfig) ClearGeoFieldKeys ¶
func (x *CommonGeoipProviderConfig) ClearGeoFieldKeys()
func (*CommonGeoipProviderConfig) ClearGeoHeadersToAdd
deprecated
func (x *CommonGeoipProviderConfig) ClearGeoHeadersToAdd()
Deprecated: Marked as deprecated in envoy/extensions/geoip_providers/common/v3/common.proto.
func (*CommonGeoipProviderConfig) GetGeoFieldKeys ¶
func (x *CommonGeoipProviderConfig) GetGeoFieldKeys() *CommonGeoipProviderConfig_GeolocationFieldKeys
func (*CommonGeoipProviderConfig) GetGeoHeadersToAdd
deprecated
func (x *CommonGeoipProviderConfig) GetGeoHeadersToAdd() *CommonGeoipProviderConfig_GeolocationHeadersToAdd
Deprecated: Marked as deprecated in envoy/extensions/geoip_providers/common/v3/common.proto.
func (*CommonGeoipProviderConfig) HasGeoFieldKeys ¶
func (x *CommonGeoipProviderConfig) HasGeoFieldKeys() bool
func (*CommonGeoipProviderConfig) HasGeoHeadersToAdd
deprecated
func (x *CommonGeoipProviderConfig) HasGeoHeadersToAdd() bool
Deprecated: Marked as deprecated in envoy/extensions/geoip_providers/common/v3/common.proto.
func (*CommonGeoipProviderConfig) ProtoMessage ¶
func (*CommonGeoipProviderConfig) ProtoMessage()
func (*CommonGeoipProviderConfig) ProtoReflect ¶
func (x *CommonGeoipProviderConfig) ProtoReflect() protoreflect.Message
func (*CommonGeoipProviderConfig) Reset ¶
func (x *CommonGeoipProviderConfig) Reset()
func (*CommonGeoipProviderConfig) SetGeoFieldKeys ¶
func (x *CommonGeoipProviderConfig) SetGeoFieldKeys(v *CommonGeoipProviderConfig_GeolocationFieldKeys)
func (*CommonGeoipProviderConfig) SetGeoHeadersToAdd
deprecated
func (x *CommonGeoipProviderConfig) SetGeoHeadersToAdd(v *CommonGeoipProviderConfig_GeolocationHeadersToAdd)
Deprecated: Marked as deprecated in envoy/extensions/geoip_providers/common/v3/common.proto.
func (*CommonGeoipProviderConfig) String ¶
func (x *CommonGeoipProviderConfig) String() string
type CommonGeoipProviderConfig_GeolocationFieldKeys ¶
type CommonGeoipProviderConfig_GeolocationFieldKeys struct {
// If set, the key will be used to populate the country ISO code associated with the IP address.
Country string `protobuf:"bytes,1,opt,name=country,proto3" json:"country,omitempty"`
// If set, the key will be used to populate the city associated with the IP address.
City string `protobuf:"bytes,2,opt,name=city,proto3" json:"city,omitempty"`
// If set, the key will be used to populate the region ISO code associated with the IP address.
// The least specific subdivision will be selected as the region value.
Region string `protobuf:"bytes,3,opt,name=region,proto3" json:"region,omitempty"`
// If set, the key will be used to populate the ASN associated with the IP address.
Asn string `protobuf:"bytes,4,opt,name=asn,proto3" json:"asn,omitempty"`
// If set, the IP address will be checked if it belongs to any type of anonymization network
// (e.g., VPN, public proxy). The result will be stored with this key. Value will be set to
// either “true“ or “false“ depending on the check result.
Anon string `protobuf:"bytes,5,opt,name=anon,proto3" json:"anon,omitempty"`
// If set, the IP address will be checked if it belongs to a VPN and the result will be stored
// with this key. Value will be set to either “true“ or “false“ depending on the check result.
AnonVpn string `protobuf:"bytes,6,opt,name=anon_vpn,json=anonVpn,proto3" json:"anon_vpn,omitempty"`
// If set, the IP address will be checked if it belongs to a hosting provider and the result
// will be stored with this key. Value will be set to either “true“ or “false“ depending on
// the check result.
AnonHosting string `protobuf:"bytes,7,opt,name=anon_hosting,json=anonHosting,proto3" json:"anon_hosting,omitempty"`
// If set, the IP address will be checked if it belongs to a TOR exit node and the result will
// be stored with this key. Value will be set to either “true“ or “false“ depending on the
// check result.
AnonTor string `protobuf:"bytes,8,opt,name=anon_tor,json=anonTor,proto3" json:"anon_tor,omitempty"`
// If set, the IP address will be checked if it belongs to a public proxy and the result will
// be stored with this key. Value will be set to either “true“ or “false“ depending on the
// check result.
AnonProxy string `protobuf:"bytes,9,opt,name=anon_proxy,json=anonProxy,proto3" json:"anon_proxy,omitempty"`
// If set, the key will be used to populate the ISP associated with the IP address.
Isp string `protobuf:"bytes,10,opt,name=isp,proto3" json:"isp,omitempty"`
// If set, the IP address will be checked if it belongs to the ISP named iCloud Private Relay
// and the result will be stored with this key. Value will be set to either “true“ or “false“
// depending on the check result.
ApplePrivateRelay string `protobuf:"bytes,11,opt,name=apple_private_relay,json=applePrivateRelay,proto3" json:"apple_private_relay,omitempty"`
// contains filtered or unexported fields
}
The set of geolocation field keys to use for storing lookup results. These keys define how the geolocation lookup results will be stored. The actual storage mechanism depends on the filter using the provider:
- The :ref:`HTTP GeoIP filter <config_http_filters_geoip>` stores results as HTTP request headers.
- The :ref:`Network GeoIP filter <config_network_filters_geoip>` stores results in the connection's filter state under the well-known key “envoy.geoip“.
[#next-free-field: 12]
func (*CommonGeoipProviderConfig_GeolocationFieldKeys) GetAnon ¶
func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) GetAnon() string
func (*CommonGeoipProviderConfig_GeolocationFieldKeys) GetAnonHosting ¶
func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) GetAnonHosting() string
func (*CommonGeoipProviderConfig_GeolocationFieldKeys) GetAnonProxy ¶
func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) GetAnonProxy() string
func (*CommonGeoipProviderConfig_GeolocationFieldKeys) GetAnonTor ¶
func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) GetAnonTor() string
func (*CommonGeoipProviderConfig_GeolocationFieldKeys) GetAnonVpn ¶
func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) GetAnonVpn() string
func (*CommonGeoipProviderConfig_GeolocationFieldKeys) GetApplePrivateRelay ¶
func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) GetApplePrivateRelay() string
func (*CommonGeoipProviderConfig_GeolocationFieldKeys) GetAsn ¶
func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) GetAsn() string
func (*CommonGeoipProviderConfig_GeolocationFieldKeys) GetCity ¶
func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) GetCity() string
func (*CommonGeoipProviderConfig_GeolocationFieldKeys) GetCountry ¶
func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) GetCountry() string
func (*CommonGeoipProviderConfig_GeolocationFieldKeys) GetIsp ¶
func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) GetIsp() string
func (*CommonGeoipProviderConfig_GeolocationFieldKeys) GetRegion ¶
func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) GetRegion() string
func (*CommonGeoipProviderConfig_GeolocationFieldKeys) ProtoMessage ¶
func (*CommonGeoipProviderConfig_GeolocationFieldKeys) ProtoMessage()
func (*CommonGeoipProviderConfig_GeolocationFieldKeys) ProtoReflect ¶
func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) ProtoReflect() protoreflect.Message
func (*CommonGeoipProviderConfig_GeolocationFieldKeys) Reset ¶
func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) Reset()
func (*CommonGeoipProviderConfig_GeolocationFieldKeys) SetAnon ¶
func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) SetAnon(v string)
func (*CommonGeoipProviderConfig_GeolocationFieldKeys) SetAnonHosting ¶
func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) SetAnonHosting(v string)
func (*CommonGeoipProviderConfig_GeolocationFieldKeys) SetAnonProxy ¶
func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) SetAnonProxy(v string)
func (*CommonGeoipProviderConfig_GeolocationFieldKeys) SetAnonTor ¶
func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) SetAnonTor(v string)
func (*CommonGeoipProviderConfig_GeolocationFieldKeys) SetAnonVpn ¶
func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) SetAnonVpn(v string)
func (*CommonGeoipProviderConfig_GeolocationFieldKeys) SetApplePrivateRelay ¶
func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) SetApplePrivateRelay(v string)
func (*CommonGeoipProviderConfig_GeolocationFieldKeys) SetAsn ¶
func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) SetAsn(v string)
func (*CommonGeoipProviderConfig_GeolocationFieldKeys) SetCity ¶
func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) SetCity(v string)
func (*CommonGeoipProviderConfig_GeolocationFieldKeys) SetCountry ¶
func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) SetCountry(v string)
func (*CommonGeoipProviderConfig_GeolocationFieldKeys) SetIsp ¶
func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) SetIsp(v string)
func (*CommonGeoipProviderConfig_GeolocationFieldKeys) SetRegion ¶
func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) SetRegion(v string)
func (*CommonGeoipProviderConfig_GeolocationFieldKeys) String ¶
func (x *CommonGeoipProviderConfig_GeolocationFieldKeys) String() string
type CommonGeoipProviderConfig_GeolocationFieldKeys_builder ¶
type CommonGeoipProviderConfig_GeolocationFieldKeys_builder struct {
// If set, the key will be used to populate the country ISO code associated with the IP address.
Country string
// If set, the key will be used to populate the city associated with the IP address.
City string
// If set, the key will be used to populate the region ISO code associated with the IP address.
// The least specific subdivision will be selected as the region value.
Region string
// If set, the key will be used to populate the ASN associated with the IP address.
Asn string
// If set, the IP address will be checked if it belongs to any type of anonymization network
// (e.g., VPN, public proxy). The result will be stored with this key. Value will be set to
// either “true“ or “false“ depending on the check result.
Anon string
// If set, the IP address will be checked if it belongs to a VPN and the result will be stored
// with this key. Value will be set to either “true“ or “false“ depending on the check result.
AnonVpn string
// If set, the IP address will be checked if it belongs to a hosting provider and the result
// will be stored with this key. Value will be set to either “true“ or “false“ depending on
// the check result.
AnonHosting string
// If set, the IP address will be checked if it belongs to a TOR exit node and the result will
// be stored with this key. Value will be set to either “true“ or “false“ depending on the
// check result.
AnonTor string
// If set, the IP address will be checked if it belongs to a public proxy and the result will
// be stored with this key. Value will be set to either “true“ or “false“ depending on the
// check result.
AnonProxy string
// If set, the key will be used to populate the ISP associated with the IP address.
Isp string
// If set, the IP address will be checked if it belongs to the ISP named iCloud Private Relay
// and the result will be stored with this key. Value will be set to either “true“ or “false“
// depending on the check result.
ApplePrivateRelay string
// contains filtered or unexported fields
}
func (CommonGeoipProviderConfig_GeolocationFieldKeys_builder) Build ¶
type CommonGeoipProviderConfig_GeolocationHeadersToAdd ¶
type CommonGeoipProviderConfig_GeolocationHeadersToAdd struct {
// If set, the header will be used to populate the country ISO code associated with the IP address.
Country string `protobuf:"bytes,1,opt,name=country,proto3" json:"country,omitempty"`
// If set, the header will be used to populate the city associated with the IP address.
City string `protobuf:"bytes,2,opt,name=city,proto3" json:"city,omitempty"`
// If set, the header will be used to populate the region ISO code associated with the IP address.
// The least specific subdivision will be selected as the region value.
Region string `protobuf:"bytes,3,opt,name=region,proto3" json:"region,omitempty"`
// If set, the header will be used to populate the ASN associated with the IP address.
Asn string `protobuf:"bytes,4,opt,name=asn,proto3" json:"asn,omitempty"`
// This field is deprecated; use “anon“ instead.
//
// Deprecated: Marked as deprecated in envoy/extensions/geoip_providers/common/v3/common.proto.
IsAnon string `protobuf:"bytes,5,opt,name=is_anon,json=isAnon,proto3" json:"is_anon,omitempty"`
// If set, the IP address will be checked if it belongs to any type of anonymization network (e.g., VPN, public proxy).
// The header will be populated with the check result. Header value will be set to either “true“ or “false“ depending on the check result.
Anon string `protobuf:"bytes,12,opt,name=anon,proto3" json:"anon,omitempty"`
// If set, the IP address will be checked if it belongs to a VPN and the header will be populated with the check result.
// Header value will be set to either “true“ or “false“ depending on the check result.
AnonVpn string `protobuf:"bytes,6,opt,name=anon_vpn,json=anonVpn,proto3" json:"anon_vpn,omitempty"`
// If set, the IP address will be checked if it belongs to a hosting provider and the header will be populated with the check result.
// Header value will be set to either “true“ or “false“ depending on the check result.
AnonHosting string `protobuf:"bytes,7,opt,name=anon_hosting,json=anonHosting,proto3" json:"anon_hosting,omitempty"`
// If set, the IP address will be checked if it belongs to a TOR exit node and the header will be populated with the check result.
// Header value will be set to either “true“ or “false“ depending on the check result.
AnonTor string `protobuf:"bytes,8,opt,name=anon_tor,json=anonTor,proto3" json:"anon_tor,omitempty"`
// If set, the IP address will be checked if it belongs to a public proxy and the header will be populated with the check result.
// Header value will be set to either “true“ or “false“ depending on the check result.
AnonProxy string `protobuf:"bytes,9,opt,name=anon_proxy,json=anonProxy,proto3" json:"anon_proxy,omitempty"`
// If set, the header will be used to populate the ISP associated with the IP address.
Isp string `protobuf:"bytes,10,opt,name=isp,proto3" json:"isp,omitempty"`
// If set, the IP address will be checked if it belongs to the ISP named iCloud Private Relay and the header will be populated with the check result.
// Header value will be set to either “true“ or “false“ depending on the check result.
ApplePrivateRelay string `protobuf:"bytes,11,opt,name=apple_private_relay,json=applePrivateRelay,proto3" json:"apple_private_relay,omitempty"`
// contains filtered or unexported fields
}
The set of geolocation headers to add to request. If any of the configured headers is present in the incoming request, it will be overridden by the :ref:`HTTP GeoIP filter <config_http_filters_geoip>`. [#next-free-field: 13]
.. attention::
This field is deprecated in favor of :ref:`geo_field_keys <envoy_v3_api_field_extensions.geoip_providers.common.v3.CommonGeoipProviderConfig.geo_field_keys>`.
func (*CommonGeoipProviderConfig_GeolocationHeadersToAdd) GetAnon ¶
func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) GetAnon() string
func (*CommonGeoipProviderConfig_GeolocationHeadersToAdd) GetAnonHosting ¶
func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) GetAnonHosting() string
func (*CommonGeoipProviderConfig_GeolocationHeadersToAdd) GetAnonProxy ¶
func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) GetAnonProxy() string
func (*CommonGeoipProviderConfig_GeolocationHeadersToAdd) GetAnonTor ¶
func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) GetAnonTor() string
func (*CommonGeoipProviderConfig_GeolocationHeadersToAdd) GetAnonVpn ¶
func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) GetAnonVpn() string
func (*CommonGeoipProviderConfig_GeolocationHeadersToAdd) GetApplePrivateRelay ¶
func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) GetApplePrivateRelay() string
func (*CommonGeoipProviderConfig_GeolocationHeadersToAdd) GetAsn ¶
func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) GetAsn() string
func (*CommonGeoipProviderConfig_GeolocationHeadersToAdd) GetCity ¶
func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) GetCity() string
func (*CommonGeoipProviderConfig_GeolocationHeadersToAdd) GetCountry ¶
func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) GetCountry() string
func (*CommonGeoipProviderConfig_GeolocationHeadersToAdd) GetIsAnon
deprecated
func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) GetIsAnon() string
Deprecated: Marked as deprecated in envoy/extensions/geoip_providers/common/v3/common.proto.
func (*CommonGeoipProviderConfig_GeolocationHeadersToAdd) GetIsp ¶
func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) GetIsp() string
func (*CommonGeoipProviderConfig_GeolocationHeadersToAdd) GetRegion ¶
func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) GetRegion() string
func (*CommonGeoipProviderConfig_GeolocationHeadersToAdd) ProtoMessage ¶
func (*CommonGeoipProviderConfig_GeolocationHeadersToAdd) ProtoMessage()
func (*CommonGeoipProviderConfig_GeolocationHeadersToAdd) ProtoReflect ¶
func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) ProtoReflect() protoreflect.Message
func (*CommonGeoipProviderConfig_GeolocationHeadersToAdd) Reset ¶
func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) Reset()
func (*CommonGeoipProviderConfig_GeolocationHeadersToAdd) SetAnon ¶
func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) SetAnon(v string)
func (*CommonGeoipProviderConfig_GeolocationHeadersToAdd) SetAnonHosting ¶
func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) SetAnonHosting(v string)
func (*CommonGeoipProviderConfig_GeolocationHeadersToAdd) SetAnonProxy ¶
func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) SetAnonProxy(v string)
func (*CommonGeoipProviderConfig_GeolocationHeadersToAdd) SetAnonTor ¶
func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) SetAnonTor(v string)
func (*CommonGeoipProviderConfig_GeolocationHeadersToAdd) SetAnonVpn ¶
func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) SetAnonVpn(v string)
func (*CommonGeoipProviderConfig_GeolocationHeadersToAdd) SetApplePrivateRelay ¶
func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) SetApplePrivateRelay(v string)
func (*CommonGeoipProviderConfig_GeolocationHeadersToAdd) SetAsn ¶
func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) SetAsn(v string)
func (*CommonGeoipProviderConfig_GeolocationHeadersToAdd) SetCity ¶
func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) SetCity(v string)
func (*CommonGeoipProviderConfig_GeolocationHeadersToAdd) SetCountry ¶
func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) SetCountry(v string)
func (*CommonGeoipProviderConfig_GeolocationHeadersToAdd) SetIsAnon
deprecated
func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) SetIsAnon(v string)
Deprecated: Marked as deprecated in envoy/extensions/geoip_providers/common/v3/common.proto.
func (*CommonGeoipProviderConfig_GeolocationHeadersToAdd) SetIsp ¶
func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) SetIsp(v string)
func (*CommonGeoipProviderConfig_GeolocationHeadersToAdd) SetRegion ¶
func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) SetRegion(v string)
func (*CommonGeoipProviderConfig_GeolocationHeadersToAdd) String ¶
func (x *CommonGeoipProviderConfig_GeolocationHeadersToAdd) String() string
type CommonGeoipProviderConfig_GeolocationHeadersToAdd_builder ¶
type CommonGeoipProviderConfig_GeolocationHeadersToAdd_builder struct {
// If set, the header will be used to populate the country ISO code associated with the IP address.
Country string
// If set, the header will be used to populate the city associated with the IP address.
City string
// If set, the header will be used to populate the region ISO code associated with the IP address.
// The least specific subdivision will be selected as the region value.
Region string
// If set, the header will be used to populate the ASN associated with the IP address.
Asn string
// This field is deprecated; use “anon“ instead.
//
// Deprecated: Marked as deprecated in envoy/extensions/geoip_providers/common/v3/common.proto.
IsAnon string
// If set, the IP address will be checked if it belongs to any type of anonymization network (e.g., VPN, public proxy).
// The header will be populated with the check result. Header value will be set to either “true“ or “false“ depending on the check result.
Anon string
// If set, the IP address will be checked if it belongs to a VPN and the header will be populated with the check result.
// Header value will be set to either “true“ or “false“ depending on the check result.
AnonVpn string
// If set, the IP address will be checked if it belongs to a hosting provider and the header will be populated with the check result.
// Header value will be set to either “true“ or “false“ depending on the check result.
AnonHosting string
// If set, the IP address will be checked if it belongs to a TOR exit node and the header will be populated with the check result.
// Header value will be set to either “true“ or “false“ depending on the check result.
AnonTor string
// If set, the IP address will be checked if it belongs to a public proxy and the header will be populated with the check result.
// Header value will be set to either “true“ or “false“ depending on the check result.
AnonProxy string
// If set, the header will be used to populate the ISP associated with the IP address.
Isp string
// If set, the IP address will be checked if it belongs to the ISP named iCloud Private Relay and the header will be populated with the check result.
// Header value will be set to either “true“ or “false“ depending on the check result.
ApplePrivateRelay string
// contains filtered or unexported fields
}
func (CommonGeoipProviderConfig_GeolocationHeadersToAdd_builder) Build ¶
type CommonGeoipProviderConfig_builder ¶
type CommonGeoipProviderConfig_builder struct {
// Configuration for geolocation headers to add to HTTP requests.
// This field is deprecated in favor of “geo_field_keys“. If both are set, “geo_field_keys“
// takes precedence.
//
// Deprecated: Marked as deprecated in envoy/extensions/geoip_providers/common/v3/common.proto.
GeoHeadersToAdd *CommonGeoipProviderConfig_GeolocationHeadersToAdd
// Configuration for geolocation field keys.
// At least one of “geo_headers_to_add“ or “geo_field_keys“ must be set.
GeoFieldKeys *CommonGeoipProviderConfig_GeolocationFieldKeys
// contains filtered or unexported fields
}
func (CommonGeoipProviderConfig_builder) Build ¶
func (b0 CommonGeoipProviderConfig_builder) Build() *CommonGeoipProviderConfig
Source Files
¶
- common.pb.go