Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var File_envoy_extensions_load_balancing_policies_pick_first_v3_pick_first_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type PickFirst ¶
type PickFirst struct {
// If set to true, instructs the LB policy to shuffle the list of addresses
// received from the name resolver before attempting to connect to them.
ShuffleAddressList bool `protobuf:"varint,1,opt,name=shuffle_address_list,json=shuffleAddressList,proto3" json:"shuffle_address_list,omitempty"`
// contains filtered or unexported fields
}
This configuration allows the built-in PICK_FIRST LB policy to be configured via the LB policy extension point.
func (*PickFirst) ProtoReflect ¶
func (x *PickFirst) ProtoReflect() protoreflect.Message
type PickFirst_builder ¶
type PickFirst_builder struct {
// If set to true, instructs the LB policy to shuffle the list of addresses
// received from the name resolver before attempting to connect to them.
ShuffleAddressList bool
// contains filtered or unexported fields
}
func (PickFirst_builder) Build ¶
func (b0 PickFirst_builder) Build() *PickFirst
Source Files
¶
- pick_first.pb.go
Click to show internal directories.
Click to hide internal directories.