Documentation
¶
Index ¶
- Variables
- type Metadata
- func (x *Metadata) ClearValue()
- func (x *Metadata) GetInvert() bool
- func (x *Metadata) GetValue() *v3.ValueMatcher
- func (x *Metadata) HasValue() bool
- func (*Metadata) ProtoMessage()
- func (x *Metadata) ProtoReflect() protoreflect.Message
- func (x *Metadata) Reset()
- func (x *Metadata) SetInvert(v bool)
- func (x *Metadata) SetValue(v *v3.ValueMatcher)
- func (x *Metadata) String() string
- type Metadata_builder
Constants ¶
This section is empty.
Variables ¶
var File_envoy_extensions_matching_input_matchers_metadata_v3_metadata_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Metadata ¶
type Metadata struct {
// The Metadata is matched if the value retrieved by metadata matching input is matched to this value.
Value *v3.ValueMatcher `protobuf:"bytes,1,opt,name=value,proto3" json:"value,omitempty"`
// If true, the match result will be inverted.
Invert bool `protobuf:"varint,4,opt,name=invert,proto3" json:"invert,omitempty"`
// contains filtered or unexported fields
}
Metadata matcher for metadata from http matching input data.
func (*Metadata) GetValue ¶
func (x *Metadata) GetValue() *v3.ValueMatcher
func (*Metadata) ProtoReflect ¶
func (x *Metadata) ProtoReflect() protoreflect.Message
func (*Metadata) SetValue ¶
func (x *Metadata) SetValue(v *v3.ValueMatcher)
type Metadata_builder ¶
type Metadata_builder struct {
// The Metadata is matched if the value retrieved by metadata matching input is matched to this value.
Value *v3.ValueMatcher
// If true, the match result will be inverted.
Invert bool
// contains filtered or unexported fields
}
func (Metadata_builder) Build ¶
func (b0 Metadata_builder) Build() *Metadata
Source Files
¶
- metadata.pb.go
Click to show internal directories.
Click to hide internal directories.