Documentation
¶
Index ¶
- Variables
- type Config
- func (x *Config) ClearUpdatePeriod()
- func (x *Config) GetUpdatePeriod() *durationpb.Duration
- func (x *Config) HasUpdatePeriod() bool
- func (*Config) ProtoMessage()
- func (x *Config) ProtoReflect() protoreflect.Message
- func (x *Config) Reset()
- func (x *Config) SetUpdatePeriod(v *durationpb.Duration)
- func (x *Config) String() string
- type Config_builder
Constants ¶
This section is empty.
Variables ¶
var File_envoy_extensions_quic_connection_debug_visitor_quic_stats_v3_quic_stats_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
// Period to update stats while the connection is open. If unset, updates only happen when the
// connection is closed. Stats are always updated one final time when the connection is closed.
UpdatePeriod *durationpb.Duration `protobuf:"bytes,2,opt,name=update_period,json=updatePeriod,proto3" json:"update_period,omitempty"`
// contains filtered or unexported fields
}
Configuration for a QUIC debug visitor which emits stats from the underlying QUIC transport.
func (*Config) GetUpdatePeriod ¶
func (x *Config) GetUpdatePeriod() *durationpb.Duration
func (*Config) ProtoReflect ¶
func (x *Config) ProtoReflect() protoreflect.Message
func (*Config) SetUpdatePeriod ¶
func (x *Config) SetUpdatePeriod(v *durationpb.Duration)
type Config_builder ¶
type Config_builder struct {
// Period to update stats while the connection is open. If unset, updates only happen when the
// connection is closed. Stats are always updated one final time when the connection is closed.
UpdatePeriod *durationpb.Duration
// contains filtered or unexported fields
}
func (Config_builder) Build ¶
func (b0 Config_builder) Build() *Config
Source Files
¶
- quic_stats.pb.go
Click to show internal directories.
Click to hide internal directories.