Documentation
¶
Index ¶
- Variables
- type InjectedResourceConfig
- func (x *InjectedResourceConfig) GetFilename() string
- func (*InjectedResourceConfig) ProtoMessage()
- func (x *InjectedResourceConfig) ProtoReflect() protoreflect.Message
- func (x *InjectedResourceConfig) Reset()
- func (x *InjectedResourceConfig) SetFilename(v string)
- func (x *InjectedResourceConfig) String() string
- type InjectedResourceConfig_builder
Constants ¶
This section is empty.
Variables ¶
var File_envoy_extensions_resource_monitors_injected_resource_v3_injected_resource_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type InjectedResourceConfig ¶
type InjectedResourceConfig struct {
Filename string `protobuf:"bytes,1,opt,name=filename,proto3" json:"filename,omitempty"`
// contains filtered or unexported fields
}
The injected resource monitor allows injecting a synthetic resource pressure into Envoy via a text file, which must contain a floating-point number in the range [0..1] representing the resource pressure and be updated atomically by a symbolic link swap. This is intended primarily for integration tests to force Envoy into an overloaded state.
func (*InjectedResourceConfig) GetFilename ¶
func (x *InjectedResourceConfig) GetFilename() string
func (*InjectedResourceConfig) ProtoMessage ¶
func (*InjectedResourceConfig) ProtoMessage()
func (*InjectedResourceConfig) ProtoReflect ¶
func (x *InjectedResourceConfig) ProtoReflect() protoreflect.Message
func (*InjectedResourceConfig) Reset ¶
func (x *InjectedResourceConfig) Reset()
func (*InjectedResourceConfig) SetFilename ¶
func (x *InjectedResourceConfig) SetFilename(v string)
func (*InjectedResourceConfig) String ¶
func (x *InjectedResourceConfig) String() string
type InjectedResourceConfig_builder ¶
type InjectedResourceConfig_builder struct {
Filename string
// contains filtered or unexported fields
}
func (InjectedResourceConfig_builder) Build ¶
func (b0 InjectedResourceConfig_builder) Build() *InjectedResourceConfig
Source Files
¶
- injected_resource.pb.go
Click to show internal directories.
Click to hide internal directories.