Documentation
¶
Index ¶
- Variables
- type ProxyProtocolUpstreamTransport
- func (x *ProxyProtocolUpstreamTransport) ClearConfig()
- func (x *ProxyProtocolUpstreamTransport) ClearTransportSocket()
- func (x *ProxyProtocolUpstreamTransport) GetAllowUnspecifiedAddress() bool
- func (x *ProxyProtocolUpstreamTransport) GetConfig() *v3.ProxyProtocolConfig
- func (x *ProxyProtocolUpstreamTransport) GetTlvAsPoolKey() bool
- func (x *ProxyProtocolUpstreamTransport) GetTransportSocket() *v3.TransportSocket
- func (x *ProxyProtocolUpstreamTransport) HasConfig() bool
- func (x *ProxyProtocolUpstreamTransport) HasTransportSocket() bool
- func (*ProxyProtocolUpstreamTransport) ProtoMessage()
- func (x *ProxyProtocolUpstreamTransport) ProtoReflect() protoreflect.Message
- func (x *ProxyProtocolUpstreamTransport) Reset()
- func (x *ProxyProtocolUpstreamTransport) SetAllowUnspecifiedAddress(v bool)
- func (x *ProxyProtocolUpstreamTransport) SetConfig(v *v3.ProxyProtocolConfig)
- func (x *ProxyProtocolUpstreamTransport) SetTlvAsPoolKey(v bool)
- func (x *ProxyProtocolUpstreamTransport) SetTransportSocket(v *v3.TransportSocket)
- func (x *ProxyProtocolUpstreamTransport) String() string
- type ProxyProtocolUpstreamTransport_builder
Constants ¶
This section is empty.
Variables ¶
var File_envoy_extensions_transport_sockets_proxy_protocol_v3_upstream_proxy_protocol_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type ProxyProtocolUpstreamTransport ¶
type ProxyProtocolUpstreamTransport struct {
// The PROXY protocol settings
Config *v3.ProxyProtocolConfig `protobuf:"bytes,1,opt,name=config,proto3" json:"config,omitempty"`
// The underlying transport socket being wrapped.
TransportSocket *v3.TransportSocket `protobuf:"bytes,2,opt,name=transport_socket,json=transportSocket,proto3" json:"transport_socket,omitempty"`
// If this is set to true, the null addresses are allowed in the PROXY protocol header.
// The proxy protocol header encodes the null addresses to AF_UNSPEC.
// [#not-implemented-hide:]
AllowUnspecifiedAddress bool `` /* 133-byte string literal not displayed */
// If true, all the TLVs are encoded in the connection pool key.
// [#not-implemented-hide:]
TlvAsPoolKey bool `protobuf:"varint,4,opt,name=tlv_as_pool_key,json=tlvAsPoolKey,proto3" json:"tlv_as_pool_key,omitempty"`
// contains filtered or unexported fields
}
Configuration for PROXY protocol socket
func (*ProxyProtocolUpstreamTransport) ClearConfig ¶
func (x *ProxyProtocolUpstreamTransport) ClearConfig()
func (*ProxyProtocolUpstreamTransport) ClearTransportSocket ¶
func (x *ProxyProtocolUpstreamTransport) ClearTransportSocket()
func (*ProxyProtocolUpstreamTransport) GetAllowUnspecifiedAddress ¶
func (x *ProxyProtocolUpstreamTransport) GetAllowUnspecifiedAddress() bool
func (*ProxyProtocolUpstreamTransport) GetConfig ¶
func (x *ProxyProtocolUpstreamTransport) GetConfig() *v3.ProxyProtocolConfig
func (*ProxyProtocolUpstreamTransport) GetTlvAsPoolKey ¶
func (x *ProxyProtocolUpstreamTransport) GetTlvAsPoolKey() bool
func (*ProxyProtocolUpstreamTransport) GetTransportSocket ¶
func (x *ProxyProtocolUpstreamTransport) GetTransportSocket() *v3.TransportSocket
func (*ProxyProtocolUpstreamTransport) HasConfig ¶
func (x *ProxyProtocolUpstreamTransport) HasConfig() bool
func (*ProxyProtocolUpstreamTransport) HasTransportSocket ¶
func (x *ProxyProtocolUpstreamTransport) HasTransportSocket() bool
func (*ProxyProtocolUpstreamTransport) ProtoMessage ¶
func (*ProxyProtocolUpstreamTransport) ProtoMessage()
func (*ProxyProtocolUpstreamTransport) ProtoReflect ¶
func (x *ProxyProtocolUpstreamTransport) ProtoReflect() protoreflect.Message
func (*ProxyProtocolUpstreamTransport) Reset ¶
func (x *ProxyProtocolUpstreamTransport) Reset()
func (*ProxyProtocolUpstreamTransport) SetAllowUnspecifiedAddress ¶
func (x *ProxyProtocolUpstreamTransport) SetAllowUnspecifiedAddress(v bool)
func (*ProxyProtocolUpstreamTransport) SetConfig ¶
func (x *ProxyProtocolUpstreamTransport) SetConfig(v *v3.ProxyProtocolConfig)
func (*ProxyProtocolUpstreamTransport) SetTlvAsPoolKey ¶
func (x *ProxyProtocolUpstreamTransport) SetTlvAsPoolKey(v bool)
func (*ProxyProtocolUpstreamTransport) SetTransportSocket ¶
func (x *ProxyProtocolUpstreamTransport) SetTransportSocket(v *v3.TransportSocket)
func (*ProxyProtocolUpstreamTransport) String ¶
func (x *ProxyProtocolUpstreamTransport) String() string
type ProxyProtocolUpstreamTransport_builder ¶
type ProxyProtocolUpstreamTransport_builder struct {
// The PROXY protocol settings
Config *v3.ProxyProtocolConfig
// The underlying transport socket being wrapped.
TransportSocket *v3.TransportSocket
// If this is set to true, the null addresses are allowed in the PROXY protocol header.
// The proxy protocol header encodes the null addresses to AF_UNSPEC.
// [#not-implemented-hide:]
AllowUnspecifiedAddress bool
// If true, all the TLVs are encoded in the connection pool key.
// [#not-implemented-hide:]
TlvAsPoolKey bool
// contains filtered or unexported fields
}
func (ProxyProtocolUpstreamTransport_builder) Build ¶
func (b0 ProxyProtocolUpstreamTransport_builder) Build() *ProxyProtocolUpstreamTransport
Source Files
¶
- upstream_proxy_protocol.pb.go
Click to show internal directories.
Click to hide internal directories.