Documentation
¶
Index ¶
- Variables
- type RedisProxyExternalAuthRequest
- func (x *RedisProxyExternalAuthRequest) GetPassword() string
- func (x *RedisProxyExternalAuthRequest) GetUsername() string
- func (*RedisProxyExternalAuthRequest) ProtoMessage()
- func (x *RedisProxyExternalAuthRequest) ProtoReflect() protoreflect.Message
- func (x *RedisProxyExternalAuthRequest) Reset()
- func (x *RedisProxyExternalAuthRequest) SetPassword(v string)
- func (x *RedisProxyExternalAuthRequest) SetUsername(v string)
- func (x *RedisProxyExternalAuthRequest) String() string
- type RedisProxyExternalAuthRequest_builder
- type RedisProxyExternalAuthResponse
- func (x *RedisProxyExternalAuthResponse) ClearExpiration()
- func (x *RedisProxyExternalAuthResponse) ClearStatus()
- func (x *RedisProxyExternalAuthResponse) GetExpiration() *timestamppb.Timestamp
- func (x *RedisProxyExternalAuthResponse) GetMessage() string
- func (x *RedisProxyExternalAuthResponse) GetStatus() *status.Status
- func (x *RedisProxyExternalAuthResponse) HasExpiration() bool
- func (x *RedisProxyExternalAuthResponse) HasStatus() bool
- func (*RedisProxyExternalAuthResponse) ProtoMessage()
- func (x *RedisProxyExternalAuthResponse) ProtoReflect() protoreflect.Message
- func (x *RedisProxyExternalAuthResponse) Reset()
- func (x *RedisProxyExternalAuthResponse) SetExpiration(v *timestamppb.Timestamp)
- func (x *RedisProxyExternalAuthResponse) SetMessage(v string)
- func (x *RedisProxyExternalAuthResponse) SetStatus(v *status.Status)
- func (x *RedisProxyExternalAuthResponse) String() string
- type RedisProxyExternalAuthResponse_builder
Constants ¶
This section is empty.
Variables ¶
var File_envoy_service_redis_auth_v3_redis_external_auth_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type RedisProxyExternalAuthRequest ¶
type RedisProxyExternalAuthRequest struct {
// Username, if applicable. Otherwise, empty.
Username string `protobuf:"bytes,1,opt,name=username,proto3" json:"username,omitempty"`
// Password sent with the AUTH command.
Password string `protobuf:"bytes,2,opt,name=password,proto3" json:"password,omitempty"`
// contains filtered or unexported fields
}
func (*RedisProxyExternalAuthRequest) GetPassword ¶
func (x *RedisProxyExternalAuthRequest) GetPassword() string
func (*RedisProxyExternalAuthRequest) GetUsername ¶
func (x *RedisProxyExternalAuthRequest) GetUsername() string
func (*RedisProxyExternalAuthRequest) ProtoMessage ¶
func (*RedisProxyExternalAuthRequest) ProtoMessage()
func (*RedisProxyExternalAuthRequest) ProtoReflect ¶
func (x *RedisProxyExternalAuthRequest) ProtoReflect() protoreflect.Message
func (*RedisProxyExternalAuthRequest) Reset ¶
func (x *RedisProxyExternalAuthRequest) Reset()
func (*RedisProxyExternalAuthRequest) SetPassword ¶
func (x *RedisProxyExternalAuthRequest) SetPassword(v string)
func (*RedisProxyExternalAuthRequest) SetUsername ¶
func (x *RedisProxyExternalAuthRequest) SetUsername(v string)
func (*RedisProxyExternalAuthRequest) String ¶
func (x *RedisProxyExternalAuthRequest) String() string
type RedisProxyExternalAuthRequest_builder ¶
type RedisProxyExternalAuthRequest_builder struct {
// Username, if applicable. Otherwise, empty.
Username string
// Password sent with the AUTH command.
Password string
// contains filtered or unexported fields
}
func (RedisProxyExternalAuthRequest_builder) Build ¶
func (b0 RedisProxyExternalAuthRequest_builder) Build() *RedisProxyExternalAuthRequest
type RedisProxyExternalAuthResponse ¶
type RedisProxyExternalAuthResponse struct {
// Status of the authentication check.
Status *status.Status `protobuf:"bytes,1,opt,name=status,proto3" json:"status,omitempty"`
// Optional expiration time for the authentication.
// If set, the authentication will be valid until this time.
// If not set, the authentication will be valid indefinitely.
Expiration *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=expiration,proto3" json:"expiration,omitempty"`
// Optional message to be sent back to the client.
Message string `protobuf:"bytes,3,opt,name=message,proto3" json:"message,omitempty"`
// contains filtered or unexported fields
}
func (*RedisProxyExternalAuthResponse) ClearExpiration ¶
func (x *RedisProxyExternalAuthResponse) ClearExpiration()
func (*RedisProxyExternalAuthResponse) ClearStatus ¶
func (x *RedisProxyExternalAuthResponse) ClearStatus()
func (*RedisProxyExternalAuthResponse) GetExpiration ¶
func (x *RedisProxyExternalAuthResponse) GetExpiration() *timestamppb.Timestamp
func (*RedisProxyExternalAuthResponse) GetMessage ¶
func (x *RedisProxyExternalAuthResponse) GetMessage() string
func (*RedisProxyExternalAuthResponse) GetStatus ¶
func (x *RedisProxyExternalAuthResponse) GetStatus() *status.Status
func (*RedisProxyExternalAuthResponse) HasExpiration ¶
func (x *RedisProxyExternalAuthResponse) HasExpiration() bool
func (*RedisProxyExternalAuthResponse) HasStatus ¶
func (x *RedisProxyExternalAuthResponse) HasStatus() bool
func (*RedisProxyExternalAuthResponse) ProtoMessage ¶
func (*RedisProxyExternalAuthResponse) ProtoMessage()
func (*RedisProxyExternalAuthResponse) ProtoReflect ¶
func (x *RedisProxyExternalAuthResponse) ProtoReflect() protoreflect.Message
func (*RedisProxyExternalAuthResponse) Reset ¶
func (x *RedisProxyExternalAuthResponse) Reset()
func (*RedisProxyExternalAuthResponse) SetExpiration ¶
func (x *RedisProxyExternalAuthResponse) SetExpiration(v *timestamppb.Timestamp)
func (*RedisProxyExternalAuthResponse) SetMessage ¶
func (x *RedisProxyExternalAuthResponse) SetMessage(v string)
func (*RedisProxyExternalAuthResponse) SetStatus ¶
func (x *RedisProxyExternalAuthResponse) SetStatus(v *status.Status)
func (*RedisProxyExternalAuthResponse) String ¶
func (x *RedisProxyExternalAuthResponse) String() string
type RedisProxyExternalAuthResponse_builder ¶
type RedisProxyExternalAuthResponse_builder struct {
// Status of the authentication check.
Status *status.Status
// Optional expiration time for the authentication.
// If set, the authentication will be valid until this time.
// If not set, the authentication will be valid indefinitely.
Expiration *timestamppb.Timestamp
// Optional message to be sent back to the client.
Message string
// contains filtered or unexported fields
}
func (RedisProxyExternalAuthResponse_builder) Build ¶
func (b0 RedisProxyExternalAuthResponse_builder) Build() *RedisProxyExternalAuthResponse
Source Files
¶
- redis_external_auth.pb.go
Click to show internal directories.
Click to hide internal directories.