Documentation
¶
Index ¶
- Constants
- Variables
- type CustomTag
- func (x *CustomTag) ClearEnvironment()
- func (x *CustomTag) ClearLiteral()
- func (x *CustomTag) ClearMetadata()
- func (x *CustomTag) ClearRequestHeader()
- func (x *CustomTag) ClearType()
- func (x *CustomTag) ClearValue()
- func (x *CustomTag) GetEnvironment() *CustomTag_Environment
- func (x *CustomTag) GetLiteral() *CustomTag_Literal
- func (x *CustomTag) GetMetadata() *CustomTag_Metadata
- func (x *CustomTag) GetRequestHeader() *CustomTag_Header
- func (x *CustomTag) GetTag() string
- func (x *CustomTag) GetType() isCustomTag_Type
- func (x *CustomTag) GetValue() string
- func (x *CustomTag) HasEnvironment() bool
- func (x *CustomTag) HasLiteral() bool
- func (x *CustomTag) HasMetadata() bool
- func (x *CustomTag) HasRequestHeader() bool
- func (x *CustomTag) HasType() bool
- func (x *CustomTag) HasValue() bool
- func (*CustomTag) ProtoMessage()
- func (x *CustomTag) ProtoReflect() protoreflect.Message
- func (x *CustomTag) Reset()
- func (x *CustomTag) SetEnvironment(v *CustomTag_Environment)
- func (x *CustomTag) SetLiteral(v *CustomTag_Literal)
- func (x *CustomTag) SetMetadata(v *CustomTag_Metadata)
- func (x *CustomTag) SetRequestHeader(v *CustomTag_Header)
- func (x *CustomTag) SetTag(v string)
- func (x *CustomTag) SetValue(v string)
- func (x *CustomTag) String() string
- func (x *CustomTag) WhichType() case_CustomTag_Type
- type CustomTag_Environment
- func (x *CustomTag_Environment) GetDefaultValue() string
- func (x *CustomTag_Environment) GetName() string
- func (*CustomTag_Environment) ProtoMessage()
- func (x *CustomTag_Environment) ProtoReflect() protoreflect.Message
- func (x *CustomTag_Environment) Reset()
- func (x *CustomTag_Environment) SetDefaultValue(v string)
- func (x *CustomTag_Environment) SetName(v string)
- func (x *CustomTag_Environment) String() string
- type CustomTag_Environment_
- type CustomTag_Environment_builder
- type CustomTag_Header
- func (x *CustomTag_Header) GetDefaultValue() string
- func (x *CustomTag_Header) GetName() string
- func (*CustomTag_Header) ProtoMessage()
- func (x *CustomTag_Header) ProtoReflect() protoreflect.Message
- func (x *CustomTag_Header) Reset()
- func (x *CustomTag_Header) SetDefaultValue(v string)
- func (x *CustomTag_Header) SetName(v string)
- func (x *CustomTag_Header) String() string
- type CustomTag_Header_builder
- type CustomTag_Literal
- type CustomTag_Literal_
- type CustomTag_Literal_builder
- type CustomTag_Metadata
- func (x *CustomTag_Metadata) ClearKind()
- func (x *CustomTag_Metadata) ClearMetadataKey()
- func (x *CustomTag_Metadata) GetDefaultValue() string
- func (x *CustomTag_Metadata) GetKind() *v3.MetadataKind
- func (x *CustomTag_Metadata) GetMetadataKey() *v3.MetadataKey
- func (x *CustomTag_Metadata) HasKind() bool
- func (x *CustomTag_Metadata) HasMetadataKey() bool
- func (*CustomTag_Metadata) ProtoMessage()
- func (x *CustomTag_Metadata) ProtoReflect() protoreflect.Message
- func (x *CustomTag_Metadata) Reset()
- func (x *CustomTag_Metadata) SetDefaultValue(v string)
- func (x *CustomTag_Metadata) SetKind(v *v3.MetadataKind)
- func (x *CustomTag_Metadata) SetMetadataKey(v *v3.MetadataKey)
- func (x *CustomTag_Metadata) String() string
- type CustomTag_Metadata_
- type CustomTag_Metadata_builder
- type CustomTag_RequestHeader
- type CustomTag_Value
- type CustomTag_builder
Constants ¶
const CustomTag_Environment_case case_CustomTag_Type = 3
const CustomTag_Literal_case case_CustomTag_Type = 2
const CustomTag_Metadata_case case_CustomTag_Type = 5
const CustomTag_RequestHeader_case case_CustomTag_Type = 4
const CustomTag_Type_not_set_case case_CustomTag_Type = 0
const CustomTag_Value_case case_CustomTag_Type = 6
Variables ¶
var File_envoy_type_tracing_v3_custom_tag_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type CustomTag ¶
type CustomTag struct {
// Used to populate the tag name.
Tag string `protobuf:"bytes,1,opt,name=tag,proto3" json:"tag,omitempty"`
// Used to specify what kind of custom tag.
//
// Types that are valid to be assigned to Type:
//
// *CustomTag_Literal_
// *CustomTag_Environment_
// *CustomTag_RequestHeader
// *CustomTag_Metadata_
// *CustomTag_Value
Type isCustomTag_Type `protobuf_oneof:"type"`
// contains filtered or unexported fields
}
Describes custom tags for the active span. [#next-free-field: 7]
func (*CustomTag) GetEnvironment ¶
func (x *CustomTag) GetEnvironment() *CustomTag_Environment
func (*CustomTag) GetLiteral ¶
func (x *CustomTag) GetLiteral() *CustomTag_Literal
func (*CustomTag) GetMetadata ¶
func (x *CustomTag) GetMetadata() *CustomTag_Metadata
func (*CustomTag) GetRequestHeader ¶
func (x *CustomTag) GetRequestHeader() *CustomTag_Header
func (*CustomTag) ProtoReflect ¶
func (x *CustomTag) ProtoReflect() protoreflect.Message
func (*CustomTag) SetEnvironment ¶
func (x *CustomTag) SetEnvironment(v *CustomTag_Environment)
func (*CustomTag) SetLiteral ¶
func (x *CustomTag) SetLiteral(v *CustomTag_Literal)
func (*CustomTag) SetMetadata ¶
func (x *CustomTag) SetMetadata(v *CustomTag_Metadata)
func (*CustomTag) SetRequestHeader ¶
func (x *CustomTag) SetRequestHeader(v *CustomTag_Header)
type CustomTag_Environment ¶
type CustomTag_Environment struct {
// Environment variable name to obtain the value to populate the tag value.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// When the environment variable is not found,
// the tag value will be populated with this default value if specified,
// otherwise no tag will be populated.
DefaultValue string `protobuf:"bytes,2,opt,name=default_value,json=defaultValue,proto3" json:"default_value,omitempty"`
// contains filtered or unexported fields
}
Environment type custom tag with environment name and default value.
func (*CustomTag_Environment) GetDefaultValue ¶
func (x *CustomTag_Environment) GetDefaultValue() string
func (*CustomTag_Environment) GetName ¶
func (x *CustomTag_Environment) GetName() string
func (*CustomTag_Environment) ProtoMessage ¶
func (*CustomTag_Environment) ProtoMessage()
func (*CustomTag_Environment) ProtoReflect ¶
func (x *CustomTag_Environment) ProtoReflect() protoreflect.Message
func (*CustomTag_Environment) Reset ¶
func (x *CustomTag_Environment) Reset()
func (*CustomTag_Environment) SetDefaultValue ¶
func (x *CustomTag_Environment) SetDefaultValue(v string)
func (*CustomTag_Environment) SetName ¶
func (x *CustomTag_Environment) SetName(v string)
func (*CustomTag_Environment) String ¶
func (x *CustomTag_Environment) String() string
type CustomTag_Environment_ ¶
type CustomTag_Environment_ struct {
// An environment custom tag.
Environment *CustomTag_Environment `protobuf:"bytes,3,opt,name=environment,proto3,oneof"`
}
type CustomTag_Environment_builder ¶
type CustomTag_Environment_builder struct {
// Environment variable name to obtain the value to populate the tag value.
Name string
// When the environment variable is not found,
// the tag value will be populated with this default value if specified,
// otherwise no tag will be populated.
DefaultValue string
// contains filtered or unexported fields
}
func (CustomTag_Environment_builder) Build ¶
func (b0 CustomTag_Environment_builder) Build() *CustomTag_Environment
type CustomTag_Header ¶
type CustomTag_Header struct {
// Header name to obtain the value to populate the tag value.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// When the header does not exist,
// the tag value will be populated with this default value if specified,
// otherwise no tag will be populated.
DefaultValue string `protobuf:"bytes,2,opt,name=default_value,json=defaultValue,proto3" json:"default_value,omitempty"`
// contains filtered or unexported fields
}
Header type custom tag with header name and default value.
func (*CustomTag_Header) GetDefaultValue ¶
func (x *CustomTag_Header) GetDefaultValue() string
func (*CustomTag_Header) GetName ¶
func (x *CustomTag_Header) GetName() string
func (*CustomTag_Header) ProtoMessage ¶
func (*CustomTag_Header) ProtoMessage()
func (*CustomTag_Header) ProtoReflect ¶
func (x *CustomTag_Header) ProtoReflect() protoreflect.Message
func (*CustomTag_Header) Reset ¶
func (x *CustomTag_Header) Reset()
func (*CustomTag_Header) SetDefaultValue ¶
func (x *CustomTag_Header) SetDefaultValue(v string)
func (*CustomTag_Header) SetName ¶
func (x *CustomTag_Header) SetName(v string)
func (*CustomTag_Header) String ¶
func (x *CustomTag_Header) String() string
type CustomTag_Header_builder ¶
type CustomTag_Header_builder struct {
// Header name to obtain the value to populate the tag value.
Name string
// When the header does not exist,
// the tag value will be populated with this default value if specified,
// otherwise no tag will be populated.
DefaultValue string
// contains filtered or unexported fields
}
func (CustomTag_Header_builder) Build ¶
func (b0 CustomTag_Header_builder) Build() *CustomTag_Header
type CustomTag_Literal ¶
type CustomTag_Literal struct {
// Static literal value to populate the tag value.
Value string `protobuf:"bytes,1,opt,name=value,proto3" json:"value,omitempty"`
// contains filtered or unexported fields
}
Literal type custom tag with static value for the tag value.
func (*CustomTag_Literal) GetValue ¶
func (x *CustomTag_Literal) GetValue() string
func (*CustomTag_Literal) ProtoMessage ¶
func (*CustomTag_Literal) ProtoMessage()
func (*CustomTag_Literal) ProtoReflect ¶
func (x *CustomTag_Literal) ProtoReflect() protoreflect.Message
func (*CustomTag_Literal) Reset ¶
func (x *CustomTag_Literal) Reset()
func (*CustomTag_Literal) SetValue ¶
func (x *CustomTag_Literal) SetValue(v string)
func (*CustomTag_Literal) String ¶
func (x *CustomTag_Literal) String() string
type CustomTag_Literal_ ¶
type CustomTag_Literal_ struct {
// A literal custom tag.
Literal *CustomTag_Literal `protobuf:"bytes,2,opt,name=literal,proto3,oneof"`
}
type CustomTag_Literal_builder ¶
type CustomTag_Literal_builder struct {
// Static literal value to populate the tag value.
Value string
// contains filtered or unexported fields
}
func (CustomTag_Literal_builder) Build ¶
func (b0 CustomTag_Literal_builder) Build() *CustomTag_Literal
type CustomTag_Metadata ¶
type CustomTag_Metadata struct {
// Specify what kind of metadata to obtain tag value from.
Kind *v3.MetadataKind `protobuf:"bytes,1,opt,name=kind,proto3" json:"kind,omitempty"`
// Metadata key to define the path to retrieve the tag value.
MetadataKey *v3.MetadataKey `protobuf:"bytes,2,opt,name=metadata_key,json=metadataKey,proto3" json:"metadata_key,omitempty"`
// When no valid metadata is found,
// the tag value would be populated with this default value if specified,
// otherwise no tag would be populated.
DefaultValue string `protobuf:"bytes,3,opt,name=default_value,json=defaultValue,proto3" json:"default_value,omitempty"`
// contains filtered or unexported fields
}
Metadata type custom tag using :ref:`MetadataKey <envoy_v3_api_msg_type.metadata.v3.MetadataKey>` to retrieve the protobuf value from :ref:`Metadata <envoy_v3_api_msg_config.core.v3.Metadata>`, and populate the tag value with `the canonical JSON <https://developers.google.com/protocol-buffers/docs/proto3#json>`_ representation of it.
func (*CustomTag_Metadata) ClearKind ¶
func (x *CustomTag_Metadata) ClearKind()
func (*CustomTag_Metadata) ClearMetadataKey ¶
func (x *CustomTag_Metadata) ClearMetadataKey()
func (*CustomTag_Metadata) GetDefaultValue ¶
func (x *CustomTag_Metadata) GetDefaultValue() string
func (*CustomTag_Metadata) GetKind ¶
func (x *CustomTag_Metadata) GetKind() *v3.MetadataKind
func (*CustomTag_Metadata) GetMetadataKey ¶
func (x *CustomTag_Metadata) GetMetadataKey() *v3.MetadataKey
func (*CustomTag_Metadata) HasKind ¶
func (x *CustomTag_Metadata) HasKind() bool
func (*CustomTag_Metadata) HasMetadataKey ¶
func (x *CustomTag_Metadata) HasMetadataKey() bool
func (*CustomTag_Metadata) ProtoMessage ¶
func (*CustomTag_Metadata) ProtoMessage()
func (*CustomTag_Metadata) ProtoReflect ¶
func (x *CustomTag_Metadata) ProtoReflect() protoreflect.Message
func (*CustomTag_Metadata) Reset ¶
func (x *CustomTag_Metadata) Reset()
func (*CustomTag_Metadata) SetDefaultValue ¶
func (x *CustomTag_Metadata) SetDefaultValue(v string)
func (*CustomTag_Metadata) SetKind ¶
func (x *CustomTag_Metadata) SetKind(v *v3.MetadataKind)
func (*CustomTag_Metadata) SetMetadataKey ¶
func (x *CustomTag_Metadata) SetMetadataKey(v *v3.MetadataKey)
func (*CustomTag_Metadata) String ¶
func (x *CustomTag_Metadata) String() string
type CustomTag_Metadata_ ¶
type CustomTag_Metadata_ struct {
// A custom tag to obtain tag value from the metadata.
Metadata *CustomTag_Metadata `protobuf:"bytes,5,opt,name=metadata,proto3,oneof"`
}
type CustomTag_Metadata_builder ¶
type CustomTag_Metadata_builder struct {
// Specify what kind of metadata to obtain tag value from.
Kind *v3.MetadataKind
// Metadata key to define the path to retrieve the tag value.
MetadataKey *v3.MetadataKey
// When no valid metadata is found,
// the tag value would be populated with this default value if specified,
// otherwise no tag would be populated.
DefaultValue string
// contains filtered or unexported fields
}
func (CustomTag_Metadata_builder) Build ¶
func (b0 CustomTag_Metadata_builder) Build() *CustomTag_Metadata
type CustomTag_RequestHeader ¶
type CustomTag_RequestHeader struct {
// A request header custom tag.
RequestHeader *CustomTag_Header `protobuf:"bytes,4,opt,name=request_header,json=requestHeader,proto3,oneof"`
}
type CustomTag_Value ¶
type CustomTag_Value struct {
// Custom tag value.
//
// The same :ref:`format specifier <config_access_log_format>` as used for
// :ref:`HTTP access logging <config_access_log>` applies here, however
// unknown specifier values are replaced with the empty string instead of “-“.
Value string `protobuf:"bytes,6,opt,name=value,proto3,oneof"`
}
type CustomTag_builder ¶
type CustomTag_builder struct {
// Used to populate the tag name.
Tag string
// Fields of oneof Type:
// A literal custom tag.
Literal *CustomTag_Literal
// An environment custom tag.
Environment *CustomTag_Environment
// A request header custom tag.
RequestHeader *CustomTag_Header
// A custom tag to obtain tag value from the metadata.
Metadata *CustomTag_Metadata
// Custom tag value.
//
// The same :ref:`format specifier <config_access_log_format>` as used for
// :ref:`HTTP access logging <config_access_log>` applies here, however
// unknown specifier values are replaced with the empty string instead of “-“.
Value *string
// contains filtered or unexported fields
}
func (CustomTag_builder) Build ¶
func (b0 CustomTag_builder) Build() *CustomTag
Source Files
¶
- custom_tag.pb.go
Click to show internal directories.
Click to hide internal directories.