Documentation
¶
Index ¶
Constants ¶
const (
HelloWorldService_GetHelloWorld_FullMethodName = "/fjarm.helloworld.v1.HelloWorldService/GetHelloWorld"
)
Variables ¶
var HelloWorldService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "fjarm.helloworld.v1.HelloWorldService", HandlerType: (*HelloWorldServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "GetHelloWorld", Handler: _HelloWorldService_GetHelloWorld_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "fjarm/helloworld/v1/helloworld.proto", }
HelloWorldService_ServiceDesc is the grpc.ServiceDesc for HelloWorldService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterHelloWorldServiceServer ¶
func RegisterHelloWorldServiceServer(s grpc.ServiceRegistrar, srv HelloWorldServiceServer)
Types ¶
type HelloWorldServiceClient ¶
type HelloWorldServiceClient interface {
GetHelloWorld(ctx context.Context, in *v1.GetHelloWorldRequest, opts ...grpc.CallOption) (*v1.GetHelloWorldResponse, error)
}
HelloWorldServiceClient is the client API for HelloWorldService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewHelloWorldServiceClient ¶
func NewHelloWorldServiceClient(cc grpc.ClientConnInterface) HelloWorldServiceClient
type HelloWorldServiceServer ¶
type HelloWorldServiceServer interface {
GetHelloWorld(context.Context, *v1.GetHelloWorldRequest) (*v1.GetHelloWorldResponse, error)
}
HelloWorldServiceServer is the server API for HelloWorldService service. All implementations should embed UnimplementedHelloWorldServiceServer for forward compatibility.
type UnimplementedHelloWorldServiceServer ¶
type UnimplementedHelloWorldServiceServer struct{}
UnimplementedHelloWorldServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedHelloWorldServiceServer) GetHelloWorld ¶
func (UnimplementedHelloWorldServiceServer) GetHelloWorld(context.Context, *v1.GetHelloWorldRequest) (*v1.GetHelloWorldResponse, error)
type UnsafeHelloWorldServiceServer ¶
type UnsafeHelloWorldServiceServer interface {
// contains filtered or unexported methods
}
UnsafeHelloWorldServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to HelloWorldServiceServer will result in compilation errors.
Source Files
¶
- helloworld_grpc.pb.go