Documentation
¶
Index ¶
- Variables
- type EntityTag
- func (x *EntityTag) ClearEntityTag()
- func (x *EntityTag) GetEntityTag() string
- func (x *EntityTag) HasEntityTag() bool
- func (*EntityTag) ProtoMessage()
- func (x *EntityTag) ProtoReflect() protoreflect.Message
- func (x *EntityTag) Reset()
- func (x *EntityTag) SetEntityTag(v string)
- func (x *EntityTag) String() string
- type EntityTag_builder
Constants ¶
This section is empty.
Variables ¶
var File_fjarm_consistency_v1_entity_tag_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type EntityTag ¶
type EntityTag struct {
// The entity tag representing the latest data as known to the server.
EntityTag *string `protobuf:"bytes,1,opt,name=entity_tag,json=entityTag,proto3,oneof" json:"entity_tag,omitempty"`
// contains filtered or unexported fields
}
SEE: https://google.aip.dev/154 AIP-154 recommends including an `etag` field on an entity. The value can be used in read RPCs to avoid expensive operations like database reads if the client already has the latest data as confirmed by the `etag`. The value can also be used in mutation RPCs to prevent clients with outdated data from overwriting a prior, concurrent mutation. If `etag` validation fails (an RPC was made with stale data), a `PRECONDITION_FAILED` result is returned.
EntityTag describes a consistency mechanism for read RPCs that need the latest data state or mutation RPCs that must have the latest state before proceeding.
func (*EntityTag) ProtoReflect ¶
func (x *EntityTag) ProtoReflect() protoreflect.Message
type EntityTag_builder ¶
type EntityTag_builder struct {
// The entity tag representing the latest data as known to the server.
EntityTag *string
// contains filtered or unexported fields
}
func (EntityTag_builder) Build ¶
func (b0 EntityTag_builder) Build() *EntityTag
Source Files
¶
- entity_tag.pb.go
Click to show internal directories.
Click to hide internal directories.