Documentation
¶
Index ¶
- Variables
- type CreateUserRequest
- func (x *CreateUserRequest) ClearIdempotencyKey()
- func (x *CreateUserRequest) ClearUser()
- func (x *CreateUserRequest) ClearUserId()
- func (x *CreateUserRequest) GetIdempotencyKey() *v1.IdempotencyKey
- func (x *CreateUserRequest) GetUser() *User
- func (x *CreateUserRequest) GetUserId() *UserId
- func (x *CreateUserRequest) HasIdempotencyKey() bool
- func (x *CreateUserRequest) HasUser() bool
- func (x *CreateUserRequest) HasUserId() bool
- func (*CreateUserRequest) ProtoMessage()
- func (x *CreateUserRequest) ProtoReflect() protoreflect.Message
- func (x *CreateUserRequest) Reset()
- func (x *CreateUserRequest) SetIdempotencyKey(v *v1.IdempotencyKey)
- func (x *CreateUserRequest) SetUser(v *User)
- func (x *CreateUserRequest) SetUserId(v *UserId)
- func (x *CreateUserRequest) String() string
- type CreateUserRequest_builder
- type CreateUserResponse
- func (x *CreateUserResponse) ClearStatus()
- func (x *CreateUserResponse) ClearUser()
- func (x *CreateUserResponse) GetStatus() *status.Status
- func (x *CreateUserResponse) GetUser() *User
- func (x *CreateUserResponse) HasStatus() bool
- func (x *CreateUserResponse) HasUser() bool
- func (*CreateUserResponse) ProtoMessage()
- func (x *CreateUserResponse) ProtoReflect() protoreflect.Message
- func (x *CreateUserResponse) Reset()
- func (x *CreateUserResponse) SetStatus(v *status.Status)
- func (x *CreateUserResponse) SetUser(v *User)
- func (x *CreateUserResponse) String() string
- type CreateUserResponse_builder
- type DeleteUserRequest
- func (x *DeleteUserRequest) ClearETag()
- func (x *DeleteUserRequest) ClearIdempotencyKey()
- func (x *DeleteUserRequest) ClearUserId()
- func (x *DeleteUserRequest) GetETag() *v11.EntityTag
- func (x *DeleteUserRequest) GetIdempotencyKey() *v1.IdempotencyKey
- func (x *DeleteUserRequest) GetUserId() *UserId
- func (x *DeleteUserRequest) HasETag() bool
- func (x *DeleteUserRequest) HasIdempotencyKey() bool
- func (x *DeleteUserRequest) HasUserId() bool
- func (*DeleteUserRequest) ProtoMessage()
- func (x *DeleteUserRequest) ProtoReflect() protoreflect.Message
- func (x *DeleteUserRequest) Reset()
- func (x *DeleteUserRequest) SetETag(v *v11.EntityTag)
- func (x *DeleteUserRequest) SetIdempotencyKey(v *v1.IdempotencyKey)
- func (x *DeleteUserRequest) SetUserId(v *UserId)
- func (x *DeleteUserRequest) String() string
- type DeleteUserRequest_builder
- type DeleteUserResponse
- func (x *DeleteUserResponse) ClearStatus()
- func (x *DeleteUserResponse) GetStatus() *status.Status
- func (x *DeleteUserResponse) HasStatus() bool
- func (*DeleteUserResponse) ProtoMessage()
- func (x *DeleteUserResponse) ProtoReflect() protoreflect.Message
- func (x *DeleteUserResponse) Reset()
- func (x *DeleteUserResponse) SetStatus(v *status.Status)
- func (x *DeleteUserResponse) String() string
- type DeleteUserResponse_builder
- type GetUserRequest
- func (x *GetUserRequest) ClearETag()
- func (x *GetUserRequest) ClearFieldMask()
- func (x *GetUserRequest) ClearUserId()
- func (x *GetUserRequest) GetETag() *v1.EntityTag
- func (x *GetUserRequest) GetFieldMask() *fieldmaskpb.FieldMask
- func (x *GetUserRequest) GetUserId() *UserId
- func (x *GetUserRequest) HasETag() bool
- func (x *GetUserRequest) HasFieldMask() bool
- func (x *GetUserRequest) HasUserId() bool
- func (*GetUserRequest) ProtoMessage()
- func (x *GetUserRequest) ProtoReflect() protoreflect.Message
- func (x *GetUserRequest) Reset()
- func (x *GetUserRequest) SetETag(v *v1.EntityTag)
- func (x *GetUserRequest) SetFieldMask(v *fieldmaskpb.FieldMask)
- func (x *GetUserRequest) SetUserId(v *UserId)
- func (x *GetUserRequest) String() string
- type GetUserRequest_builder
- type GetUserResponse
- func (x *GetUserResponse) ClearStatus()
- func (x *GetUserResponse) ClearUser()
- func (x *GetUserResponse) GetStatus() *status.Status
- func (x *GetUserResponse) GetUser() *User
- func (x *GetUserResponse) HasStatus() bool
- func (x *GetUserResponse) HasUser() bool
- func (*GetUserResponse) ProtoMessage()
- func (x *GetUserResponse) ProtoReflect() protoreflect.Message
- func (x *GetUserResponse) Reset()
- func (x *GetUserResponse) SetStatus(v *status.Status)
- func (x *GetUserResponse) SetUser(v *User)
- func (x *GetUserResponse) String() string
- type GetUserResponse_builder
- type UpdateUserRequest
- func (x *UpdateUserRequest) ClearFieldMask()
- func (x *UpdateUserRequest) ClearIdempotencyKey()
- func (x *UpdateUserRequest) ClearUser()
- func (x *UpdateUserRequest) GetFieldMask() *fieldmaskpb.FieldMask
- func (x *UpdateUserRequest) GetIdempotencyKey() *v1.IdempotencyKey
- func (x *UpdateUserRequest) GetUser() *User
- func (x *UpdateUserRequest) HasFieldMask() bool
- func (x *UpdateUserRequest) HasIdempotencyKey() bool
- func (x *UpdateUserRequest) HasUser() bool
- func (*UpdateUserRequest) ProtoMessage()
- func (x *UpdateUserRequest) ProtoReflect() protoreflect.Message
- func (x *UpdateUserRequest) Reset()
- func (x *UpdateUserRequest) SetFieldMask(v *fieldmaskpb.FieldMask)
- func (x *UpdateUserRequest) SetIdempotencyKey(v *v1.IdempotencyKey)
- func (x *UpdateUserRequest) SetUser(v *User)
- func (x *UpdateUserRequest) String() string
- type UpdateUserRequest_builder
- type UpdateUserResponse
- func (x *UpdateUserResponse) ClearStatus()
- func (x *UpdateUserResponse) ClearUser()
- func (x *UpdateUserResponse) GetStatus() *status.Status
- func (x *UpdateUserResponse) GetUser() *User
- func (x *UpdateUserResponse) HasStatus() bool
- func (x *UpdateUserResponse) HasUser() bool
- func (*UpdateUserResponse) ProtoMessage()
- func (x *UpdateUserResponse) ProtoReflect() protoreflect.Message
- func (x *UpdateUserResponse) Reset()
- func (x *UpdateUserResponse) SetStatus(v *status.Status)
- func (x *UpdateUserResponse) SetUser(v *User)
- func (x *UpdateUserResponse) String() string
- type UpdateUserResponse_builder
- type User
- func (x *User) ClearAvatar()
- func (x *User) ClearETag()
- func (x *User) ClearEmailAddress()
- func (x *User) ClearFullName()
- func (x *User) ClearHandle()
- func (x *User) ClearPassword()
- func (x *User) ClearUserId()
- func (x *User) GetAvatar() *UserAvatar
- func (x *User) GetETag() *v1.EntityTag
- func (x *User) GetEmailAddress() *UserEmailAddress
- func (x *User) GetFullName() *UserFullName
- func (x *User) GetHandle() *UserHandle
- func (x *User) GetPassword() *UserPassword
- func (x *User) GetUserId() *UserId
- func (x *User) HasAvatar() bool
- func (x *User) HasETag() bool
- func (x *User) HasEmailAddress() bool
- func (x *User) HasFullName() bool
- func (x *User) HasHandle() bool
- func (x *User) HasPassword() bool
- func (x *User) HasUserId() bool
- func (*User) ProtoMessage()
- func (x *User) ProtoReflect() protoreflect.Message
- func (x *User) Reset()
- func (x *User) SetAvatar(v *UserAvatar)
- func (x *User) SetETag(v *v1.EntityTag)
- func (x *User) SetEmailAddress(v *UserEmailAddress)
- func (x *User) SetFullName(v *UserFullName)
- func (x *User) SetHandle(v *UserHandle)
- func (x *User) SetPassword(v *UserPassword)
- func (x *User) SetUserId(v *UserId)
- func (x *User) String() string
- type UserAvatar
- func (x *UserAvatar) ClearAvatar()
- func (x *UserAvatar) GetAvatar() string
- func (x *UserAvatar) HasAvatar() bool
- func (*UserAvatar) ProtoMessage()
- func (x *UserAvatar) ProtoReflect() protoreflect.Message
- func (x *UserAvatar) Reset()
- func (x *UserAvatar) SetAvatar(v string)
- func (x *UserAvatar) String() string
- type UserAvatar_builder
- type UserEmailAddress
- func (x *UserEmailAddress) ClearEmailAddress()
- func (x *UserEmailAddress) GetEmailAddress() string
- func (x *UserEmailAddress) HasEmailAddress() bool
- func (*UserEmailAddress) ProtoMessage()
- func (x *UserEmailAddress) ProtoReflect() protoreflect.Message
- func (x *UserEmailAddress) Reset()
- func (x *UserEmailAddress) SetEmailAddress(v string)
- func (x *UserEmailAddress) String() string
- type UserEmailAddress_builder
- type UserFullName
- func (x *UserFullName) ClearFamilyName()
- func (x *UserFullName) ClearGivenName()
- func (x *UserFullName) GetFamilyName() string
- func (x *UserFullName) GetGivenName() string
- func (x *UserFullName) HasFamilyName() bool
- func (x *UserFullName) HasGivenName() bool
- func (*UserFullName) ProtoMessage()
- func (x *UserFullName) ProtoReflect() protoreflect.Message
- func (x *UserFullName) Reset()
- func (x *UserFullName) SetFamilyName(v string)
- func (x *UserFullName) SetGivenName(v string)
- func (x *UserFullName) String() string
- type UserFullName_builder
- type UserHandle
- func (x *UserHandle) ClearHandle()
- func (x *UserHandle) GetHandle() string
- func (x *UserHandle) HasHandle() bool
- func (*UserHandle) ProtoMessage()
- func (x *UserHandle) ProtoReflect() protoreflect.Message
- func (x *UserHandle) Reset()
- func (x *UserHandle) SetHandle(v string)
- func (x *UserHandle) String() string
- type UserHandle_builder
- type UserId
- type UserId_builder
- type UserPassword
- func (x *UserPassword) ClearPassword()
- func (x *UserPassword) GetPassword() string
- func (x *UserPassword) HasPassword() bool
- func (*UserPassword) ProtoMessage()
- func (x *UserPassword) ProtoReflect() protoreflect.Message
- func (x *UserPassword) Reset()
- func (x *UserPassword) SetPassword(v string)
- func (x *UserPassword) String() string
- type UserPassword_builder
- type User_builder
Constants ¶
This section is empty.
Variables ¶
var File_fjarm_users_v1_create_user_request_proto protoreflect.FileDescriptor
var File_fjarm_users_v1_create_user_response_proto protoreflect.FileDescriptor
var File_fjarm_users_v1_delete_user_request_proto protoreflect.FileDescriptor
var File_fjarm_users_v1_delete_user_response_proto protoreflect.FileDescriptor
var File_fjarm_users_v1_get_user_request_proto protoreflect.FileDescriptor
var File_fjarm_users_v1_get_user_response_proto protoreflect.FileDescriptor
var File_fjarm_users_v1_update_user_request_proto protoreflect.FileDescriptor
var File_fjarm_users_v1_update_user_response_proto protoreflect.FileDescriptor
var File_fjarm_users_v1_user_avatar_proto protoreflect.FileDescriptor
var File_fjarm_users_v1_user_email_address_proto protoreflect.FileDescriptor
var File_fjarm_users_v1_user_full_name_proto protoreflect.FileDescriptor
var File_fjarm_users_v1_user_handle_proto protoreflect.FileDescriptor
var File_fjarm_users_v1_user_id_proto protoreflect.FileDescriptor
var File_fjarm_users_v1_user_password_proto protoreflect.FileDescriptor
var File_fjarm_users_v1_user_proto protoreflect.FileDescriptor
var File_fjarm_users_v1_user_service_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type CreateUserRequest ¶
type CreateUserRequest struct {
// Uniquely identifies a request such that a client can retry the request if it failed for a retry-able
// error like `UNAVAILABLE`. The same request should always return the same response.
IdempotencyKey *v1.IdempotencyKey `protobuf:"bytes,1,opt,name=idempotency_key,json=idempotencyKey,proto3,oneof" json:"idempotency_key,omitempty"`
// The ID of the user being created. This should match the ID found in the `user` field below.
UserId *UserId `protobuf:"bytes,2,opt,name=user_id,json=userId,proto3,oneof" json:"user_id,omitempty"`
// The user to create.
User *User `protobuf:"bytes,3,opt,name=user,proto3,oneof" json:"user,omitempty"`
// contains filtered or unexported fields
}
SEE: https://google.aip.dev/133 AIP-133 recommends that Create methods use a request message that matches the RPC with a Request suffix.
CreateUserRequest is used to issue Create requests to the API when a user first registers.
When using this message, the request metadata MUST include a request ID AND an idempotency key.
func (*CreateUserRequest) ClearIdempotencyKey ¶
func (x *CreateUserRequest) ClearIdempotencyKey()
func (*CreateUserRequest) ClearUser ¶
func (x *CreateUserRequest) ClearUser()
func (*CreateUserRequest) ClearUserId ¶
func (x *CreateUserRequest) ClearUserId()
func (*CreateUserRequest) GetIdempotencyKey ¶
func (x *CreateUserRequest) GetIdempotencyKey() *v1.IdempotencyKey
func (*CreateUserRequest) GetUser ¶
func (x *CreateUserRequest) GetUser() *User
func (*CreateUserRequest) GetUserId ¶
func (x *CreateUserRequest) GetUserId() *UserId
func (*CreateUserRequest) HasIdempotencyKey ¶
func (x *CreateUserRequest) HasIdempotencyKey() bool
func (*CreateUserRequest) HasUser ¶
func (x *CreateUserRequest) HasUser() bool
func (*CreateUserRequest) HasUserId ¶
func (x *CreateUserRequest) HasUserId() bool
func (*CreateUserRequest) ProtoMessage ¶
func (*CreateUserRequest) ProtoMessage()
func (*CreateUserRequest) ProtoReflect ¶
func (x *CreateUserRequest) ProtoReflect() protoreflect.Message
func (*CreateUserRequest) Reset ¶
func (x *CreateUserRequest) Reset()
func (*CreateUserRequest) SetIdempotencyKey ¶
func (x *CreateUserRequest) SetIdempotencyKey(v *v1.IdempotencyKey)
func (*CreateUserRequest) SetUser ¶
func (x *CreateUserRequest) SetUser(v *User)
func (*CreateUserRequest) SetUserId ¶
func (x *CreateUserRequest) SetUserId(v *UserId)
func (*CreateUserRequest) String ¶
func (x *CreateUserRequest) String() string
type CreateUserRequest_builder ¶
type CreateUserRequest_builder struct {
// Uniquely identifies a request such that a client can retry the request if it failed for a retry-able
// error like `UNAVAILABLE`. The same request should always return the same response.
IdempotencyKey *v1.IdempotencyKey
// The ID of the user being created. This should match the ID found in the `user` field below.
UserId *UserId
// The user to create.
User *User
// contains filtered or unexported fields
}
func (CreateUserRequest_builder) Build ¶
func (b0 CreateUserRequest_builder) Build() *CreateUserRequest
type CreateUserResponse ¶
type CreateUserResponse struct {
// The status of the RPC request to create a user.
Status *status.Status `protobuf:"bytes,1,opt,name=status,proto3,oneof" json:"status,omitempty"`
// The user that was created or an empty result if the RPC was unsuccessful.
User *User `protobuf:"bytes,2,opt,name=user,proto3,oneof" json:"user,omitempty"`
// contains filtered or unexported fields
}
CreateUserResponse represents the result of attempting an RPC that creates a user.
func (*CreateUserResponse) ClearStatus ¶
func (x *CreateUserResponse) ClearStatus()
func (*CreateUserResponse) ClearUser ¶
func (x *CreateUserResponse) ClearUser()
func (*CreateUserResponse) GetStatus ¶
func (x *CreateUserResponse) GetStatus() *status.Status
func (*CreateUserResponse) GetUser ¶
func (x *CreateUserResponse) GetUser() *User
func (*CreateUserResponse) HasStatus ¶
func (x *CreateUserResponse) HasStatus() bool
func (*CreateUserResponse) HasUser ¶
func (x *CreateUserResponse) HasUser() bool
func (*CreateUserResponse) ProtoMessage ¶
func (*CreateUserResponse) ProtoMessage()
func (*CreateUserResponse) ProtoReflect ¶
func (x *CreateUserResponse) ProtoReflect() protoreflect.Message
func (*CreateUserResponse) Reset ¶
func (x *CreateUserResponse) Reset()
func (*CreateUserResponse) SetStatus ¶
func (x *CreateUserResponse) SetStatus(v *status.Status)
func (*CreateUserResponse) SetUser ¶
func (x *CreateUserResponse) SetUser(v *User)
func (*CreateUserResponse) String ¶
func (x *CreateUserResponse) String() string
type CreateUserResponse_builder ¶
type CreateUserResponse_builder struct {
// The status of the RPC request to create a user.
Status *status.Status
// The user that was created or an empty result if the RPC was unsuccessful.
User *User
// contains filtered or unexported fields
}
func (CreateUserResponse_builder) Build ¶
func (b0 CreateUserResponse_builder) Build() *CreateUserResponse
type DeleteUserRequest ¶
type DeleteUserRequest struct {
// The idempotency key. This can be used for client retries on retryable errors like `UNAVAILABLE`.
IdempotencyKey *v1.IdempotencyKey `protobuf:"bytes,1,opt,name=idempotency_key,json=idempotencyKey,proto3,oneof" json:"idempotency_key,omitempty"`
// The ETag, which represents the latest known state of the user. Supplying this requires the client to
// know and have the latest data before a DELETE is processed.
ETag *v11.EntityTag `protobuf:"bytes,2,opt,name=e_tag,json=eTag,proto3,oneof" json:"e_tag,omitempty"`
// The ID of the user being retrieved.
UserId *UserId `protobuf:"bytes,3,opt,name=user_id,json=userId,proto3,oneof" json:"user_id,omitempty"`
// contains filtered or unexported fields
}
DeleteUserRequest describes the input required to initiate an RPC that deletes a user from the system.
func (*DeleteUserRequest) ClearETag ¶
func (x *DeleteUserRequest) ClearETag()
func (*DeleteUserRequest) ClearIdempotencyKey ¶
func (x *DeleteUserRequest) ClearIdempotencyKey()
func (*DeleteUserRequest) ClearUserId ¶
func (x *DeleteUserRequest) ClearUserId()
func (*DeleteUserRequest) GetETag ¶
func (x *DeleteUserRequest) GetETag() *v11.EntityTag
func (*DeleteUserRequest) GetIdempotencyKey ¶
func (x *DeleteUserRequest) GetIdempotencyKey() *v1.IdempotencyKey
func (*DeleteUserRequest) GetUserId ¶
func (x *DeleteUserRequest) GetUserId() *UserId
func (*DeleteUserRequest) HasETag ¶
func (x *DeleteUserRequest) HasETag() bool
func (*DeleteUserRequest) HasIdempotencyKey ¶
func (x *DeleteUserRequest) HasIdempotencyKey() bool
func (*DeleteUserRequest) HasUserId ¶
func (x *DeleteUserRequest) HasUserId() bool
func (*DeleteUserRequest) ProtoMessage ¶
func (*DeleteUserRequest) ProtoMessage()
func (*DeleteUserRequest) ProtoReflect ¶
func (x *DeleteUserRequest) ProtoReflect() protoreflect.Message
func (*DeleteUserRequest) Reset ¶
func (x *DeleteUserRequest) Reset()
func (*DeleteUserRequest) SetETag ¶
func (x *DeleteUserRequest) SetETag(v *v11.EntityTag)
func (*DeleteUserRequest) SetIdempotencyKey ¶
func (x *DeleteUserRequest) SetIdempotencyKey(v *v1.IdempotencyKey)
func (*DeleteUserRequest) SetUserId ¶
func (x *DeleteUserRequest) SetUserId(v *UserId)
func (*DeleteUserRequest) String ¶
func (x *DeleteUserRequest) String() string
type DeleteUserRequest_builder ¶
type DeleteUserRequest_builder struct {
// The idempotency key. This can be used for client retries on retryable errors like `UNAVAILABLE`.
IdempotencyKey *v1.IdempotencyKey
// The ETag, which represents the latest known state of the user. Supplying this requires the client to
// know and have the latest data before a DELETE is processed.
ETag *v11.EntityTag
// The ID of the user being retrieved.
UserId *UserId
// contains filtered or unexported fields
}
func (DeleteUserRequest_builder) Build ¶
func (b0 DeleteUserRequest_builder) Build() *DeleteUserRequest
type DeleteUserResponse ¶
type DeleteUserResponse struct {
// The status of the RPC request to create a user.
Status *status.Status `protobuf:"bytes,1,opt,name=status,proto3,oneof" json:"status,omitempty"`
// contains filtered or unexported fields
}
DeleteUserRequest describes the result of a mutation RPC to delete a User resource.
func (*DeleteUserResponse) ClearStatus ¶
func (x *DeleteUserResponse) ClearStatus()
func (*DeleteUserResponse) GetStatus ¶
func (x *DeleteUserResponse) GetStatus() *status.Status
func (*DeleteUserResponse) HasStatus ¶
func (x *DeleteUserResponse) HasStatus() bool
func (*DeleteUserResponse) ProtoMessage ¶
func (*DeleteUserResponse) ProtoMessage()
func (*DeleteUserResponse) ProtoReflect ¶
func (x *DeleteUserResponse) ProtoReflect() protoreflect.Message
func (*DeleteUserResponse) Reset ¶
func (x *DeleteUserResponse) Reset()
func (*DeleteUserResponse) SetStatus ¶
func (x *DeleteUserResponse) SetStatus(v *status.Status)
func (*DeleteUserResponse) String ¶
func (x *DeleteUserResponse) String() string
type DeleteUserResponse_builder ¶
type DeleteUserResponse_builder struct {
// The status of the RPC request to create a user.
Status *status.Status
// contains filtered or unexported fields
}
func (DeleteUserResponse_builder) Build ¶
func (b0 DeleteUserResponse_builder) Build() *DeleteUserResponse
type GetUserRequest ¶
type GetUserRequest struct {
// The last received entity tag associated with a user if one exists.
// If the client has a stale representation of a user, an `OK` response will be sent with a non-null user.
ETag *v1.EntityTag `protobuf:"bytes,1,opt,name=e_tag,json=eTag,proto3,oneof" json:"e_tag,omitempty"`
// The ID of the user being retrieved.
UserId *UserId `protobuf:"bytes,2,opt,name=user_id,json=userId,proto3,oneof" json:"user_id,omitempty"`
// SEE: https://google.aip.dev/161
// A read mask used to specify which properties of a user to request.
FieldMask *fieldmaskpb.FieldMask `protobuf:"bytes,3,opt,name=field_mask,json=fieldMask,proto3,oneof" json:"field_mask,omitempty"`
// contains filtered or unexported fields
}
SEE: https://google.aip.dev/131
GetUserRequest describes a message used for an RPC that returns a `User` message.
When using this message, the request metadata MUST include a request ID and MAY include an ETag.
func (*GetUserRequest) ClearETag ¶
func (x *GetUserRequest) ClearETag()
func (*GetUserRequest) ClearFieldMask ¶
func (x *GetUserRequest) ClearFieldMask()
func (*GetUserRequest) ClearUserId ¶
func (x *GetUserRequest) ClearUserId()
func (*GetUserRequest) GetETag ¶
func (x *GetUserRequest) GetETag() *v1.EntityTag
func (*GetUserRequest) GetFieldMask ¶
func (x *GetUserRequest) GetFieldMask() *fieldmaskpb.FieldMask
func (*GetUserRequest) GetUserId ¶
func (x *GetUserRequest) GetUserId() *UserId
func (*GetUserRequest) HasETag ¶
func (x *GetUserRequest) HasETag() bool
func (*GetUserRequest) HasFieldMask ¶
func (x *GetUserRequest) HasFieldMask() bool
func (*GetUserRequest) HasUserId ¶
func (x *GetUserRequest) HasUserId() bool
func (*GetUserRequest) ProtoMessage ¶
func (*GetUserRequest) ProtoMessage()
func (*GetUserRequest) ProtoReflect ¶
func (x *GetUserRequest) ProtoReflect() protoreflect.Message
func (*GetUserRequest) Reset ¶
func (x *GetUserRequest) Reset()
func (*GetUserRequest) SetETag ¶
func (x *GetUserRequest) SetETag(v *v1.EntityTag)
func (*GetUserRequest) SetFieldMask ¶
func (x *GetUserRequest) SetFieldMask(v *fieldmaskpb.FieldMask)
func (*GetUserRequest) SetUserId ¶
func (x *GetUserRequest) SetUserId(v *UserId)
func (*GetUserRequest) String ¶
func (x *GetUserRequest) String() string
type GetUserRequest_builder ¶
type GetUserRequest_builder struct {
// The last received entity tag associated with a user if one exists.
// If the client has a stale representation of a user, an `OK` response will be sent with a non-null user.
ETag *v1.EntityTag
// The ID of the user being retrieved.
UserId *UserId
// SEE: https://google.aip.dev/161
// A read mask used to specify which properties of a user to request.
FieldMask *fieldmaskpb.FieldMask
// contains filtered or unexported fields
}
func (GetUserRequest_builder) Build ¶
func (b0 GetUserRequest_builder) Build() *GetUserRequest
type GetUserResponse ¶
type GetUserResponse struct {
// The status of the RPC request to retrieve a user.
Status *status.Status `protobuf:"bytes,1,opt,name=status,proto3,oneof" json:"status,omitempty"`
// The user and related details or an empty result if the RPC was unsuccessful.
User *User `protobuf:"bytes,2,opt,name=user,proto3,oneof" json:"user,omitempty"`
// contains filtered or unexported fields
}
GetUserResponse describes the result of attempting an RPC to retrieve a user.
func (*GetUserResponse) ClearStatus ¶
func (x *GetUserResponse) ClearStatus()
func (*GetUserResponse) ClearUser ¶
func (x *GetUserResponse) ClearUser()
func (*GetUserResponse) GetStatus ¶
func (x *GetUserResponse) GetStatus() *status.Status
func (*GetUserResponse) GetUser ¶
func (x *GetUserResponse) GetUser() *User
func (*GetUserResponse) HasStatus ¶
func (x *GetUserResponse) HasStatus() bool
func (*GetUserResponse) HasUser ¶
func (x *GetUserResponse) HasUser() bool
func (*GetUserResponse) ProtoMessage ¶
func (*GetUserResponse) ProtoMessage()
func (*GetUserResponse) ProtoReflect ¶
func (x *GetUserResponse) ProtoReflect() protoreflect.Message
func (*GetUserResponse) Reset ¶
func (x *GetUserResponse) Reset()
func (*GetUserResponse) SetStatus ¶
func (x *GetUserResponse) SetStatus(v *status.Status)
func (*GetUserResponse) SetUser ¶
func (x *GetUserResponse) SetUser(v *User)
func (*GetUserResponse) String ¶
func (x *GetUserResponse) String() string
type GetUserResponse_builder ¶
type GetUserResponse_builder struct {
// The status of the RPC request to retrieve a user.
Status *status.Status
// The user and related details or an empty result if the RPC was unsuccessful.
User *User
// contains filtered or unexported fields
}
func (GetUserResponse_builder) Build ¶
func (b0 GetUserResponse_builder) Build() *GetUserResponse
type UpdateUserRequest ¶
type UpdateUserRequest struct {
// Uniquely identifies a request such that a client can retry the request if it failed for a retry-able
// error like `UNAVAILABLE`. The same request should always return the same response.
IdempotencyKey *v1.IdempotencyKey `protobuf:"bytes,1,opt,name=idempotency_key,json=idempotencyKey,proto3,oneof" json:"idempotency_key,omitempty"`
// The user being updated. The `user_id` and `e_tag` fields are minimally required to be present.
User *User `protobuf:"bytes,2,opt,name=user,proto3,oneof" json:"user,omitempty"`
// An update mask used to specify which properties of a user are being mutated.
FieldMask *fieldmaskpb.FieldMask `protobuf:"bytes,3,opt,name=field_mask,json=fieldMask,proto3,oneof" json:"field_mask,omitempty"`
// contains filtered or unexported fields
}
SEE: https://google.aip.dev/134
UpdateUserRequest describes a message used in RPCs meant to mutate a `User` type.
When using this message, the request metadata MUST include a request ID, an idempotency key, AND an ETag.
func (*UpdateUserRequest) ClearFieldMask ¶
func (x *UpdateUserRequest) ClearFieldMask()
func (*UpdateUserRequest) ClearIdempotencyKey ¶
func (x *UpdateUserRequest) ClearIdempotencyKey()
func (*UpdateUserRequest) ClearUser ¶
func (x *UpdateUserRequest) ClearUser()
func (*UpdateUserRequest) GetFieldMask ¶
func (x *UpdateUserRequest) GetFieldMask() *fieldmaskpb.FieldMask
func (*UpdateUserRequest) GetIdempotencyKey ¶
func (x *UpdateUserRequest) GetIdempotencyKey() *v1.IdempotencyKey
func (*UpdateUserRequest) GetUser ¶
func (x *UpdateUserRequest) GetUser() *User
func (*UpdateUserRequest) HasFieldMask ¶
func (x *UpdateUserRequest) HasFieldMask() bool
func (*UpdateUserRequest) HasIdempotencyKey ¶
func (x *UpdateUserRequest) HasIdempotencyKey() bool
func (*UpdateUserRequest) HasUser ¶
func (x *UpdateUserRequest) HasUser() bool
func (*UpdateUserRequest) ProtoMessage ¶
func (*UpdateUserRequest) ProtoMessage()
func (*UpdateUserRequest) ProtoReflect ¶
func (x *UpdateUserRequest) ProtoReflect() protoreflect.Message
func (*UpdateUserRequest) Reset ¶
func (x *UpdateUserRequest) Reset()
func (*UpdateUserRequest) SetFieldMask ¶
func (x *UpdateUserRequest) SetFieldMask(v *fieldmaskpb.FieldMask)
func (*UpdateUserRequest) SetIdempotencyKey ¶
func (x *UpdateUserRequest) SetIdempotencyKey(v *v1.IdempotencyKey)
func (*UpdateUserRequest) SetUser ¶
func (x *UpdateUserRequest) SetUser(v *User)
func (*UpdateUserRequest) String ¶
func (x *UpdateUserRequest) String() string
type UpdateUserRequest_builder ¶
type UpdateUserRequest_builder struct {
// Uniquely identifies a request such that a client can retry the request if it failed for a retry-able
// error like `UNAVAILABLE`. The same request should always return the same response.
IdempotencyKey *v1.IdempotencyKey
// The user being updated. The `user_id` and `e_tag` fields are minimally required to be present.
User *User
// An update mask used to specify which properties of a user are being mutated.
FieldMask *fieldmaskpb.FieldMask
// contains filtered or unexported fields
}
func (UpdateUserRequest_builder) Build ¶
func (b0 UpdateUserRequest_builder) Build() *UpdateUserRequest
type UpdateUserResponse ¶
type UpdateUserResponse struct {
// The status of the RPC request to update a user.
Status *status.Status `protobuf:"bytes,1,opt,name=status,proto3,oneof" json:"status,omitempty"`
// The user that was updated or an empty result if the RPC was unsuccessful.
User *User `protobuf:"bytes,2,opt,name=user,proto3,oneof" json:"user,omitempty"`
// contains filtered or unexported fields
}
UpdateUserResponse represents the result of attempting to update a `user` entity.
func (*UpdateUserResponse) ClearStatus ¶
func (x *UpdateUserResponse) ClearStatus()
func (*UpdateUserResponse) ClearUser ¶
func (x *UpdateUserResponse) ClearUser()
func (*UpdateUserResponse) GetStatus ¶
func (x *UpdateUserResponse) GetStatus() *status.Status
func (*UpdateUserResponse) GetUser ¶
func (x *UpdateUserResponse) GetUser() *User
func (*UpdateUserResponse) HasStatus ¶
func (x *UpdateUserResponse) HasStatus() bool
func (*UpdateUserResponse) HasUser ¶
func (x *UpdateUserResponse) HasUser() bool
func (*UpdateUserResponse) ProtoMessage ¶
func (*UpdateUserResponse) ProtoMessage()
func (*UpdateUserResponse) ProtoReflect ¶
func (x *UpdateUserResponse) ProtoReflect() protoreflect.Message
func (*UpdateUserResponse) Reset ¶
func (x *UpdateUserResponse) Reset()
func (*UpdateUserResponse) SetStatus ¶
func (x *UpdateUserResponse) SetStatus(v *status.Status)
func (*UpdateUserResponse) SetUser ¶
func (x *UpdateUserResponse) SetUser(v *User)
func (*UpdateUserResponse) String ¶
func (x *UpdateUserResponse) String() string
type UpdateUserResponse_builder ¶
type UpdateUserResponse_builder struct {
// The status of the RPC request to update a user.
Status *status.Status
// The user that was updated or an empty result if the RPC was unsuccessful.
User *User
// contains filtered or unexported fields
}
func (UpdateUserResponse_builder) Build ¶
func (b0 UpdateUserResponse_builder) Build() *UpdateUserResponse
type User ¶
type User struct {
UserId *UserId `protobuf:"bytes,1,opt,name=user_id,json=userId,proto3,oneof" json:"user_id,omitempty"`
FullName *UserFullName `protobuf:"bytes,2,opt,name=full_name,json=fullName,proto3,oneof" json:"full_name,omitempty"`
Handle *UserHandle `protobuf:"bytes,3,opt,name=handle,proto3,oneof" json:"handle,omitempty"`
EmailAddress *UserEmailAddress `protobuf:"bytes,4,opt,name=email_address,json=emailAddress,proto3,oneof" json:"email_address,omitempty"`
Avatar *UserAvatar `protobuf:"bytes,5,opt,name=avatar,proto3,oneof" json:"avatar,omitempty"`
// The password a user can authenticate and authorize with. This is an input-only field as described
// in AIP-203.
Password *UserPassword `protobuf:"bytes,6,opt,name=password,proto3,oneof" json:"password,omitempty"`
// The entity tag, which represents the latest state of the user entity as described in AIP-143. For
// clients, this is an input only field that's passed along in RPCs.
ETag *v1.EntityTag `protobuf:"bytes,7,opt,name=e_tag,json=eTag,proto3,oneof" json:"e_tag,omitempty"`
// contains filtered or unexported fields
}
The uniquely identifiable user. This message represents the shared knowledge about the user between the client and the server.
func (*User) GetAvatar ¶
func (x *User) GetAvatar() *UserAvatar
func (*User) GetEmailAddress ¶
func (x *User) GetEmailAddress() *UserEmailAddress
func (*User) GetFullName ¶
func (x *User) GetFullName() *UserFullName
func (*User) GetHandle ¶
func (x *User) GetHandle() *UserHandle
func (*User) GetPassword ¶
func (x *User) GetPassword() *UserPassword
func (*User) ProtoReflect ¶
func (x *User) ProtoReflect() protoreflect.Message
func (*User) SetAvatar ¶
func (x *User) SetAvatar(v *UserAvatar)
func (*User) SetEmailAddress ¶
func (x *User) SetEmailAddress(v *UserEmailAddress)
func (*User) SetFullName ¶
func (x *User) SetFullName(v *UserFullName)
func (*User) SetHandle ¶
func (x *User) SetHandle(v *UserHandle)
func (*User) SetPassword ¶
func (x *User) SetPassword(v *UserPassword)
type UserAvatar ¶
type UserAvatar struct {
// Optional field that identifies where to load a user's profile picture from. If a user chooses NOT
// to supply a photo, then this value may be empty.
Avatar *string `protobuf:"bytes,1,opt,name=avatar,proto3,oneof" json:"avatar,omitempty"`
// contains filtered or unexported fields
}
The URI that identifies where to load a user's avatar or profile picture from.
func (*UserAvatar) ClearAvatar ¶
func (x *UserAvatar) ClearAvatar()
func (*UserAvatar) GetAvatar ¶
func (x *UserAvatar) GetAvatar() string
func (*UserAvatar) HasAvatar ¶
func (x *UserAvatar) HasAvatar() bool
func (*UserAvatar) ProtoMessage ¶
func (*UserAvatar) ProtoMessage()
func (*UserAvatar) ProtoReflect ¶
func (x *UserAvatar) ProtoReflect() protoreflect.Message
func (*UserAvatar) Reset ¶
func (x *UserAvatar) Reset()
func (*UserAvatar) SetAvatar ¶
func (x *UserAvatar) SetAvatar(v string)
func (*UserAvatar) String ¶
func (x *UserAvatar) String() string
type UserAvatar_builder ¶
type UserAvatar_builder struct {
// Optional field that identifies where to load a user's profile picture from. If a user chooses NOT
// to supply a photo, then this value may be empty.
Avatar *string
// contains filtered or unexported fields
}
func (UserAvatar_builder) Build ¶
func (b0 UserAvatar_builder) Build() *UserAvatar
type UserEmailAddress ¶
type UserEmailAddress struct {
// Required field that represents a user's email address.
EmailAddress *string `protobuf:"bytes,1,opt,name=email_address,json=emailAddress,proto3,oneof" json:"email_address,omitempty"`
// contains filtered or unexported fields
}
An email address supplied by a user at account creation time or updated later. This can be used to reach out to a user for promotions or to reset a password.
func (*UserEmailAddress) ClearEmailAddress ¶
func (x *UserEmailAddress) ClearEmailAddress()
func (*UserEmailAddress) GetEmailAddress ¶
func (x *UserEmailAddress) GetEmailAddress() string
func (*UserEmailAddress) HasEmailAddress ¶
func (x *UserEmailAddress) HasEmailAddress() bool
func (*UserEmailAddress) ProtoMessage ¶
func (*UserEmailAddress) ProtoMessage()
func (*UserEmailAddress) ProtoReflect ¶
func (x *UserEmailAddress) ProtoReflect() protoreflect.Message
func (*UserEmailAddress) Reset ¶
func (x *UserEmailAddress) Reset()
func (*UserEmailAddress) SetEmailAddress ¶
func (x *UserEmailAddress) SetEmailAddress(v string)
func (*UserEmailAddress) String ¶
func (x *UserEmailAddress) String() string
type UserEmailAddress_builder ¶
type UserEmailAddress_builder struct {
// Required field that represents a user's email address.
EmailAddress *string
// contains filtered or unexported fields
}
func (UserEmailAddress_builder) Build ¶
func (b0 UserEmailAddress_builder) Build() *UserEmailAddress
type UserFullName ¶
type UserFullName struct {
// Required field that represents a user's preferred name when addressing them.
FamilyName *string `protobuf:"bytes,1,opt,name=family_name,json=familyName,proto3,oneof" json:"family_name,omitempty"`
// Required field that represents a user's family name.
GivenName *string `protobuf:"bytes,2,opt,name=given_name,json=givenName,proto3,oneof" json:"given_name,omitempty"`
// contains filtered or unexported fields
}
The name a user supplies at registration or later updates. This should be used to address a user in official communications such as emails or push notifications.
func (*UserFullName) ClearFamilyName ¶
func (x *UserFullName) ClearFamilyName()
func (*UserFullName) ClearGivenName ¶
func (x *UserFullName) ClearGivenName()
func (*UserFullName) GetFamilyName ¶
func (x *UserFullName) GetFamilyName() string
func (*UserFullName) GetGivenName ¶
func (x *UserFullName) GetGivenName() string
func (*UserFullName) HasFamilyName ¶
func (x *UserFullName) HasFamilyName() bool
func (*UserFullName) HasGivenName ¶
func (x *UserFullName) HasGivenName() bool
func (*UserFullName) ProtoMessage ¶
func (*UserFullName) ProtoMessage()
func (*UserFullName) ProtoReflect ¶
func (x *UserFullName) ProtoReflect() protoreflect.Message
func (*UserFullName) Reset ¶
func (x *UserFullName) Reset()
func (*UserFullName) SetFamilyName ¶
func (x *UserFullName) SetFamilyName(v string)
func (*UserFullName) SetGivenName ¶
func (x *UserFullName) SetGivenName(v string)
func (*UserFullName) String ¶
func (x *UserFullName) String() string
type UserFullName_builder ¶
type UserFullName_builder struct {
// Required field that represents a user's preferred name when addressing them.
FamilyName *string
// Required field that represents a user's family name.
GivenName *string
// contains filtered or unexported fields
}
func (UserFullName_builder) Build ¶
func (b0 UserFullName_builder) Build() *UserFullName
type UserHandle ¶
type UserHandle struct {
// Required field that represents a user's globally unique identifier.
Handle *string `protobuf:"bytes,1,opt,name=handle,proto3,oneof" json:"handle,omitempty"`
// contains filtered or unexported fields
}
A custom handle or username that a user supplies at registration or later updates. This can be used for in-app communication between users. This value should be globally unique, and thus can be used to distinguish two or more users who have the same values in their `fjarm.users.v1.UserFullName`.
func (*UserHandle) ClearHandle ¶
func (x *UserHandle) ClearHandle()
func (*UserHandle) GetHandle ¶
func (x *UserHandle) GetHandle() string
func (*UserHandle) HasHandle ¶
func (x *UserHandle) HasHandle() bool
func (*UserHandle) ProtoMessage ¶
func (*UserHandle) ProtoMessage()
func (*UserHandle) ProtoReflect ¶
func (x *UserHandle) ProtoReflect() protoreflect.Message
func (*UserHandle) Reset ¶
func (x *UserHandle) Reset()
func (*UserHandle) SetHandle ¶
func (x *UserHandle) SetHandle(v string)
func (*UserHandle) String ¶
func (x *UserHandle) String() string
type UserHandle_builder ¶
type UserHandle_builder struct {
// Required field that represents a user's globally unique identifier.
Handle *string
// contains filtered or unexported fields
}
func (UserHandle_builder) Build ¶
func (b0 UserHandle_builder) Build() *UserHandle
type UserId ¶
type UserId struct {
// Required field that represents the user's unique identifier (UID).
// The supplied value must be a UUID as defined by
// [RFC 4122](https://tools.ietf.org/html/rfc4122#section-4.1.2).
UserId *string `protobuf:"bytes,1,opt,name=user_id,json=userId,proto3,oneof" json:"user_id,omitempty"`
// contains filtered or unexported fields
}
Unique identifier for a given user.
func (*UserId) ProtoReflect ¶
func (x *UserId) ProtoReflect() protoreflect.Message
type UserId_builder ¶
type UserId_builder struct {
// Required field that represents the user's unique identifier (UID).
// The supplied value must be a UUID as defined by
// [RFC 4122](https://tools.ietf.org/html/rfc4122#section-4.1.2).
UserId *string
// contains filtered or unexported fields
}
func (UserId_builder) Build ¶
func (b0 UserId_builder) Build() *UserId
type UserPassword ¶
type UserPassword struct {
Password *string `protobuf:"bytes,1,opt,name=password,proto3,oneof" json:"password,omitempty"`
// contains filtered or unexported fields
}
The password a user supplies at registration or later updates. This message should not actually contain a value outside of those scenarios.
func (*UserPassword) ClearPassword ¶
func (x *UserPassword) ClearPassword()
func (*UserPassword) GetPassword ¶
func (x *UserPassword) GetPassword() string
func (*UserPassword) HasPassword ¶
func (x *UserPassword) HasPassword() bool
func (*UserPassword) ProtoMessage ¶
func (*UserPassword) ProtoMessage()
func (*UserPassword) ProtoReflect ¶
func (x *UserPassword) ProtoReflect() protoreflect.Message
func (*UserPassword) Reset ¶
func (x *UserPassword) Reset()
func (*UserPassword) SetPassword ¶
func (x *UserPassword) SetPassword(v string)
func (*UserPassword) String ¶
func (x *UserPassword) String() string
type UserPassword_builder ¶
type UserPassword_builder struct {
Password *string
// contains filtered or unexported fields
}
func (UserPassword_builder) Build ¶
func (b0 UserPassword_builder) Build() *UserPassword
type User_builder ¶
type User_builder struct {
UserId *UserId
FullName *UserFullName
Handle *UserHandle
EmailAddress *UserEmailAddress
Avatar *UserAvatar
// The password a user can authenticate and authorize with. This is an input-only field as described
// in AIP-203.
Password *UserPassword
// The entity tag, which represents the latest state of the user entity as described in AIP-143. For
// clients, this is an input only field that's passed along in RPCs.
ETag *v1.EntityTag
// contains filtered or unexported fields
}
func (User_builder) Build ¶
func (b0 User_builder) Build() *User
Source Files
¶
- create_user_request.pb.go
- create_user_response.pb.go
- delete_user_request.pb.go
- delete_user_response.pb.go
- get_user_request.pb.go
- get_user_response.pb.go
- update_user_request.pb.go
- update_user_response.pb.go
- user.pb.go
- user_avatar.pb.go
- user_email_address.pb.go
- user_full_name.pb.go
- user_handle.pb.go
- user_id.pb.go
- user_password.pb.go
- user_service.pb.go