Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterConformanceServiceServer(s grpc.ServiceRegistrar, srv ConformanceServiceServer)
- type ConformanceServiceClient
- type ConformanceServiceServer
- type UnimplementedConformanceServiceServer
- func (UnimplementedConformanceServiceServer) Check(context.Context, *conformance.CheckRequest) (*conformance.CheckResponse, error)
- func (UnimplementedConformanceServiceServer) Eval(context.Context, *conformance.EvalRequest) (*conformance.EvalResponse, error)
- func (UnimplementedConformanceServiceServer) Parse(context.Context, *conformance.ParseRequest) (*conformance.ParseResponse, error)
- type UnsafeConformanceServiceServer
Constants ¶
const ( ConformanceService_Parse_FullMethodName = "/cel.expr.conformance.ConformanceService/Parse" ConformanceService_Check_FullMethodName = "/cel.expr.conformance.ConformanceService/Check" ConformanceService_Eval_FullMethodName = "/cel.expr.conformance.ConformanceService/Eval" )
Variables ¶
var ConformanceService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "cel.expr.conformance.ConformanceService", HandlerType: (*ConformanceServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "Parse", Handler: _ConformanceService_Parse_Handler, }, { MethodName: "Check", Handler: _ConformanceService_Check_Handler, }, { MethodName: "Eval", Handler: _ConformanceService_Eval_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "cel/expr/conformance/conformance_service.proto", }
ConformanceService_ServiceDesc is the grpc.ServiceDesc for ConformanceService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterConformanceServiceServer ¶
func RegisterConformanceServiceServer(s grpc.ServiceRegistrar, srv ConformanceServiceServer)
Types ¶
type ConformanceServiceClient ¶
type ConformanceServiceClient interface {
// Transforms CEL source text into a parsed representation.
Parse(ctx context.Context, in *conformance.ParseRequest, opts ...grpc.CallOption) (*conformance.ParseResponse, error)
// Runs static checks on a parsed CEL representation and return
// an annotated representation, or a set of issues.
Check(ctx context.Context, in *conformance.CheckRequest, opts ...grpc.CallOption) (*conformance.CheckResponse, error)
// Evaluates a parsed or annotation CEL representation given
// values of external bindings.
Eval(ctx context.Context, in *conformance.EvalRequest, opts ...grpc.CallOption) (*conformance.EvalResponse, error)
}
ConformanceServiceClient is the client API for ConformanceService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
Access a CEL implementation from another process or machine. A CEL implementation is decomposed as a parser, a static checker, and an evaluator. Every CEL implementation is expected to provide a server for this API. The API will be used for conformance testing and other utilities.
func NewConformanceServiceClient ¶
func NewConformanceServiceClient(cc grpc.ClientConnInterface) ConformanceServiceClient
type ConformanceServiceServer ¶
type ConformanceServiceServer interface {
// Transforms CEL source text into a parsed representation.
Parse(context.Context, *conformance.ParseRequest) (*conformance.ParseResponse, error)
// Runs static checks on a parsed CEL representation and return
// an annotated representation, or a set of issues.
Check(context.Context, *conformance.CheckRequest) (*conformance.CheckResponse, error)
// Evaluates a parsed or annotation CEL representation given
// values of external bindings.
Eval(context.Context, *conformance.EvalRequest) (*conformance.EvalResponse, error)
}
ConformanceServiceServer is the server API for ConformanceService service. All implementations should embed UnimplementedConformanceServiceServer for forward compatibility.
Access a CEL implementation from another process or machine. A CEL implementation is decomposed as a parser, a static checker, and an evaluator. Every CEL implementation is expected to provide a server for this API. The API will be used for conformance testing and other utilities.
type UnimplementedConformanceServiceServer ¶
type UnimplementedConformanceServiceServer struct{}
UnimplementedConformanceServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedConformanceServiceServer) Check ¶
func (UnimplementedConformanceServiceServer) Check(context.Context, *conformance.CheckRequest) (*conformance.CheckResponse, error)
func (UnimplementedConformanceServiceServer) Eval ¶
func (UnimplementedConformanceServiceServer) Eval(context.Context, *conformance.EvalRequest) (*conformance.EvalResponse, error)
func (UnimplementedConformanceServiceServer) Parse ¶
func (UnimplementedConformanceServiceServer) Parse(context.Context, *conformance.ParseRequest) (*conformance.ParseResponse, error)
type UnsafeConformanceServiceServer ¶
type UnsafeConformanceServiceServer interface {
// contains filtered or unexported methods
}
UnsafeConformanceServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ConformanceServiceServer will result in compilation errors.
Source Files
¶
- conformance_service_grpc.pb.go