Documentation
¶
Index ¶
- Constants
- Variables
- type ErrorResponsedeprecated
- func (x *ErrorResponse) GetErrorCode() int32deprecated
- func (x *ErrorResponse) GetErrorMessage() stringdeprecated
- func (*ErrorResponse) ProtoMessage()
- func (x *ErrorResponse) ProtoReflect() protoreflect.Message
- func (x *ErrorResponse) Reset()
- func (x *ErrorResponse) SetErrorCode(v int32)deprecated
- func (x *ErrorResponse) SetErrorMessage(v string)deprecated
- func (x *ErrorResponse) String() string
- type ErrorResponse_builderdeprecated
- type ExtensionNumberResponsedeprecated
- func (x *ExtensionNumberResponse) GetBaseTypeName() stringdeprecated
- func (x *ExtensionNumberResponse) GetExtensionNumber() []int32deprecated
- func (*ExtensionNumberResponse) ProtoMessage()
- func (x *ExtensionNumberResponse) ProtoReflect() protoreflect.Message
- func (x *ExtensionNumberResponse) Reset()
- func (x *ExtensionNumberResponse) SetBaseTypeName(v string)deprecated
- func (x *ExtensionNumberResponse) SetExtensionNumber(v []int32)deprecated
- func (x *ExtensionNumberResponse) String() string
- type ExtensionNumberResponse_builderdeprecated
- type ExtensionRequestdeprecated
- func (x *ExtensionRequest) GetContainingType() stringdeprecated
- func (x *ExtensionRequest) GetExtensionNumber() int32deprecated
- func (*ExtensionRequest) ProtoMessage()
- func (x *ExtensionRequest) ProtoReflect() protoreflect.Message
- func (x *ExtensionRequest) Reset()
- func (x *ExtensionRequest) SetContainingType(v string)deprecated
- func (x *ExtensionRequest) SetExtensionNumber(v int32)deprecated
- func (x *ExtensionRequest) String() string
- type ExtensionRequest_builderdeprecated
- type FileDescriptorResponsedeprecated
- func (x *FileDescriptorResponse) GetFileDescriptorProto() [][]bytedeprecated
- func (*FileDescriptorResponse) ProtoMessage()
- func (x *FileDescriptorResponse) ProtoReflect() protoreflect.Message
- func (x *FileDescriptorResponse) Reset()
- func (x *FileDescriptorResponse) SetFileDescriptorProto(v [][]byte)deprecated
- func (x *FileDescriptorResponse) String() string
- type FileDescriptorResponse_builderdeprecated
- type ListServiceResponsedeprecated
- func (x *ListServiceResponse) GetService() []*ServiceResponsedeprecated
- func (*ListServiceResponse) ProtoMessage()
- func (x *ListServiceResponse) ProtoReflect() protoreflect.Message
- func (x *ListServiceResponse) Reset()
- func (x *ListServiceResponse) SetService(v []*ServiceResponse)deprecated
- func (x *ListServiceResponse) String() string
- type ListServiceResponse_builderdeprecated
- type ServerReflectionRequestdeprecated
- func (x *ServerReflectionRequest) ClearAllExtensionNumbersOfType()deprecated
- func (x *ServerReflectionRequest) ClearFileByFilename()deprecated
- func (x *ServerReflectionRequest) ClearFileContainingExtension()deprecated
- func (x *ServerReflectionRequest) ClearFileContainingSymbol()deprecated
- func (x *ServerReflectionRequest) ClearListServices()deprecated
- func (x *ServerReflectionRequest) ClearMessageRequest()
- func (x *ServerReflectionRequest) GetAllExtensionNumbersOfType() stringdeprecated
- func (x *ServerReflectionRequest) GetFileByFilename() stringdeprecated
- func (x *ServerReflectionRequest) GetFileContainingExtension() *ExtensionRequestdeprecated
- func (x *ServerReflectionRequest) GetFileContainingSymbol() stringdeprecated
- func (x *ServerReflectionRequest) GetHost() stringdeprecated
- func (x *ServerReflectionRequest) GetListServices() stringdeprecated
- func (x *ServerReflectionRequest) GetMessageRequest() isServerReflectionRequest_MessageRequest
- func (x *ServerReflectionRequest) HasAllExtensionNumbersOfType() booldeprecated
- func (x *ServerReflectionRequest) HasFileByFilename() booldeprecated
- func (x *ServerReflectionRequest) HasFileContainingExtension() booldeprecated
- func (x *ServerReflectionRequest) HasFileContainingSymbol() booldeprecated
- func (x *ServerReflectionRequest) HasListServices() booldeprecated
- func (x *ServerReflectionRequest) HasMessageRequest() bool
- func (*ServerReflectionRequest) ProtoMessage()
- func (x *ServerReflectionRequest) ProtoReflect() protoreflect.Message
- func (x *ServerReflectionRequest) Reset()
- func (x *ServerReflectionRequest) SetAllExtensionNumbersOfType(v string)deprecated
- func (x *ServerReflectionRequest) SetFileByFilename(v string)deprecated
- func (x *ServerReflectionRequest) SetFileContainingExtension(v *ExtensionRequest)deprecated
- func (x *ServerReflectionRequest) SetFileContainingSymbol(v string)deprecated
- func (x *ServerReflectionRequest) SetHost(v string)deprecated
- func (x *ServerReflectionRequest) SetListServices(v string)deprecated
- func (x *ServerReflectionRequest) String() string
- func (x *ServerReflectionRequest) WhichMessageRequest() case_ServerReflectionRequest_MessageRequest
- type ServerReflectionRequest_AllExtensionNumbersOfType
- type ServerReflectionRequest_FileByFilename
- type ServerReflectionRequest_FileContainingExtension
- type ServerReflectionRequest_FileContainingSymbol
- type ServerReflectionRequest_ListServices
- type ServerReflectionRequest_builderdeprecated
- type ServerReflectionResponsedeprecated
- func (x *ServerReflectionResponse) ClearAllExtensionNumbersResponse()deprecated
- func (x *ServerReflectionResponse) ClearErrorResponse()deprecated
- func (x *ServerReflectionResponse) ClearFileDescriptorResponse()deprecated
- func (x *ServerReflectionResponse) ClearListServicesResponse()deprecated
- func (x *ServerReflectionResponse) ClearMessageResponse()
- func (x *ServerReflectionResponse) ClearOriginalRequest()deprecated
- func (x *ServerReflectionResponse) GetAllExtensionNumbersResponse() *ExtensionNumberResponsedeprecated
- func (x *ServerReflectionResponse) GetErrorResponse() *ErrorResponsedeprecated
- func (x *ServerReflectionResponse) GetFileDescriptorResponse() *FileDescriptorResponsedeprecated
- func (x *ServerReflectionResponse) GetListServicesResponse() *ListServiceResponsedeprecated
- func (x *ServerReflectionResponse) GetMessageResponse() isServerReflectionResponse_MessageResponse
- func (x *ServerReflectionResponse) GetOriginalRequest() *ServerReflectionRequestdeprecated
- func (x *ServerReflectionResponse) GetValidHost() stringdeprecated
- func (x *ServerReflectionResponse) HasAllExtensionNumbersResponse() booldeprecated
- func (x *ServerReflectionResponse) HasErrorResponse() booldeprecated
- func (x *ServerReflectionResponse) HasFileDescriptorResponse() booldeprecated
- func (x *ServerReflectionResponse) HasListServicesResponse() booldeprecated
- func (x *ServerReflectionResponse) HasMessageResponse() bool
- func (x *ServerReflectionResponse) HasOriginalRequest() booldeprecated
- func (*ServerReflectionResponse) ProtoMessage()
- func (x *ServerReflectionResponse) ProtoReflect() protoreflect.Message
- func (x *ServerReflectionResponse) Reset()
- func (x *ServerReflectionResponse) SetAllExtensionNumbersResponse(v *ExtensionNumberResponse)deprecated
- func (x *ServerReflectionResponse) SetErrorResponse(v *ErrorResponse)deprecated
- func (x *ServerReflectionResponse) SetFileDescriptorResponse(v *FileDescriptorResponse)deprecated
- func (x *ServerReflectionResponse) SetListServicesResponse(v *ListServiceResponse)deprecated
- func (x *ServerReflectionResponse) SetOriginalRequest(v *ServerReflectionRequest)deprecated
- func (x *ServerReflectionResponse) SetValidHost(v string)deprecated
- func (x *ServerReflectionResponse) String() string
- func (x *ServerReflectionResponse) WhichMessageResponse() case_ServerReflectionResponse_MessageResponse
- type ServerReflectionResponse_AllExtensionNumbersResponse
- type ServerReflectionResponse_ErrorResponse
- type ServerReflectionResponse_FileDescriptorResponse
- type ServerReflectionResponse_ListServicesResponse
- type ServerReflectionResponse_builderdeprecated
- type ServiceResponsedeprecated
- type ServiceResponse_builderdeprecated
Constants ¶
const ServerReflectionRequest_AllExtensionNumbersOfType_case case_ServerReflectionRequest_MessageRequest = 6
const ServerReflectionRequest_FileByFilename_case case_ServerReflectionRequest_MessageRequest = 3
const ServerReflectionRequest_FileContainingExtension_case case_ServerReflectionRequest_MessageRequest = 5
const ServerReflectionRequest_FileContainingSymbol_case case_ServerReflectionRequest_MessageRequest = 4
const ServerReflectionRequest_ListServices_case case_ServerReflectionRequest_MessageRequest = 7
const ServerReflectionRequest_MessageRequest_not_set_case case_ServerReflectionRequest_MessageRequest = 0
const ServerReflectionResponse_AllExtensionNumbersResponse_case case_ServerReflectionResponse_MessageResponse = 5
const ServerReflectionResponse_ErrorResponse_case case_ServerReflectionResponse_MessageResponse = 7
const ServerReflectionResponse_FileDescriptorResponse_case case_ServerReflectionResponse_MessageResponse = 4
const ServerReflectionResponse_ListServicesResponse_case case_ServerReflectionResponse_MessageResponse = 6
const ServerReflectionResponse_MessageResponse_not_set_case case_ServerReflectionResponse_MessageResponse = 0
Variables ¶
var File_grpc_reflection_v1alpha_reflection_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type ErrorResponse
deprecated
type ErrorResponse struct {
// This field uses the error codes defined in grpc::StatusCode.
//
// Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
ErrorCode int32 `protobuf:"varint,1,opt,name=error_code,json=errorCode,proto3" json:"error_code,omitempty"`
// Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
ErrorMessage string `protobuf:"bytes,2,opt,name=error_message,json=errorMessage,proto3" json:"error_message,omitempty"`
// contains filtered or unexported fields
}
The error code and error message sent by the server when an error occurs.
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ErrorResponse) GetErrorCode
deprecated
func (x *ErrorResponse) GetErrorCode() int32
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ErrorResponse) GetErrorMessage
deprecated
func (x *ErrorResponse) GetErrorMessage() string
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ErrorResponse) ProtoMessage ¶
func (*ErrorResponse) ProtoMessage()
func (*ErrorResponse) ProtoReflect ¶
func (x *ErrorResponse) ProtoReflect() protoreflect.Message
func (*ErrorResponse) Reset ¶
func (x *ErrorResponse) Reset()
func (*ErrorResponse) SetErrorCode
deprecated
func (x *ErrorResponse) SetErrorCode(v int32)
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ErrorResponse) SetErrorMessage
deprecated
func (x *ErrorResponse) SetErrorMessage(v string)
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ErrorResponse) String ¶
func (x *ErrorResponse) String() string
type ErrorResponse_builder
deprecated
type ErrorResponse_builder struct {
// This field uses the error codes defined in grpc::StatusCode.
//
// Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
ErrorCode int32
// Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
ErrorMessage string
// contains filtered or unexported fields
}
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (ErrorResponse_builder) Build ¶
func (b0 ErrorResponse_builder) Build() *ErrorResponse
type ExtensionNumberResponse
deprecated
type ExtensionNumberResponse struct {
// Full name of the base type, including the package name. The format
// is <package>.<type>
//
// Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
BaseTypeName string `protobuf:"bytes,1,opt,name=base_type_name,json=baseTypeName,proto3" json:"base_type_name,omitempty"`
// Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
ExtensionNumber []int32 `protobuf:"varint,2,rep,packed,name=extension_number,json=extensionNumber,proto3" json:"extension_number,omitempty"`
// contains filtered or unexported fields
}
A list of extension numbers sent by the server answering all_extension_numbers_of_type request.
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ExtensionNumberResponse) GetBaseTypeName
deprecated
func (x *ExtensionNumberResponse) GetBaseTypeName() string
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ExtensionNumberResponse) GetExtensionNumber
deprecated
func (x *ExtensionNumberResponse) GetExtensionNumber() []int32
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ExtensionNumberResponse) ProtoMessage ¶
func (*ExtensionNumberResponse) ProtoMessage()
func (*ExtensionNumberResponse) ProtoReflect ¶
func (x *ExtensionNumberResponse) ProtoReflect() protoreflect.Message
func (*ExtensionNumberResponse) Reset ¶
func (x *ExtensionNumberResponse) Reset()
func (*ExtensionNumberResponse) SetBaseTypeName
deprecated
func (x *ExtensionNumberResponse) SetBaseTypeName(v string)
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ExtensionNumberResponse) SetExtensionNumber
deprecated
func (x *ExtensionNumberResponse) SetExtensionNumber(v []int32)
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ExtensionNumberResponse) String ¶
func (x *ExtensionNumberResponse) String() string
type ExtensionNumberResponse_builder
deprecated
type ExtensionNumberResponse_builder struct {
// Full name of the base type, including the package name. The format
// is <package>.<type>
//
// Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
BaseTypeName string
// Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
ExtensionNumber []int32
// contains filtered or unexported fields
}
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (ExtensionNumberResponse_builder) Build ¶
func (b0 ExtensionNumberResponse_builder) Build() *ExtensionNumberResponse
type ExtensionRequest
deprecated
type ExtensionRequest struct {
// Fully-qualified type name. The format should be <package>.<type>
//
// Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
ContainingType string `protobuf:"bytes,1,opt,name=containing_type,json=containingType,proto3" json:"containing_type,omitempty"`
// Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
ExtensionNumber int32 `protobuf:"varint,2,opt,name=extension_number,json=extensionNumber,proto3" json:"extension_number,omitempty"`
// contains filtered or unexported fields
}
The type name and extension number sent by the client when requesting file_containing_extension.
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ExtensionRequest) GetContainingType
deprecated
func (x *ExtensionRequest) GetContainingType() string
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ExtensionRequest) GetExtensionNumber
deprecated
func (x *ExtensionRequest) GetExtensionNumber() int32
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ExtensionRequest) ProtoMessage ¶
func (*ExtensionRequest) ProtoMessage()
func (*ExtensionRequest) ProtoReflect ¶
func (x *ExtensionRequest) ProtoReflect() protoreflect.Message
func (*ExtensionRequest) Reset ¶
func (x *ExtensionRequest) Reset()
func (*ExtensionRequest) SetContainingType
deprecated
func (x *ExtensionRequest) SetContainingType(v string)
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ExtensionRequest) SetExtensionNumber
deprecated
func (x *ExtensionRequest) SetExtensionNumber(v int32)
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ExtensionRequest) String ¶
func (x *ExtensionRequest) String() string
type ExtensionRequest_builder
deprecated
type ExtensionRequest_builder struct {
// Fully-qualified type name. The format should be <package>.<type>
//
// Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
ContainingType string
// Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
ExtensionNumber int32
// contains filtered or unexported fields
}
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (ExtensionRequest_builder) Build ¶
func (b0 ExtensionRequest_builder) Build() *ExtensionRequest
type FileDescriptorResponse
deprecated
type FileDescriptorResponse struct {
// Serialized FileDescriptorProto messages. We avoid taking a dependency on
// descriptor.proto, which uses proto2 only features, by making them opaque
// bytes instead.
//
// Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
FileDescriptorProto [][]byte `protobuf:"bytes,1,rep,name=file_descriptor_proto,json=fileDescriptorProto,proto3" json:"file_descriptor_proto,omitempty"`
// contains filtered or unexported fields
}
Serialized FileDescriptorProto messages sent by the server answering a file_by_filename, file_containing_symbol, or file_containing_extension request.
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*FileDescriptorResponse) GetFileDescriptorProto
deprecated
func (x *FileDescriptorResponse) GetFileDescriptorProto() [][]byte
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*FileDescriptorResponse) ProtoMessage ¶
func (*FileDescriptorResponse) ProtoMessage()
func (*FileDescriptorResponse) ProtoReflect ¶
func (x *FileDescriptorResponse) ProtoReflect() protoreflect.Message
func (*FileDescriptorResponse) Reset ¶
func (x *FileDescriptorResponse) Reset()
func (*FileDescriptorResponse) SetFileDescriptorProto
deprecated
func (x *FileDescriptorResponse) SetFileDescriptorProto(v [][]byte)
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*FileDescriptorResponse) String ¶
func (x *FileDescriptorResponse) String() string
type FileDescriptorResponse_builder
deprecated
type FileDescriptorResponse_builder struct {
// Serialized FileDescriptorProto messages. We avoid taking a dependency on
// descriptor.proto, which uses proto2 only features, by making them opaque
// bytes instead.
//
// Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
FileDescriptorProto [][]byte
// contains filtered or unexported fields
}
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (FileDescriptorResponse_builder) Build ¶
func (b0 FileDescriptorResponse_builder) Build() *FileDescriptorResponse
type ListServiceResponse
deprecated
type ListServiceResponse struct {
// The information of each service may be expanded in the future, so we use
// ServiceResponse message to encapsulate it.
//
// Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
Service []*ServiceResponse `protobuf:"bytes,1,rep,name=service,proto3" json:"service,omitempty"`
// contains filtered or unexported fields
}
A list of ServiceResponse sent by the server answering list_services request.
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ListServiceResponse) GetService
deprecated
func (x *ListServiceResponse) GetService() []*ServiceResponse
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ListServiceResponse) ProtoMessage ¶
func (*ListServiceResponse) ProtoMessage()
func (*ListServiceResponse) ProtoReflect ¶
func (x *ListServiceResponse) ProtoReflect() protoreflect.Message
func (*ListServiceResponse) Reset ¶
func (x *ListServiceResponse) Reset()
func (*ListServiceResponse) SetService
deprecated
func (x *ListServiceResponse) SetService(v []*ServiceResponse)
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ListServiceResponse) String ¶
func (x *ListServiceResponse) String() string
type ListServiceResponse_builder
deprecated
type ListServiceResponse_builder struct {
// The information of each service may be expanded in the future, so we use
// ServiceResponse message to encapsulate it.
//
// Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
Service []*ServiceResponse
// contains filtered or unexported fields
}
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (ListServiceResponse_builder) Build ¶
func (b0 ListServiceResponse_builder) Build() *ListServiceResponse
type ServerReflectionRequest
deprecated
type ServerReflectionRequest struct {
// Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
Host string `protobuf:"bytes,1,opt,name=host,proto3" json:"host,omitempty"`
// To use reflection service, the client should set one of the following
// fields in message_request. The server distinguishes requests by their
// defined field and then handles them using corresponding methods.
//
// Types that are valid to be assigned to MessageRequest:
//
// *ServerReflectionRequest_FileByFilename
// *ServerReflectionRequest_FileContainingSymbol
// *ServerReflectionRequest_FileContainingExtension
// *ServerReflectionRequest_AllExtensionNumbersOfType
// *ServerReflectionRequest_ListServices
MessageRequest isServerReflectionRequest_MessageRequest `protobuf_oneof:"message_request"`
// contains filtered or unexported fields
}
The message sent by the client when calling ServerReflectionInfo method.
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServerReflectionRequest) ClearAllExtensionNumbersOfType
deprecated
func (x *ServerReflectionRequest) ClearAllExtensionNumbersOfType()
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServerReflectionRequest) ClearFileByFilename
deprecated
func (x *ServerReflectionRequest) ClearFileByFilename()
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServerReflectionRequest) ClearFileContainingExtension
deprecated
func (x *ServerReflectionRequest) ClearFileContainingExtension()
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServerReflectionRequest) ClearFileContainingSymbol
deprecated
func (x *ServerReflectionRequest) ClearFileContainingSymbol()
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServerReflectionRequest) ClearListServices
deprecated
func (x *ServerReflectionRequest) ClearListServices()
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServerReflectionRequest) ClearMessageRequest ¶
func (x *ServerReflectionRequest) ClearMessageRequest()
func (*ServerReflectionRequest) GetAllExtensionNumbersOfType
deprecated
func (x *ServerReflectionRequest) GetAllExtensionNumbersOfType() string
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServerReflectionRequest) GetFileByFilename
deprecated
func (x *ServerReflectionRequest) GetFileByFilename() string
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServerReflectionRequest) GetFileContainingExtension
deprecated
func (x *ServerReflectionRequest) GetFileContainingExtension() *ExtensionRequest
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServerReflectionRequest) GetFileContainingSymbol
deprecated
func (x *ServerReflectionRequest) GetFileContainingSymbol() string
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServerReflectionRequest) GetHost
deprecated
func (x *ServerReflectionRequest) GetHost() string
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServerReflectionRequest) GetListServices
deprecated
func (x *ServerReflectionRequest) GetListServices() string
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServerReflectionRequest) GetMessageRequest ¶
func (x *ServerReflectionRequest) GetMessageRequest() isServerReflectionRequest_MessageRequest
func (*ServerReflectionRequest) HasAllExtensionNumbersOfType
deprecated
func (x *ServerReflectionRequest) HasAllExtensionNumbersOfType() bool
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServerReflectionRequest) HasFileByFilename
deprecated
func (x *ServerReflectionRequest) HasFileByFilename() bool
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServerReflectionRequest) HasFileContainingExtension
deprecated
func (x *ServerReflectionRequest) HasFileContainingExtension() bool
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServerReflectionRequest) HasFileContainingSymbol
deprecated
func (x *ServerReflectionRequest) HasFileContainingSymbol() bool
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServerReflectionRequest) HasListServices
deprecated
func (x *ServerReflectionRequest) HasListServices() bool
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServerReflectionRequest) HasMessageRequest ¶
func (x *ServerReflectionRequest) HasMessageRequest() bool
func (*ServerReflectionRequest) ProtoMessage ¶
func (*ServerReflectionRequest) ProtoMessage()
func (*ServerReflectionRequest) ProtoReflect ¶
func (x *ServerReflectionRequest) ProtoReflect() protoreflect.Message
func (*ServerReflectionRequest) Reset ¶
func (x *ServerReflectionRequest) Reset()
func (*ServerReflectionRequest) SetAllExtensionNumbersOfType
deprecated
func (x *ServerReflectionRequest) SetAllExtensionNumbersOfType(v string)
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServerReflectionRequest) SetFileByFilename
deprecated
func (x *ServerReflectionRequest) SetFileByFilename(v string)
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServerReflectionRequest) SetFileContainingExtension
deprecated
func (x *ServerReflectionRequest) SetFileContainingExtension(v *ExtensionRequest)
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServerReflectionRequest) SetFileContainingSymbol
deprecated
func (x *ServerReflectionRequest) SetFileContainingSymbol(v string)
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServerReflectionRequest) SetHost
deprecated
func (x *ServerReflectionRequest) SetHost(v string)
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServerReflectionRequest) SetListServices
deprecated
func (x *ServerReflectionRequest) SetListServices(v string)
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServerReflectionRequest) String ¶
func (x *ServerReflectionRequest) String() string
func (*ServerReflectionRequest) WhichMessageRequest ¶
func (x *ServerReflectionRequest) WhichMessageRequest() case_ServerReflectionRequest_MessageRequest
type ServerReflectionRequest_AllExtensionNumbersOfType ¶
type ServerReflectionRequest_AllExtensionNumbersOfType struct {
// Finds the tag numbers used by all known extensions of extendee_type, and
// appends them to ExtensionNumberResponse in an undefined order.
// Its corresponding method is best-effort: it's not guaranteed that the
// reflection service will implement this method, and it's not guaranteed
// that this method will provide all extensions. Returns
// StatusCode::UNIMPLEMENTED if it's not implemented.
// This field should be a fully-qualified type name. The format is
// <package>.<type>
//
// Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
AllExtensionNumbersOfType string `protobuf:"bytes,6,opt,name=all_extension_numbers_of_type,json=allExtensionNumbersOfType,proto3,oneof"`
}
type ServerReflectionRequest_FileByFilename ¶
type ServerReflectionRequest_FileByFilename struct {
// Find a proto file by the file name.
//
// Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
FileByFilename string `protobuf:"bytes,3,opt,name=file_by_filename,json=fileByFilename,proto3,oneof"`
}
type ServerReflectionRequest_FileContainingExtension ¶
type ServerReflectionRequest_FileContainingExtension struct {
// Find the proto file which defines an extension extending the given
// message type with the given field number.
//
// Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
FileContainingExtension *ExtensionRequest `protobuf:"bytes,5,opt,name=file_containing_extension,json=fileContainingExtension,proto3,oneof"`
}
type ServerReflectionRequest_FileContainingSymbol ¶
type ServerReflectionRequest_FileContainingSymbol struct {
// Find the proto file that declares the given fully-qualified symbol name.
// This field should be a fully-qualified symbol name
// (e.g. <package>.<service>[.<method>] or <package>.<type>).
//
// Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
FileContainingSymbol string `protobuf:"bytes,4,opt,name=file_containing_symbol,json=fileContainingSymbol,proto3,oneof"`
}
type ServerReflectionRequest_ListServices ¶
type ServerReflectionRequest_ListServices struct {
// List the full names of registered services. The content will not be
// checked.
//
// Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
ListServices string `protobuf:"bytes,7,opt,name=list_services,json=listServices,proto3,oneof"`
}
type ServerReflectionRequest_builder
deprecated
type ServerReflectionRequest_builder struct {
// Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
Host string
// Fields of oneof MessageRequest:
// Find a proto file by the file name.
//
// Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
FileByFilename *string
// Find the proto file that declares the given fully-qualified symbol name.
// This field should be a fully-qualified symbol name
// (e.g. <package>.<service>[.<method>] or <package>.<type>).
//
// Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
FileContainingSymbol *string
// Find the proto file which defines an extension extending the given
// message type with the given field number.
//
// Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
FileContainingExtension *ExtensionRequest
// Finds the tag numbers used by all known extensions of extendee_type, and
// appends them to ExtensionNumberResponse in an undefined order.
// Its corresponding method is best-effort: it's not guaranteed that the
// reflection service will implement this method, and it's not guaranteed
// that this method will provide all extensions. Returns
// StatusCode::UNIMPLEMENTED if it's not implemented.
// This field should be a fully-qualified type name. The format is
// <package>.<type>
//
// Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
AllExtensionNumbersOfType *string
// List the full names of registered services. The content will not be
// checked.
//
// Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
ListServices *string
// contains filtered or unexported fields
}
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (ServerReflectionRequest_builder) Build ¶
func (b0 ServerReflectionRequest_builder) Build() *ServerReflectionRequest
type ServerReflectionResponse
deprecated
type ServerReflectionResponse struct {
// Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
ValidHost string `protobuf:"bytes,1,opt,name=valid_host,json=validHost,proto3" json:"valid_host,omitempty"`
// Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
OriginalRequest *ServerReflectionRequest `protobuf:"bytes,2,opt,name=original_request,json=originalRequest,proto3" json:"original_request,omitempty"`
// The server set one of the following fields according to the message_request
// in the request.
//
// Types that are valid to be assigned to MessageResponse:
//
// *ServerReflectionResponse_FileDescriptorResponse
// *ServerReflectionResponse_AllExtensionNumbersResponse
// *ServerReflectionResponse_ListServicesResponse
// *ServerReflectionResponse_ErrorResponse
MessageResponse isServerReflectionResponse_MessageResponse `protobuf_oneof:"message_response"`
// contains filtered or unexported fields
}
The message sent by the server to answer ServerReflectionInfo method.
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServerReflectionResponse) ClearAllExtensionNumbersResponse
deprecated
func (x *ServerReflectionResponse) ClearAllExtensionNumbersResponse()
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServerReflectionResponse) ClearErrorResponse
deprecated
func (x *ServerReflectionResponse) ClearErrorResponse()
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServerReflectionResponse) ClearFileDescriptorResponse
deprecated
func (x *ServerReflectionResponse) ClearFileDescriptorResponse()
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServerReflectionResponse) ClearListServicesResponse
deprecated
func (x *ServerReflectionResponse) ClearListServicesResponse()
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServerReflectionResponse) ClearMessageResponse ¶
func (x *ServerReflectionResponse) ClearMessageResponse()
func (*ServerReflectionResponse) ClearOriginalRequest
deprecated
func (x *ServerReflectionResponse) ClearOriginalRequest()
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServerReflectionResponse) GetAllExtensionNumbersResponse
deprecated
func (x *ServerReflectionResponse) GetAllExtensionNumbersResponse() *ExtensionNumberResponse
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServerReflectionResponse) GetErrorResponse
deprecated
func (x *ServerReflectionResponse) GetErrorResponse() *ErrorResponse
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServerReflectionResponse) GetFileDescriptorResponse
deprecated
func (x *ServerReflectionResponse) GetFileDescriptorResponse() *FileDescriptorResponse
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServerReflectionResponse) GetListServicesResponse
deprecated
func (x *ServerReflectionResponse) GetListServicesResponse() *ListServiceResponse
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServerReflectionResponse) GetMessageResponse ¶
func (x *ServerReflectionResponse) GetMessageResponse() isServerReflectionResponse_MessageResponse
func (*ServerReflectionResponse) GetOriginalRequest
deprecated
func (x *ServerReflectionResponse) GetOriginalRequest() *ServerReflectionRequest
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServerReflectionResponse) GetValidHost
deprecated
func (x *ServerReflectionResponse) GetValidHost() string
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServerReflectionResponse) HasAllExtensionNumbersResponse
deprecated
func (x *ServerReflectionResponse) HasAllExtensionNumbersResponse() bool
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServerReflectionResponse) HasErrorResponse
deprecated
func (x *ServerReflectionResponse) HasErrorResponse() bool
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServerReflectionResponse) HasFileDescriptorResponse
deprecated
func (x *ServerReflectionResponse) HasFileDescriptorResponse() bool
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServerReflectionResponse) HasListServicesResponse
deprecated
func (x *ServerReflectionResponse) HasListServicesResponse() bool
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServerReflectionResponse) HasMessageResponse ¶
func (x *ServerReflectionResponse) HasMessageResponse() bool
func (*ServerReflectionResponse) HasOriginalRequest
deprecated
func (x *ServerReflectionResponse) HasOriginalRequest() bool
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServerReflectionResponse) ProtoMessage ¶
func (*ServerReflectionResponse) ProtoMessage()
func (*ServerReflectionResponse) ProtoReflect ¶
func (x *ServerReflectionResponse) ProtoReflect() protoreflect.Message
func (*ServerReflectionResponse) Reset ¶
func (x *ServerReflectionResponse) Reset()
func (*ServerReflectionResponse) SetAllExtensionNumbersResponse
deprecated
func (x *ServerReflectionResponse) SetAllExtensionNumbersResponse(v *ExtensionNumberResponse)
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServerReflectionResponse) SetErrorResponse
deprecated
func (x *ServerReflectionResponse) SetErrorResponse(v *ErrorResponse)
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServerReflectionResponse) SetFileDescriptorResponse
deprecated
func (x *ServerReflectionResponse) SetFileDescriptorResponse(v *FileDescriptorResponse)
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServerReflectionResponse) SetListServicesResponse
deprecated
func (x *ServerReflectionResponse) SetListServicesResponse(v *ListServiceResponse)
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServerReflectionResponse) SetOriginalRequest
deprecated
func (x *ServerReflectionResponse) SetOriginalRequest(v *ServerReflectionRequest)
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServerReflectionResponse) SetValidHost
deprecated
func (x *ServerReflectionResponse) SetValidHost(v string)
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServerReflectionResponse) String ¶
func (x *ServerReflectionResponse) String() string
func (*ServerReflectionResponse) WhichMessageResponse ¶
func (x *ServerReflectionResponse) WhichMessageResponse() case_ServerReflectionResponse_MessageResponse
type ServerReflectionResponse_AllExtensionNumbersResponse ¶
type ServerReflectionResponse_AllExtensionNumbersResponse struct {
// This message is used to answer all_extension_numbers_of_type request.
//
// Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
AllExtensionNumbersResponse *ExtensionNumberResponse `protobuf:"bytes,5,opt,name=all_extension_numbers_response,json=allExtensionNumbersResponse,proto3,oneof"`
}
type ServerReflectionResponse_ErrorResponse ¶
type ServerReflectionResponse_ErrorResponse struct {
// This message is used when an error occurs.
//
// Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
ErrorResponse *ErrorResponse `protobuf:"bytes,7,opt,name=error_response,json=errorResponse,proto3,oneof"`
}
type ServerReflectionResponse_FileDescriptorResponse ¶
type ServerReflectionResponse_FileDescriptorResponse struct {
// This message is used to answer file_by_filename, file_containing_symbol,
// file_containing_extension requests with transitive dependencies. As
// the repeated label is not allowed in oneof fields, we use a
// FileDescriptorResponse message to encapsulate the repeated fields.
// The reflection service is allowed to avoid sending FileDescriptorProtos
// that were previously sent in response to earlier requests in the stream.
//
// Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
FileDescriptorResponse *FileDescriptorResponse `protobuf:"bytes,4,opt,name=file_descriptor_response,json=fileDescriptorResponse,proto3,oneof"`
}
type ServerReflectionResponse_ListServicesResponse ¶
type ServerReflectionResponse_ListServicesResponse struct {
// This message is used to answer list_services request.
//
// Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
ListServicesResponse *ListServiceResponse `protobuf:"bytes,6,opt,name=list_services_response,json=listServicesResponse,proto3,oneof"`
}
type ServerReflectionResponse_builder
deprecated
type ServerReflectionResponse_builder struct {
// Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
ValidHost string
// Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
OriginalRequest *ServerReflectionRequest
// Fields of oneof MessageResponse:
// This message is used to answer file_by_filename, file_containing_symbol,
// file_containing_extension requests with transitive dependencies. As
// the repeated label is not allowed in oneof fields, we use a
// FileDescriptorResponse message to encapsulate the repeated fields.
// The reflection service is allowed to avoid sending FileDescriptorProtos
// that were previously sent in response to earlier requests in the stream.
//
// Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
FileDescriptorResponse *FileDescriptorResponse
// This message is used to answer all_extension_numbers_of_type request.
//
// Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
AllExtensionNumbersResponse *ExtensionNumberResponse
// This message is used to answer list_services request.
//
// Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
ListServicesResponse *ListServiceResponse
// This message is used when an error occurs.
//
// Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
ErrorResponse *ErrorResponse
// contains filtered or unexported fields
}
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (ServerReflectionResponse_builder) Build ¶
func (b0 ServerReflectionResponse_builder) Build() *ServerReflectionResponse
type ServiceResponse
deprecated
type ServiceResponse struct {
// Full name of a registered service, including its package name. The format
// is <package>.<service>
//
// Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
The information of a single service used by ListServiceResponse to answer list_services request.
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServiceResponse) GetName
deprecated
func (x *ServiceResponse) GetName() string
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServiceResponse) ProtoMessage ¶
func (*ServiceResponse) ProtoMessage()
func (*ServiceResponse) ProtoReflect ¶
func (x *ServiceResponse) ProtoReflect() protoreflect.Message
func (*ServiceResponse) Reset ¶
func (x *ServiceResponse) Reset()
func (*ServiceResponse) SetName
deprecated
func (x *ServiceResponse) SetName(v string)
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (*ServiceResponse) String ¶
func (x *ServiceResponse) String() string
type ServiceResponse_builder
deprecated
type ServiceResponse_builder struct {
// Full name of a registered service, including its package name. The format
// is <package>.<service>
//
// Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
Name string
// contains filtered or unexported fields
}
Deprecated: The entire proto file grpc/reflection/v1alpha/reflection.proto is marked as deprecated.
func (ServiceResponse_builder) Build ¶
func (b0 ServiceResponse_builder) Build() *ServiceResponse
Source Files
¶
- reflection.pb.go