Documentation
¶
Index ¶
- Constants
- func NewTrustedDataAccessAPIHandler(svc TrustedDataAccessAPIHandler, opts ...connect_go.HandlerOption) (string, http.Handler)
- type TrustedDataAccessAPIClient
- type TrustedDataAccessAPIHandler
- type UnimplementedTrustedDataAccessAPIHandler
- func (UnimplementedTrustedDataAccessAPIHandler) DataAccess(context.Context, *connect_go.Request[v1beta1.DataAccessRequest]) (*connect_go.Response[v1beta1.DataAccessResponse], error)
- func (UnimplementedTrustedDataAccessAPIHandler) GrantConsent(context.Context, *connect_go.Request[v1beta1.GrantConsentRequest]) (*connect_go.Response[v1beta1.GrantConsentResponse], error)
- func (UnimplementedTrustedDataAccessAPIHandler) ListConsents(context.Context, *connect_go.Request[v1beta1.ListConsentsRequest]) (*connect_go.Response[v1beta1.ListConsentsResponse], error)
- func (UnimplementedTrustedDataAccessAPIHandler) RevokeConsent(context.Context, *connect_go.Request[v1beta1.RevokeConsentRequest]) (*connect_go.Response[v1beta1.RevokeConsentResponse], error)
Constants ¶
const ( // TrustedDataAccessAPIDataAccessProcedure is the fully-qualified name of the TrustedDataAccessAPI's // DataAccess RPC. TrustedDataAccessAPIDataAccessProcedure = "/indykite.tda.v1beta1.TrustedDataAccessAPI/DataAccess" // TrustedDataAccessAPIGrantConsentProcedure is the fully-qualified name of the // TrustedDataAccessAPI's GrantConsent RPC. TrustedDataAccessAPIGrantConsentProcedure = "/indykite.tda.v1beta1.TrustedDataAccessAPI/GrantConsent" // TrustedDataAccessAPIRevokeConsentProcedure is the fully-qualified name of the // TrustedDataAccessAPI's RevokeConsent RPC. TrustedDataAccessAPIRevokeConsentProcedure = "/indykite.tda.v1beta1.TrustedDataAccessAPI/RevokeConsent" // TrustedDataAccessAPIListConsentsProcedure is the fully-qualified name of the // TrustedDataAccessAPI's ListConsents RPC. TrustedDataAccessAPIListConsentsProcedure = "/indykite.tda.v1beta1.TrustedDataAccessAPI/ListConsents" )
These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.
Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.
const (
// TrustedDataAccessAPIName is the fully-qualified name of the TrustedDataAccessAPI service.
TrustedDataAccessAPIName = "indykite.tda.v1beta1.TrustedDataAccessAPI"
)
Variables ¶
This section is empty.
Functions ¶
func NewTrustedDataAccessAPIHandler ¶
func NewTrustedDataAccessAPIHandler(svc TrustedDataAccessAPIHandler, opts ...connect_go.HandlerOption) (string, http.Handler)
NewTrustedDataAccessAPIHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.
By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.
Types ¶
type TrustedDataAccessAPIClient ¶
type TrustedDataAccessAPIClient interface {
// Deprecated: do not use.
DataAccess(context.Context, *connect_go.Request[v1beta1.DataAccessRequest]) (*connect_go.Response[v1beta1.DataAccessResponse], error)
// Deprecated: do not use.
GrantConsent(context.Context, *connect_go.Request[v1beta1.GrantConsentRequest]) (*connect_go.Response[v1beta1.GrantConsentResponse], error)
// Deprecated: do not use.
RevokeConsent(context.Context, *connect_go.Request[v1beta1.RevokeConsentRequest]) (*connect_go.Response[v1beta1.RevokeConsentResponse], error)
// ListConsents returns all Consents (and the consented properties) between the specified application and user.
//
// Deprecated: do not use.
ListConsents(context.Context, *connect_go.Request[v1beta1.ListConsentsRequest]) (*connect_go.Response[v1beta1.ListConsentsResponse], error)
}
TrustedDataAccessAPIClient is a client for the indykite.tda.v1beta1.TrustedDataAccessAPI service.
func NewTrustedDataAccessAPIClient ¶
func NewTrustedDataAccessAPIClient(httpClient connect_go.HTTPClient, baseURL string, opts ...connect_go.ClientOption) TrustedDataAccessAPIClient
NewTrustedDataAccessAPIClient constructs a client for the indykite.tda.v1beta1.TrustedDataAccessAPI service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.
The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).
type TrustedDataAccessAPIHandler ¶
type TrustedDataAccessAPIHandler interface {
// Deprecated: do not use.
DataAccess(context.Context, *connect_go.Request[v1beta1.DataAccessRequest]) (*connect_go.Response[v1beta1.DataAccessResponse], error)
// Deprecated: do not use.
GrantConsent(context.Context, *connect_go.Request[v1beta1.GrantConsentRequest]) (*connect_go.Response[v1beta1.GrantConsentResponse], error)
// Deprecated: do not use.
RevokeConsent(context.Context, *connect_go.Request[v1beta1.RevokeConsentRequest]) (*connect_go.Response[v1beta1.RevokeConsentResponse], error)
// ListConsents returns all Consents (and the consented properties) between the specified application and user.
//
// Deprecated: do not use.
ListConsents(context.Context, *connect_go.Request[v1beta1.ListConsentsRequest]) (*connect_go.Response[v1beta1.ListConsentsResponse], error)
}
TrustedDataAccessAPIHandler is an implementation of the indykite.tda.v1beta1.TrustedDataAccessAPI service.
type UnimplementedTrustedDataAccessAPIHandler ¶
type UnimplementedTrustedDataAccessAPIHandler struct{}
UnimplementedTrustedDataAccessAPIHandler returns CodeUnimplemented from all methods.
func (UnimplementedTrustedDataAccessAPIHandler) DataAccess ¶
func (UnimplementedTrustedDataAccessAPIHandler) DataAccess(context.Context, *connect_go.Request[v1beta1.DataAccessRequest]) (*connect_go.Response[v1beta1.DataAccessResponse], error)
func (UnimplementedTrustedDataAccessAPIHandler) GrantConsent ¶
func (UnimplementedTrustedDataAccessAPIHandler) GrantConsent(context.Context, *connect_go.Request[v1beta1.GrantConsentRequest]) (*connect_go.Response[v1beta1.GrantConsentResponse], error)
func (UnimplementedTrustedDataAccessAPIHandler) ListConsents ¶
func (UnimplementedTrustedDataAccessAPIHandler) ListConsents(context.Context, *connect_go.Request[v1beta1.ListConsentsRequest]) (*connect_go.Response[v1beta1.ListConsentsResponse], error)
func (UnimplementedTrustedDataAccessAPIHandler) RevokeConsent ¶
func (UnimplementedTrustedDataAccessAPIHandler) RevokeConsent(context.Context, *connect_go.Request[v1beta1.RevokeConsentRequest]) (*connect_go.Response[v1beta1.RevokeConsentResponse], error)
Source Files
¶
- trusted_data_access_api.connect.go