Documentation
¶
Index ¶
- Constants
- Variables
- type ArrayValue
- type ArrayValue_builder
- type MapValue
- type MapValue_builder
- type Value
- func (x *Value) ClearAnyValue()
- func (x *Value) ClearArrayValue()
- func (x *Value) ClearBoolValue()
- func (x *Value) ClearBytesValue()
- func (x *Value) ClearDoubleValue()
- func (x *Value) ClearDurationValue()
- func (x *Value) ClearGeoPointValue()
- func (x *Value) ClearIntegerValue()
- func (x *Value) ClearMapValue()
- func (x *Value) ClearNullValue()
- func (x *Value) ClearStringValue()
- func (x *Value) ClearUnsignedIntegerValue()
- func (x *Value) ClearValue()
- func (x *Value) ClearValueTime()
- func (x *Value) GetAnyValue() *anypb.Any
- func (x *Value) GetArrayValue() *ArrayValue
- func (x *Value) GetBoolValue() bool
- func (x *Value) GetBytesValue() []byte
- func (x *Value) GetDoubleValue() float64
- func (x *Value) GetDurationValue() *durationpb.Duration
- func (x *Value) GetGeoPointValue() *latlng.LatLng
- func (x *Value) GetIntegerValue() int64
- func (x *Value) GetMapValue() *MapValue
- func (x *Value) GetNullValue() structpb.NullValue
- func (x *Value) GetStringValue() string
- func (x *Value) GetUnsignedIntegerValue() uint64
- func (x *Value) GetValue() isValue_Value
- func (x *Value) GetValueTime() *timestamppb.Timestamp
- func (x *Value) HasAnyValue() bool
- func (x *Value) HasArrayValue() bool
- func (x *Value) HasBoolValue() bool
- func (x *Value) HasBytesValue() bool
- func (x *Value) HasDoubleValue() bool
- func (x *Value) HasDurationValue() bool
- func (x *Value) HasGeoPointValue() bool
- func (x *Value) HasIntegerValue() bool
- func (x *Value) HasMapValue() bool
- func (x *Value) HasNullValue() bool
- func (x *Value) HasStringValue() bool
- func (x *Value) HasUnsignedIntegerValue() bool
- func (x *Value) HasValue() bool
- func (x *Value) HasValueTime() bool
- func (*Value) ProtoMessage()
- func (x *Value) ProtoReflect() protoreflect.Message
- func (x *Value) Reset()
- func (x *Value) SetAnyValue(v *anypb.Any)
- func (x *Value) SetArrayValue(v *ArrayValue)
- func (x *Value) SetBoolValue(v bool)
- func (x *Value) SetBytesValue(v []byte)
- func (x *Value) SetDoubleValue(v float64)
- func (x *Value) SetDurationValue(v *durationpb.Duration)
- func (x *Value) SetGeoPointValue(v *latlng.LatLng)
- func (x *Value) SetIntegerValue(v int64)
- func (x *Value) SetMapValue(v *MapValue)
- func (x *Value) SetNullValue(v structpb.NullValue)
- func (x *Value) SetStringValue(v string)
- func (x *Value) SetUnsignedIntegerValue(v uint64)
- func (x *Value) SetValueTime(v *timestamppb.Timestamp)
- func (x *Value) String() string
- func (x *Value) WhichValue() case_Value_Value
- type Value_AnyValue
- type Value_ArrayValue
- type Value_BoolValue
- type Value_BytesValue
- type Value_DoubleValue
- type Value_DurationValue
- type Value_GeoPointValue
- type Value_IntegerValue
- type Value_MapValue
- type Value_NullValue
- type Value_StringValue
- type Value_UnsignedIntegerValue
- type Value_ValueTime
- type Value_builder
Constants ¶
const Value_AnyValue_case case_Value_Value = 5
const Value_ArrayValue_case case_Value_Value = 10
const Value_BoolValue_case case_Value_Value = 2
const Value_BytesValue_case case_Value_Value = 8
const Value_DoubleValue_case case_Value_Value = 4
const Value_DurationValue_case case_Value_Value = 12
const Value_GeoPointValue_case case_Value_Value = 9
const Value_IntegerValue_case case_Value_Value = 3
const Value_MapValue_case case_Value_Value = 11
const Value_NullValue_case case_Value_Value = 1
const Value_StringValue_case case_Value_Value = 7
const Value_UnsignedIntegerValue_case case_Value_Value = 14
const Value_ValueTime_case case_Value_Value = 6
const Value_Value_not_set_case case_Value_Value = 0
Variables ¶
var File_indykite_objects_v1beta1_struct_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type ArrayValue ¶
type ArrayValue struct {
// Values in the array.
Values []*Value `protobuf:"bytes,1,rep,name=values,proto3" json:"values,omitempty"`
// contains filtered or unexported fields
}
An array value.
func (*ArrayValue) GetValues ¶
func (x *ArrayValue) GetValues() []*Value
func (*ArrayValue) ProtoMessage ¶
func (*ArrayValue) ProtoMessage()
func (*ArrayValue) ProtoReflect ¶
func (x *ArrayValue) ProtoReflect() protoreflect.Message
func (*ArrayValue) Reset ¶
func (x *ArrayValue) Reset()
func (*ArrayValue) SetValues ¶
func (x *ArrayValue) SetValues(v []*Value)
func (*ArrayValue) String ¶
func (x *ArrayValue) String() string
type ArrayValue_builder ¶
type ArrayValue_builder struct {
// Values in the array.
Values []*Value
// contains filtered or unexported fields
}
func (ArrayValue_builder) Build ¶
func (b0 ArrayValue_builder) Build() *ArrayValue
type MapValue ¶
type MapValue struct {
// The map's keys and values.
Fields map[string]*Value `` /* 139-byte string literal not displayed */
// contains filtered or unexported fields
}
A map value.
func (*MapValue) ProtoReflect ¶
func (x *MapValue) ProtoReflect() protoreflect.Message
type MapValue_builder ¶
type MapValue_builder struct {
// The map's keys and values.
Fields map[string]*Value
// contains filtered or unexported fields
}
func (MapValue_builder) Build ¶
func (b0 MapValue_builder) Build() *MapValue
type Value ¶
type Value struct {
// Must have a value set.
//
// Types that are valid to be assigned to Value:
//
// *Value_NullValue
// *Value_BoolValue
// *Value_IntegerValue
// *Value_UnsignedIntegerValue
// *Value_DoubleValue
// *Value_AnyValue
// *Value_ValueTime
// *Value_DurationValue
// *Value_StringValue
// *Value_BytesValue
// *Value_GeoPointValue
// *Value_ArrayValue
// *Value_MapValue
Value isValue_Value `protobuf_oneof:"value"`
// contains filtered or unexported fields
}
A message that can hold any of the supported value types.
func (*Value) GetArrayValue ¶
func (x *Value) GetArrayValue() *ArrayValue
func (*Value) GetDurationValue ¶
func (x *Value) GetDurationValue() *durationpb.Duration
func (*Value) GetValueTime ¶
func (x *Value) GetValueTime() *timestamppb.Timestamp
func (*Value) ProtoReflect ¶
func (x *Value) ProtoReflect() protoreflect.Message
func (*Value) SetArrayValue ¶
func (x *Value) SetArrayValue(v *ArrayValue)
func (*Value) SetDurationValue ¶
func (x *Value) SetDurationValue(v *durationpb.Duration)
func (*Value) SetValueTime ¶
func (x *Value) SetValueTime(v *timestamppb.Timestamp)
type Value_AnyValue ¶
type Value_ArrayValue ¶
type Value_ArrayValue struct {
// An array value.
ArrayValue *ArrayValue `protobuf:"bytes,10,opt,name=array_value,json=arrayValue,proto3,oneof"`
}
type Value_BoolValue ¶
type Value_BoolValue struct {
// A boolean value.
BoolValue bool `protobuf:"varint,2,opt,name=bool_value,json=boolValue,proto3,oneof"`
}
type Value_BytesValue ¶
type Value_BytesValue struct {
// A bytes value.
BytesValue []byte `protobuf:"bytes,8,opt,name=bytes_value,json=bytesValue,proto3,oneof"`
}
type Value_DoubleValue ¶
type Value_DoubleValue struct {
// A double value.
DoubleValue float64 `protobuf:"fixed64,4,opt,name=double_value,json=doubleValue,proto3,oneof"`
}
type Value_DurationValue ¶
type Value_DurationValue struct {
// A duration value.
DurationValue *durationpb.Duration `protobuf:"bytes,12,opt,name=duration_value,json=durationValue,proto3,oneof"`
}
type Value_GeoPointValue ¶
type Value_IntegerValue ¶
type Value_IntegerValue struct {
// An integer value.
IntegerValue int64 `protobuf:"varint,3,opt,name=integer_value,json=integerValue,proto3,oneof"`
}
type Value_MapValue ¶
type Value_MapValue struct {
// A map value.
MapValue *MapValue `protobuf:"bytes,11,opt,name=map_value,json=mapValue,proto3,oneof"`
}
type Value_NullValue ¶
type Value_StringValue ¶
type Value_StringValue struct {
// A string value.
StringValue string `protobuf:"bytes,7,opt,name=string_value,json=stringValue,proto3,oneof"`
}
type Value_UnsignedIntegerValue ¶
type Value_UnsignedIntegerValue struct {
// An integer value.
UnsignedIntegerValue uint64 `protobuf:"varint,14,opt,name=unsigned_integer_value,json=unsignedIntegerValue,proto3,oneof"`
}
type Value_ValueTime ¶
type Value_ValueTime struct {
// A timestamp value.
ValueTime *timestamppb.Timestamp `protobuf:"bytes,6,opt,name=value_time,json=valueTime,proto3,oneof"`
}
type Value_builder ¶
type Value_builder struct {
// Fields of oneof Value:
// A null value.
NullValue *structpb.NullValue
// A boolean value.
BoolValue *bool
// An integer value.
IntegerValue *int64
// An integer value.
UnsignedIntegerValue *uint64
// A double value.
DoubleValue *float64
// An Any value.
AnyValue *anypb.Any
// A timestamp value.
ValueTime *timestamppb.Timestamp
// A duration value.
DurationValue *durationpb.Duration
// A string value.
StringValue *string
// A bytes value.
BytesValue []byte
// A geo point value representing a point on the surface of Earth.
GeoPointValue *latlng.LatLng
// An array value.
ArrayValue *ArrayValue
// A map value.
MapValue *MapValue
// contains filtered or unexported fields
}
func (Value_builder) Build ¶
func (b0 Value_builder) Build() *Value
Source Files
¶
- struct.pb.go
Click to show internal directories.
Click to hide internal directories.