Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterTCServiceServer(s grpc.ServiceRegistrar, srv TCServiceServer)
- type TCServiceClient
- type TCServiceServer
- type UnimplementedTCServiceServer
- func (UnimplementedTCServiceServer) CheckAsyncShowTranscode(context.Context, *v1.CheckAsyncShowTranscodeRequest) (*v1.CheckAsyncShowTranscodeResponse, error)
- func (UnimplementedTCServiceServer) CheckAsyncSpreadTranscode(context.Context, *v1.CheckAsyncSpreadTranscodeRequest) (*v1.CheckAsyncSpreadTranscodeResponse, error)
- func (UnimplementedTCServiceServer) CheckAsyncTranscode(context.Context, *v1.CheckAsyncTranscodeRequest) (*v1.CheckAsyncTranscodeResponse, error)
- func (UnimplementedTCServiceServer) ListAsyncTranscodes(context.Context, *v1.ListAsyncTranscodesRequest) (*v1.ListAsyncTranscodesResponse, error)
- func (UnimplementedTCServiceServer) StartAsyncShowTranscode(context.Context, *v1.StartAsyncShowTranscodeRequest) (*v1.StartAsyncShowTranscodeResponse, error)
- func (UnimplementedTCServiceServer) StartAsyncSpreadTranscode(context.Context, *v1.StartAsyncSpreadTranscodeRequest) (*v1.StartAsyncSpreadTranscodeResponse, error)
- func (UnimplementedTCServiceServer) StartAsyncTranscode(context.Context, *v1.StartAsyncTranscodeRequest) (*v1.StartAsyncTranscodeResponse, error)
- type UnsafeTCServiceServer
Constants ¶
const ( TCService_StartAsyncTranscode_FullMethodName = "/krelinga.video.tcserver.v1.TCService/StartAsyncTranscode" TCService_CheckAsyncTranscode_FullMethodName = "/krelinga.video.tcserver.v1.TCService/CheckAsyncTranscode" TCService_StartAsyncShowTranscode_FullMethodName = "/krelinga.video.tcserver.v1.TCService/StartAsyncShowTranscode" TCService_CheckAsyncShowTranscode_FullMethodName = "/krelinga.video.tcserver.v1.TCService/CheckAsyncShowTranscode" TCService_StartAsyncSpreadTranscode_FullMethodName = "/krelinga.video.tcserver.v1.TCService/StartAsyncSpreadTranscode" TCService_CheckAsyncSpreadTranscode_FullMethodName = "/krelinga.video.tcserver.v1.TCService/CheckAsyncSpreadTranscode" TCService_ListAsyncTranscodes_FullMethodName = "/krelinga.video.tcserver.v1.TCService/ListAsyncTranscodes" )
Variables ¶
var TCService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "krelinga.video.tcserver.v1.TCService", HandlerType: (*TCServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "StartAsyncTranscode", Handler: _TCService_StartAsyncTranscode_Handler, }, { MethodName: "CheckAsyncTranscode", Handler: _TCService_CheckAsyncTranscode_Handler, }, { MethodName: "StartAsyncShowTranscode", Handler: _TCService_StartAsyncShowTranscode_Handler, }, { MethodName: "CheckAsyncShowTranscode", Handler: _TCService_CheckAsyncShowTranscode_Handler, }, { MethodName: "StartAsyncSpreadTranscode", Handler: _TCService_StartAsyncSpreadTranscode_Handler, }, { MethodName: "CheckAsyncSpreadTranscode", Handler: _TCService_CheckAsyncSpreadTranscode_Handler, }, { MethodName: "ListAsyncTranscodes", Handler: _TCService_ListAsyncTranscodes_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "krelinga/video/tcserver/v1/tcserver.proto", }
TCService_ServiceDesc is the grpc.ServiceDesc for TCService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterTCServiceServer ¶
func RegisterTCServiceServer(s grpc.ServiceRegistrar, srv TCServiceServer)
Types ¶
type TCServiceClient ¶
type TCServiceClient interface {
StartAsyncTranscode(ctx context.Context, in *v1.StartAsyncTranscodeRequest, opts ...grpc.CallOption) (*v1.StartAsyncTranscodeResponse, error)
CheckAsyncTranscode(ctx context.Context, in *v1.CheckAsyncTranscodeRequest, opts ...grpc.CallOption) (*v1.CheckAsyncTranscodeResponse, error)
StartAsyncShowTranscode(ctx context.Context, in *v1.StartAsyncShowTranscodeRequest, opts ...grpc.CallOption) (*v1.StartAsyncShowTranscodeResponse, error)
CheckAsyncShowTranscode(ctx context.Context, in *v1.CheckAsyncShowTranscodeRequest, opts ...grpc.CallOption) (*v1.CheckAsyncShowTranscodeResponse, error)
StartAsyncSpreadTranscode(ctx context.Context, in *v1.StartAsyncSpreadTranscodeRequest, opts ...grpc.CallOption) (*v1.StartAsyncSpreadTranscodeResponse, error)
CheckAsyncSpreadTranscode(ctx context.Context, in *v1.CheckAsyncSpreadTranscodeRequest, opts ...grpc.CallOption) (*v1.CheckAsyncSpreadTranscodeResponse, error)
ListAsyncTranscodes(ctx context.Context, in *v1.ListAsyncTranscodesRequest, opts ...grpc.CallOption) (*v1.ListAsyncTranscodesResponse, error)
}
TCServiceClient is the client API for TCService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewTCServiceClient ¶
func NewTCServiceClient(cc grpc.ClientConnInterface) TCServiceClient
type TCServiceServer ¶
type TCServiceServer interface {
StartAsyncTranscode(context.Context, *v1.StartAsyncTranscodeRequest) (*v1.StartAsyncTranscodeResponse, error)
CheckAsyncTranscode(context.Context, *v1.CheckAsyncTranscodeRequest) (*v1.CheckAsyncTranscodeResponse, error)
StartAsyncShowTranscode(context.Context, *v1.StartAsyncShowTranscodeRequest) (*v1.StartAsyncShowTranscodeResponse, error)
CheckAsyncShowTranscode(context.Context, *v1.CheckAsyncShowTranscodeRequest) (*v1.CheckAsyncShowTranscodeResponse, error)
StartAsyncSpreadTranscode(context.Context, *v1.StartAsyncSpreadTranscodeRequest) (*v1.StartAsyncSpreadTranscodeResponse, error)
CheckAsyncSpreadTranscode(context.Context, *v1.CheckAsyncSpreadTranscodeRequest) (*v1.CheckAsyncSpreadTranscodeResponse, error)
ListAsyncTranscodes(context.Context, *v1.ListAsyncTranscodesRequest) (*v1.ListAsyncTranscodesResponse, error)
}
TCServiceServer is the server API for TCService service. All implementations should embed UnimplementedTCServiceServer for forward compatibility.
type UnimplementedTCServiceServer ¶
type UnimplementedTCServiceServer struct{}
UnimplementedTCServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedTCServiceServer) CheckAsyncShowTranscode ¶
func (UnimplementedTCServiceServer) CheckAsyncShowTranscode(context.Context, *v1.CheckAsyncShowTranscodeRequest) (*v1.CheckAsyncShowTranscodeResponse, error)
func (UnimplementedTCServiceServer) CheckAsyncSpreadTranscode ¶
func (UnimplementedTCServiceServer) CheckAsyncSpreadTranscode(context.Context, *v1.CheckAsyncSpreadTranscodeRequest) (*v1.CheckAsyncSpreadTranscodeResponse, error)
func (UnimplementedTCServiceServer) CheckAsyncTranscode ¶
func (UnimplementedTCServiceServer) CheckAsyncTranscode(context.Context, *v1.CheckAsyncTranscodeRequest) (*v1.CheckAsyncTranscodeResponse, error)
func (UnimplementedTCServiceServer) ListAsyncTranscodes ¶
func (UnimplementedTCServiceServer) ListAsyncTranscodes(context.Context, *v1.ListAsyncTranscodesRequest) (*v1.ListAsyncTranscodesResponse, error)
func (UnimplementedTCServiceServer) StartAsyncShowTranscode ¶
func (UnimplementedTCServiceServer) StartAsyncShowTranscode(context.Context, *v1.StartAsyncShowTranscodeRequest) (*v1.StartAsyncShowTranscodeResponse, error)
func (UnimplementedTCServiceServer) StartAsyncSpreadTranscode ¶
func (UnimplementedTCServiceServer) StartAsyncSpreadTranscode(context.Context, *v1.StartAsyncSpreadTranscodeRequest) (*v1.StartAsyncSpreadTranscodeResponse, error)
func (UnimplementedTCServiceServer) StartAsyncTranscode ¶
func (UnimplementedTCServiceServer) StartAsyncTranscode(context.Context, *v1.StartAsyncTranscodeRequest) (*v1.StartAsyncTranscodeResponse, error)
type UnsafeTCServiceServer ¶
type UnsafeTCServiceServer interface {
// contains filtered or unexported methods
}
UnsafeTCServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to TCServiceServer will result in compilation errors.
Source Files
¶
- tcserver_grpc.pb.go