Documentation
¶
Index ¶
- Variables
- type Chapters
- func (x *Chapters) ClearSimple()
- func (x *Chapters) GetFormat() ChaptersFormat
- func (x *Chapters) GetSimple() *SimpleChapters
- func (x *Chapters) HasSimple() bool
- func (*Chapters) ProtoMessage()
- func (x *Chapters) ProtoReflect() protoreflect.Message
- func (x *Chapters) Reset()
- func (x *Chapters) SetFormat(v ChaptersFormat)
- func (x *Chapters) SetSimple(v *SimpleChapters)
- func (x *Chapters) String() string
- type ChaptersFormat
- type Chapters_builder
- type ConcatRequest
- func (x *ConcatRequest) GetInputPaths() []string
- func (x *ConcatRequest) GetOutputPath() string
- func (*ConcatRequest) ProtoMessage()
- func (x *ConcatRequest) ProtoReflect() protoreflect.Message
- func (x *ConcatRequest) Reset()
- func (x *ConcatRequest) SetInputPaths(v []string)
- func (x *ConcatRequest) SetOutputPath(v string)
- func (x *ConcatRequest) String() string
- type ConcatRequest_builder
- type ConcatResponse
- type ConcatResponse_builder
- type GetChaptersRequest
- func (x *GetChaptersRequest) GetFormat() ChaptersFormat
- func (x *GetChaptersRequest) GetInPath() string
- func (*GetChaptersRequest) ProtoMessage()
- func (x *GetChaptersRequest) ProtoReflect() protoreflect.Message
- func (x *GetChaptersRequest) Reset()
- func (x *GetChaptersRequest) SetFormat(v ChaptersFormat)
- func (x *GetChaptersRequest) SetInPath(v string)
- func (x *GetChaptersRequest) String() string
- type GetChaptersRequest_builder
- type GetChaptersResponse
- func (x *GetChaptersResponse) ClearChapters()
- func (x *GetChaptersResponse) GetChapters() *Chapters
- func (x *GetChaptersResponse) HasChapters() bool
- func (*GetChaptersResponse) ProtoMessage()
- func (x *GetChaptersResponse) ProtoReflect() protoreflect.Message
- func (x *GetChaptersResponse) Reset()
- func (x *GetChaptersResponse) SetChapters(v *Chapters)
- func (x *GetChaptersResponse) String() string
- type GetChaptersResponse_builder
- type GetFileSizeRequest
- type GetFileSizeRequest_builder
- type GetFileSizeResponse
- type GetFileSizeResponse_builder
- type GetInfoRequest
- type GetInfoRequest_builder
- type GetInfoResponse
- func (x *GetInfoResponse) ClearInfo()
- func (x *GetInfoResponse) GetInfo() *Info
- func (x *GetInfoResponse) HasInfo() bool
- func (*GetInfoResponse) ProtoMessage()
- func (x *GetInfoResponse) ProtoReflect() protoreflect.Message
- func (x *GetInfoResponse) Reset()
- func (x *GetInfoResponse) SetInfo(v *Info)
- func (x *GetInfoResponse) String() string
- type GetInfoResponse_builder
- type Info
- type Info_builder
- type RunMkvToolNixCommandRequest
- func (x *RunMkvToolNixCommandRequest) GetArgs() []string
- func (x *RunMkvToolNixCommandRequest) GetCommand() RunMkvToolNixCommandRequest_Command
- func (*RunMkvToolNixCommandRequest) ProtoMessage()
- func (x *RunMkvToolNixCommandRequest) ProtoReflect() protoreflect.Message
- func (x *RunMkvToolNixCommandRequest) Reset()
- func (x *RunMkvToolNixCommandRequest) SetArgs(v []string)
- func (x *RunMkvToolNixCommandRequest) SetCommand(v RunMkvToolNixCommandRequest_Command)
- func (x *RunMkvToolNixCommandRequest) String() string
- type RunMkvToolNixCommandRequest_Command
- func (RunMkvToolNixCommandRequest_Command) Descriptor() protoreflect.EnumDescriptor
- func (x RunMkvToolNixCommandRequest_Command) Enum() *RunMkvToolNixCommandRequest_Command
- func (x RunMkvToolNixCommandRequest_Command) Number() protoreflect.EnumNumber
- func (x RunMkvToolNixCommandRequest_Command) String() string
- func (RunMkvToolNixCommandRequest_Command) Type() protoreflect.EnumType
- type RunMkvToolNixCommandRequest_builder
- type RunMkvToolNixCommandResponse
- func (x *RunMkvToolNixCommandResponse) GetExitCode() int32
- func (x *RunMkvToolNixCommandResponse) GetStderr() string
- func (x *RunMkvToolNixCommandResponse) GetStdout() string
- func (*RunMkvToolNixCommandResponse) ProtoMessage()
- func (x *RunMkvToolNixCommandResponse) ProtoReflect() protoreflect.Message
- func (x *RunMkvToolNixCommandResponse) Reset()
- func (x *RunMkvToolNixCommandResponse) SetExitCode(v int32)
- func (x *RunMkvToolNixCommandResponse) SetStderr(v string)
- func (x *RunMkvToolNixCommandResponse) SetStdout(v string)
- func (x *RunMkvToolNixCommandResponse) String() string
- type RunMkvToolNixCommandResponse_builder
- type SimpleChapters
- func (x *SimpleChapters) GetChapters() []*SimpleChapters_Chapter
- func (*SimpleChapters) ProtoMessage()
- func (x *SimpleChapters) ProtoReflect() protoreflect.Message
- func (x *SimpleChapters) Reset()
- func (x *SimpleChapters) SetChapters(v []*SimpleChapters_Chapter)
- func (x *SimpleChapters) String() string
- type SimpleChapters_Chapter
- func (x *SimpleChapters_Chapter) ClearDuration()
- func (x *SimpleChapters_Chapter) ClearOffset()
- func (x *SimpleChapters_Chapter) GetDuration() *durationpb.Duration
- func (x *SimpleChapters_Chapter) GetName() string
- func (x *SimpleChapters_Chapter) GetNumber() int32
- func (x *SimpleChapters_Chapter) GetOffset() *durationpb.Duration
- func (x *SimpleChapters_Chapter) HasDuration() bool
- func (x *SimpleChapters_Chapter) HasOffset() bool
- func (*SimpleChapters_Chapter) ProtoMessage()
- func (x *SimpleChapters_Chapter) ProtoReflect() protoreflect.Message
- func (x *SimpleChapters_Chapter) Reset()
- func (x *SimpleChapters_Chapter) SetDuration(v *durationpb.Duration)
- func (x *SimpleChapters_Chapter) SetName(v string)
- func (x *SimpleChapters_Chapter) SetNumber(v int32)
- func (x *SimpleChapters_Chapter) SetOffset(v *durationpb.Duration)
- func (x *SimpleChapters_Chapter) String() string
- type SimpleChapters_Chapter_builder
- type SimpleChapters_builder
- type SplitRequest
- func (x *SplitRequest) GetByChapters() []*SplitRequest_ByChapters
- func (x *SplitRequest) GetInPath() string
- func (*SplitRequest) ProtoMessage()
- func (x *SplitRequest) ProtoReflect() protoreflect.Message
- func (x *SplitRequest) Reset()
- func (x *SplitRequest) SetByChapters(v []*SplitRequest_ByChapters)
- func (x *SplitRequest) SetInPath(v string)
- func (x *SplitRequest) String() string
- type SplitRequest_ByChapters
- func (x *SplitRequest_ByChapters) GetLimit() int32
- func (x *SplitRequest_ByChapters) GetOutPath() string
- func (x *SplitRequest_ByChapters) GetStart() int32
- func (*SplitRequest_ByChapters) ProtoMessage()
- func (x *SplitRequest_ByChapters) ProtoReflect() protoreflect.Message
- func (x *SplitRequest_ByChapters) Reset()
- func (x *SplitRequest_ByChapters) SetLimit(v int32)
- func (x *SplitRequest_ByChapters) SetOutPath(v string)
- func (x *SplitRequest_ByChapters) SetStart(v int32)
- func (x *SplitRequest_ByChapters) String() string
- type SplitRequest_ByChapters_builder
- type SplitRequest_builder
- type SplitResponse
- type SplitResponse_builder
Constants ¶
This section is empty.
Variables ¶
var ( ChaptersFormat_name = map[int32]string{ 0: "CHAPTERS_FORMAT_UNKNOWN", 1: "CHAPTERS_FORMAT_SIMPLE", 2: "CHAPTERS_FORMAT_XML", } ChaptersFormat_value = map[string]int32{ "CHAPTERS_FORMAT_UNKNOWN": 0, "CHAPTERS_FORMAT_SIMPLE": 1, "CHAPTERS_FORMAT_XML": 2, } )
Enum value maps for ChaptersFormat.
var ( RunMkvToolNixCommandRequest_Command_name = map[int32]string{ 0: "COMMAND_UNKNOWN", 1: "COMMAND_MKVINFO", } RunMkvToolNixCommandRequest_Command_value = map[string]int32{ "COMMAND_UNKNOWN": 0, "COMMAND_MKVINFO": 1, } )
Enum value maps for RunMkvToolNixCommandRequest_Command.
var File_krelinga_video_mkv_util_server_v1_mkv_util_server_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Chapters ¶
type Chapters struct {
Format ChaptersFormat `protobuf:"varint,1,opt,name=format,proto3,enum=krelinga.video.mkv_util_server.v1.ChaptersFormat" json:"format,omitempty"`
Simple *SimpleChapters `protobuf:"bytes,2,opt,name=simple,proto3" json:"simple,omitempty"`
// contains filtered or unexported fields
}
func (*Chapters) GetFormat ¶
func (x *Chapters) GetFormat() ChaptersFormat
func (*Chapters) GetSimple ¶
func (x *Chapters) GetSimple() *SimpleChapters
func (*Chapters) ProtoReflect ¶
func (x *Chapters) ProtoReflect() protoreflect.Message
func (*Chapters) SetFormat ¶
func (x *Chapters) SetFormat(v ChaptersFormat)
func (*Chapters) SetSimple ¶
func (x *Chapters) SetSimple(v *SimpleChapters)
type ChaptersFormat ¶
type ChaptersFormat int32
const ( ChaptersFormat_CHAPTERS_FORMAT_UNKNOWN ChaptersFormat = 0 ChaptersFormat_CHAPTERS_FORMAT_SIMPLE ChaptersFormat = 1 ChaptersFormat_CHAPTERS_FORMAT_XML ChaptersFormat = 2 )
func (ChaptersFormat) Descriptor ¶
func (ChaptersFormat) Descriptor() protoreflect.EnumDescriptor
func (ChaptersFormat) Enum ¶
func (x ChaptersFormat) Enum() *ChaptersFormat
func (ChaptersFormat) Number ¶
func (x ChaptersFormat) Number() protoreflect.EnumNumber
func (ChaptersFormat) String ¶
func (x ChaptersFormat) String() string
func (ChaptersFormat) Type ¶
func (ChaptersFormat) Type() protoreflect.EnumType
type Chapters_builder ¶
type Chapters_builder struct {
Format ChaptersFormat
Simple *SimpleChapters
// contains filtered or unexported fields
}
func (Chapters_builder) Build ¶
func (b0 Chapters_builder) Build() *Chapters
type ConcatRequest ¶
type ConcatRequest struct {
InputPaths []string `protobuf:"bytes,1,rep,name=input_paths,json=inputPaths,proto3" json:"input_paths,omitempty"`
OutputPath string `protobuf:"bytes,2,opt,name=output_path,json=outputPath,proto3" json:"output_path,omitempty"`
// contains filtered or unexported fields
}
func (*ConcatRequest) GetInputPaths ¶
func (x *ConcatRequest) GetInputPaths() []string
func (*ConcatRequest) GetOutputPath ¶
func (x *ConcatRequest) GetOutputPath() string
func (*ConcatRequest) ProtoMessage ¶
func (*ConcatRequest) ProtoMessage()
func (*ConcatRequest) ProtoReflect ¶
func (x *ConcatRequest) ProtoReflect() protoreflect.Message
func (*ConcatRequest) Reset ¶
func (x *ConcatRequest) Reset()
func (*ConcatRequest) SetInputPaths ¶
func (x *ConcatRequest) SetInputPaths(v []string)
func (*ConcatRequest) SetOutputPath ¶
func (x *ConcatRequest) SetOutputPath(v string)
func (*ConcatRequest) String ¶
func (x *ConcatRequest) String() string
type ConcatRequest_builder ¶
type ConcatRequest_builder struct {
InputPaths []string
OutputPath string
// contains filtered or unexported fields
}
func (ConcatRequest_builder) Build ¶
func (b0 ConcatRequest_builder) Build() *ConcatRequest
type ConcatResponse ¶
type ConcatResponse struct {
// contains filtered or unexported fields
}
func (*ConcatResponse) ProtoMessage ¶
func (*ConcatResponse) ProtoMessage()
func (*ConcatResponse) ProtoReflect ¶
func (x *ConcatResponse) ProtoReflect() protoreflect.Message
func (*ConcatResponse) Reset ¶
func (x *ConcatResponse) Reset()
func (*ConcatResponse) String ¶
func (x *ConcatResponse) String() string
type ConcatResponse_builder ¶
type ConcatResponse_builder struct {
// contains filtered or unexported fields
}
func (ConcatResponse_builder) Build ¶
func (b0 ConcatResponse_builder) Build() *ConcatResponse
type GetChaptersRequest ¶
type GetChaptersRequest struct {
InPath string `protobuf:"bytes,1,opt,name=in_path,json=inPath,proto3" json:"in_path,omitempty"`
Format ChaptersFormat `protobuf:"varint,2,opt,name=format,proto3,enum=krelinga.video.mkv_util_server.v1.ChaptersFormat" json:"format,omitempty"`
// contains filtered or unexported fields
}
func (*GetChaptersRequest) GetFormat ¶
func (x *GetChaptersRequest) GetFormat() ChaptersFormat
func (*GetChaptersRequest) GetInPath ¶
func (x *GetChaptersRequest) GetInPath() string
func (*GetChaptersRequest) ProtoMessage ¶
func (*GetChaptersRequest) ProtoMessage()
func (*GetChaptersRequest) ProtoReflect ¶
func (x *GetChaptersRequest) ProtoReflect() protoreflect.Message
func (*GetChaptersRequest) Reset ¶
func (x *GetChaptersRequest) Reset()
func (*GetChaptersRequest) SetFormat ¶
func (x *GetChaptersRequest) SetFormat(v ChaptersFormat)
func (*GetChaptersRequest) SetInPath ¶
func (x *GetChaptersRequest) SetInPath(v string)
func (*GetChaptersRequest) String ¶
func (x *GetChaptersRequest) String() string
type GetChaptersRequest_builder ¶
type GetChaptersRequest_builder struct {
InPath string
Format ChaptersFormat
// contains filtered or unexported fields
}
func (GetChaptersRequest_builder) Build ¶
func (b0 GetChaptersRequest_builder) Build() *GetChaptersRequest
type GetChaptersResponse ¶
type GetChaptersResponse struct {
Chapters *Chapters `protobuf:"bytes,1,opt,name=chapters,proto3" json:"chapters,omitempty"`
// contains filtered or unexported fields
}
func (*GetChaptersResponse) ClearChapters ¶
func (x *GetChaptersResponse) ClearChapters()
func (*GetChaptersResponse) GetChapters ¶
func (x *GetChaptersResponse) GetChapters() *Chapters
func (*GetChaptersResponse) HasChapters ¶
func (x *GetChaptersResponse) HasChapters() bool
func (*GetChaptersResponse) ProtoMessage ¶
func (*GetChaptersResponse) ProtoMessage()
func (*GetChaptersResponse) ProtoReflect ¶
func (x *GetChaptersResponse) ProtoReflect() protoreflect.Message
func (*GetChaptersResponse) Reset ¶
func (x *GetChaptersResponse) Reset()
func (*GetChaptersResponse) SetChapters ¶
func (x *GetChaptersResponse) SetChapters(v *Chapters)
func (*GetChaptersResponse) String ¶
func (x *GetChaptersResponse) String() string
type GetChaptersResponse_builder ¶
type GetChaptersResponse_builder struct {
Chapters *Chapters
// contains filtered or unexported fields
}
func (GetChaptersResponse_builder) Build ¶
func (b0 GetChaptersResponse_builder) Build() *GetChaptersResponse
type GetFileSizeRequest ¶
type GetFileSizeRequest struct {
Path string `protobuf:"bytes,1,opt,name=path,proto3" json:"path,omitempty"`
// contains filtered or unexported fields
}
func (*GetFileSizeRequest) GetPath ¶
func (x *GetFileSizeRequest) GetPath() string
func (*GetFileSizeRequest) ProtoMessage ¶
func (*GetFileSizeRequest) ProtoMessage()
func (*GetFileSizeRequest) ProtoReflect ¶
func (x *GetFileSizeRequest) ProtoReflect() protoreflect.Message
func (*GetFileSizeRequest) Reset ¶
func (x *GetFileSizeRequest) Reset()
func (*GetFileSizeRequest) SetPath ¶
func (x *GetFileSizeRequest) SetPath(v string)
func (*GetFileSizeRequest) String ¶
func (x *GetFileSizeRequest) String() string
type GetFileSizeRequest_builder ¶
type GetFileSizeRequest_builder struct {
Path string
// contains filtered or unexported fields
}
func (GetFileSizeRequest_builder) Build ¶
func (b0 GetFileSizeRequest_builder) Build() *GetFileSizeRequest
type GetFileSizeResponse ¶
type GetFileSizeResponse struct {
Size int64 `protobuf:"varint,1,opt,name=size,proto3" json:"size,omitempty"`
// contains filtered or unexported fields
}
func (*GetFileSizeResponse) GetSize ¶
func (x *GetFileSizeResponse) GetSize() int64
func (*GetFileSizeResponse) ProtoMessage ¶
func (*GetFileSizeResponse) ProtoMessage()
func (*GetFileSizeResponse) ProtoReflect ¶
func (x *GetFileSizeResponse) ProtoReflect() protoreflect.Message
func (*GetFileSizeResponse) Reset ¶
func (x *GetFileSizeResponse) Reset()
func (*GetFileSizeResponse) SetSize ¶
func (x *GetFileSizeResponse) SetSize(v int64)
func (*GetFileSizeResponse) String ¶
func (x *GetFileSizeResponse) String() string
type GetFileSizeResponse_builder ¶
type GetFileSizeResponse_builder struct {
Size int64
// contains filtered or unexported fields
}
func (GetFileSizeResponse_builder) Build ¶
func (b0 GetFileSizeResponse_builder) Build() *GetFileSizeResponse
type GetInfoRequest ¶
type GetInfoRequest struct {
InPath string `protobuf:"bytes,1,opt,name=in_path,json=inPath,proto3" json:"in_path,omitempty"`
// contains filtered or unexported fields
}
func (*GetInfoRequest) GetInPath ¶
func (x *GetInfoRequest) GetInPath() string
func (*GetInfoRequest) ProtoMessage ¶
func (*GetInfoRequest) ProtoMessage()
func (*GetInfoRequest) ProtoReflect ¶
func (x *GetInfoRequest) ProtoReflect() protoreflect.Message
func (*GetInfoRequest) Reset ¶
func (x *GetInfoRequest) Reset()
func (*GetInfoRequest) SetInPath ¶
func (x *GetInfoRequest) SetInPath(v string)
func (*GetInfoRequest) String ¶
func (x *GetInfoRequest) String() string
type GetInfoRequest_builder ¶
type GetInfoRequest_builder struct {
InPath string
// contains filtered or unexported fields
}
func (GetInfoRequest_builder) Build ¶
func (b0 GetInfoRequest_builder) Build() *GetInfoRequest
type GetInfoResponse ¶
type GetInfoResponse struct {
Info *Info `protobuf:"bytes,1,opt,name=info,proto3" json:"info,omitempty"`
// contains filtered or unexported fields
}
func (*GetInfoResponse) ClearInfo ¶
func (x *GetInfoResponse) ClearInfo()
func (*GetInfoResponse) GetInfo ¶
func (x *GetInfoResponse) GetInfo() *Info
func (*GetInfoResponse) HasInfo ¶
func (x *GetInfoResponse) HasInfo() bool
func (*GetInfoResponse) ProtoMessage ¶
func (*GetInfoResponse) ProtoMessage()
func (*GetInfoResponse) ProtoReflect ¶
func (x *GetInfoResponse) ProtoReflect() protoreflect.Message
func (*GetInfoResponse) Reset ¶
func (x *GetInfoResponse) Reset()
func (*GetInfoResponse) SetInfo ¶
func (x *GetInfoResponse) SetInfo(v *Info)
func (*GetInfoResponse) String ¶
func (x *GetInfoResponse) String() string
type GetInfoResponse_builder ¶
type GetInfoResponse_builder struct {
Info *Info
// contains filtered or unexported fields
}
func (GetInfoResponse_builder) Build ¶
func (b0 GetInfoResponse_builder) Build() *GetInfoResponse
type Info ¶
type Info struct {
Duration *durationpb.Duration `protobuf:"bytes,1,opt,name=duration,proto3" json:"duration,omitempty"`
// contains filtered or unexported fields
}
func (*Info) GetDuration ¶
func (x *Info) GetDuration() *durationpb.Duration
func (*Info) ProtoReflect ¶
func (x *Info) ProtoReflect() protoreflect.Message
func (*Info) SetDuration ¶
func (x *Info) SetDuration(v *durationpb.Duration)
type Info_builder ¶
type Info_builder struct {
Duration *durationpb.Duration
// contains filtered or unexported fields
}
func (Info_builder) Build ¶
func (b0 Info_builder) Build() *Info
type RunMkvToolNixCommandRequest ¶
type RunMkvToolNixCommandRequest struct {
Command RunMkvToolNixCommandRequest_Command `` /* 143-byte string literal not displayed */
Args []string `protobuf:"bytes,2,rep,name=args,proto3" json:"args,omitempty"`
// contains filtered or unexported fields
}
func (*RunMkvToolNixCommandRequest) GetArgs ¶
func (x *RunMkvToolNixCommandRequest) GetArgs() []string
func (*RunMkvToolNixCommandRequest) GetCommand ¶
func (x *RunMkvToolNixCommandRequest) GetCommand() RunMkvToolNixCommandRequest_Command
func (*RunMkvToolNixCommandRequest) ProtoMessage ¶
func (*RunMkvToolNixCommandRequest) ProtoMessage()
func (*RunMkvToolNixCommandRequest) ProtoReflect ¶
func (x *RunMkvToolNixCommandRequest) ProtoReflect() protoreflect.Message
func (*RunMkvToolNixCommandRequest) Reset ¶
func (x *RunMkvToolNixCommandRequest) Reset()
func (*RunMkvToolNixCommandRequest) SetArgs ¶
func (x *RunMkvToolNixCommandRequest) SetArgs(v []string)
func (*RunMkvToolNixCommandRequest) SetCommand ¶
func (x *RunMkvToolNixCommandRequest) SetCommand(v RunMkvToolNixCommandRequest_Command)
func (*RunMkvToolNixCommandRequest) String ¶
func (x *RunMkvToolNixCommandRequest) String() string
type RunMkvToolNixCommandRequest_Command ¶
type RunMkvToolNixCommandRequest_Command int32
const ( RunMkvToolNixCommandRequest_COMMAND_UNKNOWN RunMkvToolNixCommandRequest_Command = 0 RunMkvToolNixCommandRequest_COMMAND_MKVINFO RunMkvToolNixCommandRequest_Command = 1 )
func (RunMkvToolNixCommandRequest_Command) Descriptor ¶
func (RunMkvToolNixCommandRequest_Command) Descriptor() protoreflect.EnumDescriptor
func (RunMkvToolNixCommandRequest_Command) Enum ¶
func (x RunMkvToolNixCommandRequest_Command) Enum() *RunMkvToolNixCommandRequest_Command
func (RunMkvToolNixCommandRequest_Command) Number ¶
func (x RunMkvToolNixCommandRequest_Command) Number() protoreflect.EnumNumber
func (RunMkvToolNixCommandRequest_Command) String ¶
func (x RunMkvToolNixCommandRequest_Command) String() string
func (RunMkvToolNixCommandRequest_Command) Type ¶
func (RunMkvToolNixCommandRequest_Command) Type() protoreflect.EnumType
type RunMkvToolNixCommandRequest_builder ¶
type RunMkvToolNixCommandRequest_builder struct {
Command RunMkvToolNixCommandRequest_Command
Args []string
// contains filtered or unexported fields
}
func (RunMkvToolNixCommandRequest_builder) Build ¶
func (b0 RunMkvToolNixCommandRequest_builder) Build() *RunMkvToolNixCommandRequest
type RunMkvToolNixCommandResponse ¶
type RunMkvToolNixCommandResponse struct {
ExitCode int32 `protobuf:"varint,1,opt,name=exit_code,json=exitCode,proto3" json:"exit_code,omitempty"`
Stdout string `protobuf:"bytes,2,opt,name=stdout,proto3" json:"stdout,omitempty"`
Stderr string `protobuf:"bytes,3,opt,name=stderr,proto3" json:"stderr,omitempty"`
// contains filtered or unexported fields
}
func (*RunMkvToolNixCommandResponse) GetExitCode ¶
func (x *RunMkvToolNixCommandResponse) GetExitCode() int32
func (*RunMkvToolNixCommandResponse) GetStderr ¶
func (x *RunMkvToolNixCommandResponse) GetStderr() string
func (*RunMkvToolNixCommandResponse) GetStdout ¶
func (x *RunMkvToolNixCommandResponse) GetStdout() string
func (*RunMkvToolNixCommandResponse) ProtoMessage ¶
func (*RunMkvToolNixCommandResponse) ProtoMessage()
func (*RunMkvToolNixCommandResponse) ProtoReflect ¶
func (x *RunMkvToolNixCommandResponse) ProtoReflect() protoreflect.Message
func (*RunMkvToolNixCommandResponse) Reset ¶
func (x *RunMkvToolNixCommandResponse) Reset()
func (*RunMkvToolNixCommandResponse) SetExitCode ¶
func (x *RunMkvToolNixCommandResponse) SetExitCode(v int32)
func (*RunMkvToolNixCommandResponse) SetStderr ¶
func (x *RunMkvToolNixCommandResponse) SetStderr(v string)
func (*RunMkvToolNixCommandResponse) SetStdout ¶
func (x *RunMkvToolNixCommandResponse) SetStdout(v string)
func (*RunMkvToolNixCommandResponse) String ¶
func (x *RunMkvToolNixCommandResponse) String() string
type RunMkvToolNixCommandResponse_builder ¶
type RunMkvToolNixCommandResponse_builder struct {
ExitCode int32
Stdout string
Stderr string
// contains filtered or unexported fields
}
func (RunMkvToolNixCommandResponse_builder) Build ¶
func (b0 RunMkvToolNixCommandResponse_builder) Build() *RunMkvToolNixCommandResponse
type SimpleChapters ¶
type SimpleChapters struct {
Chapters []*SimpleChapters_Chapter `protobuf:"bytes,1,rep,name=chapters,proto3" json:"chapters,omitempty"`
// contains filtered or unexported fields
}
func (*SimpleChapters) GetChapters ¶
func (x *SimpleChapters) GetChapters() []*SimpleChapters_Chapter
func (*SimpleChapters) ProtoMessage ¶
func (*SimpleChapters) ProtoMessage()
func (*SimpleChapters) ProtoReflect ¶
func (x *SimpleChapters) ProtoReflect() protoreflect.Message
func (*SimpleChapters) Reset ¶
func (x *SimpleChapters) Reset()
func (*SimpleChapters) SetChapters ¶
func (x *SimpleChapters) SetChapters(v []*SimpleChapters_Chapter)
func (*SimpleChapters) String ¶
func (x *SimpleChapters) String() string
type SimpleChapters_Chapter ¶
type SimpleChapters_Chapter struct {
Number int32 `protobuf:"varint,1,opt,name=number,proto3" json:"number,omitempty"`
Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
Offset *durationpb.Duration `protobuf:"bytes,3,opt,name=offset,proto3" json:"offset,omitempty"`
Duration *durationpb.Duration `protobuf:"bytes,4,opt,name=duration,proto3" json:"duration,omitempty"`
// contains filtered or unexported fields
}
func (*SimpleChapters_Chapter) ClearDuration ¶
func (x *SimpleChapters_Chapter) ClearDuration()
func (*SimpleChapters_Chapter) ClearOffset ¶
func (x *SimpleChapters_Chapter) ClearOffset()
func (*SimpleChapters_Chapter) GetDuration ¶
func (x *SimpleChapters_Chapter) GetDuration() *durationpb.Duration
func (*SimpleChapters_Chapter) GetName ¶
func (x *SimpleChapters_Chapter) GetName() string
func (*SimpleChapters_Chapter) GetNumber ¶
func (x *SimpleChapters_Chapter) GetNumber() int32
func (*SimpleChapters_Chapter) GetOffset ¶
func (x *SimpleChapters_Chapter) GetOffset() *durationpb.Duration
func (*SimpleChapters_Chapter) HasDuration ¶
func (x *SimpleChapters_Chapter) HasDuration() bool
func (*SimpleChapters_Chapter) HasOffset ¶
func (x *SimpleChapters_Chapter) HasOffset() bool
func (*SimpleChapters_Chapter) ProtoMessage ¶
func (*SimpleChapters_Chapter) ProtoMessage()
func (*SimpleChapters_Chapter) ProtoReflect ¶
func (x *SimpleChapters_Chapter) ProtoReflect() protoreflect.Message
func (*SimpleChapters_Chapter) Reset ¶
func (x *SimpleChapters_Chapter) Reset()
func (*SimpleChapters_Chapter) SetDuration ¶
func (x *SimpleChapters_Chapter) SetDuration(v *durationpb.Duration)
func (*SimpleChapters_Chapter) SetName ¶
func (x *SimpleChapters_Chapter) SetName(v string)
func (*SimpleChapters_Chapter) SetNumber ¶
func (x *SimpleChapters_Chapter) SetNumber(v int32)
func (*SimpleChapters_Chapter) SetOffset ¶
func (x *SimpleChapters_Chapter) SetOffset(v *durationpb.Duration)
func (*SimpleChapters_Chapter) String ¶
func (x *SimpleChapters_Chapter) String() string
type SimpleChapters_Chapter_builder ¶
type SimpleChapters_Chapter_builder struct {
Number int32
Name string
Offset *durationpb.Duration
Duration *durationpb.Duration
// contains filtered or unexported fields
}
func (SimpleChapters_Chapter_builder) Build ¶
func (b0 SimpleChapters_Chapter_builder) Build() *SimpleChapters_Chapter
type SimpleChapters_builder ¶
type SimpleChapters_builder struct {
Chapters []*SimpleChapters_Chapter
// contains filtered or unexported fields
}
func (SimpleChapters_builder) Build ¶
func (b0 SimpleChapters_builder) Build() *SimpleChapters
type SplitRequest ¶
type SplitRequest struct {
InPath string `protobuf:"bytes,1,opt,name=in_path,json=inPath,proto3" json:"in_path,omitempty"`
ByChapters []*SplitRequest_ByChapters `protobuf:"bytes,2,rep,name=by_chapters,json=byChapters,proto3" json:"by_chapters,omitempty"`
// contains filtered or unexported fields
}
func (*SplitRequest) GetByChapters ¶
func (x *SplitRequest) GetByChapters() []*SplitRequest_ByChapters
func (*SplitRequest) GetInPath ¶
func (x *SplitRequest) GetInPath() string
func (*SplitRequest) ProtoMessage ¶
func (*SplitRequest) ProtoMessage()
func (*SplitRequest) ProtoReflect ¶
func (x *SplitRequest) ProtoReflect() protoreflect.Message
func (*SplitRequest) Reset ¶
func (x *SplitRequest) Reset()
func (*SplitRequest) SetByChapters ¶
func (x *SplitRequest) SetByChapters(v []*SplitRequest_ByChapters)
func (*SplitRequest) SetInPath ¶
func (x *SplitRequest) SetInPath(v string)
func (*SplitRequest) String ¶
func (x *SplitRequest) String() string
type SplitRequest_ByChapters ¶
type SplitRequest_ByChapters struct {
// If not specified, will split from the beginning of the file.
Start int32 `protobuf:"varint,1,opt,name=start,proto3" json:"start,omitempty"`
// If not specified, will split until the end of the file.
Limit int32 `protobuf:"varint,2,opt,name=limit,proto3" json:"limit,omitempty"`
OutPath string `protobuf:"bytes,3,opt,name=out_path,json=outPath,proto3" json:"out_path,omitempty"`
// contains filtered or unexported fields
}
func (*SplitRequest_ByChapters) GetLimit ¶
func (x *SplitRequest_ByChapters) GetLimit() int32
func (*SplitRequest_ByChapters) GetOutPath ¶
func (x *SplitRequest_ByChapters) GetOutPath() string
func (*SplitRequest_ByChapters) GetStart ¶
func (x *SplitRequest_ByChapters) GetStart() int32
func (*SplitRequest_ByChapters) ProtoMessage ¶
func (*SplitRequest_ByChapters) ProtoMessage()
func (*SplitRequest_ByChapters) ProtoReflect ¶
func (x *SplitRequest_ByChapters) ProtoReflect() protoreflect.Message
func (*SplitRequest_ByChapters) Reset ¶
func (x *SplitRequest_ByChapters) Reset()
func (*SplitRequest_ByChapters) SetLimit ¶
func (x *SplitRequest_ByChapters) SetLimit(v int32)
func (*SplitRequest_ByChapters) SetOutPath ¶
func (x *SplitRequest_ByChapters) SetOutPath(v string)
func (*SplitRequest_ByChapters) SetStart ¶
func (x *SplitRequest_ByChapters) SetStart(v int32)
func (*SplitRequest_ByChapters) String ¶
func (x *SplitRequest_ByChapters) String() string
type SplitRequest_ByChapters_builder ¶
type SplitRequest_ByChapters_builder struct {
// If not specified, will split from the beginning of the file.
Start int32
// If not specified, will split until the end of the file.
Limit int32
OutPath string
// contains filtered or unexported fields
}
func (SplitRequest_ByChapters_builder) Build ¶
func (b0 SplitRequest_ByChapters_builder) Build() *SplitRequest_ByChapters
type SplitRequest_builder ¶
type SplitRequest_builder struct {
InPath string
ByChapters []*SplitRequest_ByChapters
// contains filtered or unexported fields
}
func (SplitRequest_builder) Build ¶
func (b0 SplitRequest_builder) Build() *SplitRequest
type SplitResponse ¶
type SplitResponse struct {
// contains filtered or unexported fields
}
func (*SplitResponse) ProtoMessage ¶
func (*SplitResponse) ProtoMessage()
func (*SplitResponse) ProtoReflect ¶
func (x *SplitResponse) ProtoReflect() protoreflect.Message
func (*SplitResponse) Reset ¶
func (x *SplitResponse) Reset()
func (*SplitResponse) String ¶
func (x *SplitResponse) String() string
type SplitResponse_builder ¶
type SplitResponse_builder struct {
// contains filtered or unexported fields
}
func (SplitResponse_builder) Build ¶
func (b0 SplitResponse_builder) Build() *SplitResponse
Source Files
¶
- mkv_util_server.pb.go
Click to show internal directories.
Click to hide internal directories.