Documentation
¶
Index ¶
- Variables
- type CheckAsyncShowTranscodeRequest
- func (x *CheckAsyncShowTranscodeRequest) GetName() string
- func (*CheckAsyncShowTranscodeRequest) ProtoMessage()
- func (x *CheckAsyncShowTranscodeRequest) ProtoReflect() protoreflect.Message
- func (x *CheckAsyncShowTranscodeRequest) Reset()
- func (x *CheckAsyncShowTranscodeRequest) SetName(v string)
- func (x *CheckAsyncShowTranscodeRequest) String() string
- type CheckAsyncShowTranscodeRequest_builder
- type CheckAsyncShowTranscodeResponse
- func (x *CheckAsyncShowTranscodeResponse) GetErrorMessage() string
- func (x *CheckAsyncShowTranscodeResponse) GetFile() []*CheckAsyncShowTranscodeResponse_File
- func (x *CheckAsyncShowTranscodeResponse) GetProfile() string
- func (x *CheckAsyncShowTranscodeResponse) GetState() TranscodeState
- func (*CheckAsyncShowTranscodeResponse) ProtoMessage()
- func (x *CheckAsyncShowTranscodeResponse) ProtoReflect() protoreflect.Message
- func (x *CheckAsyncShowTranscodeResponse) Reset()
- func (x *CheckAsyncShowTranscodeResponse) SetErrorMessage(v string)
- func (x *CheckAsyncShowTranscodeResponse) SetFile(v []*CheckAsyncShowTranscodeResponse_File)
- func (x *CheckAsyncShowTranscodeResponse) SetProfile(v string)
- func (x *CheckAsyncShowTranscodeResponse) SetState(v TranscodeState)
- func (x *CheckAsyncShowTranscodeResponse) String() string
- type CheckAsyncShowTranscodeResponse_File
- func (x *CheckAsyncShowTranscodeResponse_File) GetEpisode() string
- func (x *CheckAsyncShowTranscodeResponse_File) GetErrorMessage() string
- func (x *CheckAsyncShowTranscodeResponse_File) GetProgress() string
- func (x *CheckAsyncShowTranscodeResponse_File) GetState() TranscodeState
- func (*CheckAsyncShowTranscodeResponse_File) ProtoMessage()
- func (x *CheckAsyncShowTranscodeResponse_File) ProtoReflect() protoreflect.Message
- func (x *CheckAsyncShowTranscodeResponse_File) Reset()
- func (x *CheckAsyncShowTranscodeResponse_File) SetEpisode(v string)
- func (x *CheckAsyncShowTranscodeResponse_File) SetErrorMessage(v string)
- func (x *CheckAsyncShowTranscodeResponse_File) SetProgress(v string)
- func (x *CheckAsyncShowTranscodeResponse_File) SetState(v TranscodeState)
- func (x *CheckAsyncShowTranscodeResponse_File) String() string
- type CheckAsyncShowTranscodeResponse_File_builder
- type CheckAsyncShowTranscodeResponse_builder
- type CheckAsyncSpreadTranscodeRequest
- func (x *CheckAsyncSpreadTranscodeRequest) GetName() string
- func (*CheckAsyncSpreadTranscodeRequest) ProtoMessage()
- func (x *CheckAsyncSpreadTranscodeRequest) ProtoReflect() protoreflect.Message
- func (x *CheckAsyncSpreadTranscodeRequest) Reset()
- func (x *CheckAsyncSpreadTranscodeRequest) SetName(v string)
- func (x *CheckAsyncSpreadTranscodeRequest) String() string
- type CheckAsyncSpreadTranscodeRequest_builder
- type CheckAsyncSpreadTranscodeResponse
- func (x *CheckAsyncSpreadTranscodeResponse) GetErrorMessage() string
- func (x *CheckAsyncSpreadTranscodeResponse) GetProfile() []*CheckAsyncSpreadTranscodeResponse_Profile
- func (x *CheckAsyncSpreadTranscodeResponse) GetState() TranscodeState
- func (*CheckAsyncSpreadTranscodeResponse) ProtoMessage()
- func (x *CheckAsyncSpreadTranscodeResponse) ProtoReflect() protoreflect.Message
- func (x *CheckAsyncSpreadTranscodeResponse) Reset()
- func (x *CheckAsyncSpreadTranscodeResponse) SetErrorMessage(v string)
- func (x *CheckAsyncSpreadTranscodeResponse) SetProfile(v []*CheckAsyncSpreadTranscodeResponse_Profile)
- func (x *CheckAsyncSpreadTranscodeResponse) SetState(v TranscodeState)
- func (x *CheckAsyncSpreadTranscodeResponse) String() string
- type CheckAsyncSpreadTranscodeResponse_Profile
- func (x *CheckAsyncSpreadTranscodeResponse_Profile) GetErrorMessage() string
- func (x *CheckAsyncSpreadTranscodeResponse_Profile) GetProfile() string
- func (x *CheckAsyncSpreadTranscodeResponse_Profile) GetProgress() string
- func (x *CheckAsyncSpreadTranscodeResponse_Profile) GetState() TranscodeState
- func (*CheckAsyncSpreadTranscodeResponse_Profile) ProtoMessage()
- func (x *CheckAsyncSpreadTranscodeResponse_Profile) ProtoReflect() protoreflect.Message
- func (x *CheckAsyncSpreadTranscodeResponse_Profile) Reset()
- func (x *CheckAsyncSpreadTranscodeResponse_Profile) SetErrorMessage(v string)
- func (x *CheckAsyncSpreadTranscodeResponse_Profile) SetProfile(v string)
- func (x *CheckAsyncSpreadTranscodeResponse_Profile) SetProgress(v string)
- func (x *CheckAsyncSpreadTranscodeResponse_Profile) SetState(v TranscodeState)
- func (x *CheckAsyncSpreadTranscodeResponse_Profile) String() string
- type CheckAsyncSpreadTranscodeResponse_Profile_builder
- type CheckAsyncSpreadTranscodeResponse_builder
- type CheckAsyncTranscodeRequest
- func (x *CheckAsyncTranscodeRequest) GetName() string
- func (*CheckAsyncTranscodeRequest) ProtoMessage()
- func (x *CheckAsyncTranscodeRequest) ProtoReflect() protoreflect.Message
- func (x *CheckAsyncTranscodeRequest) Reset()
- func (x *CheckAsyncTranscodeRequest) SetName(v string)
- func (x *CheckAsyncTranscodeRequest) String() string
- type CheckAsyncTranscodeRequest_builder
- type CheckAsyncTranscodeResponse
- func (x *CheckAsyncTranscodeResponse) GetErrorMessage() string
- func (x *CheckAsyncTranscodeResponse) GetProfile() string
- func (x *CheckAsyncTranscodeResponse) GetProgress() string
- func (x *CheckAsyncTranscodeResponse) GetState() TranscodeState
- func (*CheckAsyncTranscodeResponse) ProtoMessage()
- func (x *CheckAsyncTranscodeResponse) ProtoReflect() protoreflect.Message
- func (x *CheckAsyncTranscodeResponse) Reset()
- func (x *CheckAsyncTranscodeResponse) SetErrorMessage(v string)
- func (x *CheckAsyncTranscodeResponse) SetProfile(v string)
- func (x *CheckAsyncTranscodeResponse) SetProgress(v string)
- func (x *CheckAsyncTranscodeResponse) SetState(v TranscodeState)
- func (x *CheckAsyncTranscodeResponse) String() string
- type CheckAsyncTranscodeResponse_builder
- type ListAsyncTranscodesRequest
- type ListAsyncTranscodesRequest_builder
- type ListAsyncTranscodesResponse
- func (x *ListAsyncTranscodesResponse) GetOp() []*ListAsyncTranscodesResponse_Op
- func (*ListAsyncTranscodesResponse) ProtoMessage()
- func (x *ListAsyncTranscodesResponse) ProtoReflect() protoreflect.Message
- func (x *ListAsyncTranscodesResponse) Reset()
- func (x *ListAsyncTranscodesResponse) SetOp(v []*ListAsyncTranscodesResponse_Op)
- func (x *ListAsyncTranscodesResponse) String() string
- type ListAsyncTranscodesResponse_Op
- func (x *ListAsyncTranscodesResponse_Op) GetName() string
- func (x *ListAsyncTranscodesResponse_Op) GetState() TranscodeState
- func (x *ListAsyncTranscodesResponse_Op) GetType() ListAsyncTranscodesResponse_Op_Type
- func (*ListAsyncTranscodesResponse_Op) ProtoMessage()
- func (x *ListAsyncTranscodesResponse_Op) ProtoReflect() protoreflect.Message
- func (x *ListAsyncTranscodesResponse_Op) Reset()
- func (x *ListAsyncTranscodesResponse_Op) SetName(v string)
- func (x *ListAsyncTranscodesResponse_Op) SetState(v TranscodeState)
- func (x *ListAsyncTranscodesResponse_Op) SetType(v ListAsyncTranscodesResponse_Op_Type)
- func (x *ListAsyncTranscodesResponse_Op) String() string
- type ListAsyncTranscodesResponse_Op_Type
- func (ListAsyncTranscodesResponse_Op_Type) Descriptor() protoreflect.EnumDescriptor
- func (x ListAsyncTranscodesResponse_Op_Type) Enum() *ListAsyncTranscodesResponse_Op_Type
- func (x ListAsyncTranscodesResponse_Op_Type) Number() protoreflect.EnumNumber
- func (x ListAsyncTranscodesResponse_Op_Type) String() string
- func (ListAsyncTranscodesResponse_Op_Type) Type() protoreflect.EnumType
- type ListAsyncTranscodesResponse_Op_builder
- type ListAsyncTranscodesResponse_builder
- type StartAsyncShowTranscodeRequest
- func (x *StartAsyncShowTranscodeRequest) GetInDirPath() string
- func (x *StartAsyncShowTranscodeRequest) GetName() string
- func (x *StartAsyncShowTranscodeRequest) GetOutParentDirPath() string
- func (x *StartAsyncShowTranscodeRequest) GetProfile() string
- func (*StartAsyncShowTranscodeRequest) ProtoMessage()
- func (x *StartAsyncShowTranscodeRequest) ProtoReflect() protoreflect.Message
- func (x *StartAsyncShowTranscodeRequest) Reset()
- func (x *StartAsyncShowTranscodeRequest) SetInDirPath(v string)
- func (x *StartAsyncShowTranscodeRequest) SetName(v string)
- func (x *StartAsyncShowTranscodeRequest) SetOutParentDirPath(v string)
- func (x *StartAsyncShowTranscodeRequest) SetProfile(v string)
- func (x *StartAsyncShowTranscodeRequest) String() string
- type StartAsyncShowTranscodeRequest_builder
- type StartAsyncShowTranscodeResponse
- type StartAsyncShowTranscodeResponse_builder
- type StartAsyncSpreadTranscodeRequest
- func (x *StartAsyncSpreadTranscodeRequest) ClearProfileList()
- func (x *StartAsyncSpreadTranscodeRequest) GetInPath() string
- func (x *StartAsyncSpreadTranscodeRequest) GetName() string
- func (x *StartAsyncSpreadTranscodeRequest) GetOutParentDirPath() string
- func (x *StartAsyncSpreadTranscodeRequest) GetProfileList() *StartAsyncSpreadTranscodeRequest_ProfileList
- func (x *StartAsyncSpreadTranscodeRequest) HasProfileList() bool
- func (*StartAsyncSpreadTranscodeRequest) ProtoMessage()
- func (x *StartAsyncSpreadTranscodeRequest) ProtoReflect() protoreflect.Message
- func (x *StartAsyncSpreadTranscodeRequest) Reset()
- func (x *StartAsyncSpreadTranscodeRequest) SetInPath(v string)
- func (x *StartAsyncSpreadTranscodeRequest) SetName(v string)
- func (x *StartAsyncSpreadTranscodeRequest) SetOutParentDirPath(v string)
- func (x *StartAsyncSpreadTranscodeRequest) SetProfileList(v *StartAsyncSpreadTranscodeRequest_ProfileList)
- func (x *StartAsyncSpreadTranscodeRequest) String() string
- type StartAsyncSpreadTranscodeRequest_ProfileList
- func (x *StartAsyncSpreadTranscodeRequest_ProfileList) GetProfile() []string
- func (*StartAsyncSpreadTranscodeRequest_ProfileList) ProtoMessage()
- func (x *StartAsyncSpreadTranscodeRequest_ProfileList) ProtoReflect() protoreflect.Message
- func (x *StartAsyncSpreadTranscodeRequest_ProfileList) Reset()
- func (x *StartAsyncSpreadTranscodeRequest_ProfileList) SetProfile(v []string)
- func (x *StartAsyncSpreadTranscodeRequest_ProfileList) String() string
- type StartAsyncSpreadTranscodeRequest_ProfileList_builder
- type StartAsyncSpreadTranscodeRequest_builder
- type StartAsyncSpreadTranscodeResponse
- type StartAsyncSpreadTranscodeResponse_builder
- type StartAsyncTranscodeRequest
- func (x *StartAsyncTranscodeRequest) GetInPath() string
- func (x *StartAsyncTranscodeRequest) GetName() string
- func (x *StartAsyncTranscodeRequest) GetOutPath() string
- func (x *StartAsyncTranscodeRequest) GetProfile() string
- func (*StartAsyncTranscodeRequest) ProtoMessage()
- func (x *StartAsyncTranscodeRequest) ProtoReflect() protoreflect.Message
- func (x *StartAsyncTranscodeRequest) Reset()
- func (x *StartAsyncTranscodeRequest) SetInPath(v string)
- func (x *StartAsyncTranscodeRequest) SetName(v string)
- func (x *StartAsyncTranscodeRequest) SetOutPath(v string)
- func (x *StartAsyncTranscodeRequest) SetProfile(v string)
- func (x *StartAsyncTranscodeRequest) String() string
- type StartAsyncTranscodeRequest_builder
- type StartAsyncTranscodeResponse
- type StartAsyncTranscodeResponse_builder
- type TranscodeState
Constants ¶
This section is empty.
Variables ¶
var ( TranscodeState_name = map[int32]string{ 0: "TRANSCODE_STATE_UNKNOWN", 4: "TRANSCODE_STATE_NOT_STARTED", 1: "TRANSCODE_STATE_IN_PROGRESS", 2: "TRANSCODE_STATE_DONE", 3: "TRANSCODE_STATE_FAILED", } TranscodeState_value = map[string]int32{ "TRANSCODE_STATE_UNKNOWN": 0, "TRANSCODE_STATE_NOT_STARTED": 4, "TRANSCODE_STATE_IN_PROGRESS": 1, "TRANSCODE_STATE_DONE": 2, "TRANSCODE_STATE_FAILED": 3, } )
Enum value maps for TranscodeState.
var ( ListAsyncTranscodesResponse_Op_Type_name = map[int32]string{ 0: "TYPE_UNKNOWN", 1: "TYPE_SINGLE_FILE", 2: "TYPE_SHOW", 3: "TYPE_SPREAD", } ListAsyncTranscodesResponse_Op_Type_value = map[string]int32{ "TYPE_UNKNOWN": 0, "TYPE_SINGLE_FILE": 1, "TYPE_SHOW": 2, "TYPE_SPREAD": 3, } )
Enum value maps for ListAsyncTranscodesResponse_Op_Type.
var File_krelinga_video_tcserver_v1_tcserver_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type CheckAsyncShowTranscodeRequest ¶
type CheckAsyncShowTranscodeRequest struct {
// Must match the name given in StartAsyncTranscodeRequest.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
func (*CheckAsyncShowTranscodeRequest) GetName ¶
func (x *CheckAsyncShowTranscodeRequest) GetName() string
func (*CheckAsyncShowTranscodeRequest) ProtoMessage ¶
func (*CheckAsyncShowTranscodeRequest) ProtoMessage()
func (*CheckAsyncShowTranscodeRequest) ProtoReflect ¶
func (x *CheckAsyncShowTranscodeRequest) ProtoReflect() protoreflect.Message
func (*CheckAsyncShowTranscodeRequest) Reset ¶
func (x *CheckAsyncShowTranscodeRequest) Reset()
func (*CheckAsyncShowTranscodeRequest) SetName ¶
func (x *CheckAsyncShowTranscodeRequest) SetName(v string)
func (*CheckAsyncShowTranscodeRequest) String ¶
func (x *CheckAsyncShowTranscodeRequest) String() string
type CheckAsyncShowTranscodeRequest_builder ¶
type CheckAsyncShowTranscodeRequest_builder struct {
// Must match the name given in StartAsyncTranscodeRequest.
Name string
// contains filtered or unexported fields
}
func (CheckAsyncShowTranscodeRequest_builder) Build ¶
func (b0 CheckAsyncShowTranscodeRequest_builder) Build() *CheckAsyncShowTranscodeRequest
type CheckAsyncShowTranscodeResponse ¶
type CheckAsyncShowTranscodeResponse struct {
File []*CheckAsyncShowTranscodeResponse_File `protobuf:"bytes,1,rep,name=file,proto3" json:"file,omitempty"`
// State & error of anything not related to individual files.
State TranscodeState `protobuf:"varint,2,opt,name=state,proto3,enum=krelinga.video.tcserver.v1.TranscodeState" json:"state,omitempty"`
ErrorMessage string `protobuf:"bytes,3,opt,name=error_message,json=errorMessage,proto3" json:"error_message,omitempty"`
Profile string `protobuf:"bytes,4,opt,name=profile,proto3" json:"profile,omitempty"`
// contains filtered or unexported fields
}
func (*CheckAsyncShowTranscodeResponse) GetErrorMessage ¶
func (x *CheckAsyncShowTranscodeResponse) GetErrorMessage() string
func (*CheckAsyncShowTranscodeResponse) GetFile ¶
func (x *CheckAsyncShowTranscodeResponse) GetFile() []*CheckAsyncShowTranscodeResponse_File
func (*CheckAsyncShowTranscodeResponse) GetProfile ¶
func (x *CheckAsyncShowTranscodeResponse) GetProfile() string
func (*CheckAsyncShowTranscodeResponse) GetState ¶
func (x *CheckAsyncShowTranscodeResponse) GetState() TranscodeState
func (*CheckAsyncShowTranscodeResponse) ProtoMessage ¶
func (*CheckAsyncShowTranscodeResponse) ProtoMessage()
func (*CheckAsyncShowTranscodeResponse) ProtoReflect ¶
func (x *CheckAsyncShowTranscodeResponse) ProtoReflect() protoreflect.Message
func (*CheckAsyncShowTranscodeResponse) Reset ¶
func (x *CheckAsyncShowTranscodeResponse) Reset()
func (*CheckAsyncShowTranscodeResponse) SetErrorMessage ¶
func (x *CheckAsyncShowTranscodeResponse) SetErrorMessage(v string)
func (*CheckAsyncShowTranscodeResponse) SetFile ¶
func (x *CheckAsyncShowTranscodeResponse) SetFile(v []*CheckAsyncShowTranscodeResponse_File)
func (*CheckAsyncShowTranscodeResponse) SetProfile ¶
func (x *CheckAsyncShowTranscodeResponse) SetProfile(v string)
func (*CheckAsyncShowTranscodeResponse) SetState ¶
func (x *CheckAsyncShowTranscodeResponse) SetState(v TranscodeState)
func (*CheckAsyncShowTranscodeResponse) String ¶
func (x *CheckAsyncShowTranscodeResponse) String() string
type CheckAsyncShowTranscodeResponse_File ¶
type CheckAsyncShowTranscodeResponse_File struct {
Episode string `protobuf:"bytes,1,opt,name=episode,proto3" json:"episode,omitempty"`
State TranscodeState `protobuf:"varint,2,opt,name=state,proto3,enum=krelinga.video.tcserver.v1.TranscodeState" json:"state,omitempty"`
ErrorMessage string `protobuf:"bytes,3,opt,name=error_message,json=errorMessage,proto3" json:"error_message,omitempty"`
// Only set if state is TRANSCODE_STATE_IN_PROGRESS
Progress string `protobuf:"bytes,4,opt,name=progress,proto3" json:"progress,omitempty"`
// contains filtered or unexported fields
}
func (*CheckAsyncShowTranscodeResponse_File) GetEpisode ¶
func (x *CheckAsyncShowTranscodeResponse_File) GetEpisode() string
func (*CheckAsyncShowTranscodeResponse_File) GetErrorMessage ¶
func (x *CheckAsyncShowTranscodeResponse_File) GetErrorMessage() string
func (*CheckAsyncShowTranscodeResponse_File) GetProgress ¶
func (x *CheckAsyncShowTranscodeResponse_File) GetProgress() string
func (*CheckAsyncShowTranscodeResponse_File) GetState ¶
func (x *CheckAsyncShowTranscodeResponse_File) GetState() TranscodeState
func (*CheckAsyncShowTranscodeResponse_File) ProtoMessage ¶
func (*CheckAsyncShowTranscodeResponse_File) ProtoMessage()
func (*CheckAsyncShowTranscodeResponse_File) ProtoReflect ¶
func (x *CheckAsyncShowTranscodeResponse_File) ProtoReflect() protoreflect.Message
func (*CheckAsyncShowTranscodeResponse_File) Reset ¶
func (x *CheckAsyncShowTranscodeResponse_File) Reset()
func (*CheckAsyncShowTranscodeResponse_File) SetEpisode ¶
func (x *CheckAsyncShowTranscodeResponse_File) SetEpisode(v string)
func (*CheckAsyncShowTranscodeResponse_File) SetErrorMessage ¶
func (x *CheckAsyncShowTranscodeResponse_File) SetErrorMessage(v string)
func (*CheckAsyncShowTranscodeResponse_File) SetProgress ¶
func (x *CheckAsyncShowTranscodeResponse_File) SetProgress(v string)
func (*CheckAsyncShowTranscodeResponse_File) SetState ¶
func (x *CheckAsyncShowTranscodeResponse_File) SetState(v TranscodeState)
func (*CheckAsyncShowTranscodeResponse_File) String ¶
func (x *CheckAsyncShowTranscodeResponse_File) String() string
type CheckAsyncShowTranscodeResponse_File_builder ¶
type CheckAsyncShowTranscodeResponse_File_builder struct {
Episode string
State TranscodeState
ErrorMessage string
// Only set if state is TRANSCODE_STATE_IN_PROGRESS
Progress string
// contains filtered or unexported fields
}
func (CheckAsyncShowTranscodeResponse_File_builder) Build ¶
func (b0 CheckAsyncShowTranscodeResponse_File_builder) Build() *CheckAsyncShowTranscodeResponse_File
type CheckAsyncShowTranscodeResponse_builder ¶
type CheckAsyncShowTranscodeResponse_builder struct {
File []*CheckAsyncShowTranscodeResponse_File
// State & error of anything not related to individual files.
State TranscodeState
ErrorMessage string
Profile string
// contains filtered or unexported fields
}
func (CheckAsyncShowTranscodeResponse_builder) Build ¶
func (b0 CheckAsyncShowTranscodeResponse_builder) Build() *CheckAsyncShowTranscodeResponse
type CheckAsyncSpreadTranscodeRequest ¶
type CheckAsyncSpreadTranscodeRequest struct {
// Must match the name given in StartAsyncSpreadTranscodeRequest.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
func (*CheckAsyncSpreadTranscodeRequest) GetName ¶
func (x *CheckAsyncSpreadTranscodeRequest) GetName() string
func (*CheckAsyncSpreadTranscodeRequest) ProtoMessage ¶
func (*CheckAsyncSpreadTranscodeRequest) ProtoMessage()
func (*CheckAsyncSpreadTranscodeRequest) ProtoReflect ¶
func (x *CheckAsyncSpreadTranscodeRequest) ProtoReflect() protoreflect.Message
func (*CheckAsyncSpreadTranscodeRequest) Reset ¶
func (x *CheckAsyncSpreadTranscodeRequest) Reset()
func (*CheckAsyncSpreadTranscodeRequest) SetName ¶
func (x *CheckAsyncSpreadTranscodeRequest) SetName(v string)
func (*CheckAsyncSpreadTranscodeRequest) String ¶
func (x *CheckAsyncSpreadTranscodeRequest) String() string
type CheckAsyncSpreadTranscodeRequest_builder ¶
type CheckAsyncSpreadTranscodeRequest_builder struct {
// Must match the name given in StartAsyncSpreadTranscodeRequest.
Name string
// contains filtered or unexported fields
}
func (CheckAsyncSpreadTranscodeRequest_builder) Build ¶
func (b0 CheckAsyncSpreadTranscodeRequest_builder) Build() *CheckAsyncSpreadTranscodeRequest
type CheckAsyncSpreadTranscodeResponse ¶
type CheckAsyncSpreadTranscodeResponse struct {
Profile []*CheckAsyncSpreadTranscodeResponse_Profile `protobuf:"bytes,1,rep,name=profile,proto3" json:"profile,omitempty"`
State TranscodeState `protobuf:"varint,2,opt,name=state,proto3,enum=krelinga.video.tcserver.v1.TranscodeState" json:"state,omitempty"`
ErrorMessage string `protobuf:"bytes,3,opt,name=error_message,json=errorMessage,proto3" json:"error_message,omitempty"`
// contains filtered or unexported fields
}
func (*CheckAsyncSpreadTranscodeResponse) GetErrorMessage ¶
func (x *CheckAsyncSpreadTranscodeResponse) GetErrorMessage() string
func (*CheckAsyncSpreadTranscodeResponse) GetProfile ¶
func (x *CheckAsyncSpreadTranscodeResponse) GetProfile() []*CheckAsyncSpreadTranscodeResponse_Profile
func (*CheckAsyncSpreadTranscodeResponse) GetState ¶
func (x *CheckAsyncSpreadTranscodeResponse) GetState() TranscodeState
func (*CheckAsyncSpreadTranscodeResponse) ProtoMessage ¶
func (*CheckAsyncSpreadTranscodeResponse) ProtoMessage()
func (*CheckAsyncSpreadTranscodeResponse) ProtoReflect ¶
func (x *CheckAsyncSpreadTranscodeResponse) ProtoReflect() protoreflect.Message
func (*CheckAsyncSpreadTranscodeResponse) Reset ¶
func (x *CheckAsyncSpreadTranscodeResponse) Reset()
func (*CheckAsyncSpreadTranscodeResponse) SetErrorMessage ¶
func (x *CheckAsyncSpreadTranscodeResponse) SetErrorMessage(v string)
func (*CheckAsyncSpreadTranscodeResponse) SetProfile ¶
func (x *CheckAsyncSpreadTranscodeResponse) SetProfile(v []*CheckAsyncSpreadTranscodeResponse_Profile)
func (*CheckAsyncSpreadTranscodeResponse) SetState ¶
func (x *CheckAsyncSpreadTranscodeResponse) SetState(v TranscodeState)
func (*CheckAsyncSpreadTranscodeResponse) String ¶
func (x *CheckAsyncSpreadTranscodeResponse) String() string
type CheckAsyncSpreadTranscodeResponse_Profile ¶
type CheckAsyncSpreadTranscodeResponse_Profile struct {
Profile string `protobuf:"bytes,1,opt,name=profile,proto3" json:"profile,omitempty"`
State TranscodeState `protobuf:"varint,2,opt,name=state,proto3,enum=krelinga.video.tcserver.v1.TranscodeState" json:"state,omitempty"`
ErrorMessage string `protobuf:"bytes,3,opt,name=error_message,json=errorMessage,proto3" json:"error_message,omitempty"`
// Only set if state is TRANSCODE_STATE_IN_PROGRESS
Progress string `protobuf:"bytes,4,opt,name=progress,proto3" json:"progress,omitempty"`
// contains filtered or unexported fields
}
func (*CheckAsyncSpreadTranscodeResponse_Profile) GetErrorMessage ¶
func (x *CheckAsyncSpreadTranscodeResponse_Profile) GetErrorMessage() string
func (*CheckAsyncSpreadTranscodeResponse_Profile) GetProfile ¶
func (x *CheckAsyncSpreadTranscodeResponse_Profile) GetProfile() string
func (*CheckAsyncSpreadTranscodeResponse_Profile) GetProgress ¶
func (x *CheckAsyncSpreadTranscodeResponse_Profile) GetProgress() string
func (*CheckAsyncSpreadTranscodeResponse_Profile) GetState ¶
func (x *CheckAsyncSpreadTranscodeResponse_Profile) GetState() TranscodeState
func (*CheckAsyncSpreadTranscodeResponse_Profile) ProtoMessage ¶
func (*CheckAsyncSpreadTranscodeResponse_Profile) ProtoMessage()
func (*CheckAsyncSpreadTranscodeResponse_Profile) ProtoReflect ¶
func (x *CheckAsyncSpreadTranscodeResponse_Profile) ProtoReflect() protoreflect.Message
func (*CheckAsyncSpreadTranscodeResponse_Profile) Reset ¶
func (x *CheckAsyncSpreadTranscodeResponse_Profile) Reset()
func (*CheckAsyncSpreadTranscodeResponse_Profile) SetErrorMessage ¶
func (x *CheckAsyncSpreadTranscodeResponse_Profile) SetErrorMessage(v string)
func (*CheckAsyncSpreadTranscodeResponse_Profile) SetProfile ¶
func (x *CheckAsyncSpreadTranscodeResponse_Profile) SetProfile(v string)
func (*CheckAsyncSpreadTranscodeResponse_Profile) SetProgress ¶
func (x *CheckAsyncSpreadTranscodeResponse_Profile) SetProgress(v string)
func (*CheckAsyncSpreadTranscodeResponse_Profile) SetState ¶
func (x *CheckAsyncSpreadTranscodeResponse_Profile) SetState(v TranscodeState)
func (*CheckAsyncSpreadTranscodeResponse_Profile) String ¶
func (x *CheckAsyncSpreadTranscodeResponse_Profile) String() string
type CheckAsyncSpreadTranscodeResponse_Profile_builder ¶
type CheckAsyncSpreadTranscodeResponse_Profile_builder struct {
Profile string
State TranscodeState
ErrorMessage string
// Only set if state is TRANSCODE_STATE_IN_PROGRESS
Progress string
// contains filtered or unexported fields
}
func (CheckAsyncSpreadTranscodeResponse_Profile_builder) Build ¶
type CheckAsyncSpreadTranscodeResponse_builder ¶
type CheckAsyncSpreadTranscodeResponse_builder struct {
Profile []*CheckAsyncSpreadTranscodeResponse_Profile
State TranscodeState
ErrorMessage string
// contains filtered or unexported fields
}
func (CheckAsyncSpreadTranscodeResponse_builder) Build ¶
func (b0 CheckAsyncSpreadTranscodeResponse_builder) Build() *CheckAsyncSpreadTranscodeResponse
type CheckAsyncTranscodeRequest ¶
type CheckAsyncTranscodeRequest struct {
// Must match the name given in StartAsyncTranscodeRequest.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
func (*CheckAsyncTranscodeRequest) GetName ¶
func (x *CheckAsyncTranscodeRequest) GetName() string
func (*CheckAsyncTranscodeRequest) ProtoMessage ¶
func (*CheckAsyncTranscodeRequest) ProtoMessage()
func (*CheckAsyncTranscodeRequest) ProtoReflect ¶
func (x *CheckAsyncTranscodeRequest) ProtoReflect() protoreflect.Message
func (*CheckAsyncTranscodeRequest) Reset ¶
func (x *CheckAsyncTranscodeRequest) Reset()
func (*CheckAsyncTranscodeRequest) SetName ¶
func (x *CheckAsyncTranscodeRequest) SetName(v string)
func (*CheckAsyncTranscodeRequest) String ¶
func (x *CheckAsyncTranscodeRequest) String() string
type CheckAsyncTranscodeRequest_builder ¶
type CheckAsyncTranscodeRequest_builder struct {
// Must match the name given in StartAsyncTranscodeRequest.
Name string
// contains filtered or unexported fields
}
func (CheckAsyncTranscodeRequest_builder) Build ¶
func (b0 CheckAsyncTranscodeRequest_builder) Build() *CheckAsyncTranscodeRequest
type CheckAsyncTranscodeResponse ¶
type CheckAsyncTranscodeResponse struct {
State TranscodeState `protobuf:"varint,1,opt,name=state,proto3,enum=krelinga.video.tcserver.v1.TranscodeState" json:"state,omitempty"`
ErrorMessage string `protobuf:"bytes,2,opt,name=error_message,json=errorMessage,proto3" json:"error_message,omitempty"`
// Only set if state is TRANSCODE_STATE_IN_PROGRESS
Progress string `protobuf:"bytes,3,opt,name=progress,proto3" json:"progress,omitempty"`
Profile string `protobuf:"bytes,4,opt,name=profile,proto3" json:"profile,omitempty"`
// contains filtered or unexported fields
}
func (*CheckAsyncTranscodeResponse) GetErrorMessage ¶
func (x *CheckAsyncTranscodeResponse) GetErrorMessage() string
func (*CheckAsyncTranscodeResponse) GetProfile ¶
func (x *CheckAsyncTranscodeResponse) GetProfile() string
func (*CheckAsyncTranscodeResponse) GetProgress ¶
func (x *CheckAsyncTranscodeResponse) GetProgress() string
func (*CheckAsyncTranscodeResponse) GetState ¶
func (x *CheckAsyncTranscodeResponse) GetState() TranscodeState
func (*CheckAsyncTranscodeResponse) ProtoMessage ¶
func (*CheckAsyncTranscodeResponse) ProtoMessage()
func (*CheckAsyncTranscodeResponse) ProtoReflect ¶
func (x *CheckAsyncTranscodeResponse) ProtoReflect() protoreflect.Message
func (*CheckAsyncTranscodeResponse) Reset ¶
func (x *CheckAsyncTranscodeResponse) Reset()
func (*CheckAsyncTranscodeResponse) SetErrorMessage ¶
func (x *CheckAsyncTranscodeResponse) SetErrorMessage(v string)
func (*CheckAsyncTranscodeResponse) SetProfile ¶
func (x *CheckAsyncTranscodeResponse) SetProfile(v string)
func (*CheckAsyncTranscodeResponse) SetProgress ¶
func (x *CheckAsyncTranscodeResponse) SetProgress(v string)
func (*CheckAsyncTranscodeResponse) SetState ¶
func (x *CheckAsyncTranscodeResponse) SetState(v TranscodeState)
func (*CheckAsyncTranscodeResponse) String ¶
func (x *CheckAsyncTranscodeResponse) String() string
type CheckAsyncTranscodeResponse_builder ¶
type CheckAsyncTranscodeResponse_builder struct {
State TranscodeState
ErrorMessage string
// Only set if state is TRANSCODE_STATE_IN_PROGRESS
Progress string
Profile string
// contains filtered or unexported fields
}
func (CheckAsyncTranscodeResponse_builder) Build ¶
func (b0 CheckAsyncTranscodeResponse_builder) Build() *CheckAsyncTranscodeResponse
type ListAsyncTranscodesRequest ¶
type ListAsyncTranscodesRequest struct {
// contains filtered or unexported fields
}
func (*ListAsyncTranscodesRequest) ProtoMessage ¶
func (*ListAsyncTranscodesRequest) ProtoMessage()
func (*ListAsyncTranscodesRequest) ProtoReflect ¶
func (x *ListAsyncTranscodesRequest) ProtoReflect() protoreflect.Message
func (*ListAsyncTranscodesRequest) Reset ¶
func (x *ListAsyncTranscodesRequest) Reset()
func (*ListAsyncTranscodesRequest) String ¶
func (x *ListAsyncTranscodesRequest) String() string
type ListAsyncTranscodesRequest_builder ¶
type ListAsyncTranscodesRequest_builder struct {
// contains filtered or unexported fields
}
func (ListAsyncTranscodesRequest_builder) Build ¶
func (b0 ListAsyncTranscodesRequest_builder) Build() *ListAsyncTranscodesRequest
type ListAsyncTranscodesResponse ¶
type ListAsyncTranscodesResponse struct {
Op []*ListAsyncTranscodesResponse_Op `protobuf:"bytes,1,rep,name=op,proto3" json:"op,omitempty"`
// contains filtered or unexported fields
}
func (*ListAsyncTranscodesResponse) GetOp ¶
func (x *ListAsyncTranscodesResponse) GetOp() []*ListAsyncTranscodesResponse_Op
func (*ListAsyncTranscodesResponse) ProtoMessage ¶
func (*ListAsyncTranscodesResponse) ProtoMessage()
func (*ListAsyncTranscodesResponse) ProtoReflect ¶
func (x *ListAsyncTranscodesResponse) ProtoReflect() protoreflect.Message
func (*ListAsyncTranscodesResponse) Reset ¶
func (x *ListAsyncTranscodesResponse) Reset()
func (*ListAsyncTranscodesResponse) SetOp ¶
func (x *ListAsyncTranscodesResponse) SetOp(v []*ListAsyncTranscodesResponse_Op)
func (*ListAsyncTranscodesResponse) String ¶
func (x *ListAsyncTranscodesResponse) String() string
type ListAsyncTranscodesResponse_Op ¶
type ListAsyncTranscodesResponse_Op struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
Type ListAsyncTranscodesResponse_Op_Type `` /* 130-byte string literal not displayed */
State TranscodeState `protobuf:"varint,3,opt,name=state,proto3,enum=krelinga.video.tcserver.v1.TranscodeState" json:"state,omitempty"`
// contains filtered or unexported fields
}
func (*ListAsyncTranscodesResponse_Op) GetName ¶
func (x *ListAsyncTranscodesResponse_Op) GetName() string
func (*ListAsyncTranscodesResponse_Op) GetState ¶
func (x *ListAsyncTranscodesResponse_Op) GetState() TranscodeState
func (*ListAsyncTranscodesResponse_Op) GetType ¶
func (x *ListAsyncTranscodesResponse_Op) GetType() ListAsyncTranscodesResponse_Op_Type
func (*ListAsyncTranscodesResponse_Op) ProtoMessage ¶
func (*ListAsyncTranscodesResponse_Op) ProtoMessage()
func (*ListAsyncTranscodesResponse_Op) ProtoReflect ¶
func (x *ListAsyncTranscodesResponse_Op) ProtoReflect() protoreflect.Message
func (*ListAsyncTranscodesResponse_Op) Reset ¶
func (x *ListAsyncTranscodesResponse_Op) Reset()
func (*ListAsyncTranscodesResponse_Op) SetName ¶
func (x *ListAsyncTranscodesResponse_Op) SetName(v string)
func (*ListAsyncTranscodesResponse_Op) SetState ¶
func (x *ListAsyncTranscodesResponse_Op) SetState(v TranscodeState)
func (*ListAsyncTranscodesResponse_Op) SetType ¶
func (x *ListAsyncTranscodesResponse_Op) SetType(v ListAsyncTranscodesResponse_Op_Type)
func (*ListAsyncTranscodesResponse_Op) String ¶
func (x *ListAsyncTranscodesResponse_Op) String() string
type ListAsyncTranscodesResponse_Op_Type ¶
type ListAsyncTranscodesResponse_Op_Type int32
const ( ListAsyncTranscodesResponse_Op_TYPE_UNKNOWN ListAsyncTranscodesResponse_Op_Type = 0 ListAsyncTranscodesResponse_Op_TYPE_SINGLE_FILE ListAsyncTranscodesResponse_Op_Type = 1 ListAsyncTranscodesResponse_Op_TYPE_SHOW ListAsyncTranscodesResponse_Op_Type = 2 ListAsyncTranscodesResponse_Op_TYPE_SPREAD ListAsyncTranscodesResponse_Op_Type = 3 )
func (ListAsyncTranscodesResponse_Op_Type) Descriptor ¶
func (ListAsyncTranscodesResponse_Op_Type) Descriptor() protoreflect.EnumDescriptor
func (ListAsyncTranscodesResponse_Op_Type) Enum ¶
func (x ListAsyncTranscodesResponse_Op_Type) Enum() *ListAsyncTranscodesResponse_Op_Type
func (ListAsyncTranscodesResponse_Op_Type) Number ¶
func (x ListAsyncTranscodesResponse_Op_Type) Number() protoreflect.EnumNumber
func (ListAsyncTranscodesResponse_Op_Type) String ¶
func (x ListAsyncTranscodesResponse_Op_Type) String() string
func (ListAsyncTranscodesResponse_Op_Type) Type ¶
func (ListAsyncTranscodesResponse_Op_Type) Type() protoreflect.EnumType
type ListAsyncTranscodesResponse_Op_builder ¶
type ListAsyncTranscodesResponse_Op_builder struct {
Name string
Type ListAsyncTranscodesResponse_Op_Type
State TranscodeState
// contains filtered or unexported fields
}
func (ListAsyncTranscodesResponse_Op_builder) Build ¶
func (b0 ListAsyncTranscodesResponse_Op_builder) Build() *ListAsyncTranscodesResponse_Op
type ListAsyncTranscodesResponse_builder ¶
type ListAsyncTranscodesResponse_builder struct {
Op []*ListAsyncTranscodesResponse_Op
// contains filtered or unexported fields
}
func (ListAsyncTranscodesResponse_builder) Build ¶
func (b0 ListAsyncTranscodesResponse_builder) Build() *ListAsyncTranscodesResponse
type StartAsyncShowTranscodeRequest ¶
type StartAsyncShowTranscodeRequest struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
InDirPath string `protobuf:"bytes,2,opt,name=in_dir_path,json=inDirPath,proto3" json:"in_dir_path,omitempty"`
OutParentDirPath string `protobuf:"bytes,3,opt,name=out_parent_dir_path,json=outParentDirPath,proto3" json:"out_parent_dir_path,omitempty"`
Profile string `protobuf:"bytes,4,opt,name=profile,proto3" json:"profile,omitempty"`
// contains filtered or unexported fields
}
func (*StartAsyncShowTranscodeRequest) GetInDirPath ¶
func (x *StartAsyncShowTranscodeRequest) GetInDirPath() string
func (*StartAsyncShowTranscodeRequest) GetName ¶
func (x *StartAsyncShowTranscodeRequest) GetName() string
func (*StartAsyncShowTranscodeRequest) GetOutParentDirPath ¶
func (x *StartAsyncShowTranscodeRequest) GetOutParentDirPath() string
func (*StartAsyncShowTranscodeRequest) GetProfile ¶
func (x *StartAsyncShowTranscodeRequest) GetProfile() string
func (*StartAsyncShowTranscodeRequest) ProtoMessage ¶
func (*StartAsyncShowTranscodeRequest) ProtoMessage()
func (*StartAsyncShowTranscodeRequest) ProtoReflect ¶
func (x *StartAsyncShowTranscodeRequest) ProtoReflect() protoreflect.Message
func (*StartAsyncShowTranscodeRequest) Reset ¶
func (x *StartAsyncShowTranscodeRequest) Reset()
func (*StartAsyncShowTranscodeRequest) SetInDirPath ¶
func (x *StartAsyncShowTranscodeRequest) SetInDirPath(v string)
func (*StartAsyncShowTranscodeRequest) SetName ¶
func (x *StartAsyncShowTranscodeRequest) SetName(v string)
func (*StartAsyncShowTranscodeRequest) SetOutParentDirPath ¶
func (x *StartAsyncShowTranscodeRequest) SetOutParentDirPath(v string)
func (*StartAsyncShowTranscodeRequest) SetProfile ¶
func (x *StartAsyncShowTranscodeRequest) SetProfile(v string)
func (*StartAsyncShowTranscodeRequest) String ¶
func (x *StartAsyncShowTranscodeRequest) String() string
type StartAsyncShowTranscodeRequest_builder ¶
type StartAsyncShowTranscodeRequest_builder struct {
Name string
InDirPath string
OutParentDirPath string
Profile string
// contains filtered or unexported fields
}
func (StartAsyncShowTranscodeRequest_builder) Build ¶
func (b0 StartAsyncShowTranscodeRequest_builder) Build() *StartAsyncShowTranscodeRequest
type StartAsyncShowTranscodeResponse ¶
type StartAsyncShowTranscodeResponse struct {
// contains filtered or unexported fields
}
func (*StartAsyncShowTranscodeResponse) ProtoMessage ¶
func (*StartAsyncShowTranscodeResponse) ProtoMessage()
func (*StartAsyncShowTranscodeResponse) ProtoReflect ¶
func (x *StartAsyncShowTranscodeResponse) ProtoReflect() protoreflect.Message
func (*StartAsyncShowTranscodeResponse) Reset ¶
func (x *StartAsyncShowTranscodeResponse) Reset()
func (*StartAsyncShowTranscodeResponse) String ¶
func (x *StartAsyncShowTranscodeResponse) String() string
type StartAsyncShowTranscodeResponse_builder ¶
type StartAsyncShowTranscodeResponse_builder struct {
// contains filtered or unexported fields
}
func (StartAsyncShowTranscodeResponse_builder) Build ¶
func (b0 StartAsyncShowTranscodeResponse_builder) Build() *StartAsyncShowTranscodeResponse
type StartAsyncSpreadTranscodeRequest ¶
type StartAsyncSpreadTranscodeRequest struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
InPath string `protobuf:"bytes,2,opt,name=in_path,json=inPath,proto3" json:"in_path,omitempty"`
OutParentDirPath string `protobuf:"bytes,3,opt,name=out_parent_dir_path,json=outParentDirPath,proto3" json:"out_parent_dir_path,omitempty"`
ProfileList *StartAsyncSpreadTranscodeRequest_ProfileList `protobuf:"bytes,4,opt,name=profile_list,json=profileList,proto3" json:"profile_list,omitempty"`
// contains filtered or unexported fields
}
func (*StartAsyncSpreadTranscodeRequest) ClearProfileList ¶
func (x *StartAsyncSpreadTranscodeRequest) ClearProfileList()
func (*StartAsyncSpreadTranscodeRequest) GetInPath ¶
func (x *StartAsyncSpreadTranscodeRequest) GetInPath() string
func (*StartAsyncSpreadTranscodeRequest) GetName ¶
func (x *StartAsyncSpreadTranscodeRequest) GetName() string
func (*StartAsyncSpreadTranscodeRequest) GetOutParentDirPath ¶
func (x *StartAsyncSpreadTranscodeRequest) GetOutParentDirPath() string
func (*StartAsyncSpreadTranscodeRequest) GetProfileList ¶
func (x *StartAsyncSpreadTranscodeRequest) GetProfileList() *StartAsyncSpreadTranscodeRequest_ProfileList
func (*StartAsyncSpreadTranscodeRequest) HasProfileList ¶
func (x *StartAsyncSpreadTranscodeRequest) HasProfileList() bool
func (*StartAsyncSpreadTranscodeRequest) ProtoMessage ¶
func (*StartAsyncSpreadTranscodeRequest) ProtoMessage()
func (*StartAsyncSpreadTranscodeRequest) ProtoReflect ¶
func (x *StartAsyncSpreadTranscodeRequest) ProtoReflect() protoreflect.Message
func (*StartAsyncSpreadTranscodeRequest) Reset ¶
func (x *StartAsyncSpreadTranscodeRequest) Reset()
func (*StartAsyncSpreadTranscodeRequest) SetInPath ¶
func (x *StartAsyncSpreadTranscodeRequest) SetInPath(v string)
func (*StartAsyncSpreadTranscodeRequest) SetName ¶
func (x *StartAsyncSpreadTranscodeRequest) SetName(v string)
func (*StartAsyncSpreadTranscodeRequest) SetOutParentDirPath ¶
func (x *StartAsyncSpreadTranscodeRequest) SetOutParentDirPath(v string)
func (*StartAsyncSpreadTranscodeRequest) SetProfileList ¶
func (x *StartAsyncSpreadTranscodeRequest) SetProfileList(v *StartAsyncSpreadTranscodeRequest_ProfileList)
func (*StartAsyncSpreadTranscodeRequest) String ¶
func (x *StartAsyncSpreadTranscodeRequest) String() string
type StartAsyncSpreadTranscodeRequest_ProfileList ¶
type StartAsyncSpreadTranscodeRequest_ProfileList struct {
Profile []string `protobuf:"bytes,1,rep,name=profile,proto3" json:"profile,omitempty"`
// contains filtered or unexported fields
}
TODO: expand how these can be specified in the future.
func (*StartAsyncSpreadTranscodeRequest_ProfileList) GetProfile ¶
func (x *StartAsyncSpreadTranscodeRequest_ProfileList) GetProfile() []string
func (*StartAsyncSpreadTranscodeRequest_ProfileList) ProtoMessage ¶
func (*StartAsyncSpreadTranscodeRequest_ProfileList) ProtoMessage()
func (*StartAsyncSpreadTranscodeRequest_ProfileList) ProtoReflect ¶
func (x *StartAsyncSpreadTranscodeRequest_ProfileList) ProtoReflect() protoreflect.Message
func (*StartAsyncSpreadTranscodeRequest_ProfileList) Reset ¶
func (x *StartAsyncSpreadTranscodeRequest_ProfileList) Reset()
func (*StartAsyncSpreadTranscodeRequest_ProfileList) SetProfile ¶
func (x *StartAsyncSpreadTranscodeRequest_ProfileList) SetProfile(v []string)
func (*StartAsyncSpreadTranscodeRequest_ProfileList) String ¶
func (x *StartAsyncSpreadTranscodeRequest_ProfileList) String() string
type StartAsyncSpreadTranscodeRequest_ProfileList_builder ¶
type StartAsyncSpreadTranscodeRequest_ProfileList_builder struct {
Profile []string
// contains filtered or unexported fields
}
func (StartAsyncSpreadTranscodeRequest_ProfileList_builder) Build ¶
type StartAsyncSpreadTranscodeRequest_builder ¶
type StartAsyncSpreadTranscodeRequest_builder struct {
Name string
InPath string
OutParentDirPath string
ProfileList *StartAsyncSpreadTranscodeRequest_ProfileList
// contains filtered or unexported fields
}
func (StartAsyncSpreadTranscodeRequest_builder) Build ¶
func (b0 StartAsyncSpreadTranscodeRequest_builder) Build() *StartAsyncSpreadTranscodeRequest
type StartAsyncSpreadTranscodeResponse ¶
type StartAsyncSpreadTranscodeResponse struct {
// contains filtered or unexported fields
}
func (*StartAsyncSpreadTranscodeResponse) ProtoMessage ¶
func (*StartAsyncSpreadTranscodeResponse) ProtoMessage()
func (*StartAsyncSpreadTranscodeResponse) ProtoReflect ¶
func (x *StartAsyncSpreadTranscodeResponse) ProtoReflect() protoreflect.Message
func (*StartAsyncSpreadTranscodeResponse) Reset ¶
func (x *StartAsyncSpreadTranscodeResponse) Reset()
func (*StartAsyncSpreadTranscodeResponse) String ¶
func (x *StartAsyncSpreadTranscodeResponse) String() string
type StartAsyncSpreadTranscodeResponse_builder ¶
type StartAsyncSpreadTranscodeResponse_builder struct {
// contains filtered or unexported fields
}
func (StartAsyncSpreadTranscodeResponse_builder) Build ¶
func (b0 StartAsyncSpreadTranscodeResponse_builder) Build() *StartAsyncSpreadTranscodeResponse
type StartAsyncTranscodeRequest ¶
type StartAsyncTranscodeRequest struct {
// Must be unique among all running transcodes on the server.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
InPath string `protobuf:"bytes,2,opt,name=in_path,json=inPath,proto3" json:"in_path,omitempty"`
OutPath string `protobuf:"bytes,3,opt,name=out_path,json=outPath,proto3" json:"out_path,omitempty"`
// If set, the name of the profile to use.
Profile string `protobuf:"bytes,4,opt,name=profile,proto3" json:"profile,omitempty"`
// contains filtered or unexported fields
}
func (*StartAsyncTranscodeRequest) GetInPath ¶
func (x *StartAsyncTranscodeRequest) GetInPath() string
func (*StartAsyncTranscodeRequest) GetName ¶
func (x *StartAsyncTranscodeRequest) GetName() string
func (*StartAsyncTranscodeRequest) GetOutPath ¶
func (x *StartAsyncTranscodeRequest) GetOutPath() string
func (*StartAsyncTranscodeRequest) GetProfile ¶
func (x *StartAsyncTranscodeRequest) GetProfile() string
func (*StartAsyncTranscodeRequest) ProtoMessage ¶
func (*StartAsyncTranscodeRequest) ProtoMessage()
func (*StartAsyncTranscodeRequest) ProtoReflect ¶
func (x *StartAsyncTranscodeRequest) ProtoReflect() protoreflect.Message
func (*StartAsyncTranscodeRequest) Reset ¶
func (x *StartAsyncTranscodeRequest) Reset()
func (*StartAsyncTranscodeRequest) SetInPath ¶
func (x *StartAsyncTranscodeRequest) SetInPath(v string)
func (*StartAsyncTranscodeRequest) SetName ¶
func (x *StartAsyncTranscodeRequest) SetName(v string)
func (*StartAsyncTranscodeRequest) SetOutPath ¶
func (x *StartAsyncTranscodeRequest) SetOutPath(v string)
func (*StartAsyncTranscodeRequest) SetProfile ¶
func (x *StartAsyncTranscodeRequest) SetProfile(v string)
func (*StartAsyncTranscodeRequest) String ¶
func (x *StartAsyncTranscodeRequest) String() string
type StartAsyncTranscodeRequest_builder ¶
type StartAsyncTranscodeRequest_builder struct {
// Must be unique among all running transcodes on the server.
Name string
InPath string
OutPath string
// If set, the name of the profile to use.
Profile string
// contains filtered or unexported fields
}
func (StartAsyncTranscodeRequest_builder) Build ¶
func (b0 StartAsyncTranscodeRequest_builder) Build() *StartAsyncTranscodeRequest
type StartAsyncTranscodeResponse ¶
type StartAsyncTranscodeResponse struct {
// contains filtered or unexported fields
}
func (*StartAsyncTranscodeResponse) ProtoMessage ¶
func (*StartAsyncTranscodeResponse) ProtoMessage()
func (*StartAsyncTranscodeResponse) ProtoReflect ¶
func (x *StartAsyncTranscodeResponse) ProtoReflect() protoreflect.Message
func (*StartAsyncTranscodeResponse) Reset ¶
func (x *StartAsyncTranscodeResponse) Reset()
func (*StartAsyncTranscodeResponse) String ¶
func (x *StartAsyncTranscodeResponse) String() string
type StartAsyncTranscodeResponse_builder ¶
type StartAsyncTranscodeResponse_builder struct {
// contains filtered or unexported fields
}
func (StartAsyncTranscodeResponse_builder) Build ¶
func (b0 StartAsyncTranscodeResponse_builder) Build() *StartAsyncTranscodeResponse
type TranscodeState ¶
type TranscodeState int32
const ( TranscodeState_TRANSCODE_STATE_UNKNOWN TranscodeState = 0 TranscodeState_TRANSCODE_STATE_NOT_STARTED TranscodeState = 4 TranscodeState_TRANSCODE_STATE_IN_PROGRESS TranscodeState = 1 TranscodeState_TRANSCODE_STATE_DONE TranscodeState = 2 TranscodeState_TRANSCODE_STATE_FAILED TranscodeState = 3 )
func (TranscodeState) Descriptor ¶
func (TranscodeState) Descriptor() protoreflect.EnumDescriptor
func (TranscodeState) Enum ¶
func (x TranscodeState) Enum() *TranscodeState
func (TranscodeState) Number ¶
func (x TranscodeState) Number() protoreflect.EnumNumber
func (TranscodeState) String ¶
func (x TranscodeState) String() string
func (TranscodeState) Type ¶
func (TranscodeState) Type() protoreflect.EnumType
Source Files
¶
- tcserver.pb.go
Click to show internal directories.
Click to hide internal directories.