Documentation
¶
Index ¶
- Variables
- type AccountsResponse
- func (x *AccountsResponse) GetAccounts() []*GetBalanceResponse
- func (*AccountsResponse) ProtoMessage()
- func (x *AccountsResponse) ProtoReflect() protoreflect.Message
- func (x *AccountsResponse) Reset()
- func (x *AccountsResponse) SetAccounts(v []*GetBalanceResponse)
- func (x *AccountsResponse) String() string
- type AccountsResponse_builder
- type GetBalanceRequest
- func (x *GetBalanceRequest) ClearCurrency()
- func (x *GetBalanceRequest) GetCurrency() string
- func (x *GetBalanceRequest) HasCurrency() bool
- func (*GetBalanceRequest) ProtoMessage()
- func (x *GetBalanceRequest) ProtoReflect() protoreflect.Message
- func (x *GetBalanceRequest) Reset()
- func (x *GetBalanceRequest) SetCurrency(v string)
- func (x *GetBalanceRequest) String() string
- type GetBalanceRequest_builder
- type GetBalanceResponse
- func (x *GetBalanceResponse) GetBalance() uint32
- func (x *GetBalanceResponse) GetCurrency() string
- func (x *GetBalanceResponse) GetNumber() string
- func (*GetBalanceResponse) ProtoMessage()
- func (x *GetBalanceResponse) ProtoReflect() protoreflect.Message
- func (x *GetBalanceResponse) Reset()
- func (x *GetBalanceResponse) SetBalance(v uint32)
- func (x *GetBalanceResponse) SetCurrency(v string)
- func (x *GetBalanceResponse) SetNumber(v string)
- func (x *GetBalanceResponse) String() string
- type GetBalanceResponse_builder
- type MoneyRequest
- func (x *MoneyRequest) ClearExtra()
- func (x *MoneyRequest) ClearFee()
- func (x *MoneyRequest) ClearReason()
- func (x *MoneyRequest) ClearReference()
- func (x *MoneyRequest) GetAmount() uint32
- func (x *MoneyRequest) GetExtra() string
- func (x *MoneyRequest) GetFee() uint32
- func (x *MoneyRequest) GetIdempotencyKey() string
- func (x *MoneyRequest) GetReason() string
- func (x *MoneyRequest) GetReference() string
- func (x *MoneyRequest) HasExtra() bool
- func (x *MoneyRequest) HasFee() bool
- func (x *MoneyRequest) HasReason() bool
- func (x *MoneyRequest) HasReference() bool
- func (*MoneyRequest) ProtoMessage()
- func (x *MoneyRequest) ProtoReflect() protoreflect.Message
- func (x *MoneyRequest) Reset()
- func (x *MoneyRequest) SetAmount(v uint32)
- func (x *MoneyRequest) SetExtra(v string)
- func (x *MoneyRequest) SetFee(v uint32)
- func (x *MoneyRequest) SetIdempotencyKey(v string)
- func (x *MoneyRequest) SetReason(v string)
- func (x *MoneyRequest) SetReference(v string)
- func (x *MoneyRequest) String() string
- type MoneyRequest_builder
- type MoneyResponse
- func (x *MoneyResponse) ClearAccount()
- func (x *MoneyResponse) GetAccount() *GetBalanceResponse
- func (x *MoneyResponse) GetAmount() uint32
- func (x *MoneyResponse) GetId() string
- func (x *MoneyResponse) GetReference() string
- func (x *MoneyResponse) GetStatus() string
- func (x *MoneyResponse) HasAccount() bool
- func (*MoneyResponse) ProtoMessage()
- func (x *MoneyResponse) ProtoReflect() protoreflect.Message
- func (x *MoneyResponse) Reset()
- func (x *MoneyResponse) SetAccount(v *GetBalanceResponse)
- func (x *MoneyResponse) SetAmount(v uint32)
- func (x *MoneyResponse) SetId(v string)
- func (x *MoneyResponse) SetReference(v string)
- func (x *MoneyResponse) SetStatus(v string)
- func (x *MoneyResponse) String() string
- type MoneyResponse_builder
Constants ¶
This section is empty.
Variables ¶
var File_linq_money_accounts_v1_accounts_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type AccountsResponse ¶
type AccountsResponse struct {
// Returns list of accounts, limited by user access
// For the game request only LinQ and this game accounts will be returned
Accounts []*GetBalanceResponse `protobuf:"bytes,1,rep,name=accounts,proto3" json:"accounts,omitempty"`
// contains filtered or unexported fields
}
List of active assets accounts for the current user
func (*AccountsResponse) GetAccounts ¶
func (x *AccountsResponse) GetAccounts() []*GetBalanceResponse
func (*AccountsResponse) ProtoMessage ¶
func (*AccountsResponse) ProtoMessage()
func (*AccountsResponse) ProtoReflect ¶
func (x *AccountsResponse) ProtoReflect() protoreflect.Message
func (*AccountsResponse) Reset ¶
func (x *AccountsResponse) Reset()
func (*AccountsResponse) SetAccounts ¶
func (x *AccountsResponse) SetAccounts(v []*GetBalanceResponse)
func (*AccountsResponse) String ¶
func (x *AccountsResponse) String() string
type AccountsResponse_builder ¶
type AccountsResponse_builder struct {
// Returns list of accounts, limited by user access
// For the game request only LinQ and this game accounts will be returned
Accounts []*GetBalanceResponse
// contains filtered or unexported fields
}
func (AccountsResponse_builder) Build ¶
func (b0 AccountsResponse_builder) Build() *AccountsResponse
type GetBalanceRequest ¶
type GetBalanceRequest struct {
// Internal currency code
// If not specified, by default it returns balance for LNQ currency
Currency *string `protobuf:"bytes,1,opt,name=currency,proto3,oneof" json:"currency,omitempty"`
// contains filtered or unexported fields
}
Requests information about current user balance
func (*GetBalanceRequest) ClearCurrency ¶
func (x *GetBalanceRequest) ClearCurrency()
func (*GetBalanceRequest) GetCurrency ¶
func (x *GetBalanceRequest) GetCurrency() string
func (*GetBalanceRequest) HasCurrency ¶
func (x *GetBalanceRequest) HasCurrency() bool
func (*GetBalanceRequest) ProtoMessage ¶
func (*GetBalanceRequest) ProtoMessage()
func (*GetBalanceRequest) ProtoReflect ¶
func (x *GetBalanceRequest) ProtoReflect() protoreflect.Message
func (*GetBalanceRequest) Reset ¶
func (x *GetBalanceRequest) Reset()
func (*GetBalanceRequest) SetCurrency ¶
func (x *GetBalanceRequest) SetCurrency(v string)
func (*GetBalanceRequest) String ¶
func (x *GetBalanceRequest) String() string
type GetBalanceRequest_builder ¶
type GetBalanceRequest_builder struct {
// Internal currency code
// If not specified, by default it returns balance for LNQ currency
Currency *string
// contains filtered or unexported fields
}
func (GetBalanceRequest_builder) Build ¶
func (b0 GetBalanceRequest_builder) Build() *GetBalanceRequest
type GetBalanceResponse ¶
type GetBalanceResponse struct {
// number of internal account
Number string `protobuf:"bytes,1,opt,name=number,proto3" json:"number,omitempty"`
// Internal currency 3-letters code
// LNQ for wallet balance, for example
Currency string `protobuf:"bytes,2,opt,name=currency,proto3" json:"currency,omitempty"`
// Current balance of the user in coins
// It means, that real balance should be devided by 100
// before displaying to the user
Balance uint32 `protobuf:"varint,3,opt,name=balance,proto3" json:"balance,omitempty"`
// contains filtered or unexported fields
}
Returns detailed information about user balance on the requested account
func (*GetBalanceResponse) GetBalance ¶
func (x *GetBalanceResponse) GetBalance() uint32
func (*GetBalanceResponse) GetCurrency ¶
func (x *GetBalanceResponse) GetCurrency() string
func (*GetBalanceResponse) GetNumber ¶
func (x *GetBalanceResponse) GetNumber() string
func (*GetBalanceResponse) ProtoMessage ¶
func (*GetBalanceResponse) ProtoMessage()
func (*GetBalanceResponse) ProtoReflect ¶
func (x *GetBalanceResponse) ProtoReflect() protoreflect.Message
func (*GetBalanceResponse) Reset ¶
func (x *GetBalanceResponse) Reset()
func (*GetBalanceResponse) SetBalance ¶
func (x *GetBalanceResponse) SetBalance(v uint32)
func (*GetBalanceResponse) SetCurrency ¶
func (x *GetBalanceResponse) SetCurrency(v string)
func (*GetBalanceResponse) SetNumber ¶
func (x *GetBalanceResponse) SetNumber(v string)
func (*GetBalanceResponse) String ¶
func (x *GetBalanceResponse) String() string
type GetBalanceResponse_builder ¶
type GetBalanceResponse_builder struct {
// number of internal account
Number string
// Internal currency 3-letters code
// LNQ for wallet balance, for example
Currency string
// Current balance of the user in coins
// It means, that real balance should be devided by 100
// before displaying to the user
Balance uint32
// contains filtered or unexported fields
}
func (GetBalanceResponse_builder) Build ¶
func (b0 GetBalanceResponse_builder) Build() *GetBalanceResponse
type MoneyRequest ¶
type MoneyRequest struct {
// Unique key for idempotency
IdempotencyKey string `protobuf:"bytes,1,opt,name=idempotency_key,json=idempotencyKey,proto3" json:"idempotency_key,omitempty"`
// Amount of money to take or give without a fee
Amount uint32 `protobuf:"varint,2,opt,name=amount,proto3" json:"amount,omitempty"`
// Fee value if applicable
Fee *uint32 `protobuf:"varint,3,opt,name=fee,proto3,oneof" json:"fee,omitempty"`
// Some string data to describe money transaction
// e.g. Entry fee for super tournament
Reason *string `protobuf:"bytes,4,opt,name=reason,proto3,oneof" json:"reason,omitempty"`
// Some JSON string for correlation data
// e.g. {"tournament_id":123}
Extra *string `protobuf:"bytes,5,opt,name=extra,proto3,oneof" json:"extra,omitempty"`
// Reference data that will be placed into the order
Reference *string `protobuf:"bytes,6,opt,name=reference,proto3,oneof" json:"reference,omitempty"`
// contains filtered or unexported fields
}
Amount of money to deposit/withdrawal
func (*MoneyRequest) ClearExtra ¶
func (x *MoneyRequest) ClearExtra()
func (*MoneyRequest) ClearFee ¶
func (x *MoneyRequest) ClearFee()
func (*MoneyRequest) ClearReason ¶
func (x *MoneyRequest) ClearReason()
func (*MoneyRequest) ClearReference ¶
func (x *MoneyRequest) ClearReference()
func (*MoneyRequest) GetAmount ¶
func (x *MoneyRequest) GetAmount() uint32
func (*MoneyRequest) GetExtra ¶
func (x *MoneyRequest) GetExtra() string
func (*MoneyRequest) GetFee ¶
func (x *MoneyRequest) GetFee() uint32
func (*MoneyRequest) GetIdempotencyKey ¶
func (x *MoneyRequest) GetIdempotencyKey() string
func (*MoneyRequest) GetReason ¶
func (x *MoneyRequest) GetReason() string
func (*MoneyRequest) GetReference ¶
func (x *MoneyRequest) GetReference() string
func (*MoneyRequest) HasExtra ¶
func (x *MoneyRequest) HasExtra() bool
func (*MoneyRequest) HasFee ¶
func (x *MoneyRequest) HasFee() bool
func (*MoneyRequest) HasReason ¶
func (x *MoneyRequest) HasReason() bool
func (*MoneyRequest) HasReference ¶
func (x *MoneyRequest) HasReference() bool
func (*MoneyRequest) ProtoMessage ¶
func (*MoneyRequest) ProtoMessage()
func (*MoneyRequest) ProtoReflect ¶
func (x *MoneyRequest) ProtoReflect() protoreflect.Message
func (*MoneyRequest) Reset ¶
func (x *MoneyRequest) Reset()
func (*MoneyRequest) SetAmount ¶
func (x *MoneyRequest) SetAmount(v uint32)
func (*MoneyRequest) SetExtra ¶
func (x *MoneyRequest) SetExtra(v string)
func (*MoneyRequest) SetFee ¶
func (x *MoneyRequest) SetFee(v uint32)
func (*MoneyRequest) SetIdempotencyKey ¶
func (x *MoneyRequest) SetIdempotencyKey(v string)
func (*MoneyRequest) SetReason ¶
func (x *MoneyRequest) SetReason(v string)
func (*MoneyRequest) SetReference ¶
func (x *MoneyRequest) SetReference(v string)
func (*MoneyRequest) String ¶
func (x *MoneyRequest) String() string
type MoneyRequest_builder ¶
type MoneyRequest_builder struct {
// Unique key for idempotency
IdempotencyKey string
// Amount of money to take or give without a fee
Amount uint32
// Fee value if applicable
Fee *uint32
// Some string data to describe money transaction
// e.g. Entry fee for super tournament
Reason *string
// Some JSON string for correlation data
// e.g. {"tournament_id":123}
Extra *string
// Reference data that will be placed into the order
Reference *string
// contains filtered or unexported fields
}
func (MoneyRequest_builder) Build ¶
func (b0 MoneyRequest_builder) Build() *MoneyRequest
type MoneyResponse ¶
type MoneyResponse struct {
// Order identifier, uuid string
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
// Order status
// Possible values:
// - completed: order completed and its status may be used
// as final for futher decisions
Status string `protobuf:"bytes,2,opt,name=status,proto3" json:"status,omitempty"`
// Amount in the order
Amount uint32 `protobuf:"varint,3,opt,name=amount,proto3" json:"amount,omitempty"`
// see GetBalanceResponse
Account *GetBalanceResponse `protobuf:"bytes,4,opt,name=account,proto3" json:"account,omitempty"`
// Reference data that was placed into the order during the creation
Reference string `protobuf:"bytes,5,opt,name=reference,proto3" json:"reference,omitempty"`
// contains filtered or unexported fields
}
Returns order id and account data
func (*MoneyResponse) ClearAccount ¶
func (x *MoneyResponse) ClearAccount()
func (*MoneyResponse) GetAccount ¶
func (x *MoneyResponse) GetAccount() *GetBalanceResponse
func (*MoneyResponse) GetAmount ¶
func (x *MoneyResponse) GetAmount() uint32
func (*MoneyResponse) GetId ¶
func (x *MoneyResponse) GetId() string
func (*MoneyResponse) GetReference ¶
func (x *MoneyResponse) GetReference() string
func (*MoneyResponse) GetStatus ¶
func (x *MoneyResponse) GetStatus() string
func (*MoneyResponse) HasAccount ¶
func (x *MoneyResponse) HasAccount() bool
func (*MoneyResponse) ProtoMessage ¶
func (*MoneyResponse) ProtoMessage()
func (*MoneyResponse) ProtoReflect ¶
func (x *MoneyResponse) ProtoReflect() protoreflect.Message
func (*MoneyResponse) Reset ¶
func (x *MoneyResponse) Reset()
func (*MoneyResponse) SetAccount ¶
func (x *MoneyResponse) SetAccount(v *GetBalanceResponse)
func (*MoneyResponse) SetAmount ¶
func (x *MoneyResponse) SetAmount(v uint32)
func (*MoneyResponse) SetId ¶
func (x *MoneyResponse) SetId(v string)
func (*MoneyResponse) SetReference ¶
func (x *MoneyResponse) SetReference(v string)
func (*MoneyResponse) SetStatus ¶
func (x *MoneyResponse) SetStatus(v string)
func (*MoneyResponse) String ¶
func (x *MoneyResponse) String() string
type MoneyResponse_builder ¶
type MoneyResponse_builder struct {
// Order identifier, uuid string
Id string
// Order status
// Possible values:
// - completed: order completed and its status may be used
// as final for futher decisions
Status string
// Amount in the order
Amount uint32
// see GetBalanceResponse
Account *GetBalanceResponse
// Reference data that was placed into the order during the creation
Reference string
// contains filtered or unexported fields
}
func (MoneyResponse_builder) Build ¶
func (b0 MoneyResponse_builder) Build() *MoneyResponse
Source Files
¶
- accounts.pb.go
Click to show internal directories.
Click to hide internal directories.