Documentation
¶
Index ¶
- Variables
- type HistoryEntry
- func (x *HistoryEntry) ClearTransferDestinationApp()
- func (x *HistoryEntry) ClearTransferSourceApp()
- func (x *HistoryEntry) ClearUpdatedAt()
- func (x *HistoryEntry) GetAmount() uint32
- func (x *HistoryEntry) GetApp() string
- func (x *HistoryEntry) GetAppLabel() string
- func (x *HistoryEntry) GetCurrency() string
- func (x *HistoryEntry) GetId() string
- func (x *HistoryEntry) GetIsIncoming() bool
- func (x *HistoryEntry) GetReference() string
- func (x *HistoryEntry) GetStatus() string
- func (x *HistoryEntry) GetTransferDestinationApp() string
- func (x *HistoryEntry) GetTransferSourceApp() string
- func (x *HistoryEntry) GetType() string
- func (x *HistoryEntry) GetUpdatedAt() *timestamppb.Timestamp
- func (x *HistoryEntry) HasTransferDestinationApp() bool
- func (x *HistoryEntry) HasTransferSourceApp() bool
- func (x *HistoryEntry) HasUpdatedAt() bool
- func (*HistoryEntry) ProtoMessage()
- func (x *HistoryEntry) ProtoReflect() protoreflect.Message
- func (x *HistoryEntry) Reset()
- func (x *HistoryEntry) SetAmount(v uint32)
- func (x *HistoryEntry) SetApp(v string)
- func (x *HistoryEntry) SetAppLabel(v string)
- func (x *HistoryEntry) SetCurrency(v string)
- func (x *HistoryEntry) SetId(v string)
- func (x *HistoryEntry) SetIsIncoming(v bool)
- func (x *HistoryEntry) SetReference(v string)
- func (x *HistoryEntry) SetStatus(v string)
- func (x *HistoryEntry) SetTransferDestinationApp(v string)
- func (x *HistoryEntry) SetTransferSourceApp(v string)
- func (x *HistoryEntry) SetType(v string)
- func (x *HistoryEntry) SetUpdatedAt(v *timestamppb.Timestamp)
- func (x *HistoryEntry) String() string
- type HistoryEntry_builder
- type OrdersHistory
- func (x *OrdersHistory) ClearNextId()
- func (x *OrdersHistory) GetEntries() []*HistoryEntry
- func (x *OrdersHistory) GetNextId() string
- func (x *OrdersHistory) GetTotal() uint32
- func (x *OrdersHistory) HasNextId() bool
- func (*OrdersHistory) ProtoMessage()
- func (x *OrdersHistory) ProtoReflect() protoreflect.Message
- func (x *OrdersHistory) Reset()
- func (x *OrdersHistory) SetEntries(v []*HistoryEntry)
- func (x *OrdersHistory) SetNextId(v string)
- func (x *OrdersHistory) SetTotal(v uint32)
- func (x *OrdersHistory) String() string
- type OrdersHistoryRequest
- func (x *OrdersHistoryRequest) ClearEndDate()
- func (x *OrdersHistoryRequest) ClearLimit()
- func (x *OrdersHistoryRequest) ClearNextId()
- func (x *OrdersHistoryRequest) ClearStartDate()
- func (x *OrdersHistoryRequest) ClearStatus()
- func (x *OrdersHistoryRequest) ClearType()
- func (x *OrdersHistoryRequest) GetAssets() []string
- func (x *OrdersHistoryRequest) GetEndDate() *timestamppb.Timestamp
- func (x *OrdersHistoryRequest) GetLimit() uint32
- func (x *OrdersHistoryRequest) GetNextId() string
- func (x *OrdersHistoryRequest) GetStartDate() *timestamppb.Timestamp
- func (x *OrdersHistoryRequest) GetStatus() string
- func (x *OrdersHistoryRequest) GetStatuses() []string
- func (x *OrdersHistoryRequest) GetType() string
- func (x *OrdersHistoryRequest) GetTypes() []string
- func (x *OrdersHistoryRequest) HasEndDate() bool
- func (x *OrdersHistoryRequest) HasLimit() bool
- func (x *OrdersHistoryRequest) HasNextId() bool
- func (x *OrdersHistoryRequest) HasStartDate() bool
- func (x *OrdersHistoryRequest) HasStatus() bool
- func (x *OrdersHistoryRequest) HasType() bool
- func (*OrdersHistoryRequest) ProtoMessage()
- func (x *OrdersHistoryRequest) ProtoReflect() protoreflect.Message
- func (x *OrdersHistoryRequest) Reset()
- func (x *OrdersHistoryRequest) SetAssets(v []string)
- func (x *OrdersHistoryRequest) SetEndDate(v *timestamppb.Timestamp)
- func (x *OrdersHistoryRequest) SetLimit(v uint32)
- func (x *OrdersHistoryRequest) SetNextId(v string)
- func (x *OrdersHistoryRequest) SetStartDate(v *timestamppb.Timestamp)
- func (x *OrdersHistoryRequest) SetStatus(v string)
- func (x *OrdersHistoryRequest) SetStatuses(v []string)
- func (x *OrdersHistoryRequest) SetType(v string)
- func (x *OrdersHistoryRequest) SetTypes(v []string)
- func (x *OrdersHistoryRequest) String() string
- type OrdersHistoryRequest_builder
- type OrdersHistory_builder
Constants ¶
This section is empty.
Variables ¶
var File_linq_money_operations_v1_operations_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type HistoryEntry ¶
type HistoryEntry struct {
// Order identifier, uuid string
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
// Order status
// Possible values:
// - pending: just created order
// - awaiting: checkout linq created, it is awaiting payment from user
// - processing: order handling by services to validate payment internally
// - accepted: order was paid and it transaction was applied
// - declined: order was declined by payment provides due any kind of error
// - completed: order completed and its status may be used as final
// - cancelled: order was canceled by user
// - terminated: order was canceled by system
Status string `protobuf:"bytes,2,opt,name=status,proto3" json:"status,omitempty"`
// order type: charge, entry_fee, prize, transfer
Type string `protobuf:"bytes,3,opt,name=type,proto3" json:"type,omitempty"`
// Amount in the order
Amount uint32 `protobuf:"varint,4,opt,name=amount,proto3" json:"amount,omitempty"`
// Order last status change
UpdatedAt *timestamppb.Timestamp `protobuf:"bytes,5,opt,name=updated_at,json=updatedAt,proto3" json:"updated_at,omitempty"`
// Order app id
AppLabel string `protobuf:"bytes,6,opt,name=app_label,json=appLabel,proto3" json:"app_label,omitempty"`
// Order app name
App string `protobuf:"bytes,7,opt,name=app,proto3" json:"app,omitempty"`
// Order money in or out
// charge, prize = true
// entry_fee = false
// transfer:
// - to current app = true
// - from current app = false
IsIncoming bool `protobuf:"varint,8,opt,name=is_incoming,json=isIncoming,proto3" json:"is_incoming,omitempty"`
// Name of the app from which transfer occurs
TransferSourceApp *string `protobuf:"bytes,9,opt,name=transfer_source_app,json=transferSourceApp,proto3,oneof" json:"transfer_source_app,omitempty"`
// Name of the app to which transfer occurs
TransferDestinationApp *string `` /* 136-byte string literal not displayed */
// Real money currency
Currency string `protobuf:"bytes,11,opt,name=currency,proto3" json:"currency,omitempty"`
// Reference data that was placed into the order during the creation
// In current version it will return idempotency_key if reference is not set
Reference string `protobuf:"bytes,12,opt,name=reference,proto3" json:"reference,omitempty"`
// contains filtered or unexported fields
}
func (*HistoryEntry) ClearTransferDestinationApp ¶
func (x *HistoryEntry) ClearTransferDestinationApp()
func (*HistoryEntry) ClearTransferSourceApp ¶
func (x *HistoryEntry) ClearTransferSourceApp()
func (*HistoryEntry) ClearUpdatedAt ¶
func (x *HistoryEntry) ClearUpdatedAt()
func (*HistoryEntry) GetAmount ¶
func (x *HistoryEntry) GetAmount() uint32
func (*HistoryEntry) GetApp ¶
func (x *HistoryEntry) GetApp() string
func (*HistoryEntry) GetAppLabel ¶
func (x *HistoryEntry) GetAppLabel() string
func (*HistoryEntry) GetCurrency ¶
func (x *HistoryEntry) GetCurrency() string
func (*HistoryEntry) GetId ¶
func (x *HistoryEntry) GetId() string
func (*HistoryEntry) GetIsIncoming ¶
func (x *HistoryEntry) GetIsIncoming() bool
func (*HistoryEntry) GetReference ¶
func (x *HistoryEntry) GetReference() string
func (*HistoryEntry) GetStatus ¶
func (x *HistoryEntry) GetStatus() string
func (*HistoryEntry) GetTransferDestinationApp ¶
func (x *HistoryEntry) GetTransferDestinationApp() string
func (*HistoryEntry) GetTransferSourceApp ¶
func (x *HistoryEntry) GetTransferSourceApp() string
func (*HistoryEntry) GetType ¶
func (x *HistoryEntry) GetType() string
func (*HistoryEntry) GetUpdatedAt ¶
func (x *HistoryEntry) GetUpdatedAt() *timestamppb.Timestamp
func (*HistoryEntry) HasTransferDestinationApp ¶
func (x *HistoryEntry) HasTransferDestinationApp() bool
func (*HistoryEntry) HasTransferSourceApp ¶
func (x *HistoryEntry) HasTransferSourceApp() bool
func (*HistoryEntry) HasUpdatedAt ¶
func (x *HistoryEntry) HasUpdatedAt() bool
func (*HistoryEntry) ProtoMessage ¶
func (*HistoryEntry) ProtoMessage()
func (*HistoryEntry) ProtoReflect ¶
func (x *HistoryEntry) ProtoReflect() protoreflect.Message
func (*HistoryEntry) Reset ¶
func (x *HistoryEntry) Reset()
func (*HistoryEntry) SetAmount ¶
func (x *HistoryEntry) SetAmount(v uint32)
func (*HistoryEntry) SetApp ¶
func (x *HistoryEntry) SetApp(v string)
func (*HistoryEntry) SetAppLabel ¶
func (x *HistoryEntry) SetAppLabel(v string)
func (*HistoryEntry) SetCurrency ¶
func (x *HistoryEntry) SetCurrency(v string)
func (*HistoryEntry) SetId ¶
func (x *HistoryEntry) SetId(v string)
func (*HistoryEntry) SetIsIncoming ¶
func (x *HistoryEntry) SetIsIncoming(v bool)
func (*HistoryEntry) SetReference ¶
func (x *HistoryEntry) SetReference(v string)
func (*HistoryEntry) SetStatus ¶
func (x *HistoryEntry) SetStatus(v string)
func (*HistoryEntry) SetTransferDestinationApp ¶
func (x *HistoryEntry) SetTransferDestinationApp(v string)
func (*HistoryEntry) SetTransferSourceApp ¶
func (x *HistoryEntry) SetTransferSourceApp(v string)
func (*HistoryEntry) SetType ¶
func (x *HistoryEntry) SetType(v string)
func (*HistoryEntry) SetUpdatedAt ¶
func (x *HistoryEntry) SetUpdatedAt(v *timestamppb.Timestamp)
func (*HistoryEntry) String ¶
func (x *HistoryEntry) String() string
type HistoryEntry_builder ¶
type HistoryEntry_builder struct {
// Order identifier, uuid string
Id string
// Order status
// Possible values:
// - pending: just created order
// - awaiting: checkout linq created, it is awaiting payment from user
// - processing: order handling by services to validate payment internally
// - accepted: order was paid and it transaction was applied
// - declined: order was declined by payment provides due any kind of error
// - completed: order completed and its status may be used as final
// - cancelled: order was canceled by user
// - terminated: order was canceled by system
Status string
// order type: charge, entry_fee, prize, transfer
Type string
// Amount in the order
Amount uint32
// Order last status change
UpdatedAt *timestamppb.Timestamp
// Order app id
AppLabel string
// Order app name
App string
// Order money in or out
// charge, prize = true
// entry_fee = false
// transfer:
// - to current app = true
// - from current app = false
IsIncoming bool
// Name of the app from which transfer occurs
TransferSourceApp *string
// Name of the app to which transfer occurs
TransferDestinationApp *string
// Real money currency
Currency string
// Reference data that was placed into the order during the creation
// In current version it will return idempotency_key if reference is not set
Reference string
// contains filtered or unexported fields
}
func (HistoryEntry_builder) Build ¶
func (b0 HistoryEntry_builder) Build() *HistoryEntry
type OrdersHistory ¶
type OrdersHistory struct {
Entries []*HistoryEntry `protobuf:"bytes,1,rep,name=entries,proto3" json:"entries,omitempty"`
// Total number of orders
Total uint32 `protobuf:"varint,2,opt,name=total,proto3" json:"total,omitempty"`
// Pagination, next order id if present
NextId *string `protobuf:"bytes,3,opt,name=next_id,json=nextId,proto3,oneof" json:"next_id,omitempty"`
// contains filtered or unexported fields
}
func (*OrdersHistory) ClearNextId ¶
func (x *OrdersHistory) ClearNextId()
func (*OrdersHistory) GetEntries ¶
func (x *OrdersHistory) GetEntries() []*HistoryEntry
func (*OrdersHistory) GetNextId ¶
func (x *OrdersHistory) GetNextId() string
func (*OrdersHistory) GetTotal ¶
func (x *OrdersHistory) GetTotal() uint32
func (*OrdersHistory) HasNextId ¶
func (x *OrdersHistory) HasNextId() bool
func (*OrdersHistory) ProtoMessage ¶
func (*OrdersHistory) ProtoMessage()
func (*OrdersHistory) ProtoReflect ¶
func (x *OrdersHistory) ProtoReflect() protoreflect.Message
func (*OrdersHistory) Reset ¶
func (x *OrdersHistory) Reset()
func (*OrdersHistory) SetEntries ¶
func (x *OrdersHistory) SetEntries(v []*HistoryEntry)
func (*OrdersHistory) SetNextId ¶
func (x *OrdersHistory) SetNextId(v string)
func (*OrdersHistory) SetTotal ¶
func (x *OrdersHistory) SetTotal(v uint32)
func (*OrdersHistory) String ¶
func (x *OrdersHistory) String() string
type OrdersHistoryRequest ¶
type OrdersHistoryRequest struct {
// order type: charge, entry_fee, prize, transfer
Type *string `protobuf:"bytes,2,opt,name=type,proto3,oneof" json:"type,omitempty"`
Types []string `protobuf:"bytes,9,rep,name=types,proto3" json:"types,omitempty"`
// Order status
// Possible values:
// - pending: just created order
// - awaiting: checkout linq created, it is awaiting payment from user
// - processing: order handling by services to validate payment internally
// - accepted: order was paid and it transaction was applied
// - declined: order was declined by payment provides due any kind of error
// - completed: order completed and its status may be used as final
// - cancelled: order was canceled by user
// - terminated: order was canceled by system
Status *string `protobuf:"bytes,3,opt,name=status,proto3,oneof" json:"status,omitempty"`
Statuses []string `protobuf:"bytes,10,rep,name=statuses,proto3" json:"statuses,omitempty"`
// Orders after start_date
StartDate *timestamppb.Timestamp `protobuf:"bytes,4,opt,name=start_date,json=startDate,proto3,oneof" json:"start_date,omitempty"`
// Orders before end_date
EndDate *timestamppb.Timestamp `protobuf:"bytes,5,opt,name=end_date,json=endDate,proto3,oneof" json:"end_date,omitempty"`
// Response items limit
Limit *uint32 `protobuf:"varint,6,opt,name=limit,proto3,oneof" json:"limit,omitempty"`
// Pagination, start from next_id returned in previous response
NextId *string `protobuf:"bytes,7,opt,name=next_id,json=nextId,proto3,oneof" json:"next_id,omitempty"`
// do not use, has no effect
Assets []string `protobuf:"bytes,8,rep,name=assets,proto3" json:"assets,omitempty"`
// contains filtered or unexported fields
}
func (*OrdersHistoryRequest) ClearEndDate ¶
func (x *OrdersHistoryRequest) ClearEndDate()
func (*OrdersHistoryRequest) ClearLimit ¶
func (x *OrdersHistoryRequest) ClearLimit()
func (*OrdersHistoryRequest) ClearNextId ¶
func (x *OrdersHistoryRequest) ClearNextId()
func (*OrdersHistoryRequest) ClearStartDate ¶
func (x *OrdersHistoryRequest) ClearStartDate()
func (*OrdersHistoryRequest) ClearStatus ¶
func (x *OrdersHistoryRequest) ClearStatus()
func (*OrdersHistoryRequest) ClearType ¶
func (x *OrdersHistoryRequest) ClearType()
func (*OrdersHistoryRequest) GetAssets ¶
func (x *OrdersHistoryRequest) GetAssets() []string
func (*OrdersHistoryRequest) GetEndDate ¶
func (x *OrdersHistoryRequest) GetEndDate() *timestamppb.Timestamp
func (*OrdersHistoryRequest) GetLimit ¶
func (x *OrdersHistoryRequest) GetLimit() uint32
func (*OrdersHistoryRequest) GetNextId ¶
func (x *OrdersHistoryRequest) GetNextId() string
func (*OrdersHistoryRequest) GetStartDate ¶
func (x *OrdersHistoryRequest) GetStartDate() *timestamppb.Timestamp
func (*OrdersHistoryRequest) GetStatus ¶
func (x *OrdersHistoryRequest) GetStatus() string
func (*OrdersHistoryRequest) GetStatuses ¶
func (x *OrdersHistoryRequest) GetStatuses() []string
func (*OrdersHistoryRequest) GetType ¶
func (x *OrdersHistoryRequest) GetType() string
func (*OrdersHistoryRequest) GetTypes ¶
func (x *OrdersHistoryRequest) GetTypes() []string
func (*OrdersHistoryRequest) HasEndDate ¶
func (x *OrdersHistoryRequest) HasEndDate() bool
func (*OrdersHistoryRequest) HasLimit ¶
func (x *OrdersHistoryRequest) HasLimit() bool
func (*OrdersHistoryRequest) HasNextId ¶
func (x *OrdersHistoryRequest) HasNextId() bool
func (*OrdersHistoryRequest) HasStartDate ¶
func (x *OrdersHistoryRequest) HasStartDate() bool
func (*OrdersHistoryRequest) HasStatus ¶
func (x *OrdersHistoryRequest) HasStatus() bool
func (*OrdersHistoryRequest) HasType ¶
func (x *OrdersHistoryRequest) HasType() bool
func (*OrdersHistoryRequest) ProtoMessage ¶
func (*OrdersHistoryRequest) ProtoMessage()
func (*OrdersHistoryRequest) ProtoReflect ¶
func (x *OrdersHistoryRequest) ProtoReflect() protoreflect.Message
func (*OrdersHistoryRequest) Reset ¶
func (x *OrdersHistoryRequest) Reset()
func (*OrdersHistoryRequest) SetAssets ¶
func (x *OrdersHistoryRequest) SetAssets(v []string)
func (*OrdersHistoryRequest) SetEndDate ¶
func (x *OrdersHistoryRequest) SetEndDate(v *timestamppb.Timestamp)
func (*OrdersHistoryRequest) SetLimit ¶
func (x *OrdersHistoryRequest) SetLimit(v uint32)
func (*OrdersHistoryRequest) SetNextId ¶
func (x *OrdersHistoryRequest) SetNextId(v string)
func (*OrdersHistoryRequest) SetStartDate ¶
func (x *OrdersHistoryRequest) SetStartDate(v *timestamppb.Timestamp)
func (*OrdersHistoryRequest) SetStatus ¶
func (x *OrdersHistoryRequest) SetStatus(v string)
func (*OrdersHistoryRequest) SetStatuses ¶
func (x *OrdersHistoryRequest) SetStatuses(v []string)
func (*OrdersHistoryRequest) SetType ¶
func (x *OrdersHistoryRequest) SetType(v string)
func (*OrdersHistoryRequest) SetTypes ¶
func (x *OrdersHistoryRequest) SetTypes(v []string)
func (*OrdersHistoryRequest) String ¶
func (x *OrdersHistoryRequest) String() string
type OrdersHistoryRequest_builder ¶
type OrdersHistoryRequest_builder struct {
// order type: charge, entry_fee, prize, transfer
Type *string
Types []string
// Order status
// Possible values:
// - pending: just created order
// - awaiting: checkout linq created, it is awaiting payment from user
// - processing: order handling by services to validate payment internally
// - accepted: order was paid and it transaction was applied
// - declined: order was declined by payment provides due any kind of error
// - completed: order completed and its status may be used as final
// - cancelled: order was canceled by user
// - terminated: order was canceled by system
Status *string
Statuses []string
// Orders after start_date
StartDate *timestamppb.Timestamp
// Orders before end_date
EndDate *timestamppb.Timestamp
// Response items limit
Limit *uint32
// Pagination, start from next_id returned in previous response
NextId *string
// do not use, has no effect
Assets []string
// contains filtered or unexported fields
}
func (OrdersHistoryRequest_builder) Build ¶
func (b0 OrdersHistoryRequest_builder) Build() *OrdersHistoryRequest
type OrdersHistory_builder ¶
type OrdersHistory_builder struct {
Entries []*HistoryEntry
// Total number of orders
Total uint32
// Pagination, next order id if present
NextId *string
// contains filtered or unexported fields
}
func (OrdersHistory_builder) Build ¶
func (b0 OrdersHistory_builder) Build() *OrdersHistory
Source Files
¶
- operations.pb.go
Click to show internal directories.
Click to hide internal directories.