Documentation
¶
Index ¶
- Constants
- func NewStreamingServiceHandler(svc StreamingServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
- type StreamingServiceClient
- type StreamingServiceHandler
- type UnimplementedStreamingServiceHandler
- func (UnimplementedStreamingServiceHandler) CloseStream(context.Context, *connect.Request[v1.CloseStreamRequest]) (*connect.Response[v1.CloseStreamResponse], error)
- func (UnimplementedStreamingServiceHandler) CreateStream(context.Context, *connect.Request[v1.CreateStreamRequest]) (*connect.Response[v1.CreateStreamResponse], error)
- func (UnimplementedStreamingServiceHandler) SendStreamPacket(context.Context, *connect.ClientStream[v1.SendStreamPacketRequest]) (*connect.Response[v1.SendStreamPacketResponse], error)
Constants ¶
const ( // StreamingServiceCreateStreamProcedure is the fully-qualified name of the StreamingService's // CreateStream RPC. StreamingServiceCreateStreamProcedure = "/plume.api.streaming.v1.StreamingService/CreateStream" // StreamingServiceCloseStreamProcedure is the fully-qualified name of the StreamingService's // CloseStream RPC. StreamingServiceCloseStreamProcedure = "/plume.api.streaming.v1.StreamingService/CloseStream" // StreamingServiceSendStreamPacketProcedure is the fully-qualified name of the StreamingService's // SendStreamPacket RPC. StreamingServiceSendStreamPacketProcedure = "/plume.api.streaming.v1.StreamingService/SendStreamPacket" )
These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.
Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.
const (
// StreamingServiceName is the fully-qualified name of the StreamingService service.
StreamingServiceName = "plume.api.streaming.v1.StreamingService"
)
Variables ¶
This section is empty.
Functions ¶
func NewStreamingServiceHandler ¶
func NewStreamingServiceHandler(svc StreamingServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
NewStreamingServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.
By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.
Types ¶
type StreamingServiceClient ¶
type StreamingServiceClient interface {
CreateStream(context.Context, *connect.Request[v1.CreateStreamRequest]) (*connect.Response[v1.CreateStreamResponse], error)
CloseStream(context.Context, *connect.Request[v1.CloseStreamRequest]) (*connect.Response[v1.CloseStreamResponse], error)
SendStreamPacket(context.Context) *connect.ClientStreamForClient[v1.SendStreamPacketRequest, v1.SendStreamPacketResponse]
}
StreamingServiceClient is a client for the plume.api.streaming.v1.StreamingService service.
func NewStreamingServiceClient ¶
func NewStreamingServiceClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) StreamingServiceClient
NewStreamingServiceClient constructs a client for the plume.api.streaming.v1.StreamingService service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.
The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).
type StreamingServiceHandler ¶
type StreamingServiceHandler interface {
CreateStream(context.Context, *connect.Request[v1.CreateStreamRequest]) (*connect.Response[v1.CreateStreamResponse], error)
CloseStream(context.Context, *connect.Request[v1.CloseStreamRequest]) (*connect.Response[v1.CloseStreamResponse], error)
SendStreamPacket(context.Context, *connect.ClientStream[v1.SendStreamPacketRequest]) (*connect.Response[v1.SendStreamPacketResponse], error)
}
StreamingServiceHandler is an implementation of the plume.api.streaming.v1.StreamingService service.
type UnimplementedStreamingServiceHandler ¶
type UnimplementedStreamingServiceHandler struct{}
UnimplementedStreamingServiceHandler returns CodeUnimplemented from all methods.
func (UnimplementedStreamingServiceHandler) CloseStream ¶
func (UnimplementedStreamingServiceHandler) CloseStream(context.Context, *connect.Request[v1.CloseStreamRequest]) (*connect.Response[v1.CloseStreamResponse], error)
func (UnimplementedStreamingServiceHandler) CreateStream ¶
func (UnimplementedStreamingServiceHandler) CreateStream(context.Context, *connect.Request[v1.CreateStreamRequest]) (*connect.Response[v1.CreateStreamResponse], error)
func (UnimplementedStreamingServiceHandler) SendStreamPacket ¶
func (UnimplementedStreamingServiceHandler) SendStreamPacket(context.Context, *connect.ClientStream[v1.SendStreamPacketRequest]) (*connect.Response[v1.SendStreamPacketResponse], error)
Source Files
¶
- streaming.connect.go