Documentation
¶
Index ¶
- Constants
- func NewLibraryServiceHandler(svc LibraryServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
- type LibraryServiceClient
- type LibraryServiceHandler
- type UnimplementedLibraryServiceHandler
- func (UnimplementedLibraryServiceHandler) AddDirectoryToLibrary(context.Context, *connect.Request[v1.AddDirectoryToLibraryRequest]) (*connect.Response[v1.AddDirectoryToLibraryResponse], error)
- func (UnimplementedLibraryServiceHandler) CreateLibrary(context.Context, *connect.Request[v1.CreateLibraryRequest]) (*connect.Response[v1.CreateLibraryResponse], error)
- func (UnimplementedLibraryServiceHandler) GetLibrariesForUser(context.Context, *connect.Request[v1.GetLibrariesForUserRequest]) (*connect.Response[v1.GetLibrariesForUserResponse], error)
- func (UnimplementedLibraryServiceHandler) GetLibrary(context.Context, *connect.Request[v1.GetLibraryRequest]) (*connect.Response[v1.GetLibraryResponse], error)
- func (UnimplementedLibraryServiceHandler) ListLibraries(context.Context, *connect.Request[v1.ListLibrariesRequest]) (*connect.Response[v1.ListLibrariesResponse], error)
Constants ¶
const ( // LibraryServiceGetLibraryProcedure is the fully-qualified name of the LibraryService's GetLibrary // RPC. LibraryServiceGetLibraryProcedure = "/listenup.library.v1.LibraryService/GetLibrary" // LibraryServiceListLibrariesProcedure is the fully-qualified name of the LibraryService's // ListLibraries RPC. LibraryServiceListLibrariesProcedure = "/listenup.library.v1.LibraryService/ListLibraries" // LibraryServiceCreateLibraryProcedure is the fully-qualified name of the LibraryService's // CreateLibrary RPC. LibraryServiceCreateLibraryProcedure = "/listenup.library.v1.LibraryService/CreateLibrary" // LibraryServiceGetLibrariesForUserProcedure is the fully-qualified name of the LibraryService's // GetLibrariesForUser RPC. LibraryServiceGetLibrariesForUserProcedure = "/listenup.library.v1.LibraryService/GetLibrariesForUser" // LibraryServiceAddDirectoryToLibraryProcedure is the fully-qualified name of the LibraryService's // AddDirectoryToLibrary RPC. LibraryServiceAddDirectoryToLibraryProcedure = "/listenup.library.v1.LibraryService/AddDirectoryToLibrary" )
These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.
Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.
const (
// LibraryServiceName is the fully-qualified name of the LibraryService service.
LibraryServiceName = "listenup.library.v1.LibraryService"
)
Variables ¶
This section is empty.
Functions ¶
func NewLibraryServiceHandler ¶
func NewLibraryServiceHandler(svc LibraryServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
NewLibraryServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.
By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.
Types ¶
type LibraryServiceClient ¶
type LibraryServiceClient interface {
// Retrieves a single library by ID
GetLibrary(context.Context, *connect.Request[v1.GetLibraryRequest]) (*connect.Response[v1.GetLibraryResponse], error)
// Returns a paginated list of libraries
ListLibraries(context.Context, *connect.Request[v1.ListLibrariesRequest]) (*connect.Response[v1.ListLibrariesResponse], error)
// Creates a library
CreateLibrary(context.Context, *connect.Request[v1.CreateLibraryRequest]) (*connect.Response[v1.CreateLibraryResponse], error)
// Returns all libraries for a given User
GetLibrariesForUser(context.Context, *connect.Request[v1.GetLibrariesForUserRequest]) (*connect.Response[v1.GetLibrariesForUserResponse], error)
// Adds a directory to a library
AddDirectoryToLibrary(context.Context, *connect.Request[v1.AddDirectoryToLibraryRequest]) (*connect.Response[v1.AddDirectoryToLibraryResponse], error)
}
LibraryServiceClient is a client for the listenup.library.v1.LibraryService service.
func NewLibraryServiceClient ¶
func NewLibraryServiceClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) LibraryServiceClient
NewLibraryServiceClient constructs a client for the listenup.library.v1.LibraryService service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.
The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).
type LibraryServiceHandler ¶
type LibraryServiceHandler interface {
// Retrieves a single library by ID
GetLibrary(context.Context, *connect.Request[v1.GetLibraryRequest]) (*connect.Response[v1.GetLibraryResponse], error)
// Returns a paginated list of libraries
ListLibraries(context.Context, *connect.Request[v1.ListLibrariesRequest]) (*connect.Response[v1.ListLibrariesResponse], error)
// Creates a library
CreateLibrary(context.Context, *connect.Request[v1.CreateLibraryRequest]) (*connect.Response[v1.CreateLibraryResponse], error)
// Returns all libraries for a given User
GetLibrariesForUser(context.Context, *connect.Request[v1.GetLibrariesForUserRequest]) (*connect.Response[v1.GetLibrariesForUserResponse], error)
// Adds a directory to a library
AddDirectoryToLibrary(context.Context, *connect.Request[v1.AddDirectoryToLibraryRequest]) (*connect.Response[v1.AddDirectoryToLibraryResponse], error)
}
LibraryServiceHandler is an implementation of the listenup.library.v1.LibraryService service.
type UnimplementedLibraryServiceHandler ¶
type UnimplementedLibraryServiceHandler struct{}
UnimplementedLibraryServiceHandler returns CodeUnimplemented from all methods.
func (UnimplementedLibraryServiceHandler) AddDirectoryToLibrary ¶
func (UnimplementedLibraryServiceHandler) AddDirectoryToLibrary(context.Context, *connect.Request[v1.AddDirectoryToLibraryRequest]) (*connect.Response[v1.AddDirectoryToLibraryResponse], error)
func (UnimplementedLibraryServiceHandler) CreateLibrary ¶
func (UnimplementedLibraryServiceHandler) CreateLibrary(context.Context, *connect.Request[v1.CreateLibraryRequest]) (*connect.Response[v1.CreateLibraryResponse], error)
func (UnimplementedLibraryServiceHandler) GetLibrariesForUser ¶
func (UnimplementedLibraryServiceHandler) GetLibrariesForUser(context.Context, *connect.Request[v1.GetLibrariesForUserRequest]) (*connect.Response[v1.GetLibrariesForUserResponse], error)
func (UnimplementedLibraryServiceHandler) GetLibrary ¶
func (UnimplementedLibraryServiceHandler) GetLibrary(context.Context, *connect.Request[v1.GetLibraryRequest]) (*connect.Response[v1.GetLibraryResponse], error)
func (UnimplementedLibraryServiceHandler) ListLibraries ¶
func (UnimplementedLibraryServiceHandler) ListLibraries(context.Context, *connect.Request[v1.ListLibrariesRequest]) (*connect.Response[v1.ListLibrariesResponse], error)
Source Files
¶
- library.connect.go