Documentation
¶
Index ¶
- Variables
- type Folder
- func (x *Folder) GetLevel() int32
- func (x *Folder) GetName() string
- func (x *Folder) GetPath() string
- func (x *Folder) GetSubFolders() []*Folder
- func (*Folder) ProtoMessage()
- func (x *Folder) ProtoReflect() protoreflect.Message
- func (x *Folder) Reset()
- func (x *Folder) SetLevel(v int32)
- func (x *Folder) SetName(v string)
- func (x *Folder) SetPath(v string)
- func (x *Folder) SetSubFolders(v []*Folder)
- func (x *Folder) String() string
- type Folder_builder
- type GetFolderRequest
- func (x *GetFolderRequest) ClearLevel()
- func (x *GetFolderRequest) ClearPath()
- func (x *GetFolderRequest) GetLevel() int32
- func (x *GetFolderRequest) GetPath() string
- func (x *GetFolderRequest) HasLevel() bool
- func (x *GetFolderRequest) HasPath() bool
- func (*GetFolderRequest) ProtoMessage()
- func (x *GetFolderRequest) ProtoReflect() protoreflect.Message
- func (x *GetFolderRequest) Reset()
- func (x *GetFolderRequest) SetLevel(v int32)
- func (x *GetFolderRequest) SetPath(v string)
- func (x *GetFolderRequest) String() string
- type GetFolderRequest_builder
- type GetFolderResponse
- type GetFolderResponse_builder
Constants ¶
This section is empty.
Variables ¶
var File_listenup_folder_v1_folder_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Folder ¶
type Folder struct {
// The name of the folder
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// The path to the folder
Path string `protobuf:"bytes,2,opt,name=path,proto3" json:"path,omitempty"`
// The depth of the folder on the filesystem
Level int32 `protobuf:"varint,3,opt,name=level,proto3" json:"level,omitempty"`
// The list of subfolders inside the directory
SubFolders []*Folder `protobuf:"bytes,50,rep,name=sub_folders,json=subFolders,proto3" json:"sub_folders,omitempty"`
// contains filtered or unexported fields
}
Represents a folder on the Host Machine. This type differs from listenup.v1.Directory by providing folders as a navigatable tree for the UI. This allows the user to navigate and select the folders to include in a library which we then convert to a directory
func (*Folder) ProtoReflect ¶
func (x *Folder) ProtoReflect() protoreflect.Message
type Folder_builder ¶
type Folder_builder struct {
// The name of the folder
Name string
// The path to the folder
Path string
// The depth of the folder on the filesystem
Level int32
// The list of subfolders inside the directory
SubFolders []*Folder
// contains filtered or unexported fields
}
func (Folder_builder) Build ¶
func (b0 Folder_builder) Build() *Folder
type GetFolderRequest ¶
type GetFolderRequest struct {
// The path to the directory
Path *string `protobuf:"bytes,1,opt,name=path,proto3,oneof" json:"path,omitempty"`
// The depth of the folder on the filesystem
Level *int32 `protobuf:"varint,2,opt,name=level,proto3,oneof" json:"level,omitempty"`
// contains filtered or unexported fields
}
func (*GetFolderRequest) ClearLevel ¶
func (x *GetFolderRequest) ClearLevel()
func (*GetFolderRequest) ClearPath ¶
func (x *GetFolderRequest) ClearPath()
func (*GetFolderRequest) GetLevel ¶
func (x *GetFolderRequest) GetLevel() int32
func (*GetFolderRequest) GetPath ¶
func (x *GetFolderRequest) GetPath() string
func (*GetFolderRequest) HasLevel ¶
func (x *GetFolderRequest) HasLevel() bool
func (*GetFolderRequest) HasPath ¶
func (x *GetFolderRequest) HasPath() bool
func (*GetFolderRequest) ProtoMessage ¶
func (*GetFolderRequest) ProtoMessage()
func (*GetFolderRequest) ProtoReflect ¶
func (x *GetFolderRequest) ProtoReflect() protoreflect.Message
func (*GetFolderRequest) Reset ¶
func (x *GetFolderRequest) Reset()
func (*GetFolderRequest) SetLevel ¶
func (x *GetFolderRequest) SetLevel(v int32)
func (*GetFolderRequest) SetPath ¶
func (x *GetFolderRequest) SetPath(v string)
func (*GetFolderRequest) String ¶
func (x *GetFolderRequest) String() string
type GetFolderRequest_builder ¶
type GetFolderRequest_builder struct {
// The path to the directory
Path *string
// The depth of the folder on the filesystem
Level *int32
// contains filtered or unexported fields
}
func (GetFolderRequest_builder) Build ¶
func (b0 GetFolderRequest_builder) Build() *GetFolderRequest
type GetFolderResponse ¶
type GetFolderResponse struct {
// The list of folders in a directory
Folders []*Folder `protobuf:"bytes,1,rep,name=folders,proto3" json:"folders,omitempty"`
// contains filtered or unexported fields
}
func (*GetFolderResponse) GetFolders ¶
func (x *GetFolderResponse) GetFolders() []*Folder
func (*GetFolderResponse) ProtoMessage ¶
func (*GetFolderResponse) ProtoMessage()
func (*GetFolderResponse) ProtoReflect ¶
func (x *GetFolderResponse) ProtoReflect() protoreflect.Message
func (*GetFolderResponse) Reset ¶
func (x *GetFolderResponse) Reset()
func (*GetFolderResponse) SetFolders ¶
func (x *GetFolderResponse) SetFolders(v []*Folder)
func (*GetFolderResponse) String ¶
func (x *GetFolderResponse) String() string
type GetFolderResponse_builder ¶
type GetFolderResponse_builder struct {
// The list of folders in a directory
Folders []*Folder
// contains filtered or unexported fields
}
func (GetFolderResponse_builder) Build ¶
func (b0 GetFolderResponse_builder) Build() *GetFolderResponse
Source Files
¶
- folder.pb.go
Click to show internal directories.
Click to hide internal directories.