Documentation
¶
Index ¶
- Variables
- type AddDirectoryToLibraryRequest
- func (x *AddDirectoryToLibraryRequest) ClearDirectory()
- func (x *AddDirectoryToLibraryRequest) GetDirectory() *v1.Folder
- func (x *AddDirectoryToLibraryRequest) GetLibraryId() string
- func (x *AddDirectoryToLibraryRequest) HasDirectory() bool
- func (*AddDirectoryToLibraryRequest) ProtoMessage()
- func (x *AddDirectoryToLibraryRequest) ProtoReflect() protoreflect.Message
- func (x *AddDirectoryToLibraryRequest) Reset()
- func (x *AddDirectoryToLibraryRequest) SetDirectory(v *v1.Folder)
- func (x *AddDirectoryToLibraryRequest) SetLibraryId(v string)
- func (x *AddDirectoryToLibraryRequest) String() string
- type AddDirectoryToLibraryRequest_builder
- type AddDirectoryToLibraryResponse
- func (x *AddDirectoryToLibraryResponse) ClearDirectory()
- func (x *AddDirectoryToLibraryResponse) GetDirectory() *Directory
- func (x *AddDirectoryToLibraryResponse) HasDirectory() bool
- func (*AddDirectoryToLibraryResponse) ProtoMessage()
- func (x *AddDirectoryToLibraryResponse) ProtoReflect() protoreflect.Message
- func (x *AddDirectoryToLibraryResponse) Reset()
- func (x *AddDirectoryToLibraryResponse) SetDirectory(v *Directory)
- func (x *AddDirectoryToLibraryResponse) String() string
- type AddDirectoryToLibraryResponse_builder
- type CreateLibraryRequest
- func (x *CreateLibraryRequest) ClearSettings()
- func (x *CreateLibraryRequest) GetFolders() []*v1.Folder
- func (x *CreateLibraryRequest) GetName() string
- func (x *CreateLibraryRequest) GetSettings() *LibrarySettings
- func (x *CreateLibraryRequest) HasSettings() bool
- func (*CreateLibraryRequest) ProtoMessage()
- func (x *CreateLibraryRequest) ProtoReflect() protoreflect.Message
- func (x *CreateLibraryRequest) Reset()
- func (x *CreateLibraryRequest) SetFolders(v []*v1.Folder)
- func (x *CreateLibraryRequest) SetName(v string)
- func (x *CreateLibraryRequest) SetSettings(v *LibrarySettings)
- func (x *CreateLibraryRequest) String() string
- type CreateLibraryRequest_builder
- type CreateLibraryResponse
- func (x *CreateLibraryResponse) ClearLibrary()
- func (x *CreateLibraryResponse) GetLibrary() *Library
- func (x *CreateLibraryResponse) HasLibrary() bool
- func (*CreateLibraryResponse) ProtoMessage()
- func (x *CreateLibraryResponse) ProtoReflect() protoreflect.Message
- func (x *CreateLibraryResponse) Reset()
- func (x *CreateLibraryResponse) SetLibrary(v *Library)
- func (x *CreateLibraryResponse) String() string
- type CreateLibraryResponse_builder
- type Directory
- func (x *Directory) GetId() string
- func (x *Directory) GetName() string
- func (x *Directory) GetPath() string
- func (x *Directory) GetTotalBooks() int32
- func (*Directory) ProtoMessage()
- func (x *Directory) ProtoReflect() protoreflect.Message
- func (x *Directory) Reset()
- func (x *Directory) SetId(v string)
- func (x *Directory) SetName(v string)
- func (x *Directory) SetPath(v string)
- func (x *Directory) SetTotalBooks(v int32)
- func (x *Directory) String() string
- type Directory_builder
- type GetLibrariesForUserRequest
- func (x *GetLibrariesForUserRequest) GetUserId() string
- func (*GetLibrariesForUserRequest) ProtoMessage()
- func (x *GetLibrariesForUserRequest) ProtoReflect() protoreflect.Message
- func (x *GetLibrariesForUserRequest) Reset()
- func (x *GetLibrariesForUserRequest) SetUserId(v string)
- func (x *GetLibrariesForUserRequest) String() string
- type GetLibrariesForUserRequest_builder
- type GetLibrariesForUserResponse
- func (x *GetLibrariesForUserResponse) GetLibraries() []*Library
- func (*GetLibrariesForUserResponse) ProtoMessage()
- func (x *GetLibrariesForUserResponse) ProtoReflect() protoreflect.Message
- func (x *GetLibrariesForUserResponse) Reset()
- func (x *GetLibrariesForUserResponse) SetLibraries(v []*Library)
- func (x *GetLibrariesForUserResponse) String() string
- type GetLibrariesForUserResponse_builder
- type GetLibraryRequest
- type GetLibraryRequest_builder
- type GetLibraryResponse
- func (x *GetLibraryResponse) ClearLibrary()
- func (x *GetLibraryResponse) GetLibrary() *Library
- func (x *GetLibraryResponse) HasLibrary() bool
- func (*GetLibraryResponse) ProtoMessage()
- func (x *GetLibraryResponse) ProtoReflect() protoreflect.Message
- func (x *GetLibraryResponse) Reset()
- func (x *GetLibraryResponse) SetLibrary(v *Library)
- func (x *GetLibraryResponse) String() string
- type GetLibraryResponse_builder
- type Library
- func (x *Library) ClearCreatedAt()
- func (x *Library) ClearSettings()
- func (x *Library) GetCreatedAt() *timestamppb.Timestamp
- func (x *Library) GetDirectories() []*Directory
- func (x *Library) GetId() string
- func (x *Library) GetName() string
- func (x *Library) GetSettings() *LibrarySettings
- func (x *Library) GetTotalBooks() int32
- func (x *Library) HasCreatedAt() bool
- func (x *Library) HasSettings() bool
- func (*Library) ProtoMessage()
- func (x *Library) ProtoReflect() protoreflect.Message
- func (x *Library) Reset()
- func (x *Library) SetCreatedAt(v *timestamppb.Timestamp)
- func (x *Library) SetDirectories(v []*Directory)
- func (x *Library) SetId(v string)
- func (x *Library) SetName(v string)
- func (x *Library) SetSettings(v *LibrarySettings)
- func (x *Library) SetTotalBooks(v int32)
- func (x *Library) String() string
- type LibrarySettings
- type LibrarySettings_builder
- type Library_builder
- type ListLibrariesRequest
- func (x *ListLibrariesRequest) GetPageIndex() string
- func (x *ListLibrariesRequest) GetPageSize() int32
- func (*ListLibrariesRequest) ProtoMessage()
- func (x *ListLibrariesRequest) ProtoReflect() protoreflect.Message
- func (x *ListLibrariesRequest) Reset()
- func (x *ListLibrariesRequest) SetPageIndex(v string)
- func (x *ListLibrariesRequest) SetPageSize(v int32)
- func (x *ListLibrariesRequest) String() string
- type ListLibrariesRequest_builder
- type ListLibrariesResponse
- func (x *ListLibrariesResponse) GetLibraries() []*Library
- func (*ListLibrariesResponse) ProtoMessage()
- func (x *ListLibrariesResponse) ProtoReflect() protoreflect.Message
- func (x *ListLibrariesResponse) Reset()
- func (x *ListLibrariesResponse) SetLibraries(v []*Library)
- func (x *ListLibrariesResponse) String() string
- type ListLibrariesResponse_builder
Constants ¶
This section is empty.
Variables ¶
var File_listenup_library_v1_library_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type AddDirectoryToLibraryRequest ¶
type AddDirectoryToLibraryRequest struct {
LibraryId string `protobuf:"bytes,1,opt,name=library_id,json=libraryId,proto3" json:"library_id,omitempty"`
Directory *v1.Folder `protobuf:"bytes,2,opt,name=directory,proto3" json:"directory,omitempty"`
// contains filtered or unexported fields
}
func (*AddDirectoryToLibraryRequest) ClearDirectory ¶
func (x *AddDirectoryToLibraryRequest) ClearDirectory()
func (*AddDirectoryToLibraryRequest) GetDirectory ¶
func (x *AddDirectoryToLibraryRequest) GetDirectory() *v1.Folder
func (*AddDirectoryToLibraryRequest) GetLibraryId ¶
func (x *AddDirectoryToLibraryRequest) GetLibraryId() string
func (*AddDirectoryToLibraryRequest) HasDirectory ¶
func (x *AddDirectoryToLibraryRequest) HasDirectory() bool
func (*AddDirectoryToLibraryRequest) ProtoMessage ¶
func (*AddDirectoryToLibraryRequest) ProtoMessage()
func (*AddDirectoryToLibraryRequest) ProtoReflect ¶
func (x *AddDirectoryToLibraryRequest) ProtoReflect() protoreflect.Message
func (*AddDirectoryToLibraryRequest) Reset ¶
func (x *AddDirectoryToLibraryRequest) Reset()
func (*AddDirectoryToLibraryRequest) SetDirectory ¶
func (x *AddDirectoryToLibraryRequest) SetDirectory(v *v1.Folder)
func (*AddDirectoryToLibraryRequest) SetLibraryId ¶
func (x *AddDirectoryToLibraryRequest) SetLibraryId(v string)
func (*AddDirectoryToLibraryRequest) String ¶
func (x *AddDirectoryToLibraryRequest) String() string
type AddDirectoryToLibraryRequest_builder ¶
type AddDirectoryToLibraryRequest_builder struct {
LibraryId string
Directory *v1.Folder
// contains filtered or unexported fields
}
func (AddDirectoryToLibraryRequest_builder) Build ¶
func (b0 AddDirectoryToLibraryRequest_builder) Build() *AddDirectoryToLibraryRequest
type AddDirectoryToLibraryResponse ¶
type AddDirectoryToLibraryResponse struct {
Directory *Directory `protobuf:"bytes,1,opt,name=directory,proto3" json:"directory,omitempty"`
// contains filtered or unexported fields
}
func (*AddDirectoryToLibraryResponse) ClearDirectory ¶
func (x *AddDirectoryToLibraryResponse) ClearDirectory()
func (*AddDirectoryToLibraryResponse) GetDirectory ¶
func (x *AddDirectoryToLibraryResponse) GetDirectory() *Directory
func (*AddDirectoryToLibraryResponse) HasDirectory ¶
func (x *AddDirectoryToLibraryResponse) HasDirectory() bool
func (*AddDirectoryToLibraryResponse) ProtoMessage ¶
func (*AddDirectoryToLibraryResponse) ProtoMessage()
func (*AddDirectoryToLibraryResponse) ProtoReflect ¶
func (x *AddDirectoryToLibraryResponse) ProtoReflect() protoreflect.Message
func (*AddDirectoryToLibraryResponse) Reset ¶
func (x *AddDirectoryToLibraryResponse) Reset()
func (*AddDirectoryToLibraryResponse) SetDirectory ¶
func (x *AddDirectoryToLibraryResponse) SetDirectory(v *Directory)
func (*AddDirectoryToLibraryResponse) String ¶
func (x *AddDirectoryToLibraryResponse) String() string
type AddDirectoryToLibraryResponse_builder ¶
type AddDirectoryToLibraryResponse_builder struct {
Directory *Directory
// contains filtered or unexported fields
}
func (AddDirectoryToLibraryResponse_builder) Build ¶
func (b0 AddDirectoryToLibraryResponse_builder) Build() *AddDirectoryToLibraryResponse
type CreateLibraryRequest ¶
type CreateLibraryRequest struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
Folders []*v1.Folder `protobuf:"bytes,2,rep,name=folders,proto3" json:"folders,omitempty"`
Settings *LibrarySettings `protobuf:"bytes,3,opt,name=settings,proto3" json:"settings,omitempty"`
// contains filtered or unexported fields
}
func (*CreateLibraryRequest) ClearSettings ¶
func (x *CreateLibraryRequest) ClearSettings()
func (*CreateLibraryRequest) GetFolders ¶
func (x *CreateLibraryRequest) GetFolders() []*v1.Folder
func (*CreateLibraryRequest) GetName ¶
func (x *CreateLibraryRequest) GetName() string
func (*CreateLibraryRequest) GetSettings ¶
func (x *CreateLibraryRequest) GetSettings() *LibrarySettings
func (*CreateLibraryRequest) HasSettings ¶
func (x *CreateLibraryRequest) HasSettings() bool
func (*CreateLibraryRequest) ProtoMessage ¶
func (*CreateLibraryRequest) ProtoMessage()
func (*CreateLibraryRequest) ProtoReflect ¶
func (x *CreateLibraryRequest) ProtoReflect() protoreflect.Message
func (*CreateLibraryRequest) Reset ¶
func (x *CreateLibraryRequest) Reset()
func (*CreateLibraryRequest) SetFolders ¶
func (x *CreateLibraryRequest) SetFolders(v []*v1.Folder)
func (*CreateLibraryRequest) SetName ¶
func (x *CreateLibraryRequest) SetName(v string)
func (*CreateLibraryRequest) SetSettings ¶
func (x *CreateLibraryRequest) SetSettings(v *LibrarySettings)
func (*CreateLibraryRequest) String ¶
func (x *CreateLibraryRequest) String() string
type CreateLibraryRequest_builder ¶
type CreateLibraryRequest_builder struct {
Name string
Folders []*v1.Folder
Settings *LibrarySettings
// contains filtered or unexported fields
}
func (CreateLibraryRequest_builder) Build ¶
func (b0 CreateLibraryRequest_builder) Build() *CreateLibraryRequest
type CreateLibraryResponse ¶
type CreateLibraryResponse struct {
Library *Library `protobuf:"bytes,1,opt,name=library,proto3" json:"library,omitempty"`
// contains filtered or unexported fields
}
func (*CreateLibraryResponse) ClearLibrary ¶
func (x *CreateLibraryResponse) ClearLibrary()
func (*CreateLibraryResponse) GetLibrary ¶
func (x *CreateLibraryResponse) GetLibrary() *Library
func (*CreateLibraryResponse) HasLibrary ¶
func (x *CreateLibraryResponse) HasLibrary() bool
func (*CreateLibraryResponse) ProtoMessage ¶
func (*CreateLibraryResponse) ProtoMessage()
func (*CreateLibraryResponse) ProtoReflect ¶
func (x *CreateLibraryResponse) ProtoReflect() protoreflect.Message
func (*CreateLibraryResponse) Reset ¶
func (x *CreateLibraryResponse) Reset()
func (*CreateLibraryResponse) SetLibrary ¶
func (x *CreateLibraryResponse) SetLibrary(v *Library)
func (*CreateLibraryResponse) String ¶
func (x *CreateLibraryResponse) String() string
type CreateLibraryResponse_builder ¶
type CreateLibraryResponse_builder struct {
Library *Library
// contains filtered or unexported fields
}
func (CreateLibraryResponse_builder) Build ¶
func (b0 CreateLibraryResponse_builder) Build() *CreateLibraryResponse
type Directory ¶
type Directory struct {
// The directories ID
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
// The name of the directory or folder
Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
// The path on the host machine to the directory
Path string `protobuf:"bytes,3,opt,name=path,proto3" json:"path,omitempty"`
// The total number of books in a directory
TotalBooks int32 `protobuf:"varint,4,opt,name=total_books,json=totalBooks,proto3" json:"total_books,omitempty"`
// contains filtered or unexported fields
}
A directory represents a physical directory on the host machine's hard drive. This is used for scanning books.
func (*Directory) ProtoReflect ¶
func (x *Directory) ProtoReflect() protoreflect.Message
type Directory_builder ¶
type Directory_builder struct {
// The directories ID
Id string
// The name of the directory or folder
Name string
// The path on the host machine to the directory
Path string
// The total number of books in a directory
TotalBooks int32
// contains filtered or unexported fields
}
func (Directory_builder) Build ¶
func (b0 Directory_builder) Build() *Directory
type GetLibrariesForUserRequest ¶
type GetLibrariesForUserRequest struct {
// The users ID
UserId string `protobuf:"bytes,1,opt,name=user_id,json=userId,proto3" json:"user_id,omitempty"`
// contains filtered or unexported fields
}
func (*GetLibrariesForUserRequest) GetUserId ¶
func (x *GetLibrariesForUserRequest) GetUserId() string
func (*GetLibrariesForUserRequest) ProtoMessage ¶
func (*GetLibrariesForUserRequest) ProtoMessage()
func (*GetLibrariesForUserRequest) ProtoReflect ¶
func (x *GetLibrariesForUserRequest) ProtoReflect() protoreflect.Message
func (*GetLibrariesForUserRequest) Reset ¶
func (x *GetLibrariesForUserRequest) Reset()
func (*GetLibrariesForUserRequest) SetUserId ¶
func (x *GetLibrariesForUserRequest) SetUserId(v string)
func (*GetLibrariesForUserRequest) String ¶
func (x *GetLibrariesForUserRequest) String() string
type GetLibrariesForUserRequest_builder ¶
type GetLibrariesForUserRequest_builder struct {
// The users ID
UserId string
// contains filtered or unexported fields
}
func (GetLibrariesForUserRequest_builder) Build ¶
func (b0 GetLibrariesForUserRequest_builder) Build() *GetLibrariesForUserRequest
type GetLibrariesForUserResponse ¶
type GetLibrariesForUserResponse struct {
// The users libraries
Libraries []*Library `protobuf:"bytes,1,rep,name=libraries,proto3" json:"libraries,omitempty"`
// contains filtered or unexported fields
}
func (*GetLibrariesForUserResponse) GetLibraries ¶
func (x *GetLibrariesForUserResponse) GetLibraries() []*Library
func (*GetLibrariesForUserResponse) ProtoMessage ¶
func (*GetLibrariesForUserResponse) ProtoMessage()
func (*GetLibrariesForUserResponse) ProtoReflect ¶
func (x *GetLibrariesForUserResponse) ProtoReflect() protoreflect.Message
func (*GetLibrariesForUserResponse) Reset ¶
func (x *GetLibrariesForUserResponse) Reset()
func (*GetLibrariesForUserResponse) SetLibraries ¶
func (x *GetLibrariesForUserResponse) SetLibraries(v []*Library)
func (*GetLibrariesForUserResponse) String ¶
func (x *GetLibrariesForUserResponse) String() string
type GetLibrariesForUserResponse_builder ¶
type GetLibrariesForUserResponse_builder struct {
// The users libraries
Libraries []*Library
// contains filtered or unexported fields
}
func (GetLibrariesForUserResponse_builder) Build ¶
func (b0 GetLibrariesForUserResponse_builder) Build() *GetLibrariesForUserResponse
type GetLibraryRequest ¶
type GetLibraryRequest struct {
// The libraries ID
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
// contains filtered or unexported fields
}
func (*GetLibraryRequest) GetId ¶
func (x *GetLibraryRequest) GetId() string
func (*GetLibraryRequest) ProtoMessage ¶
func (*GetLibraryRequest) ProtoMessage()
func (*GetLibraryRequest) ProtoReflect ¶
func (x *GetLibraryRequest) ProtoReflect() protoreflect.Message
func (*GetLibraryRequest) Reset ¶
func (x *GetLibraryRequest) Reset()
func (*GetLibraryRequest) SetId ¶
func (x *GetLibraryRequest) SetId(v string)
func (*GetLibraryRequest) String ¶
func (x *GetLibraryRequest) String() string
type GetLibraryRequest_builder ¶
type GetLibraryRequest_builder struct {
// The libraries ID
Id string
// contains filtered or unexported fields
}
func (GetLibraryRequest_builder) Build ¶
func (b0 GetLibraryRequest_builder) Build() *GetLibraryRequest
type GetLibraryResponse ¶
type GetLibraryResponse struct {
Library *Library `protobuf:"bytes,2,opt,name=library,proto3" json:"library,omitempty"`
// contains filtered or unexported fields
}
func (*GetLibraryResponse) ClearLibrary ¶
func (x *GetLibraryResponse) ClearLibrary()
func (*GetLibraryResponse) GetLibrary ¶
func (x *GetLibraryResponse) GetLibrary() *Library
func (*GetLibraryResponse) HasLibrary ¶
func (x *GetLibraryResponse) HasLibrary() bool
func (*GetLibraryResponse) ProtoMessage ¶
func (*GetLibraryResponse) ProtoMessage()
func (*GetLibraryResponse) ProtoReflect ¶
func (x *GetLibraryResponse) ProtoReflect() protoreflect.Message
func (*GetLibraryResponse) Reset ¶
func (x *GetLibraryResponse) Reset()
func (*GetLibraryResponse) SetLibrary ¶
func (x *GetLibraryResponse) SetLibrary(v *Library)
func (*GetLibraryResponse) String ¶
func (x *GetLibraryResponse) String() string
type GetLibraryResponse_builder ¶
type GetLibraryResponse_builder struct {
Library *Library
// contains filtered or unexported fields
}
func (GetLibraryResponse_builder) Build ¶
func (b0 GetLibraryResponse_builder) Build() *GetLibraryResponse
type Library ¶
type Library struct {
// The library's id
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
// The libraries name
Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
// The total number of books in a library
TotalBooks int32 `protobuf:"varint,3,opt,name=total_books,json=totalBooks,proto3" json:"total_books,omitempty"`
// The directories that make up a library
Directories []*Directory `protobuf:"bytes,4,rep,name=directories,proto3" json:"directories,omitempty"`
// When was the library created
CreatedAt *timestamppb.Timestamp `protobuf:"bytes,5,opt,name=created_at,json=createdAt,proto3" json:"created_at,omitempty"`
// Settings for the library
Settings *LibrarySettings `protobuf:"bytes,6,opt,name=settings,proto3" json:"settings,omitempty"`
// contains filtered or unexported fields
}
A library is a collection of directories and associated settings and users.
func (*Library) GetCreatedAt ¶
func (x *Library) GetCreatedAt() *timestamppb.Timestamp
func (*Library) GetSettings ¶
func (x *Library) GetSettings() *LibrarySettings
func (*Library) ProtoReflect ¶
func (x *Library) ProtoReflect() protoreflect.Message
func (*Library) SetCreatedAt ¶
func (x *Library) SetCreatedAt(v *timestamppb.Timestamp)
func (*Library) SetSettings ¶
func (x *Library) SetSettings(v *LibrarySettings)
type LibrarySettings ¶
type LibrarySettings struct {
// contains filtered or unexported fields
}
A list of settings for the library, we can expand on this over time.
func (*LibrarySettings) ProtoMessage ¶
func (*LibrarySettings) ProtoMessage()
func (*LibrarySettings) ProtoReflect ¶
func (x *LibrarySettings) ProtoReflect() protoreflect.Message
func (*LibrarySettings) Reset ¶
func (x *LibrarySettings) Reset()
func (*LibrarySettings) String ¶
func (x *LibrarySettings) String() string
type LibrarySettings_builder ¶
type LibrarySettings_builder struct {
// contains filtered or unexported fields
}
func (LibrarySettings_builder) Build ¶
func (b0 LibrarySettings_builder) Build() *LibrarySettings
type Library_builder ¶
type Library_builder struct {
// The library's id
Id string
// The libraries name
Name string
// The total number of books in a library
TotalBooks int32
// The directories that make up a library
Directories []*Directory
// When was the library created
CreatedAt *timestamppb.Timestamp
// Settings for the library
Settings *LibrarySettings
// contains filtered or unexported fields
}
func (Library_builder) Build ¶
func (b0 Library_builder) Build() *Library
type ListLibrariesRequest ¶
type ListLibrariesRequest struct {
// The number of items to return per page
PageSize int32 `protobuf:"varint,1,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
// The index for the page
PageIndex string `protobuf:"bytes,2,opt,name=page_index,json=pageIndex,proto3" json:"page_index,omitempty"`
// contains filtered or unexported fields
}
func (*ListLibrariesRequest) GetPageIndex ¶
func (x *ListLibrariesRequest) GetPageIndex() string
func (*ListLibrariesRequest) GetPageSize ¶
func (x *ListLibrariesRequest) GetPageSize() int32
func (*ListLibrariesRequest) ProtoMessage ¶
func (*ListLibrariesRequest) ProtoMessage()
func (*ListLibrariesRequest) ProtoReflect ¶
func (x *ListLibrariesRequest) ProtoReflect() protoreflect.Message
func (*ListLibrariesRequest) Reset ¶
func (x *ListLibrariesRequest) Reset()
func (*ListLibrariesRequest) SetPageIndex ¶
func (x *ListLibrariesRequest) SetPageIndex(v string)
func (*ListLibrariesRequest) SetPageSize ¶
func (x *ListLibrariesRequest) SetPageSize(v int32)
func (*ListLibrariesRequest) String ¶
func (x *ListLibrariesRequest) String() string
type ListLibrariesRequest_builder ¶
type ListLibrariesRequest_builder struct {
// The number of items to return per page
PageSize int32
// The index for the page
PageIndex string
// contains filtered or unexported fields
}
func (ListLibrariesRequest_builder) Build ¶
func (b0 ListLibrariesRequest_builder) Build() *ListLibrariesRequest
type ListLibrariesResponse ¶
type ListLibrariesResponse struct {
// List of libraries
Libraries []*Library `protobuf:"bytes,1,rep,name=libraries,proto3" json:"libraries,omitempty"`
// contains filtered or unexported fields
}
func (*ListLibrariesResponse) GetLibraries ¶
func (x *ListLibrariesResponse) GetLibraries() []*Library
func (*ListLibrariesResponse) ProtoMessage ¶
func (*ListLibrariesResponse) ProtoMessage()
func (*ListLibrariesResponse) ProtoReflect ¶
func (x *ListLibrariesResponse) ProtoReflect() protoreflect.Message
func (*ListLibrariesResponse) Reset ¶
func (x *ListLibrariesResponse) Reset()
func (*ListLibrariesResponse) SetLibraries ¶
func (x *ListLibrariesResponse) SetLibraries(v []*Library)
func (*ListLibrariesResponse) String ¶
func (x *ListLibrariesResponse) String() string
type ListLibrariesResponse_builder ¶
type ListLibrariesResponse_builder struct {
// List of libraries
Libraries []*Library
// contains filtered or unexported fields
}
func (ListLibrariesResponse_builder) Build ¶
func (b0 ListLibrariesResponse_builder) Build() *ListLibrariesResponse
Source Files
¶
- library.pb.go
Click to show internal directories.
Click to hide internal directories.