Documentation
¶
Index ¶
Constants ¶
const (
PDFService_Generate_FullMethodName = "/pdfserv.v1.PDFService/Generate"
)
Variables ¶
var PDFService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "pdfserv.v1.PDFService", HandlerType: (*PDFServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "Generate", Handler: _PDFService_Generate_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "pdfserv/v1/service.proto", }
PDFService_ServiceDesc is the grpc.ServiceDesc for PDFService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterPDFServiceServer ¶
func RegisterPDFServiceServer(s grpc.ServiceRegistrar, srv PDFServiceServer)
Types ¶
type PDFServiceClient ¶
type PDFServiceClient interface {
// Generate PDF.
Generate(ctx context.Context, in *v1.GenerateRequest, opts ...grpc.CallOption) (*v1.GenerateResponse, error)
}
PDFServiceClient is the client API for PDFService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
PDF generation microservice.
func NewPDFServiceClient ¶
func NewPDFServiceClient(cc grpc.ClientConnInterface) PDFServiceClient
type PDFServiceServer ¶
type PDFServiceServer interface {
// Generate PDF.
Generate(context.Context, *v1.GenerateRequest) (*v1.GenerateResponse, error)
}
PDFServiceServer is the server API for PDFService service. All implementations should embed UnimplementedPDFServiceServer for forward compatibility.
PDF generation microservice.
type UnimplementedPDFServiceServer ¶
type UnimplementedPDFServiceServer struct{}
UnimplementedPDFServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedPDFServiceServer) Generate ¶
func (UnimplementedPDFServiceServer) Generate(context.Context, *v1.GenerateRequest) (*v1.GenerateResponse, error)
type UnsafePDFServiceServer ¶
type UnsafePDFServiceServer interface {
// contains filtered or unexported methods
}
UnsafePDFServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to PDFServiceServer will result in compilation errors.
Source Files
¶
- service_grpc.pb.go