Documentation
¶
Index ¶
- Variables
- type GetHealthCheckRequest
- func (x *GetHealthCheckRequest) GetHttpOnly() bool
- func (*GetHealthCheckRequest) ProtoMessage()
- func (x *GetHealthCheckRequest) ProtoReflect() protoreflect.Message
- func (x *GetHealthCheckRequest) Reset()
- func (x *GetHealthCheckRequest) SetHttpOnly(v bool)
- func (x *GetHealthCheckRequest) String() string
- type GetHealthCheckRequest_builder
- type GetHealthCheckResponse
- func (x *GetHealthCheckResponse) ClearException()
- func (x *GetHealthCheckResponse) GetException() *v1.Exception
- func (x *GetHealthCheckResponse) GetReports() []*HealthCheckReport
- func (x *GetHealthCheckResponse) HasException() bool
- func (*GetHealthCheckResponse) ProtoMessage()
- func (x *GetHealthCheckResponse) ProtoReflect() protoreflect.Message
- func (x *GetHealthCheckResponse) Reset()
- func (x *GetHealthCheckResponse) SetException(v *v1.Exception)
- func (x *GetHealthCheckResponse) SetReports(v []*HealthCheckReport)
- func (x *GetHealthCheckResponse) String() string
- type GetHealthCheckResponse_builder
- type HealthCheckReport
- func (x *HealthCheckReport) GetServiceName() string
- func (x *HealthCheckReport) GetServiceVersion() string
- func (x *HealthCheckReport) GetStatus() string
- func (x *HealthCheckReport) GetTimestamp() string
- func (*HealthCheckReport) ProtoMessage()
- func (x *HealthCheckReport) ProtoReflect() protoreflect.Message
- func (x *HealthCheckReport) Reset()
- func (x *HealthCheckReport) SetServiceName(v string)
- func (x *HealthCheckReport) SetServiceVersion(v string)
- func (x *HealthCheckReport) SetStatus(v string)
- func (x *HealthCheckReport) SetTimestamp(v string)
- func (x *HealthCheckReport) String() string
- type HealthCheckReport_builder
Constants ¶
This section is empty.
Variables ¶
var File_healthcheck_v1_healthcheck_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type GetHealthCheckRequest ¶
type GetHealthCheckRequest struct {
// Check only the http service
HttpOnly bool `protobuf:"varint,1,opt,name=http_only,json=httpOnly,proto3" json:"http_only,omitempty"`
// contains filtered or unexported fields
}
Get health status of services.
func (*GetHealthCheckRequest) GetHttpOnly ¶
func (x *GetHealthCheckRequest) GetHttpOnly() bool
func (*GetHealthCheckRequest) ProtoMessage ¶
func (*GetHealthCheckRequest) ProtoMessage()
func (*GetHealthCheckRequest) ProtoReflect ¶
func (x *GetHealthCheckRequest) ProtoReflect() protoreflect.Message
func (*GetHealthCheckRequest) Reset ¶
func (x *GetHealthCheckRequest) Reset()
func (*GetHealthCheckRequest) SetHttpOnly ¶
func (x *GetHealthCheckRequest) SetHttpOnly(v bool)
func (*GetHealthCheckRequest) String ¶
func (x *GetHealthCheckRequest) String() string
type GetHealthCheckRequest_builder ¶
type GetHealthCheckRequest_builder struct {
// Check only the http service
HttpOnly bool
// contains filtered or unexported fields
}
func (GetHealthCheckRequest_builder) Build ¶
func (b0 GetHealthCheckRequest_builder) Build() *GetHealthCheckRequest
type GetHealthCheckResponse ¶
type GetHealthCheckResponse struct {
// The status of the relevant sub services.
Reports []*HealthCheckReport `protobuf:"bytes,1,rep,name=reports,proto3" json:"reports,omitempty"`
// An exception if an error occurred during processing request.
Exception *v1.Exception `protobuf:"bytes,2,opt,name=exception,proto3" json:"exception,omitempty"`
// contains filtered or unexported fields
}
Health status of services.
func (*GetHealthCheckResponse) ClearException ¶
func (x *GetHealthCheckResponse) ClearException()
func (*GetHealthCheckResponse) GetException ¶
func (x *GetHealthCheckResponse) GetException() *v1.Exception
func (*GetHealthCheckResponse) GetReports ¶
func (x *GetHealthCheckResponse) GetReports() []*HealthCheckReport
func (*GetHealthCheckResponse) HasException ¶
func (x *GetHealthCheckResponse) HasException() bool
func (*GetHealthCheckResponse) ProtoMessage ¶
func (*GetHealthCheckResponse) ProtoMessage()
func (*GetHealthCheckResponse) ProtoReflect ¶
func (x *GetHealthCheckResponse) ProtoReflect() protoreflect.Message
func (*GetHealthCheckResponse) Reset ¶
func (x *GetHealthCheckResponse) Reset()
func (*GetHealthCheckResponse) SetException ¶
func (x *GetHealthCheckResponse) SetException(v *v1.Exception)
func (*GetHealthCheckResponse) SetReports ¶
func (x *GetHealthCheckResponse) SetReports(v []*HealthCheckReport)
func (*GetHealthCheckResponse) String ¶
func (x *GetHealthCheckResponse) String() string
type GetHealthCheckResponse_builder ¶
type GetHealthCheckResponse_builder struct {
// The status of the relevant sub services.
Reports []*HealthCheckReport
// An exception if an error occurred during processing request.
Exception *v1.Exception
// contains filtered or unexported fields
}
func (GetHealthCheckResponse_builder) Build ¶
func (b0 GetHealthCheckResponse_builder) Build() *GetHealthCheckResponse
type HealthCheckReport ¶
type HealthCheckReport struct {
// Timestamp of when the report was generated (RFC3339).
Timestamp string `protobuf:"bytes,1,opt,name=timestamp,proto3" json:"timestamp,omitempty"`
// Status of the service.
Status string `protobuf:"bytes,2,opt,name=status,proto3" json:"status,omitempty"`
// Name of the service.
ServiceName string `protobuf:"bytes,3,opt,name=service_name,json=serviceName,proto3" json:"service_name,omitempty"`
// Version of the service.
ServiceVersion string `protobuf:"bytes,4,opt,name=service_version,json=serviceVersion,proto3" json:"service_version,omitempty"`
// contains filtered or unexported fields
}
Health check status of an individual service.
func (*HealthCheckReport) GetServiceName ¶
func (x *HealthCheckReport) GetServiceName() string
func (*HealthCheckReport) GetServiceVersion ¶
func (x *HealthCheckReport) GetServiceVersion() string
func (*HealthCheckReport) GetStatus ¶
func (x *HealthCheckReport) GetStatus() string
func (*HealthCheckReport) GetTimestamp ¶
func (x *HealthCheckReport) GetTimestamp() string
func (*HealthCheckReport) ProtoMessage ¶
func (*HealthCheckReport) ProtoMessage()
func (*HealthCheckReport) ProtoReflect ¶
func (x *HealthCheckReport) ProtoReflect() protoreflect.Message
func (*HealthCheckReport) Reset ¶
func (x *HealthCheckReport) Reset()
func (*HealthCheckReport) SetServiceName ¶
func (x *HealthCheckReport) SetServiceName(v string)
func (*HealthCheckReport) SetServiceVersion ¶
func (x *HealthCheckReport) SetServiceVersion(v string)
func (*HealthCheckReport) SetStatus ¶
func (x *HealthCheckReport) SetStatus(v string)
func (*HealthCheckReport) SetTimestamp ¶
func (x *HealthCheckReport) SetTimestamp(v string)
func (*HealthCheckReport) String ¶
func (x *HealthCheckReport) String() string
type HealthCheckReport_builder ¶
type HealthCheckReport_builder struct {
// Timestamp of when the report was generated (RFC3339).
Timestamp string
// Status of the service.
Status string
// Name of the service.
ServiceName string
// Version of the service.
ServiceVersion string
// contains filtered or unexported fields
}
func (HealthCheckReport_builder) Build ¶
func (b0 HealthCheckReport_builder) Build() *HealthCheckReport
Source Files
¶
- healthcheck.pb.go
Click to show internal directories.
Click to hide internal directories.