Documentation
¶
Index ¶
- Constants
- func NewPredictServiceHandler(svc PredictServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
- type PredictServiceClient
- type PredictServiceHandler
- type UnimplementedPredictServiceHandler
- func (UnimplementedPredictServiceHandler) GetLivePredictParam(context.Context, *connect.Request[v1.GetLivePredictParamRequest]) (*connect.Response[v1.GetLivePredictParamResponse], error)
- func (UnimplementedPredictServiceHandler) GetPredictParam(context.Context, *connect.Request[v1.GetPredictParamRequest]) (*connect.Response[v1.GetPredictParamResponse], error)
- func (UnimplementedPredictServiceHandler) PredictRace(context.Context, *connect.Request[v1.PredictRaceRequest]) (*connect.Response[v1.PredictRaceResponse], error)
Constants ¶
const ( // PredictServicePredictRaceProcedure is the fully-qualified name of the PredictService's // PredictRace RPC. PredictServicePredictRaceProcedure = "/iracelog.predict.v1.PredictService/PredictRace" // PredictServiceGetLivePredictParamProcedure is the fully-qualified name of the PredictService's // GetLivePredictParam RPC. PredictServiceGetLivePredictParamProcedure = "/iracelog.predict.v1.PredictService/GetLivePredictParam" // PredictServiceGetPredictParamProcedure is the fully-qualified name of the PredictService's // GetPredictParam RPC. PredictServiceGetPredictParamProcedure = "/iracelog.predict.v1.PredictService/GetPredictParam" )
These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.
Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.
const (
// PredictServiceName is the fully-qualified name of the PredictService service.
PredictServiceName = "iracelog.predict.v1.PredictService"
)
Variables ¶
This section is empty.
Functions ¶
func NewPredictServiceHandler ¶
func NewPredictServiceHandler(svc PredictServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
NewPredictServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.
By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.
Types ¶
type PredictServiceClient ¶
type PredictServiceClient interface {
PredictRace(context.Context, *connect.Request[v1.PredictRaceRequest]) (*connect.Response[v1.PredictRaceResponse], error)
GetLivePredictParam(context.Context, *connect.Request[v1.GetLivePredictParamRequest]) (*connect.Response[v1.GetLivePredictParamResponse], error)
// used for development on existing events
GetPredictParam(context.Context, *connect.Request[v1.GetPredictParamRequest]) (*connect.Response[v1.GetPredictParamResponse], error)
}
PredictServiceClient is a client for the iracelog.predict.v1.PredictService service.
func NewPredictServiceClient ¶
func NewPredictServiceClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) PredictServiceClient
NewPredictServiceClient constructs a client for the iracelog.predict.v1.PredictService service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.
The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).
type PredictServiceHandler ¶
type PredictServiceHandler interface {
PredictRace(context.Context, *connect.Request[v1.PredictRaceRequest]) (*connect.Response[v1.PredictRaceResponse], error)
GetLivePredictParam(context.Context, *connect.Request[v1.GetLivePredictParamRequest]) (*connect.Response[v1.GetLivePredictParamResponse], error)
// used for development on existing events
GetPredictParam(context.Context, *connect.Request[v1.GetPredictParamRequest]) (*connect.Response[v1.GetPredictParamResponse], error)
}
PredictServiceHandler is an implementation of the iracelog.predict.v1.PredictService service.
type UnimplementedPredictServiceHandler ¶
type UnimplementedPredictServiceHandler struct{}
UnimplementedPredictServiceHandler returns CodeUnimplemented from all methods.
func (UnimplementedPredictServiceHandler) GetLivePredictParam ¶
func (UnimplementedPredictServiceHandler) GetLivePredictParam(context.Context, *connect.Request[v1.GetLivePredictParamRequest]) (*connect.Response[v1.GetLivePredictParamResponse], error)
func (UnimplementedPredictServiceHandler) GetPredictParam ¶
func (UnimplementedPredictServiceHandler) GetPredictParam(context.Context, *connect.Request[v1.GetPredictParamRequest]) (*connect.Response[v1.GetPredictParamResponse], error)
func (UnimplementedPredictServiceHandler) PredictRace ¶
func (UnimplementedPredictServiceHandler) PredictRace(context.Context, *connect.Request[v1.PredictRaceRequest]) (*connect.Response[v1.PredictRaceResponse], error)
Source Files
¶
- predict_service.connect.go