Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterLiveDataServiceServer(s grpc.ServiceRegistrar, srv LiveDataServiceServer)
- type LiveDataServiceClient
- type LiveDataServiceServer
- type LiveDataService_LiveAnalysisClient
- type LiveDataService_LiveAnalysisSelClient
- type LiveDataService_LiveAnalysisSelServer
- type LiveDataService_LiveAnalysisServer
- type LiveDataService_LiveCarOccupanciesClient
- type LiveDataService_LiveCarOccupanciesServer
- type LiveDataService_LiveCarPitsClient
- type LiveDataService_LiveCarPitsServer
- type LiveDataService_LiveCarStintsClient
- type LiveDataService_LiveCarStintsServer
- type LiveDataService_LiveDriverDataClient
- type LiveDataService_LiveDriverDataServer
- type LiveDataService_LiveRaceStateClient
- type LiveDataService_LiveRaceStateServer
- type LiveDataService_LiveSnapshotDataClient
- type LiveDataService_LiveSnapshotDataServer
- type LiveDataService_LiveSpeedmapClient
- type LiveDataService_LiveSpeedmapServer
- type UnimplementedLiveDataServiceServer
- func (UnimplementedLiveDataServiceServer) LiveAnalysis(*v1.LiveAnalysisRequest, grpc.ServerStreamingServer[v1.LiveAnalysisResponse]) error
- func (UnimplementedLiveDataServiceServer) LiveAnalysisSel(*v1.LiveAnalysisSelRequest, ...) error
- func (UnimplementedLiveDataServiceServer) LiveCarOccupancies(*v1.LiveCarOccupanciesRequest, ...) error
- func (UnimplementedLiveDataServiceServer) LiveCarPits(*v1.LiveCarPitsRequest, grpc.ServerStreamingServer[v1.LiveCarPitsResponse]) error
- func (UnimplementedLiveDataServiceServer) LiveCarStints(*v1.LiveCarStintsRequest, grpc.ServerStreamingServer[v1.LiveCarStintsResponse]) error
- func (UnimplementedLiveDataServiceServer) LiveDriverData(*v1.LiveDriverDataRequest, ...) error
- func (UnimplementedLiveDataServiceServer) LiveRaceState(*v1.LiveRaceStateRequest, grpc.ServerStreamingServer[v1.LiveRaceStateResponse]) error
- func (UnimplementedLiveDataServiceServer) LiveSnapshotData(*v1.LiveSnapshotDataRequest, ...) error
- func (UnimplementedLiveDataServiceServer) LiveSpeedmap(*v1.LiveSpeedmapRequest, grpc.ServerStreamingServer[v1.LiveSpeedmapResponse]) error
- type UnsafeLiveDataServiceServer
Constants ¶
const ( LiveDataService_LiveRaceState_FullMethodName = "/iracelog.livedata.v1.LiveDataService/LiveRaceState" LiveDataService_LiveSpeedmap_FullMethodName = "/iracelog.livedata.v1.LiveDataService/LiveSpeedmap" LiveDataService_LiveAnalysis_FullMethodName = "/iracelog.livedata.v1.LiveDataService/LiveAnalysis" LiveDataService_LiveCarOccupancies_FullMethodName = "/iracelog.livedata.v1.LiveDataService/LiveCarOccupancies" LiveDataService_LiveCarPits_FullMethodName = "/iracelog.livedata.v1.LiveDataService/LiveCarPits" LiveDataService_LiveCarStints_FullMethodName = "/iracelog.livedata.v1.LiveDataService/LiveCarStints" LiveDataService_LiveDriverData_FullMethodName = "/iracelog.livedata.v1.LiveDataService/LiveDriverData" LiveDataService_LiveSnapshotData_FullMethodName = "/iracelog.livedata.v1.LiveDataService/LiveSnapshotData" LiveDataService_LiveAnalysisSel_FullMethodName = "/iracelog.livedata.v1.LiveDataService/LiveAnalysisSel" )
Variables ¶
var LiveDataService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "iracelog.livedata.v1.LiveDataService", HandlerType: (*LiveDataServiceServer)(nil), Methods: []grpc.MethodDesc{}, Streams: []grpc.StreamDesc{ { StreamName: "LiveRaceState", Handler: _LiveDataService_LiveRaceState_Handler, ServerStreams: true, }, { StreamName: "LiveSpeedmap", Handler: _LiveDataService_LiveSpeedmap_Handler, ServerStreams: true, }, { StreamName: "LiveAnalysis", Handler: _LiveDataService_LiveAnalysis_Handler, ServerStreams: true, }, { StreamName: "LiveCarOccupancies", Handler: _LiveDataService_LiveCarOccupancies_Handler, ServerStreams: true, }, { StreamName: "LiveCarPits", Handler: _LiveDataService_LiveCarPits_Handler, ServerStreams: true, }, { StreamName: "LiveCarStints", Handler: _LiveDataService_LiveCarStints_Handler, ServerStreams: true, }, { StreamName: "LiveDriverData", Handler: _LiveDataService_LiveDriverData_Handler, ServerStreams: true, }, { StreamName: "LiveSnapshotData", Handler: _LiveDataService_LiveSnapshotData_Handler, ServerStreams: true, }, { StreamName: "LiveAnalysisSel", Handler: _LiveDataService_LiveAnalysisSel_Handler, ServerStreams: true, }, }, Metadata: "iracelog/livedata/v1/live_service.proto", }
LiveDataService_ServiceDesc is the grpc.ServiceDesc for LiveDataService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterLiveDataServiceServer ¶
func RegisterLiveDataServiceServer(s grpc.ServiceRegistrar, srv LiveDataServiceServer)
Types ¶
type LiveDataServiceClient ¶
type LiveDataServiceClient interface {
LiveRaceState(ctx context.Context, in *v1.LiveRaceStateRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[v1.LiveRaceStateResponse], error)
LiveSpeedmap(ctx context.Context, in *v1.LiveSpeedmapRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[v1.LiveSpeedmapResponse], error)
LiveAnalysis(ctx context.Context, in *v1.LiveAnalysisRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[v1.LiveAnalysisResponse], error)
LiveCarOccupancies(ctx context.Context, in *v1.LiveCarOccupanciesRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[v1.LiveCarOccupanciesResponse], error)
LiveCarPits(ctx context.Context, in *v1.LiveCarPitsRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[v1.LiveCarPitsResponse], error)
LiveCarStints(ctx context.Context, in *v1.LiveCarStintsRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[v1.LiveCarStintsResponse], error)
LiveDriverData(ctx context.Context, in *v1.LiveDriverDataRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[v1.LiveDriverDataResponse], error)
LiveSnapshotData(ctx context.Context, in *v1.LiveSnapshotDataRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[v1.LiveSnapshotDataResponse], error)
// The first response will include all attributes with all data
// The following entries of the stream will only include those attributes configured in the request
LiveAnalysisSel(ctx context.Context, in *v1.LiveAnalysisSelRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[v1.LiveAnalysisSelResponse], error)
}
LiveDataServiceClient is the client API for LiveDataService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewLiveDataServiceClient ¶
func NewLiveDataServiceClient(cc grpc.ClientConnInterface) LiveDataServiceClient
type LiveDataServiceServer ¶
type LiveDataServiceServer interface {
LiveRaceState(*v1.LiveRaceStateRequest, grpc.ServerStreamingServer[v1.LiveRaceStateResponse]) error
LiveSpeedmap(*v1.LiveSpeedmapRequest, grpc.ServerStreamingServer[v1.LiveSpeedmapResponse]) error
LiveAnalysis(*v1.LiveAnalysisRequest, grpc.ServerStreamingServer[v1.LiveAnalysisResponse]) error
LiveCarOccupancies(*v1.LiveCarOccupanciesRequest, grpc.ServerStreamingServer[v1.LiveCarOccupanciesResponse]) error
LiveCarPits(*v1.LiveCarPitsRequest, grpc.ServerStreamingServer[v1.LiveCarPitsResponse]) error
LiveCarStints(*v1.LiveCarStintsRequest, grpc.ServerStreamingServer[v1.LiveCarStintsResponse]) error
LiveDriverData(*v1.LiveDriverDataRequest, grpc.ServerStreamingServer[v1.LiveDriverDataResponse]) error
LiveSnapshotData(*v1.LiveSnapshotDataRequest, grpc.ServerStreamingServer[v1.LiveSnapshotDataResponse]) error
// The first response will include all attributes with all data
// The following entries of the stream will only include those attributes configured in the request
LiveAnalysisSel(*v1.LiveAnalysisSelRequest, grpc.ServerStreamingServer[v1.LiveAnalysisSelResponse]) error
}
LiveDataServiceServer is the server API for LiveDataService service. All implementations should embed UnimplementedLiveDataServiceServer for forward compatibility.
type LiveDataService_LiveAnalysisClient ¶
type LiveDataService_LiveAnalysisClient = grpc.ServerStreamingClient[v1.LiveAnalysisResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type LiveDataService_LiveAnalysisSelClient ¶
type LiveDataService_LiveAnalysisSelClient = grpc.ServerStreamingClient[v1.LiveAnalysisSelResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type LiveDataService_LiveAnalysisSelServer ¶
type LiveDataService_LiveAnalysisSelServer = grpc.ServerStreamingServer[v1.LiveAnalysisSelResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type LiveDataService_LiveAnalysisServer ¶
type LiveDataService_LiveAnalysisServer = grpc.ServerStreamingServer[v1.LiveAnalysisResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type LiveDataService_LiveCarOccupanciesClient ¶
type LiveDataService_LiveCarOccupanciesClient = grpc.ServerStreamingClient[v1.LiveCarOccupanciesResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type LiveDataService_LiveCarOccupanciesServer ¶
type LiveDataService_LiveCarOccupanciesServer = grpc.ServerStreamingServer[v1.LiveCarOccupanciesResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type LiveDataService_LiveCarPitsClient ¶
type LiveDataService_LiveCarPitsClient = grpc.ServerStreamingClient[v1.LiveCarPitsResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type LiveDataService_LiveCarPitsServer ¶
type LiveDataService_LiveCarPitsServer = grpc.ServerStreamingServer[v1.LiveCarPitsResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type LiveDataService_LiveCarStintsClient ¶
type LiveDataService_LiveCarStintsClient = grpc.ServerStreamingClient[v1.LiveCarStintsResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type LiveDataService_LiveCarStintsServer ¶
type LiveDataService_LiveCarStintsServer = grpc.ServerStreamingServer[v1.LiveCarStintsResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type LiveDataService_LiveDriverDataClient ¶
type LiveDataService_LiveDriverDataClient = grpc.ServerStreamingClient[v1.LiveDriverDataResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type LiveDataService_LiveDriverDataServer ¶
type LiveDataService_LiveDriverDataServer = grpc.ServerStreamingServer[v1.LiveDriverDataResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type LiveDataService_LiveRaceStateClient ¶
type LiveDataService_LiveRaceStateClient = grpc.ServerStreamingClient[v1.LiveRaceStateResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type LiveDataService_LiveRaceStateServer ¶
type LiveDataService_LiveRaceStateServer = grpc.ServerStreamingServer[v1.LiveRaceStateResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type LiveDataService_LiveSnapshotDataClient ¶
type LiveDataService_LiveSnapshotDataClient = grpc.ServerStreamingClient[v1.LiveSnapshotDataResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type LiveDataService_LiveSnapshotDataServer ¶
type LiveDataService_LiveSnapshotDataServer = grpc.ServerStreamingServer[v1.LiveSnapshotDataResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type LiveDataService_LiveSpeedmapClient ¶
type LiveDataService_LiveSpeedmapClient = grpc.ServerStreamingClient[v1.LiveSpeedmapResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type LiveDataService_LiveSpeedmapServer ¶
type LiveDataService_LiveSpeedmapServer = grpc.ServerStreamingServer[v1.LiveSpeedmapResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type UnimplementedLiveDataServiceServer ¶
type UnimplementedLiveDataServiceServer struct{}
UnimplementedLiveDataServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedLiveDataServiceServer) LiveAnalysis ¶
func (UnimplementedLiveDataServiceServer) LiveAnalysis(*v1.LiveAnalysisRequest, grpc.ServerStreamingServer[v1.LiveAnalysisResponse]) error
func (UnimplementedLiveDataServiceServer) LiveAnalysisSel ¶
func (UnimplementedLiveDataServiceServer) LiveAnalysisSel(*v1.LiveAnalysisSelRequest, grpc.ServerStreamingServer[v1.LiveAnalysisSelResponse]) error
func (UnimplementedLiveDataServiceServer) LiveCarOccupancies ¶
func (UnimplementedLiveDataServiceServer) LiveCarOccupancies(*v1.LiveCarOccupanciesRequest, grpc.ServerStreamingServer[v1.LiveCarOccupanciesResponse]) error
func (UnimplementedLiveDataServiceServer) LiveCarPits ¶
func (UnimplementedLiveDataServiceServer) LiveCarPits(*v1.LiveCarPitsRequest, grpc.ServerStreamingServer[v1.LiveCarPitsResponse]) error
func (UnimplementedLiveDataServiceServer) LiveCarStints ¶
func (UnimplementedLiveDataServiceServer) LiveCarStints(*v1.LiveCarStintsRequest, grpc.ServerStreamingServer[v1.LiveCarStintsResponse]) error
func (UnimplementedLiveDataServiceServer) LiveDriverData ¶
func (UnimplementedLiveDataServiceServer) LiveDriverData(*v1.LiveDriverDataRequest, grpc.ServerStreamingServer[v1.LiveDriverDataResponse]) error
func (UnimplementedLiveDataServiceServer) LiveRaceState ¶
func (UnimplementedLiveDataServiceServer) LiveRaceState(*v1.LiveRaceStateRequest, grpc.ServerStreamingServer[v1.LiveRaceStateResponse]) error
func (UnimplementedLiveDataServiceServer) LiveSnapshotData ¶
func (UnimplementedLiveDataServiceServer) LiveSnapshotData(*v1.LiveSnapshotDataRequest, grpc.ServerStreamingServer[v1.LiveSnapshotDataResponse]) error
func (UnimplementedLiveDataServiceServer) LiveSpeedmap ¶
func (UnimplementedLiveDataServiceServer) LiveSpeedmap(*v1.LiveSpeedmapRequest, grpc.ServerStreamingServer[v1.LiveSpeedmapResponse]) error
type UnsafeLiveDataServiceServer ¶
type UnsafeLiveDataServiceServer interface {
// contains filtered or unexported methods
}
UnsafeLiveDataServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to LiveDataServiceServer will result in compilation errors.
Source Files
¶
- live_service_grpc.pb.go