Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterPredictServiceServer(s grpc.ServiceRegistrar, srv PredictServiceServer)
- type PredictServiceClient
- type PredictServiceServer
- type UnimplementedPredictServiceServer
- func (UnimplementedPredictServiceServer) GetLivePredictParam(context.Context, *v1.GetLivePredictParamRequest) (*v1.GetLivePredictParamResponse, error)
- func (UnimplementedPredictServiceServer) GetPredictParam(context.Context, *v1.GetPredictParamRequest) (*v1.GetPredictParamResponse, error)
- func (UnimplementedPredictServiceServer) PredictRace(context.Context, *v1.PredictRaceRequest) (*v1.PredictRaceResponse, error)
- type UnsafePredictServiceServer
Constants ¶
const ( PredictService_PredictRace_FullMethodName = "/iracelog.predict.v1.PredictService/PredictRace" PredictService_GetLivePredictParam_FullMethodName = "/iracelog.predict.v1.PredictService/GetLivePredictParam" PredictService_GetPredictParam_FullMethodName = "/iracelog.predict.v1.PredictService/GetPredictParam" )
Variables ¶
var PredictService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "iracelog.predict.v1.PredictService", HandlerType: (*PredictServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "PredictRace", Handler: _PredictService_PredictRace_Handler, }, { MethodName: "GetLivePredictParam", Handler: _PredictService_GetLivePredictParam_Handler, }, { MethodName: "GetPredictParam", Handler: _PredictService_GetPredictParam_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "iracelog/predict/v1/predict_service.proto", }
PredictService_ServiceDesc is the grpc.ServiceDesc for PredictService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterPredictServiceServer ¶
func RegisterPredictServiceServer(s grpc.ServiceRegistrar, srv PredictServiceServer)
Types ¶
type PredictServiceClient ¶
type PredictServiceClient interface {
PredictRace(ctx context.Context, in *v1.PredictRaceRequest, opts ...grpc.CallOption) (*v1.PredictRaceResponse, error)
GetLivePredictParam(ctx context.Context, in *v1.GetLivePredictParamRequest, opts ...grpc.CallOption) (*v1.GetLivePredictParamResponse, error)
// used for development on existing events
GetPredictParam(ctx context.Context, in *v1.GetPredictParamRequest, opts ...grpc.CallOption) (*v1.GetPredictParamResponse, error)
}
PredictServiceClient is the client API for PredictService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
functions around predicting a race outcome
func NewPredictServiceClient ¶
func NewPredictServiceClient(cc grpc.ClientConnInterface) PredictServiceClient
type PredictServiceServer ¶
type PredictServiceServer interface {
PredictRace(context.Context, *v1.PredictRaceRequest) (*v1.PredictRaceResponse, error)
GetLivePredictParam(context.Context, *v1.GetLivePredictParamRequest) (*v1.GetLivePredictParamResponse, error)
// used for development on existing events
GetPredictParam(context.Context, *v1.GetPredictParamRequest) (*v1.GetPredictParamResponse, error)
}
PredictServiceServer is the server API for PredictService service. All implementations should embed UnimplementedPredictServiceServer for forward compatibility.
functions around predicting a race outcome
type UnimplementedPredictServiceServer ¶
type UnimplementedPredictServiceServer struct{}
UnimplementedPredictServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedPredictServiceServer) GetLivePredictParam ¶
func (UnimplementedPredictServiceServer) GetLivePredictParam(context.Context, *v1.GetLivePredictParamRequest) (*v1.GetLivePredictParamResponse, error)
func (UnimplementedPredictServiceServer) GetPredictParam ¶
func (UnimplementedPredictServiceServer) GetPredictParam(context.Context, *v1.GetPredictParamRequest) (*v1.GetPredictParamResponse, error)
func (UnimplementedPredictServiceServer) PredictRace ¶
func (UnimplementedPredictServiceServer) PredictRace(context.Context, *v1.PredictRaceRequest) (*v1.PredictRaceResponse, error)
type UnsafePredictServiceServer ¶
type UnsafePredictServiceServer interface {
// contains filtered or unexported methods
}
UnsafePredictServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to PredictServiceServer will result in compilation errors.
Source Files
¶
- predict_service_grpc.pb.go