Documentation
¶
Index ¶
- Constants
- Variables
- type CarParam
- func (x *CarParam) ClearRemainLapTime()
- func (x *CarParam) GetCurrentTrackPos() float32
- func (x *CarParam) GetInPit() bool
- func (x *CarParam) GetRemainLapTime() *durationpb.Duration
- func (x *CarParam) GetStintLap() int32
- func (x *CarParam) HasRemainLapTime() bool
- func (*CarParam) ProtoMessage()
- func (x *CarParam) ProtoReflect() protoreflect.Message
- func (x *CarParam) Reset()
- func (x *CarParam) SetCurrentTrackPos(v float32)
- func (x *CarParam) SetInPit(v bool)
- func (x *CarParam) SetRemainLapTime(v *durationpb.Duration)
- func (x *CarParam) SetStintLap(v int32)
- func (x *CarParam) String() string
- type CarParam_builder
- type FuelParam
- func (x *FuelParam) GetLapConsumption() float32
- func (x *FuelParam) GetRefuelRate() float32
- func (x *FuelParam) GetTankVolume() float32
- func (*FuelParam) ProtoMessage()
- func (x *FuelParam) ProtoReflect() protoreflect.Message
- func (x *FuelParam) Reset()
- func (x *FuelParam) SetLapConsumption(v float32)
- func (x *FuelParam) SetRefuelRate(v float32)
- func (x *FuelParam) SetTankVolume(v float32)
- func (x *FuelParam) String() string
- type FuelParam_builder
- type GetLivePredictParamRequest
- func (x *GetLivePredictParamRequest) ClearEventSelector()
- func (x *GetLivePredictParamRequest) GetCarNum() string
- func (x *GetLivePredictParamRequest) GetEventSelector() *v1.EventSelector
- func (x *GetLivePredictParamRequest) GetLaptimeSelector() LaptimeSelector
- func (x *GetLivePredictParamRequest) HasEventSelector() bool
- func (*GetLivePredictParamRequest) ProtoMessage()
- func (x *GetLivePredictParamRequest) ProtoReflect() protoreflect.Message
- func (x *GetLivePredictParamRequest) Reset()
- func (x *GetLivePredictParamRequest) SetCarNum(v string)
- func (x *GetLivePredictParamRequest) SetEventSelector(v *v1.EventSelector)
- func (x *GetLivePredictParamRequest) SetLaptimeSelector(v LaptimeSelector)
- func (x *GetLivePredictParamRequest) String() string
- type GetLivePredictParamRequest_builder
- type GetLivePredictParamResponse
- func (x *GetLivePredictParamResponse) ClearParam()
- func (x *GetLivePredictParamResponse) GetParam() *PredictParam
- func (x *GetLivePredictParamResponse) HasParam() bool
- func (*GetLivePredictParamResponse) ProtoMessage()
- func (x *GetLivePredictParamResponse) ProtoReflect() protoreflect.Message
- func (x *GetLivePredictParamResponse) Reset()
- func (x *GetLivePredictParamResponse) SetParam(v *PredictParam)
- func (x *GetLivePredictParamResponse) String() string
- type GetLivePredictParamResponse_builder
- type GetPredictParamRequest
- func (x *GetPredictParamRequest) ClearEventSelector()
- func (x *GetPredictParamRequest) ClearStartSelector()
- func (x *GetPredictParamRequest) GetCarNum() string
- func (x *GetPredictParamRequest) GetEventSelector() *v1.EventSelector
- func (x *GetPredictParamRequest) GetLaptimeSelector() LaptimeSelector
- func (x *GetPredictParamRequest) GetStartSelector() *v1.StartSelector
- func (x *GetPredictParamRequest) HasEventSelector() bool
- func (x *GetPredictParamRequest) HasStartSelector() bool
- func (*GetPredictParamRequest) ProtoMessage()
- func (x *GetPredictParamRequest) ProtoReflect() protoreflect.Message
- func (x *GetPredictParamRequest) Reset()
- func (x *GetPredictParamRequest) SetCarNum(v string)
- func (x *GetPredictParamRequest) SetEventSelector(v *v1.EventSelector)
- func (x *GetPredictParamRequest) SetLaptimeSelector(v LaptimeSelector)
- func (x *GetPredictParamRequest) SetStartSelector(v *v1.StartSelector)
- func (x *GetPredictParamRequest) String() string
- type GetPredictParamRequest_builder
- type GetPredictParamResponse
- func (x *GetPredictParamResponse) ClearParam()
- func (x *GetPredictParamResponse) GetParam() *PredictParam
- func (x *GetPredictParamResponse) HasParam() bool
- func (*GetPredictParamResponse) ProtoMessage()
- func (x *GetPredictParamResponse) ProtoReflect() protoreflect.Message
- func (x *GetPredictParamResponse) Reset()
- func (x *GetPredictParamResponse) SetParam(v *PredictParam)
- func (x *GetPredictParamResponse) String() string
- type GetPredictParamResponse_builder
- type LaptimeSelector
- type Part
- func (x *Part) ClearDuration()
- func (x *Part) ClearEnd()
- func (x *Part) ClearPartType()
- func (x *Part) ClearPit()
- func (x *Part) ClearStart()
- func (x *Part) ClearStint()
- func (x *Part) GetDuration() *durationpb.Duration
- func (x *Part) GetEnd() *durationpb.Duration
- func (x *Part) GetPartType() isPart_PartType
- func (x *Part) GetPit() *PitPart
- func (x *Part) GetStart() *durationpb.Duration
- func (x *Part) GetStint() *StintPart
- func (x *Part) HasDuration() bool
- func (x *Part) HasEnd() bool
- func (x *Part) HasPartType() bool
- func (x *Part) HasPit() bool
- func (x *Part) HasStart() bool
- func (x *Part) HasStint() bool
- func (*Part) ProtoMessage()
- func (x *Part) ProtoReflect() protoreflect.Message
- func (x *Part) Reset()
- func (x *Part) SetDuration(v *durationpb.Duration)
- func (x *Part) SetEnd(v *durationpb.Duration)
- func (x *Part) SetPit(v *PitPart)
- func (x *Part) SetStart(v *durationpb.Duration)
- func (x *Part) SetStint(v *StintPart)
- func (x *Part) String() string
- func (x *Part) WhichPartType() case_Part_PartType
- type Part_Pit
- type Part_Stint
- type Part_builder
- type PitParam
- func (x *PitParam) ClearLane()
- func (x *PitParam) ClearOverall()
- func (x *PitParam) GetLane() *durationpb.Duration
- func (x *PitParam) GetOverall() *durationpb.Duration
- func (x *PitParam) HasLane() bool
- func (x *PitParam) HasOverall() bool
- func (*PitParam) ProtoMessage()
- func (x *PitParam) ProtoReflect() protoreflect.Message
- func (x *PitParam) Reset()
- func (x *PitParam) SetLane(v *durationpb.Duration)
- func (x *PitParam) SetOverall(v *durationpb.Duration)
- func (x *PitParam) String() string
- type PitParam_builder
- type PitPart
- type PitPart_builder
- type PredictParam
- func (x *PredictParam) ClearCar()
- func (x *PredictParam) ClearFuel()
- func (x *PredictParam) ClearPit()
- func (x *PredictParam) ClearRace()
- func (x *PredictParam) ClearStint()
- func (x *PredictParam) GetCar() *CarParam
- func (x *PredictParam) GetFuel() *FuelParam
- func (x *PredictParam) GetPit() *PitParam
- func (x *PredictParam) GetRace() *RaceParam
- func (x *PredictParam) GetStint() *StintParam
- func (x *PredictParam) HasCar() bool
- func (x *PredictParam) HasFuel() bool
- func (x *PredictParam) HasPit() bool
- func (x *PredictParam) HasRace() bool
- func (x *PredictParam) HasStint() bool
- func (*PredictParam) ProtoMessage()
- func (x *PredictParam) ProtoReflect() protoreflect.Message
- func (x *PredictParam) Reset()
- func (x *PredictParam) SetCar(v *CarParam)
- func (x *PredictParam) SetFuel(v *FuelParam)
- func (x *PredictParam) SetPit(v *PitParam)
- func (x *PredictParam) SetRace(v *RaceParam)
- func (x *PredictParam) SetStint(v *StintParam)
- func (x *PredictParam) String() string
- type PredictParam_builder
- type PredictRaceRequest
- func (x *PredictRaceRequest) ClearParam()
- func (x *PredictRaceRequest) GetParam() *PredictParam
- func (x *PredictRaceRequest) HasParam() bool
- func (*PredictRaceRequest) ProtoMessage()
- func (x *PredictRaceRequest) ProtoReflect() protoreflect.Message
- func (x *PredictRaceRequest) Reset()
- func (x *PredictRaceRequest) SetParam(v *PredictParam)
- func (x *PredictRaceRequest) String() string
- type PredictRaceRequest_builder
- type PredictRaceResponse
- func (x *PredictRaceResponse) ClearResult()
- func (x *PredictRaceResponse) GetResult() *PredictResult
- func (x *PredictRaceResponse) HasResult() bool
- func (*PredictRaceResponse) ProtoMessage()
- func (x *PredictRaceResponse) ProtoReflect() protoreflect.Message
- func (x *PredictRaceResponse) Reset()
- func (x *PredictRaceResponse) SetResult(v *PredictResult)
- func (x *PredictRaceResponse) String() string
- type PredictRaceResponse_builder
- type PredictResult
- type PredictResult_builder
- type RaceParam
- func (x *RaceParam) ClearDuration()
- func (x *RaceParam) ClearSession()
- func (x *RaceParam) GetDuration() *durationpb.Duration
- func (x *RaceParam) GetLc() int32
- func (x *RaceParam) GetSession() *durationpb.Duration
- func (x *RaceParam) HasDuration() bool
- func (x *RaceParam) HasSession() bool
- func (*RaceParam) ProtoMessage()
- func (x *RaceParam) ProtoReflect() protoreflect.Message
- func (x *RaceParam) Reset()
- func (x *RaceParam) SetDuration(v *durationpb.Duration)
- func (x *RaceParam) SetLc(v int32)
- func (x *RaceParam) SetSession(v *durationpb.Duration)
- func (x *RaceParam) String() string
- type RaceParam_builder
- type StintParam
- func (x *StintParam) ClearAvgLaptime()
- func (x *StintParam) ClearInLaptime()
- func (x *StintParam) ClearOutLaptime()
- func (x *StintParam) GetAvgLaptime() *durationpb.Duration
- func (x *StintParam) GetInLaptime() *durationpb.Duration
- func (x *StintParam) GetLps() int32
- func (x *StintParam) GetOutLaptime() *durationpb.Duration
- func (x *StintParam) HasAvgLaptime() bool
- func (x *StintParam) HasInLaptime() bool
- func (x *StintParam) HasOutLaptime() bool
- func (*StintParam) ProtoMessage()
- func (x *StintParam) ProtoReflect() protoreflect.Message
- func (x *StintParam) Reset()
- func (x *StintParam) SetAvgLaptime(v *durationpb.Duration)
- func (x *StintParam) SetInLaptime(v *durationpb.Duration)
- func (x *StintParam) SetLps(v int32)
- func (x *StintParam) SetOutLaptime(v *durationpb.Duration)
- func (x *StintParam) String() string
- type StintParam_builder
- type StintPart
- func (x *StintPart) GetLapEnd() int32
- func (x *StintPart) GetLapStart() int32
- func (x *StintPart) GetLaps() int32
- func (*StintPart) ProtoMessage()
- func (x *StintPart) ProtoReflect() protoreflect.Message
- func (x *StintPart) Reset()
- func (x *StintPart) SetLapEnd(v int32)
- func (x *StintPart) SetLapStart(v int32)
- func (x *StintPart) SetLaps(v int32)
- func (x *StintPart) String() string
- type StintPart_builder
Constants ¶
const Part_PartType_not_set_case case_Part_PartType = 0
const Part_Pit_case case_Part_PartType = 5
const Part_Stint_case case_Part_PartType = 4
Variables ¶
var ( LaptimeSelector_name = map[int32]string{ 0: "LAPTIME_SELECTOR_UNSPECIFIED", 1: "LAPTIME_SELECTOR_LAST", 2: "LAPTIME_SELECTOR_CURRENT_STINT_AVG", 3: "LAPTIME_SELECTOR_PREVIOUS_STINT_AVG", } LaptimeSelector_value = map[string]int32{ "LAPTIME_SELECTOR_UNSPECIFIED": 0, "LAPTIME_SELECTOR_LAST": 1, "LAPTIME_SELECTOR_CURRENT_STINT_AVG": 2, "LAPTIME_SELECTOR_PREVIOUS_STINT_AVG": 3, } )
Enum value maps for LaptimeSelector.
var File_iracelog_predict_v1_predict_proto protoreflect.FileDescriptor
var File_iracelog_predict_v1_predict_service_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type CarParam ¶
type CarParam struct {
// where is the car right now on the track
CurrentTrackPos float32 `protobuf:"fixed32,1,opt,name=current_track_pos,json=currentTrackPos,proto3" json:"current_track_pos,omitempty"`
// is the car in pits
InPit bool `protobuf:"varint,2,opt,name=in_pit,json=inPit,proto3" json:"in_pit,omitempty"`
// the lap of the stint the car is currently on
StintLap int32 `protobuf:"varint,3,opt,name=stint_lap,json=stintLap,proto3" json:"stint_lap,omitempty"`
// how long does the car take to complete the current stint lap
RemainLapTime *durationpb.Duration `protobuf:"bytes,4,opt,name=remain_lap_time,json=remainLapTime,proto3" json:"remain_lap_time,omitempty"`
// contains filtered or unexported fields
}
func (*CarParam) GetRemainLapTime ¶
func (x *CarParam) GetRemainLapTime() *durationpb.Duration
func (*CarParam) ProtoReflect ¶
func (x *CarParam) ProtoReflect() protoreflect.Message
func (*CarParam) SetRemainLapTime ¶
func (x *CarParam) SetRemainLapTime(v *durationpb.Duration)
type CarParam_builder ¶
type CarParam_builder struct {
// where is the car right now on the track
CurrentTrackPos float32
// is the car in pits
InPit bool
// the lap of the stint the car is currently on
StintLap int32
// how long does the car take to complete the current stint lap
RemainLapTime *durationpb.Duration
// contains filtered or unexported fields
}
func (CarParam_builder) Build ¶
func (b0 CarParam_builder) Build() *CarParam
type FuelParam ¶
type FuelParam struct {
// available tank volume
TankVolume float32 `protobuf:"fixed32,1,opt,name=tank_volume,json=tankVolume,proto3" json:"tank_volume,omitempty"`
// how many units can be refueled per second
RefuelRate float32 `protobuf:"fixed32,2,opt,name=refuel_rate,json=refuelRate,proto3" json:"refuel_rate,omitempty"`
// how many units does the car burn per lap
LapConsumption float32 `protobuf:"fixed32,3,opt,name=lap_consumption,json=lapConsumption,proto3" json:"lap_consumption,omitempty"`
// contains filtered or unexported fields
}
func (*FuelParam) ProtoReflect ¶
func (x *FuelParam) ProtoReflect() protoreflect.Message
type FuelParam_builder ¶
type FuelParam_builder struct {
// available tank volume
TankVolume float32
// how many units can be refueled per second
RefuelRate float32
// how many units does the car burn per lap
LapConsumption float32
// contains filtered or unexported fields
}
func (FuelParam_builder) Build ¶
func (b0 FuelParam_builder) Build() *FuelParam
type GetLivePredictParamRequest ¶
type GetLivePredictParamRequest struct {
EventSelector *v1.EventSelector `protobuf:"bytes,1,opt,name=event_selector,json=eventSelector,proto3" json:"event_selector,omitempty"`
CarNum string `protobuf:"bytes,2,opt,name=car_num,json=carNum,proto3" json:"car_num,omitempty"`
LaptimeSelector LaptimeSelector `` /* 148-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*GetLivePredictParamRequest) ClearEventSelector ¶
func (x *GetLivePredictParamRequest) ClearEventSelector()
func (*GetLivePredictParamRequest) GetCarNum ¶
func (x *GetLivePredictParamRequest) GetCarNum() string
func (*GetLivePredictParamRequest) GetEventSelector ¶
func (x *GetLivePredictParamRequest) GetEventSelector() *v1.EventSelector
func (*GetLivePredictParamRequest) GetLaptimeSelector ¶
func (x *GetLivePredictParamRequest) GetLaptimeSelector() LaptimeSelector
func (*GetLivePredictParamRequest) HasEventSelector ¶
func (x *GetLivePredictParamRequest) HasEventSelector() bool
func (*GetLivePredictParamRequest) ProtoMessage ¶
func (*GetLivePredictParamRequest) ProtoMessage()
func (*GetLivePredictParamRequest) ProtoReflect ¶
func (x *GetLivePredictParamRequest) ProtoReflect() protoreflect.Message
func (*GetLivePredictParamRequest) Reset ¶
func (x *GetLivePredictParamRequest) Reset()
func (*GetLivePredictParamRequest) SetCarNum ¶
func (x *GetLivePredictParamRequest) SetCarNum(v string)
func (*GetLivePredictParamRequest) SetEventSelector ¶
func (x *GetLivePredictParamRequest) SetEventSelector(v *v1.EventSelector)
func (*GetLivePredictParamRequest) SetLaptimeSelector ¶
func (x *GetLivePredictParamRequest) SetLaptimeSelector(v LaptimeSelector)
func (*GetLivePredictParamRequest) String ¶
func (x *GetLivePredictParamRequest) String() string
type GetLivePredictParamRequest_builder ¶
type GetLivePredictParamRequest_builder struct {
EventSelector *v1.EventSelector
CarNum string
LaptimeSelector LaptimeSelector
// contains filtered or unexported fields
}
func (GetLivePredictParamRequest_builder) Build ¶
func (b0 GetLivePredictParamRequest_builder) Build() *GetLivePredictParamRequest
type GetLivePredictParamResponse ¶
type GetLivePredictParamResponse struct {
Param *PredictParam `protobuf:"bytes,1,opt,name=param,proto3" json:"param,omitempty"`
// contains filtered or unexported fields
}
func (*GetLivePredictParamResponse) ClearParam ¶
func (x *GetLivePredictParamResponse) ClearParam()
func (*GetLivePredictParamResponse) GetParam ¶
func (x *GetLivePredictParamResponse) GetParam() *PredictParam
func (*GetLivePredictParamResponse) HasParam ¶
func (x *GetLivePredictParamResponse) HasParam() bool
func (*GetLivePredictParamResponse) ProtoMessage ¶
func (*GetLivePredictParamResponse) ProtoMessage()
func (*GetLivePredictParamResponse) ProtoReflect ¶
func (x *GetLivePredictParamResponse) ProtoReflect() protoreflect.Message
func (*GetLivePredictParamResponse) Reset ¶
func (x *GetLivePredictParamResponse) Reset()
func (*GetLivePredictParamResponse) SetParam ¶
func (x *GetLivePredictParamResponse) SetParam(v *PredictParam)
func (*GetLivePredictParamResponse) String ¶
func (x *GetLivePredictParamResponse) String() string
type GetLivePredictParamResponse_builder ¶
type GetLivePredictParamResponse_builder struct {
Param *PredictParam
// contains filtered or unexported fields
}
func (GetLivePredictParamResponse_builder) Build ¶
func (b0 GetLivePredictParamResponse_builder) Build() *GetLivePredictParamResponse
type GetPredictParamRequest ¶
type GetPredictParamRequest struct {
EventSelector *v1.EventSelector `protobuf:"bytes,1,opt,name=event_selector,json=eventSelector,proto3" json:"event_selector,omitempty"`
StartSelector *v1.StartSelector `protobuf:"bytes,2,opt,name=start_selector,json=startSelector,proto3" json:"start_selector,omitempty"`
CarNum string `protobuf:"bytes,3,opt,name=car_num,json=carNum,proto3" json:"car_num,omitempty"`
LaptimeSelector LaptimeSelector `` /* 148-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*GetPredictParamRequest) ClearEventSelector ¶
func (x *GetPredictParamRequest) ClearEventSelector()
func (*GetPredictParamRequest) ClearStartSelector ¶
func (x *GetPredictParamRequest) ClearStartSelector()
func (*GetPredictParamRequest) GetCarNum ¶
func (x *GetPredictParamRequest) GetCarNum() string
func (*GetPredictParamRequest) GetEventSelector ¶
func (x *GetPredictParamRequest) GetEventSelector() *v1.EventSelector
func (*GetPredictParamRequest) GetLaptimeSelector ¶
func (x *GetPredictParamRequest) GetLaptimeSelector() LaptimeSelector
func (*GetPredictParamRequest) GetStartSelector ¶
func (x *GetPredictParamRequest) GetStartSelector() *v1.StartSelector
func (*GetPredictParamRequest) HasEventSelector ¶
func (x *GetPredictParamRequest) HasEventSelector() bool
func (*GetPredictParamRequest) HasStartSelector ¶
func (x *GetPredictParamRequest) HasStartSelector() bool
func (*GetPredictParamRequest) ProtoMessage ¶
func (*GetPredictParamRequest) ProtoMessage()
func (*GetPredictParamRequest) ProtoReflect ¶
func (x *GetPredictParamRequest) ProtoReflect() protoreflect.Message
func (*GetPredictParamRequest) Reset ¶
func (x *GetPredictParamRequest) Reset()
func (*GetPredictParamRequest) SetCarNum ¶
func (x *GetPredictParamRequest) SetCarNum(v string)
func (*GetPredictParamRequest) SetEventSelector ¶
func (x *GetPredictParamRequest) SetEventSelector(v *v1.EventSelector)
func (*GetPredictParamRequest) SetLaptimeSelector ¶
func (x *GetPredictParamRequest) SetLaptimeSelector(v LaptimeSelector)
func (*GetPredictParamRequest) SetStartSelector ¶
func (x *GetPredictParamRequest) SetStartSelector(v *v1.StartSelector)
func (*GetPredictParamRequest) String ¶
func (x *GetPredictParamRequest) String() string
type GetPredictParamRequest_builder ¶
type GetPredictParamRequest_builder struct {
EventSelector *v1.EventSelector
StartSelector *v1.StartSelector
CarNum string
LaptimeSelector LaptimeSelector
// contains filtered or unexported fields
}
func (GetPredictParamRequest_builder) Build ¶
func (b0 GetPredictParamRequest_builder) Build() *GetPredictParamRequest
type GetPredictParamResponse ¶
type GetPredictParamResponse struct {
Param *PredictParam `protobuf:"bytes,1,opt,name=param,proto3" json:"param,omitempty"`
// contains filtered or unexported fields
}
func (*GetPredictParamResponse) ClearParam ¶
func (x *GetPredictParamResponse) ClearParam()
func (*GetPredictParamResponse) GetParam ¶
func (x *GetPredictParamResponse) GetParam() *PredictParam
func (*GetPredictParamResponse) HasParam ¶
func (x *GetPredictParamResponse) HasParam() bool
func (*GetPredictParamResponse) ProtoMessage ¶
func (*GetPredictParamResponse) ProtoMessage()
func (*GetPredictParamResponse) ProtoReflect ¶
func (x *GetPredictParamResponse) ProtoReflect() protoreflect.Message
func (*GetPredictParamResponse) Reset ¶
func (x *GetPredictParamResponse) Reset()
func (*GetPredictParamResponse) SetParam ¶
func (x *GetPredictParamResponse) SetParam(v *PredictParam)
func (*GetPredictParamResponse) String ¶
func (x *GetPredictParamResponse) String() string
type GetPredictParamResponse_builder ¶
type GetPredictParamResponse_builder struct {
Param *PredictParam
// contains filtered or unexported fields
}
func (GetPredictParamResponse_builder) Build ¶
func (b0 GetPredictParamResponse_builder) Build() *GetPredictParamResponse
type LaptimeSelector ¶
type LaptimeSelector int32
const ( LaptimeSelector_LAPTIME_SELECTOR_UNSPECIFIED LaptimeSelector = 0 LaptimeSelector_LAPTIME_SELECTOR_LAST LaptimeSelector = 1 LaptimeSelector_LAPTIME_SELECTOR_CURRENT_STINT_AVG LaptimeSelector = 2 LaptimeSelector_LAPTIME_SELECTOR_PREVIOUS_STINT_AVG LaptimeSelector = 3 )
func (LaptimeSelector) Descriptor ¶
func (LaptimeSelector) Descriptor() protoreflect.EnumDescriptor
func (LaptimeSelector) Enum ¶
func (x LaptimeSelector) Enum() *LaptimeSelector
func (LaptimeSelector) Number ¶
func (x LaptimeSelector) Number() protoreflect.EnumNumber
func (LaptimeSelector) String ¶
func (x LaptimeSelector) String() string
func (LaptimeSelector) Type ¶
func (LaptimeSelector) Type() protoreflect.EnumType
type Part ¶
type Part struct {
// duration measured from race start
Start *durationpb.Duration `protobuf:"bytes,1,opt,name=start,proto3" json:"start,omitempty"`
// duration measured from race start
End *durationpb.Duration `protobuf:"bytes,2,opt,name=end,proto3" json:"end,omitempty"`
// the effective duration of that part
Duration *durationpb.Duration `protobuf:"bytes,3,opt,name=duration,proto3" json:"duration,omitempty"`
// Types that are valid to be assigned to PartType:
//
// *Part_Stint
// *Part_Pit
PartType isPart_PartType `protobuf_oneof:"part_type"`
// contains filtered or unexported fields
}
func (*Part) GetDuration ¶
func (x *Part) GetDuration() *durationpb.Duration
func (*Part) GetEnd ¶
func (x *Part) GetEnd() *durationpb.Duration
func (*Part) GetStart ¶
func (x *Part) GetStart() *durationpb.Duration
func (*Part) ProtoReflect ¶
func (x *Part) ProtoReflect() protoreflect.Message
func (*Part) SetDuration ¶
func (x *Part) SetDuration(v *durationpb.Duration)
func (*Part) SetEnd ¶
func (x *Part) SetEnd(v *durationpb.Duration)
func (*Part) SetStart ¶
func (x *Part) SetStart(v *durationpb.Duration)
type Part_Pit ¶
type Part_Pit struct {
Pit *PitPart `protobuf:"bytes,5,opt,name=pit,proto3,oneof"`
}
type Part_Stint ¶
type Part_Stint struct {
Stint *StintPart `protobuf:"bytes,4,opt,name=stint,proto3,oneof"`
}
type Part_builder ¶
type Part_builder struct {
// duration measured from race start
Start *durationpb.Duration
// duration measured from race start
End *durationpb.Duration
// the effective duration of that part
Duration *durationpb.Duration
// Fields of oneof PartType:
Stint *StintPart
Pit *PitPart
// contains filtered or unexported fields
}
func (Part_builder) Build ¶
func (b0 Part_builder) Build() *Part
type PitParam ¶
type PitParam struct {
// the overall pit time to use for calculation
Overall *durationpb.Duration `protobuf:"bytes,1,opt,name=overall,proto3" json:"overall,omitempty"`
// the time the car uses when driving in the pit lane
Lane *durationpb.Duration `protobuf:"bytes,2,opt,name=lane,proto3" json:"lane,omitempty"`
// contains filtered or unexported fields
}
func (*PitParam) GetLane ¶
func (x *PitParam) GetLane() *durationpb.Duration
func (*PitParam) GetOverall ¶
func (x *PitParam) GetOverall() *durationpb.Duration
func (*PitParam) ProtoReflect ¶
func (x *PitParam) ProtoReflect() protoreflect.Message
func (*PitParam) SetLane ¶
func (x *PitParam) SetLane(v *durationpb.Duration)
func (*PitParam) SetOverall ¶
func (x *PitParam) SetOverall(v *durationpb.Duration)
type PitParam_builder ¶
type PitParam_builder struct {
// the overall pit time to use for calculation
Overall *durationpb.Duration
// the time the car uses when driving in the pit lane
Lane *durationpb.Duration
// contains filtered or unexported fields
}
func (PitParam_builder) Build ¶
func (b0 PitParam_builder) Build() *PitParam
type PitPart ¶
type PitPart struct {
// contains filtered or unexported fields
}
func (*PitPart) ProtoReflect ¶
func (x *PitPart) ProtoReflect() protoreflect.Message
type PitPart_builder ¶
type PitPart_builder struct {
// contains filtered or unexported fields
}
func (PitPart_builder) Build ¶
func (b0 PitPart_builder) Build() *PitPart
type PredictParam ¶
type PredictParam struct {
Race *RaceParam `protobuf:"bytes,1,opt,name=race,proto3" json:"race,omitempty"`
Stint *StintParam `protobuf:"bytes,2,opt,name=stint,proto3" json:"stint,omitempty"`
Car *CarParam `protobuf:"bytes,3,opt,name=car,proto3" json:"car,omitempty"`
Fuel *FuelParam `protobuf:"bytes,4,opt,name=fuel,proto3" json:"fuel,omitempty"`
Pit *PitParam `protobuf:"bytes,5,opt,name=pit,proto3" json:"pit,omitempty"`
// contains filtered or unexported fields
}
func (*PredictParam) ClearCar ¶
func (x *PredictParam) ClearCar()
func (*PredictParam) ClearFuel ¶
func (x *PredictParam) ClearFuel()
func (*PredictParam) ClearPit ¶
func (x *PredictParam) ClearPit()
func (*PredictParam) ClearRace ¶
func (x *PredictParam) ClearRace()
func (*PredictParam) ClearStint ¶
func (x *PredictParam) ClearStint()
func (*PredictParam) GetCar ¶
func (x *PredictParam) GetCar() *CarParam
func (*PredictParam) GetFuel ¶
func (x *PredictParam) GetFuel() *FuelParam
func (*PredictParam) GetPit ¶
func (x *PredictParam) GetPit() *PitParam
func (*PredictParam) GetRace ¶
func (x *PredictParam) GetRace() *RaceParam
func (*PredictParam) GetStint ¶
func (x *PredictParam) GetStint() *StintParam
func (*PredictParam) HasCar ¶
func (x *PredictParam) HasCar() bool
func (*PredictParam) HasFuel ¶
func (x *PredictParam) HasFuel() bool
func (*PredictParam) HasPit ¶
func (x *PredictParam) HasPit() bool
func (*PredictParam) HasRace ¶
func (x *PredictParam) HasRace() bool
func (*PredictParam) HasStint ¶
func (x *PredictParam) HasStint() bool
func (*PredictParam) ProtoMessage ¶
func (*PredictParam) ProtoMessage()
func (*PredictParam) ProtoReflect ¶
func (x *PredictParam) ProtoReflect() protoreflect.Message
func (*PredictParam) Reset ¶
func (x *PredictParam) Reset()
func (*PredictParam) SetCar ¶
func (x *PredictParam) SetCar(v *CarParam)
func (*PredictParam) SetFuel ¶
func (x *PredictParam) SetFuel(v *FuelParam)
func (*PredictParam) SetPit ¶
func (x *PredictParam) SetPit(v *PitParam)
func (*PredictParam) SetRace ¶
func (x *PredictParam) SetRace(v *RaceParam)
func (*PredictParam) SetStint ¶
func (x *PredictParam) SetStint(v *StintParam)
func (*PredictParam) String ¶
func (x *PredictParam) String() string
type PredictParam_builder ¶
type PredictParam_builder struct {
Race *RaceParam
Stint *StintParam
Car *CarParam
Fuel *FuelParam
Pit *PitParam
// contains filtered or unexported fields
}
func (PredictParam_builder) Build ¶
func (b0 PredictParam_builder) Build() *PredictParam
type PredictRaceRequest ¶
type PredictRaceRequest struct {
Param *PredictParam `protobuf:"bytes,1,opt,name=param,proto3" json:"param,omitempty"`
// contains filtered or unexported fields
}
func (*PredictRaceRequest) ClearParam ¶
func (x *PredictRaceRequest) ClearParam()
func (*PredictRaceRequest) GetParam ¶
func (x *PredictRaceRequest) GetParam() *PredictParam
func (*PredictRaceRequest) HasParam ¶
func (x *PredictRaceRequest) HasParam() bool
func (*PredictRaceRequest) ProtoMessage ¶
func (*PredictRaceRequest) ProtoMessage()
func (*PredictRaceRequest) ProtoReflect ¶
func (x *PredictRaceRequest) ProtoReflect() protoreflect.Message
func (*PredictRaceRequest) Reset ¶
func (x *PredictRaceRequest) Reset()
func (*PredictRaceRequest) SetParam ¶
func (x *PredictRaceRequest) SetParam(v *PredictParam)
func (*PredictRaceRequest) String ¶
func (x *PredictRaceRequest) String() string
type PredictRaceRequest_builder ¶
type PredictRaceRequest_builder struct {
Param *PredictParam
// contains filtered or unexported fields
}
func (PredictRaceRequest_builder) Build ¶
func (b0 PredictRaceRequest_builder) Build() *PredictRaceRequest
type PredictRaceResponse ¶
type PredictRaceResponse struct {
Result *PredictResult `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*PredictRaceResponse) ClearResult ¶
func (x *PredictRaceResponse) ClearResult()
func (*PredictRaceResponse) GetResult ¶
func (x *PredictRaceResponse) GetResult() *PredictResult
func (*PredictRaceResponse) HasResult ¶
func (x *PredictRaceResponse) HasResult() bool
func (*PredictRaceResponse) ProtoMessage ¶
func (*PredictRaceResponse) ProtoMessage()
func (*PredictRaceResponse) ProtoReflect ¶
func (x *PredictRaceResponse) ProtoReflect() protoreflect.Message
func (*PredictRaceResponse) Reset ¶
func (x *PredictRaceResponse) Reset()
func (*PredictRaceResponse) SetResult ¶
func (x *PredictRaceResponse) SetResult(v *PredictResult)
func (*PredictRaceResponse) String ¶
func (x *PredictRaceResponse) String() string
type PredictRaceResponse_builder ¶
type PredictRaceResponse_builder struct {
Result *PredictResult
// contains filtered or unexported fields
}
func (PredictRaceResponse_builder) Build ¶
func (b0 PredictRaceResponse_builder) Build() *PredictRaceResponse
type PredictResult ¶
type PredictResult struct {
Parts []*Part `protobuf:"bytes,1,rep,name=parts,proto3" json:"parts,omitempty"`
// contains filtered or unexported fields
}
func (*PredictResult) GetParts ¶
func (x *PredictResult) GetParts() []*Part
func (*PredictResult) ProtoMessage ¶
func (*PredictResult) ProtoMessage()
func (*PredictResult) ProtoReflect ¶
func (x *PredictResult) ProtoReflect() protoreflect.Message
func (*PredictResult) Reset ¶
func (x *PredictResult) Reset()
func (*PredictResult) SetParts ¶
func (x *PredictResult) SetParts(v []*Part)
func (*PredictResult) String ¶
func (x *PredictResult) String() string
type PredictResult_builder ¶
type PredictResult_builder struct {
Parts []*Part
// contains filtered or unexported fields
}
func (PredictResult_builder) Build ¶
func (b0 PredictResult_builder) Build() *PredictResult
type RaceParam ¶
type RaceParam struct {
// predict for this (remaining) duration (for live sessions this is the iRacing SessionTimeRemain value)
Duration *durationpb.Duration `protobuf:"bytes,1,opt,name=duration,proto3" json:"duration,omitempty"`
// the current time in the race session (only used to produce meaningful session times when used in a live race)
Session *durationpb.Duration `protobuf:"bytes,2,opt,name=session,proto3" json:"session,omitempty"`
// how many laps are already completed
Lc int32 `protobuf:"varint,3,opt,name=lc,proto3" json:"lc,omitempty"`
// contains filtered or unexported fields
}
func (*RaceParam) GetDuration ¶
func (x *RaceParam) GetDuration() *durationpb.Duration
func (*RaceParam) GetSession ¶
func (x *RaceParam) GetSession() *durationpb.Duration
func (*RaceParam) ProtoReflect ¶
func (x *RaceParam) ProtoReflect() protoreflect.Message
func (*RaceParam) SetDuration ¶
func (x *RaceParam) SetDuration(v *durationpb.Duration)
func (*RaceParam) SetSession ¶
func (x *RaceParam) SetSession(v *durationpb.Duration)
type RaceParam_builder ¶
type RaceParam_builder struct {
// predict for this (remaining) duration (for live sessions this is the iRacing SessionTimeRemain value)
Duration *durationpb.Duration
// the current time in the race session (only used to produce meaningful session times when used in a live race)
Session *durationpb.Duration
// how many laps are already completed
Lc int32
// contains filtered or unexported fields
}
func (RaceParam_builder) Build ¶
func (b0 RaceParam_builder) Build() *RaceParam
type StintParam ¶
type StintParam struct {
AvgLaptime *durationpb.Duration `protobuf:"bytes,1,opt,name=avg_laptime,json=avgLaptime,proto3" json:"avg_laptime,omitempty"`
// how many laps can be done in one stint
Lps int32 `protobuf:"varint,2,opt,name=lps,proto3" json:"lps,omitempty"`
// if provided this will be used for the inlap, otherwise avg_laptime
InLaptime *durationpb.Duration `protobuf:"bytes,3,opt,name=in_laptime,json=inLaptime,proto3" json:"in_laptime,omitempty"`
// if provided this will be used for the outlap, otherwise avg_laptime
OutLaptime *durationpb.Duration `protobuf:"bytes,4,opt,name=out_laptime,json=outLaptime,proto3" json:"out_laptime,omitempty"`
// contains filtered or unexported fields
}
func (*StintParam) ClearAvgLaptime ¶
func (x *StintParam) ClearAvgLaptime()
func (*StintParam) ClearInLaptime ¶
func (x *StintParam) ClearInLaptime()
func (*StintParam) ClearOutLaptime ¶
func (x *StintParam) ClearOutLaptime()
func (*StintParam) GetAvgLaptime ¶
func (x *StintParam) GetAvgLaptime() *durationpb.Duration
func (*StintParam) GetInLaptime ¶
func (x *StintParam) GetInLaptime() *durationpb.Duration
func (*StintParam) GetLps ¶
func (x *StintParam) GetLps() int32
func (*StintParam) GetOutLaptime ¶
func (x *StintParam) GetOutLaptime() *durationpb.Duration
func (*StintParam) HasAvgLaptime ¶
func (x *StintParam) HasAvgLaptime() bool
func (*StintParam) HasInLaptime ¶
func (x *StintParam) HasInLaptime() bool
func (*StintParam) HasOutLaptime ¶
func (x *StintParam) HasOutLaptime() bool
func (*StintParam) ProtoMessage ¶
func (*StintParam) ProtoMessage()
func (*StintParam) ProtoReflect ¶
func (x *StintParam) ProtoReflect() protoreflect.Message
func (*StintParam) Reset ¶
func (x *StintParam) Reset()
func (*StintParam) SetAvgLaptime ¶
func (x *StintParam) SetAvgLaptime(v *durationpb.Duration)
func (*StintParam) SetInLaptime ¶
func (x *StintParam) SetInLaptime(v *durationpb.Duration)
func (*StintParam) SetLps ¶
func (x *StintParam) SetLps(v int32)
func (*StintParam) SetOutLaptime ¶
func (x *StintParam) SetOutLaptime(v *durationpb.Duration)
func (*StintParam) String ¶
func (x *StintParam) String() string
type StintParam_builder ¶
type StintParam_builder struct {
AvgLaptime *durationpb.Duration
// how many laps can be done in one stint
Lps int32
// if provided this will be used for the inlap, otherwise avg_laptime
InLaptime *durationpb.Duration
// if provided this will be used for the outlap, otherwise avg_laptime
OutLaptime *durationpb.Duration
// contains filtered or unexported fields
}
func (StintParam_builder) Build ¶
func (b0 StintParam_builder) Build() *StintParam
type StintPart ¶
type StintPart struct {
Laps int32 `protobuf:"varint,1,opt,name=laps,proto3" json:"laps,omitempty"`
LapStart int32 `protobuf:"varint,2,opt,name=lap_start,json=lapStart,proto3" json:"lap_start,omitempty"`
LapEnd int32 `protobuf:"varint,3,opt,name=lap_end,json=lapEnd,proto3" json:"lap_end,omitempty"`
// contains filtered or unexported fields
}
func (*StintPart) ProtoReflect ¶
func (x *StintPart) ProtoReflect() protoreflect.Message
Source Files
¶
- predict.pb.go
- predict_service.pb.go
Click to show internal directories.
Click to hide internal directories.