Documentation
¶
Index ¶
- Variables
- type Analysis
- func (x *Analysis) GetCarComputeStates() []*CarComputeState
- func (x *Analysis) GetCarLaps() []*CarLaps
- func (x *Analysis) GetCarOccupancies() []*CarOccupancy
- func (x *Analysis) GetCarPits() []*CarPit
- func (x *Analysis) GetCarStints() []*CarStint
- func (x *Analysis) GetRaceGraph() []*RaceGraph
- func (x *Analysis) GetRaceOrder() []string
- func (*Analysis) ProtoMessage()
- func (x *Analysis) ProtoReflect() protoreflect.Message
- func (x *Analysis) Reset()
- func (x *Analysis) SetCarComputeStates(v []*CarComputeState)
- func (x *Analysis) SetCarLaps(v []*CarLaps)
- func (x *Analysis) SetCarOccupancies(v []*CarOccupancy)
- func (x *Analysis) SetCarPits(v []*CarPit)
- func (x *Analysis) SetCarStints(v []*CarStint)
- func (x *Analysis) SetRaceGraph(v []*RaceGraph)
- func (x *Analysis) SetRaceOrder(v []string)
- func (x *Analysis) String() string
- type Analysis_builder
- type CarComputeState
- func (x *CarComputeState) GetCarNum() string
- func (x *CarComputeState) GetCarState() v1.CarState
- func (x *CarComputeState) GetOutEncountered() float32
- func (*CarComputeState) ProtoMessage()
- func (x *CarComputeState) ProtoReflect() protoreflect.Message
- func (x *CarComputeState) Reset()
- func (x *CarComputeState) SetCarNum(v string)
- func (x *CarComputeState) SetCarState(v v1.CarState)
- func (x *CarComputeState) SetOutEncountered(v float32)
- func (x *CarComputeState) String() string
- type CarComputeState_builder
- type CarLaps
- type CarLaps_builder
- type CarOccupancy
- func (x *CarOccupancy) GetCarClass() string
- func (x *CarOccupancy) GetCarNum() string
- func (x *CarOccupancy) GetCurrentDriverName() string
- func (x *CarOccupancy) GetDrivers() []*Driver
- func (x *CarOccupancy) GetName() string
- func (*CarOccupancy) ProtoMessage()
- func (x *CarOccupancy) ProtoReflect() protoreflect.Message
- func (x *CarOccupancy) Reset()
- func (x *CarOccupancy) SetCarClass(v string)
- func (x *CarOccupancy) SetCarNum(v string)
- func (x *CarOccupancy) SetCurrentDriverName(v string)
- func (x *CarOccupancy) SetDrivers(v []*Driver)
- func (x *CarOccupancy) SetName(v string)
- func (x *CarOccupancy) String() string
- type CarOccupancy_builder
- type CarPit
- func (x *CarPit) ClearCurrent()
- func (x *CarPit) GetCarNum() string
- func (x *CarPit) GetCurrent() *PitInfo
- func (x *CarPit) GetHistory() []*PitInfo
- func (x *CarPit) HasCurrent() bool
- func (*CarPit) ProtoMessage()
- func (x *CarPit) ProtoReflect() protoreflect.Message
- func (x *CarPit) Reset()
- func (x *CarPit) SetCarNum(v string)
- func (x *CarPit) SetCurrent(v *PitInfo)
- func (x *CarPit) SetHistory(v []*PitInfo)
- func (x *CarPit) String() string
- type CarPit_builder
- type CarStint
- func (x *CarStint) ClearCurrent()
- func (x *CarStint) GetCarNum() string
- func (x *CarStint) GetCurrent() *StintInfo
- func (x *CarStint) GetHistory() []*StintInfo
- func (x *CarStint) HasCurrent() bool
- func (*CarStint) ProtoMessage()
- func (x *CarStint) ProtoReflect() protoreflect.Message
- func (x *CarStint) Reset()
- func (x *CarStint) SetCarNum(v string)
- func (x *CarStint) SetCurrent(v *StintInfo)
- func (x *CarStint) SetHistory(v []*StintInfo)
- func (x *CarStint) String() string
- type CarStint_builder
- type Driver
- type Driver_builder
- type GapInfo
- func (x *GapInfo) GetCarNum() string
- func (x *GapInfo) GetGap() float32
- func (x *GapInfo) GetLapNo() int32
- func (x *GapInfo) GetPic() int32
- func (x *GapInfo) GetPos() int32
- func (*GapInfo) ProtoMessage()
- func (x *GapInfo) ProtoReflect() protoreflect.Message
- func (x *GapInfo) Reset()
- func (x *GapInfo) SetCarNum(v string)
- func (x *GapInfo) SetGap(v float32)
- func (x *GapInfo) SetLapNo(v int32)
- func (x *GapInfo) SetPic(v int32)
- func (x *GapInfo) SetPos(v int32)
- func (x *GapInfo) String() string
- type GapInfo_builder
- type GetAnalysisRequest
- func (x *GetAnalysisRequest) ClearEventSelector()
- func (x *GetAnalysisRequest) GetEventSelector() *v1.EventSelector
- func (x *GetAnalysisRequest) HasEventSelector() bool
- func (*GetAnalysisRequest) ProtoMessage()
- func (x *GetAnalysisRequest) ProtoReflect() protoreflect.Message
- func (x *GetAnalysisRequest) Reset()
- func (x *GetAnalysisRequest) SetEventSelector(v *v1.EventSelector)
- func (x *GetAnalysisRequest) String() string
- type GetAnalysisRequest_builder
- type GetAnalysisResponse
- func (x *GetAnalysisResponse) ClearAnalysis()
- func (x *GetAnalysisResponse) GetAnalysis() *Analysis
- func (x *GetAnalysisResponse) HasAnalysis() bool
- func (*GetAnalysisResponse) ProtoMessage()
- func (x *GetAnalysisResponse) ProtoReflect() protoreflect.Message
- func (x *GetAnalysisResponse) Reset()
- func (x *GetAnalysisResponse) SetAnalysis(v *Analysis)
- func (x *GetAnalysisResponse) String() string
- type GetAnalysisResponse_builder
- type Lap
- type Lap_builder
- type PitInfo
- func (x *PitInfo) GetCarNum() string
- func (x *PitInfo) GetEnterTime() float32
- func (x *PitInfo) GetExitTime() float32
- func (x *PitInfo) GetIsCurrentPitstop() bool
- func (x *PitInfo) GetLaneTime() float32
- func (x *PitInfo) GetLapEnter() int32
- func (x *PitInfo) GetLapExit() int32
- func (*PitInfo) ProtoMessage()
- func (x *PitInfo) ProtoReflect() protoreflect.Message
- func (x *PitInfo) Reset()
- func (x *PitInfo) SetCarNum(v string)
- func (x *PitInfo) SetEnterTime(v float32)
- func (x *PitInfo) SetExitTime(v float32)
- func (x *PitInfo) SetIsCurrentPitstop(v bool)
- func (x *PitInfo) SetLaneTime(v float32)
- func (x *PitInfo) SetLapEnter(v int32)
- func (x *PitInfo) SetLapExit(v int32)
- func (x *PitInfo) String() string
- type PitInfo_builder
- type RaceGraph
- func (x *RaceGraph) GetCarClass() string
- func (x *RaceGraph) GetGaps() []*GapInfo
- func (x *RaceGraph) GetLapNo() int32
- func (*RaceGraph) ProtoMessage()
- func (x *RaceGraph) ProtoReflect() protoreflect.Message
- func (x *RaceGraph) Reset()
- func (x *RaceGraph) SetCarClass(v string)
- func (x *RaceGraph) SetGaps(v []*GapInfo)
- func (x *RaceGraph) SetLapNo(v int32)
- func (x *RaceGraph) String() string
- type RaceGraph_builder
- type SeatTime
- func (x *SeatTime) GetEnterCarTime() float32
- func (x *SeatTime) GetLeaveCarTime() float32
- func (*SeatTime) ProtoMessage()
- func (x *SeatTime) ProtoReflect() protoreflect.Message
- func (x *SeatTime) Reset()
- func (x *SeatTime) SetEnterCarTime(v float32)
- func (x *SeatTime) SetLeaveCarTime(v float32)
- func (x *SeatTime) String() string
- type SeatTime_builder
- type StintInfo
- func (x *StintInfo) GetCarNum() string
- func (x *StintInfo) GetEnterTime() float32
- func (x *StintInfo) GetExitTime() float32
- func (x *StintInfo) GetIsCurrentStint() bool
- func (x *StintInfo) GetLapEnter() int32
- func (x *StintInfo) GetLapExit() int32
- func (x *StintInfo) GetNumLaps() int32
- func (x *StintInfo) GetStintTime() float32
- func (*StintInfo) ProtoMessage()
- func (x *StintInfo) ProtoReflect() protoreflect.Message
- func (x *StintInfo) Reset()
- func (x *StintInfo) SetCarNum(v string)
- func (x *StintInfo) SetEnterTime(v float32)
- func (x *StintInfo) SetExitTime(v float32)
- func (x *StintInfo) SetIsCurrentStint(v bool)
- func (x *StintInfo) SetLapEnter(v int32)
- func (x *StintInfo) SetLapExit(v int32)
- func (x *StintInfo) SetNumLaps(v int32)
- func (x *StintInfo) SetStintTime(v float32)
- func (x *StintInfo) String() string
- type StintInfo_builder
Constants ¶
This section is empty.
Variables ¶
var File_testrepo_analysis_v1_analysis_proto protoreflect.FileDescriptor
var File_testrepo_analysis_v1_analysis_service_proto protoreflect.FileDescriptor
var File_testrepo_analysis_v1_car_compute_state_proto protoreflect.FileDescriptor
var File_testrepo_analysis_v1_car_laps_proto protoreflect.FileDescriptor
var File_testrepo_analysis_v1_car_occupancy_proto protoreflect.FileDescriptor
var File_testrepo_analysis_v1_car_pit_proto protoreflect.FileDescriptor
var File_testrepo_analysis_v1_car_stint_proto protoreflect.FileDescriptor
var File_testrepo_analysis_v1_racegraph_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Analysis ¶
type Analysis struct {
CarOccupancies []*CarOccupancy `protobuf:"bytes,1,rep,name=car_occupancies,json=carOccupancies,proto3" json:"car_occupancies,omitempty"`
CarLaps []*CarLaps `protobuf:"bytes,2,rep,name=car_laps,json=carLaps,proto3" json:"car_laps,omitempty"`
CarPits []*CarPit `protobuf:"bytes,3,rep,name=car_pits,json=carPits,proto3" json:"car_pits,omitempty"`
CarStints []*CarStint `protobuf:"bytes,4,rep,name=car_stints,json=carStints,proto3" json:"car_stints,omitempty"`
CarComputeStates []*CarComputeState `protobuf:"bytes,5,rep,name=car_compute_states,json=carComputeStates,proto3" json:"car_compute_states,omitempty"`
RaceGraph []*RaceGraph `protobuf:"bytes,6,rep,name=race_graph,json=raceGraph,proto3" json:"race_graph,omitempty"`
RaceOrder []string `protobuf:"bytes,7,rep,name=race_order,json=raceOrder,proto3" json:"race_order,omitempty"`
// contains filtered or unexported fields
}
func (*Analysis) GetCarComputeStates ¶
func (x *Analysis) GetCarComputeStates() []*CarComputeState
func (*Analysis) GetCarOccupancies ¶
func (x *Analysis) GetCarOccupancies() []*CarOccupancy
func (*Analysis) ProtoReflect ¶
func (x *Analysis) ProtoReflect() protoreflect.Message
func (*Analysis) SetCarComputeStates ¶
func (x *Analysis) SetCarComputeStates(v []*CarComputeState)
func (*Analysis) SetCarOccupancies ¶
func (x *Analysis) SetCarOccupancies(v []*CarOccupancy)
type Analysis_builder ¶
type Analysis_builder struct {
CarOccupancies []*CarOccupancy
CarLaps []*CarLaps
CarPits []*CarPit
CarStints []*CarStint
CarComputeStates []*CarComputeState
RaceGraph []*RaceGraph
RaceOrder []string
// contains filtered or unexported fields
}
func (Analysis_builder) Build ¶
func (b0 Analysis_builder) Build() *Analysis
type CarComputeState ¶
type CarComputeState struct {
CarNum string `protobuf:"bytes,1,opt,name=car_num,json=carNum,proto3" json:"car_num,omitempty"`
CarState v1.CarState `protobuf:"varint,2,opt,name=car_state,json=carState,proto3,enum=testrepo.racestate.v1.CarState" json:"car_state,omitempty"`
OutEncountered float32 `protobuf:"fixed32,3,opt,name=out_encountered,json=outEncountered,proto3" json:"out_encountered,omitempty"`
// contains filtered or unexported fields
}
func (*CarComputeState) GetCarNum ¶
func (x *CarComputeState) GetCarNum() string
func (*CarComputeState) GetCarState ¶
func (x *CarComputeState) GetCarState() v1.CarState
func (*CarComputeState) GetOutEncountered ¶
func (x *CarComputeState) GetOutEncountered() float32
func (*CarComputeState) ProtoMessage ¶
func (*CarComputeState) ProtoMessage()
func (*CarComputeState) ProtoReflect ¶
func (x *CarComputeState) ProtoReflect() protoreflect.Message
func (*CarComputeState) Reset ¶
func (x *CarComputeState) Reset()
func (*CarComputeState) SetCarNum ¶
func (x *CarComputeState) SetCarNum(v string)
func (*CarComputeState) SetCarState ¶
func (x *CarComputeState) SetCarState(v v1.CarState)
func (*CarComputeState) SetOutEncountered ¶
func (x *CarComputeState) SetOutEncountered(v float32)
func (*CarComputeState) String ¶
func (x *CarComputeState) String() string
type CarComputeState_builder ¶
type CarComputeState_builder struct {
CarNum string
CarState v1.CarState
OutEncountered float32
// contains filtered or unexported fields
}
func (CarComputeState_builder) Build ¶
func (b0 CarComputeState_builder) Build() *CarComputeState
type CarLaps ¶
type CarLaps struct {
CarNum string `protobuf:"bytes,1,opt,name=car_num,json=carNum,proto3" json:"car_num,omitempty"`
Laps []*Lap `protobuf:"bytes,2,rep,name=laps,proto3" json:"laps,omitempty"`
// contains filtered or unexported fields
}
CarLaps
func (*CarLaps) ProtoReflect ¶
func (x *CarLaps) ProtoReflect() protoreflect.Message
type CarLaps_builder ¶
func (CarLaps_builder) Build ¶
func (b0 CarLaps_builder) Build() *CarLaps
type CarOccupancy ¶
type CarOccupancy struct {
// in team races this is the team name, otherwise the driver name
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
CarNum string `protobuf:"bytes,2,opt,name=car_num,json=carNum,proto3" json:"car_num,omitempty"`
CarClass string `protobuf:"bytes,3,opt,name=car_class,json=carClass,proto3" json:"car_class,omitempty"`
CurrentDriverName string `protobuf:"bytes,4,opt,name=current_driver_name,json=currentDriverName,proto3" json:"current_driver_name,omitempty"`
Drivers []*Driver `protobuf:"bytes,5,rep,name=drivers,proto3" json:"drivers,omitempty"`
// contains filtered or unexported fields
}
CarOccupancy contains information which drivers used a specific car
func (*CarOccupancy) GetCarClass ¶
func (x *CarOccupancy) GetCarClass() string
func (*CarOccupancy) GetCarNum ¶
func (x *CarOccupancy) GetCarNum() string
func (*CarOccupancy) GetCurrentDriverName ¶
func (x *CarOccupancy) GetCurrentDriverName() string
func (*CarOccupancy) GetDrivers ¶
func (x *CarOccupancy) GetDrivers() []*Driver
func (*CarOccupancy) GetName ¶
func (x *CarOccupancy) GetName() string
func (*CarOccupancy) ProtoMessage ¶
func (*CarOccupancy) ProtoMessage()
func (*CarOccupancy) ProtoReflect ¶
func (x *CarOccupancy) ProtoReflect() protoreflect.Message
func (*CarOccupancy) Reset ¶
func (x *CarOccupancy) Reset()
func (*CarOccupancy) SetCarClass ¶
func (x *CarOccupancy) SetCarClass(v string)
func (*CarOccupancy) SetCarNum ¶
func (x *CarOccupancy) SetCarNum(v string)
func (*CarOccupancy) SetCurrentDriverName ¶
func (x *CarOccupancy) SetCurrentDriverName(v string)
func (*CarOccupancy) SetDrivers ¶
func (x *CarOccupancy) SetDrivers(v []*Driver)
func (*CarOccupancy) SetName ¶
func (x *CarOccupancy) SetName(v string)
func (*CarOccupancy) String ¶
func (x *CarOccupancy) String() string
type CarOccupancy_builder ¶
type CarOccupancy_builder struct {
// in team races this is the team name, otherwise the driver name
Name string
CarNum string
CarClass string
CurrentDriverName string
Drivers []*Driver
// contains filtered or unexported fields
}
func (CarOccupancy_builder) Build ¶
func (b0 CarOccupancy_builder) Build() *CarOccupancy
type CarPit ¶
type CarPit struct {
CarNum string `protobuf:"bytes,1,opt,name=car_num,json=carNum,proto3" json:"car_num,omitempty"`
Current *PitInfo `protobuf:"bytes,2,opt,name=current,proto3" json:"current,omitempty"`
History []*PitInfo `protobuf:"bytes,3,rep,name=history,proto3" json:"history,omitempty"`
// contains filtered or unexported fields
}
CarPit
func (*CarPit) ProtoReflect ¶
func (x *CarPit) ProtoReflect() protoreflect.Message
type CarPit_builder ¶
type CarPit_builder struct {
CarNum string
Current *PitInfo
History []*PitInfo
// contains filtered or unexported fields
}
func (CarPit_builder) Build ¶
func (b0 CarPit_builder) Build() *CarPit
type CarStint ¶
type CarStint struct {
CarNum string `protobuf:"bytes,1,opt,name=car_num,json=carNum,proto3" json:"car_num,omitempty"`
Current *StintInfo `protobuf:"bytes,2,opt,name=current,proto3" json:"current,omitempty"`
History []*StintInfo `protobuf:"bytes,3,rep,name=history,proto3" json:"history,omitempty"`
// contains filtered or unexported fields
}
CarStint
func (*CarStint) ProtoReflect ¶
func (x *CarStint) ProtoReflect() protoreflect.Message
type CarStint_builder ¶
type CarStint_builder struct {
CarNum string
Current *StintInfo
History []*StintInfo
// contains filtered or unexported fields
}
func (CarStint_builder) Build ¶
func (b0 CarStint_builder) Build() *CarStint
type Driver ¶
type Driver struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
SeatTimes []*SeatTime `protobuf:"bytes,2,rep,name=seat_times,json=seatTimes,proto3" json:"seat_times,omitempty"`
// contains filtered or unexported fields
}
func (*Driver) ProtoReflect ¶
func (x *Driver) ProtoReflect() protoreflect.Message
type Driver_builder ¶
type Driver_builder struct {
Name string
SeatTimes []*SeatTime
// contains filtered or unexported fields
}
func (Driver_builder) Build ¶
func (b0 Driver_builder) Build() *Driver
type GapInfo ¶
type GapInfo struct {
CarNum string `protobuf:"bytes,1,opt,name=car_num,json=carNum,proto3" json:"car_num,omitempty"`
LapNo int32 `protobuf:"varint,2,opt,name=lap_no,json=lapNo,proto3" json:"lap_no,omitempty"`
Pos int32 `protobuf:"varint,3,opt,name=pos,proto3" json:"pos,omitempty"`
Pic int32 `protobuf:"varint,4,opt,name=pic,proto3" json:"pic,omitempty"`
Gap float32 `protobuf:"fixed32,5,opt,name=gap,proto3" json:"gap,omitempty"`
// contains filtered or unexported fields
}
func (*GapInfo) ProtoReflect ¶
func (x *GapInfo) ProtoReflect() protoreflect.Message
type GapInfo_builder ¶
type GapInfo_builder struct {
CarNum string
LapNo int32
Pos int32
Pic int32
Gap float32
// contains filtered or unexported fields
}
func (GapInfo_builder) Build ¶
func (b0 GapInfo_builder) Build() *GapInfo
type GetAnalysisRequest ¶
type GetAnalysisRequest struct {
EventSelector *v1.EventSelector `protobuf:"bytes,1,opt,name=event_selector,json=eventSelector,proto3" json:"event_selector,omitempty"`
// contains filtered or unexported fields
}
func (*GetAnalysisRequest) ClearEventSelector ¶
func (x *GetAnalysisRequest) ClearEventSelector()
func (*GetAnalysisRequest) GetEventSelector ¶
func (x *GetAnalysisRequest) GetEventSelector() *v1.EventSelector
func (*GetAnalysisRequest) HasEventSelector ¶
func (x *GetAnalysisRequest) HasEventSelector() bool
func (*GetAnalysisRequest) ProtoMessage ¶
func (*GetAnalysisRequest) ProtoMessage()
func (*GetAnalysisRequest) ProtoReflect ¶
func (x *GetAnalysisRequest) ProtoReflect() protoreflect.Message
func (*GetAnalysisRequest) Reset ¶
func (x *GetAnalysisRequest) Reset()
func (*GetAnalysisRequest) SetEventSelector ¶
func (x *GetAnalysisRequest) SetEventSelector(v *v1.EventSelector)
func (*GetAnalysisRequest) String ¶
func (x *GetAnalysisRequest) String() string
type GetAnalysisRequest_builder ¶
type GetAnalysisRequest_builder struct {
EventSelector *v1.EventSelector
// contains filtered or unexported fields
}
func (GetAnalysisRequest_builder) Build ¶
func (b0 GetAnalysisRequest_builder) Build() *GetAnalysisRequest
type GetAnalysisResponse ¶
type GetAnalysisResponse struct {
Analysis *Analysis `protobuf:"bytes,1,opt,name=analysis,proto3" json:"analysis,omitempty"`
// contains filtered or unexported fields
}
func (*GetAnalysisResponse) ClearAnalysis ¶
func (x *GetAnalysisResponse) ClearAnalysis()
func (*GetAnalysisResponse) GetAnalysis ¶
func (x *GetAnalysisResponse) GetAnalysis() *Analysis
func (*GetAnalysisResponse) HasAnalysis ¶
func (x *GetAnalysisResponse) HasAnalysis() bool
func (*GetAnalysisResponse) ProtoMessage ¶
func (*GetAnalysisResponse) ProtoMessage()
func (*GetAnalysisResponse) ProtoReflect ¶
func (x *GetAnalysisResponse) ProtoReflect() protoreflect.Message
func (*GetAnalysisResponse) Reset ¶
func (x *GetAnalysisResponse) Reset()
func (*GetAnalysisResponse) SetAnalysis ¶
func (x *GetAnalysisResponse) SetAnalysis(v *Analysis)
func (*GetAnalysisResponse) String ¶
func (x *GetAnalysisResponse) String() string
type GetAnalysisResponse_builder ¶
type GetAnalysisResponse_builder struct {
Analysis *Analysis
// contains filtered or unexported fields
}
func (GetAnalysisResponse_builder) Build ¶
func (b0 GetAnalysisResponse_builder) Build() *GetAnalysisResponse
type Lap ¶
type Lap struct {
LapNo int32 `protobuf:"varint,1,opt,name=lap_no,json=lapNo,proto3" json:"lap_no,omitempty"`
LapTime float32 `protobuf:"fixed32,2,opt,name=lap_time,json=lapTime,proto3" json:"lap_time,omitempty"`
// contains filtered or unexported fields
}
Lap
func (*Lap) ProtoReflect ¶
func (x *Lap) ProtoReflect() protoreflect.Message
type Lap_builder ¶
func (Lap_builder) Build ¶
func (b0 Lap_builder) Build() *Lap
type PitInfo ¶
type PitInfo struct {
CarNum string `protobuf:"bytes,1,opt,name=car_num,json=carNum,proto3" json:"car_num,omitempty"`
EnterTime float32 `protobuf:"fixed32,2,opt,name=enter_time,json=enterTime,proto3" json:"enter_time,omitempty"`
ExitTime float32 `protobuf:"fixed32,3,opt,name=exit_time,json=exitTime,proto3" json:"exit_time,omitempty"`
LapEnter int32 `protobuf:"varint,4,opt,name=lap_enter,json=lapEnter,proto3" json:"lap_enter,omitempty"`
LapExit int32 `protobuf:"varint,5,opt,name=lap_exit,json=lapExit,proto3" json:"lap_exit,omitempty"`
LaneTime float32 `protobuf:"fixed32,6,opt,name=lane_time,json=laneTime,proto3" json:"lane_time,omitempty"`
IsCurrentPitstop bool `protobuf:"varint,7,opt,name=is_current_pitstop,json=isCurrentPitstop,proto3" json:"is_current_pitstop,omitempty"`
// contains filtered or unexported fields
}
func (*PitInfo) ProtoReflect ¶
func (x *PitInfo) ProtoReflect() protoreflect.Message
type PitInfo_builder ¶
type PitInfo_builder struct {
CarNum string
EnterTime float32
ExitTime float32
LapEnter int32
LapExit int32
LaneTime float32
IsCurrentPitstop bool
// contains filtered or unexported fields
}
func (PitInfo_builder) Build ¶
func (b0 PitInfo_builder) Build() *PitInfo
type RaceGraph ¶
type RaceGraph struct {
LapNo int32 `protobuf:"varint,1,opt,name=lap_no,json=lapNo,proto3" json:"lap_no,omitempty"`
CarClass string `protobuf:"bytes,2,opt,name=car_class,json=carClass,proto3" json:"car_class,omitempty"`
Gaps []*GapInfo `protobuf:"bytes,3,rep,name=gaps,proto3" json:"gaps,omitempty"`
// contains filtered or unexported fields
}
func (*RaceGraph) ProtoReflect ¶
func (x *RaceGraph) ProtoReflect() protoreflect.Message
type RaceGraph_builder ¶
type RaceGraph_builder struct {
LapNo int32
CarClass string
Gaps []*GapInfo
// contains filtered or unexported fields
}
func (RaceGraph_builder) Build ¶
func (b0 RaceGraph_builder) Build() *RaceGraph
type SeatTime ¶
type SeatTime struct {
EnterCarTime float32 `protobuf:"fixed32,1,opt,name=enter_car_time,json=enterCarTime,proto3" json:"enter_car_time,omitempty"`
LeaveCarTime float32 `protobuf:"fixed32,2,opt,name=leave_car_time,json=leaveCarTime,proto3" json:"leave_car_time,omitempty"`
// contains filtered or unexported fields
}
func (*SeatTime) ProtoReflect ¶
func (x *SeatTime) ProtoReflect() protoreflect.Message
type SeatTime_builder ¶
type SeatTime_builder struct {
EnterCarTime float32
LeaveCarTime float32
// contains filtered or unexported fields
}
func (SeatTime_builder) Build ¶
func (b0 SeatTime_builder) Build() *SeatTime
type StintInfo ¶
type StintInfo struct {
CarNum string `protobuf:"bytes,1,opt,name=car_num,json=carNum,proto3" json:"car_num,omitempty"`
EnterTime float32 `protobuf:"fixed32,2,opt,name=enter_time,json=enterTime,proto3" json:"enter_time,omitempty"`
ExitTime float32 `protobuf:"fixed32,3,opt,name=exit_time,json=exitTime,proto3" json:"exit_time,omitempty"`
LapEnter int32 `protobuf:"varint,4,opt,name=lap_enter,json=lapEnter,proto3" json:"lap_enter,omitempty"`
LapExit int32 `protobuf:"varint,5,opt,name=lap_exit,json=lapExit,proto3" json:"lap_exit,omitempty"`
StintTime float32 `protobuf:"fixed32,6,opt,name=stint_time,json=stintTime,proto3" json:"stint_time,omitempty"`
NumLaps int32 `protobuf:"varint,7,opt,name=num_laps,json=numLaps,proto3" json:"num_laps,omitempty"`
IsCurrentStint bool `protobuf:"varint,8,opt,name=is_current_stint,json=isCurrentStint,proto3" json:"is_current_stint,omitempty"`
// contains filtered or unexported fields
}
func (*StintInfo) ProtoReflect ¶
func (x *StintInfo) ProtoReflect() protoreflect.Message
type StintInfo_builder ¶
type StintInfo_builder struct {
CarNum string
EnterTime float32
ExitTime float32
LapEnter int32
LapExit int32
StintTime float32
NumLaps int32
IsCurrentStint bool
// contains filtered or unexported fields
}
func (StintInfo_builder) Build ¶
func (b0 StintInfo_builder) Build() *StintInfo
Source Files
¶
- analysis.pb.go
- analysis_service.pb.go
- car_compute_state.pb.go
- car_laps.pb.go
- car_occupancy.pb.go
- car_pit.pb.go
- car_stint.pb.go
- racegraph.pb.go
Click to show internal directories.
Click to hide internal directories.