Documentation
¶
Index ¶
- Constants
- func NewSantaSyncHandler(svc SantaSyncHandler, opts ...connect.HandlerOption) (string, http.Handler)
- type SantaSyncClient
- type SantaSyncHandler
- type UnimplementedSantaSyncHandler
- func (UnimplementedSantaSyncHandler) EventUpload(context.Context, *connect.Request[sync.EventUploadRequest]) (*connect.Response[sync.EventUploadResponse], error)
- func (UnimplementedSantaSyncHandler) Postflight(context.Context, *connect.Request[sync.PostflightRequest]) (*connect.Response[sync.PostflightResponse], error)
- func (UnimplementedSantaSyncHandler) Preflight(context.Context, *connect.Request[sync.PreflightRequest]) (*connect.Response[sync.PreflightResponse], error)
- func (UnimplementedSantaSyncHandler) RuleDownload(context.Context, *connect.Request[sync.RuleDownloadRequest]) (*connect.Response[sync.RuleDownloadResponse], error)
Constants ¶
const ( // SantaSyncPreflightProcedure is the fully-qualified name of the SantaSync's Preflight RPC. SantaSyncPreflightProcedure = "/santa.sync.v1.SantaSync/Preflight" // SantaSyncEventUploadProcedure is the fully-qualified name of the SantaSync's EventUpload RPC. SantaSyncEventUploadProcedure = "/santa.sync.v1.SantaSync/EventUpload" // SantaSyncRuleDownloadProcedure is the fully-qualified name of the SantaSync's RuleDownload RPC. SantaSyncRuleDownloadProcedure = "/santa.sync.v1.SantaSync/RuleDownload" // SantaSyncPostflightProcedure is the fully-qualified name of the SantaSync's Postflight RPC. SantaSyncPostflightProcedure = "/santa.sync.v1.SantaSync/Postflight" )
These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.
Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.
const (
// SantaSyncName is the fully-qualified name of the SantaSync service.
SantaSyncName = "santa.sync.v1.SantaSync"
)
Variables ¶
This section is empty.
Functions ¶
func NewSantaSyncHandler ¶
func NewSantaSyncHandler(svc SantaSyncHandler, opts ...connect.HandlerOption) (string, http.Handler)
NewSantaSyncHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.
By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.
Types ¶
type SantaSyncClient ¶
type SantaSyncClient interface {
// Preflight is used to send current configuration data to the server and to
// retrieve new configuration values from the server.
Preflight(context.Context, *connect.Request[sync.PreflightRequest]) (*connect.Response[sync.PreflightResponse], error)
// EventUpload sends details about blocked (or would-be-blocked) executions to
// the server.
EventUpload(context.Context, *connect.Request[sync.EventUploadRequest]) (*connect.Response[sync.EventUploadResponse], error)
// RuleDownload retrieves new rules from the server.
RuleDownload(context.Context, *connect.Request[sync.RuleDownloadRequest]) (*connect.Response[sync.RuleDownloadResponse], error)
// Postflight sends status data back to the server after applying any new
// configuration received in the previous stages.
Postflight(context.Context, *connect.Request[sync.PostflightRequest]) (*connect.Response[sync.PostflightResponse], error)
}
SantaSyncClient is a client for the santa.sync.v1.SantaSync service.
func NewSantaSyncClient ¶
func NewSantaSyncClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) SantaSyncClient
NewSantaSyncClient constructs a client for the santa.sync.v1.SantaSync service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.
The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).
type SantaSyncHandler ¶
type SantaSyncHandler interface {
// Preflight is used to send current configuration data to the server and to
// retrieve new configuration values from the server.
Preflight(context.Context, *connect.Request[sync.PreflightRequest]) (*connect.Response[sync.PreflightResponse], error)
// EventUpload sends details about blocked (or would-be-blocked) executions to
// the server.
EventUpload(context.Context, *connect.Request[sync.EventUploadRequest]) (*connect.Response[sync.EventUploadResponse], error)
// RuleDownload retrieves new rules from the server.
RuleDownload(context.Context, *connect.Request[sync.RuleDownloadRequest]) (*connect.Response[sync.RuleDownloadResponse], error)
// Postflight sends status data back to the server after applying any new
// configuration received in the previous stages.
Postflight(context.Context, *connect.Request[sync.PostflightRequest]) (*connect.Response[sync.PostflightResponse], error)
}
SantaSyncHandler is an implementation of the santa.sync.v1.SantaSync service.
type UnimplementedSantaSyncHandler ¶
type UnimplementedSantaSyncHandler struct{}
UnimplementedSantaSyncHandler returns CodeUnimplemented from all methods.
func (UnimplementedSantaSyncHandler) EventUpload ¶
func (UnimplementedSantaSyncHandler) EventUpload(context.Context, *connect.Request[sync.EventUploadRequest]) (*connect.Response[sync.EventUploadResponse], error)
func (UnimplementedSantaSyncHandler) Postflight ¶
func (UnimplementedSantaSyncHandler) Postflight(context.Context, *connect.Request[sync.PostflightRequest]) (*connect.Response[sync.PostflightResponse], error)
func (UnimplementedSantaSyncHandler) Preflight ¶
func (UnimplementedSantaSyncHandler) Preflight(context.Context, *connect.Request[sync.PreflightRequest]) (*connect.Response[sync.PreflightResponse], error)
func (UnimplementedSantaSyncHandler) RuleDownload ¶
func (UnimplementedSantaSyncHandler) RuleDownload(context.Context, *connect.Request[sync.RuleDownloadRequest]) (*connect.Response[sync.RuleDownloadResponse], error)
Source Files
¶
- v1.connect.go