Documentation
¶
Index ¶
- Constants
- func NewPetStoreHandler(svc PetStoreHandler, opts ...connect.HandlerOption) (string, http.Handler)
- type PetStoreClient
- type PetStoreHandler
- type UnimplementedPetStoreHandler
- func (UnimplementedPetStoreHandler) DeletePet(context.Context, *connect.Request[v1.DeletePetRequest]) (*connect.Response[v1.DeletePetResponse], error)
- func (UnimplementedPetStoreHandler) GetPet(context.Context, *connect.Request[v1.GetPetRequest]) (*connect.Response[v1.GetPetResponse], error)
- func (UnimplementedPetStoreHandler) PutPet(context.Context, *connect.Request[v1.PutPetRequest]) (*connect.Response[v1.PutPetResponse], error)
Constants ¶
const ( // PetStoreGetPetProcedure is the fully-qualified name of the PetStore's GetPet RPC. PetStoreGetPetProcedure = "/pet.v1.PetStore/GetPet" // PetStorePutPetProcedure is the fully-qualified name of the PetStore's PutPet RPC. PetStorePutPetProcedure = "/pet.v1.PetStore/PutPet" // PetStoreDeletePetProcedure is the fully-qualified name of the PetStore's DeletePet RPC. PetStoreDeletePetProcedure = "/pet.v1.PetStore/DeletePet" )
These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.
Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.
const (
// PetStoreName is the fully-qualified name of the PetStore service.
PetStoreName = "pet.v1.PetStore"
)
Variables ¶
This section is empty.
Functions ¶
func NewPetStoreHandler ¶
func NewPetStoreHandler(svc PetStoreHandler, opts ...connect.HandlerOption) (string, http.Handler)
NewPetStoreHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.
By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.
Types ¶
type PetStoreClient ¶
type PetStoreClient interface {
GetPet(context.Context, *connect.Request[v1.GetPetRequest]) (*connect.Response[v1.GetPetResponse], error)
PutPet(context.Context, *connect.Request[v1.PutPetRequest]) (*connect.Response[v1.PutPetResponse], error)
DeletePet(context.Context, *connect.Request[v1.DeletePetRequest]) (*connect.Response[v1.DeletePetResponse], error)
}
PetStoreClient is a client for the pet.v1.PetStore service.
func NewPetStoreClient ¶
func NewPetStoreClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) PetStoreClient
NewPetStoreClient constructs a client for the pet.v1.PetStore service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.
The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).
type PetStoreHandler ¶
type PetStoreHandler interface {
GetPet(context.Context, *connect.Request[v1.GetPetRequest]) (*connect.Response[v1.GetPetResponse], error)
PutPet(context.Context, *connect.Request[v1.PutPetRequest]) (*connect.Response[v1.PutPetResponse], error)
DeletePet(context.Context, *connect.Request[v1.DeletePetRequest]) (*connect.Response[v1.DeletePetResponse], error)
}
PetStoreHandler is an implementation of the pet.v1.PetStore service.
type UnimplementedPetStoreHandler ¶
type UnimplementedPetStoreHandler struct{}
UnimplementedPetStoreHandler returns CodeUnimplemented from all methods.
func (UnimplementedPetStoreHandler) DeletePet ¶
func (UnimplementedPetStoreHandler) DeletePet(context.Context, *connect.Request[v1.DeletePetRequest]) (*connect.Response[v1.DeletePetResponse], error)
func (UnimplementedPetStoreHandler) GetPet ¶
func (UnimplementedPetStoreHandler) GetPet(context.Context, *connect.Request[v1.GetPetRequest]) (*connect.Response[v1.GetPetResponse], error)
func (UnimplementedPetStoreHandler) PutPet ¶
func (UnimplementedPetStoreHandler) PutPet(context.Context, *connect.Request[v1.PutPetRequest]) (*connect.Response[v1.PutPetResponse], error)
Source Files
¶
- pet.connect.go