Documentation
¶
Index ¶
- Constants
- Variables
- type AvatarColor
- type BcryptHashingConfig
- type BcryptHashingConfig_builder
- type BcryptHashingInstance
- type BcryptHashingInstance_builder
- type HashingConfig
- func (x *HashingConfig) ClearBcrypt()
- func (x *HashingConfig) ClearMethod()
- func (x *HashingConfig) ClearScrypt()
- func (x *HashingConfig) GetBcrypt() *BcryptHashingConfig
- func (x *HashingConfig) GetMethod() isHashingConfig_Method
- func (x *HashingConfig) GetScrypt() *ScryptHashingConfig
- func (x *HashingConfig) HasBcrypt() bool
- func (x *HashingConfig) HasMethod() bool
- func (x *HashingConfig) HasScrypt() bool
- func (*HashingConfig) ProtoMessage()
- func (x *HashingConfig) ProtoReflect() protoreflect.Message
- func (x *HashingConfig) Reset()
- func (x *HashingConfig) SetBcrypt(v *BcryptHashingConfig)
- func (x *HashingConfig) SetScrypt(v *ScryptHashingConfig)
- func (x *HashingConfig) String() string
- func (x *HashingConfig) WhichMethod() case_HashingConfig_Method
- type HashingConfig_Bcrypt
- type HashingConfig_Scrypt
- type HashingConfig_builder
- type HashingInstance
- func (x *HashingInstance) ClearBcrypt()
- func (x *HashingInstance) ClearConfig()
- func (x *HashingInstance) ClearInstance()
- func (x *HashingInstance) ClearScrypt()
- func (x *HashingInstance) GetBcrypt() *BcryptHashingInstance
- func (x *HashingInstance) GetConfig() *HashingConfig
- func (x *HashingInstance) GetHash() []byte
- func (x *HashingInstance) GetInstance() isHashingInstance_Instance
- func (x *HashingInstance) GetScrypt() *ScryptHashingInstance
- func (x *HashingInstance) HasBcrypt() bool
- func (x *HashingInstance) HasConfig() bool
- func (x *HashingInstance) HasInstance() bool
- func (x *HashingInstance) HasScrypt() bool
- func (*HashingInstance) ProtoMessage()
- func (x *HashingInstance) ProtoReflect() protoreflect.Message
- func (x *HashingInstance) Reset()
- func (x *HashingInstance) SetBcrypt(v *BcryptHashingInstance)
- func (x *HashingInstance) SetConfig(v *HashingConfig)
- func (x *HashingInstance) SetHash(v []byte)
- func (x *HashingInstance) SetScrypt(v *ScryptHashingInstance)
- func (x *HashingInstance) String() string
- func (x *HashingInstance) WhichInstance() case_HashingInstance_Instance
- type HashingInstance_Bcrypt
- type HashingInstance_Scrypt
- type HashingInstance_builder
- type Image
- func (x *Image) ClearExpiresAt()
- func (x *Image) GetExpires() bool
- func (x *Image) GetExpiresAt() *timestamppb.Timestamp
- func (x *Image) GetKey() string
- func (x *Image) GetUrl() string
- func (x *Image) HasExpiresAt() bool
- func (*Image) ProtoMessage()
- func (x *Image) ProtoReflect() protoreflect.Message
- func (x *Image) Reset()
- func (x *Image) SetExpires(v bool)
- func (x *Image) SetExpiresAt(v *timestamppb.Timestamp)
- func (x *Image) SetKey(v string)
- func (x *Image) SetUrl(v string)
- func (x *Image) String() string
- type Image_builder
- type Metadata
- type Metadata_builder
- type Pagination
- func (x *Pagination) GetDescending() bool
- func (x *Pagination) GetLimit() uint32
- func (x *Pagination) GetOffset() uint32
- func (*Pagination) ProtoMessage()
- func (x *Pagination) ProtoReflect() protoreflect.Message
- func (x *Pagination) Reset()
- func (x *Pagination) SetDescending(v bool)
- func (x *Pagination) SetLimit(v uint32)
- func (x *Pagination) SetOffset(v uint32)
- func (x *Pagination) String() string
- type Pagination_builder
- type ScryptHashingConfig
- func (x *ScryptHashingConfig) GetKeyLen() int32
- func (x *ScryptHashingConfig) GetMemCost() int32
- func (x *ScryptHashingConfig) GetP() int32
- func (x *ScryptHashingConfig) GetRounds() int32
- func (x *ScryptHashingConfig) GetSaltSeparator() string
- func (x *ScryptHashingConfig) GetSignerKey() string
- func (*ScryptHashingConfig) ProtoMessage()
- func (x *ScryptHashingConfig) ProtoReflect() protoreflect.Message
- func (x *ScryptHashingConfig) Reset()
- func (x *ScryptHashingConfig) SetKeyLen(v int32)
- func (x *ScryptHashingConfig) SetMemCost(v int32)
- func (x *ScryptHashingConfig) SetP(v int32)
- func (x *ScryptHashingConfig) SetRounds(v int32)
- func (x *ScryptHashingConfig) SetSaltSeparator(v string)
- func (x *ScryptHashingConfig) SetSignerKey(v string)
- func (x *ScryptHashingConfig) String() string
- type ScryptHashingConfig_builder
- type ScryptHashingInstance
- type ScryptHashingInstance_builder
Constants ¶
const HashingConfig_Bcrypt_case case_HashingConfig_Method = 1
const HashingConfig_Method_not_set_case case_HashingConfig_Method = 0
const HashingConfig_Scrypt_case case_HashingConfig_Method = 2
const HashingInstance_Bcrypt_case case_HashingInstance_Instance = 3
const HashingInstance_Instance_not_set_case case_HashingInstance_Instance = 0
const HashingInstance_Scrypt_case case_HashingInstance_Instance = 4
Variables ¶
var ( AvatarColor_name = map[int32]string{ 0: "AVATAR_COLOR_UNSPECIFIED", 1: "AVATAR_COLOR_BLUE", 2: "AVATAR_COLOR_GREEN", 3: "AVATAR_COLOR_RED", 4: "AVATAR_COLOR_ORANGE", } AvatarColor_value = map[string]int32{ "AVATAR_COLOR_UNSPECIFIED": 0, "AVATAR_COLOR_BLUE": 1, "AVATAR_COLOR_GREEN": 2, "AVATAR_COLOR_RED": 3, "AVATAR_COLOR_ORANGE": 4, } )
Enum value maps for AvatarColor.
var File_nuntio_management_model_common_common_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type AvatarColor ¶
type AvatarColor int32
const ( AvatarColor_AVATAR_COLOR_UNSPECIFIED AvatarColor = 0 AvatarColor_AVATAR_COLOR_BLUE AvatarColor = 1 AvatarColor_AVATAR_COLOR_GREEN AvatarColor = 2 AvatarColor_AVATAR_COLOR_RED AvatarColor = 3 AvatarColor_AVATAR_COLOR_ORANGE AvatarColor = 4 )
func (AvatarColor) Descriptor ¶
func (AvatarColor) Descriptor() protoreflect.EnumDescriptor
func (AvatarColor) Enum ¶
func (x AvatarColor) Enum() *AvatarColor
func (AvatarColor) Number ¶
func (x AvatarColor) Number() protoreflect.EnumNumber
func (AvatarColor) String ¶
func (x AvatarColor) String() string
func (AvatarColor) Type ¶
func (AvatarColor) Type() protoreflect.EnumType
type BcryptHashingConfig ¶
type BcryptHashingConfig struct {
Cost int32 `protobuf:"varint,1,opt,name=cost,proto3" json:"cost,omitempty"`
// contains filtered or unexported fields
}
func (*BcryptHashingConfig) GetCost ¶
func (x *BcryptHashingConfig) GetCost() int32
func (*BcryptHashingConfig) ProtoMessage ¶
func (*BcryptHashingConfig) ProtoMessage()
func (*BcryptHashingConfig) ProtoReflect ¶
func (x *BcryptHashingConfig) ProtoReflect() protoreflect.Message
func (*BcryptHashingConfig) Reset ¶
func (x *BcryptHashingConfig) Reset()
func (*BcryptHashingConfig) SetCost ¶
func (x *BcryptHashingConfig) SetCost(v int32)
func (*BcryptHashingConfig) String ¶
func (x *BcryptHashingConfig) String() string
type BcryptHashingConfig_builder ¶
type BcryptHashingConfig_builder struct {
Cost int32
// contains filtered or unexported fields
}
func (BcryptHashingConfig_builder) Build ¶
func (b0 BcryptHashingConfig_builder) Build() *BcryptHashingConfig
type BcryptHashingInstance ¶
type BcryptHashingInstance struct {
// contains filtered or unexported fields
}
func (*BcryptHashingInstance) ProtoMessage ¶
func (*BcryptHashingInstance) ProtoMessage()
func (*BcryptHashingInstance) ProtoReflect ¶
func (x *BcryptHashingInstance) ProtoReflect() protoreflect.Message
func (*BcryptHashingInstance) Reset ¶
func (x *BcryptHashingInstance) Reset()
func (*BcryptHashingInstance) String ¶
func (x *BcryptHashingInstance) String() string
type BcryptHashingInstance_builder ¶
type BcryptHashingInstance_builder struct {
// contains filtered or unexported fields
}
func (BcryptHashingInstance_builder) Build ¶
func (b0 BcryptHashingInstance_builder) Build() *BcryptHashingInstance
type HashingConfig ¶
type HashingConfig struct {
// Types that are valid to be assigned to Method:
//
// *HashingConfig_Bcrypt
// *HashingConfig_Scrypt
Method isHashingConfig_Method `protobuf_oneof:"method"`
// contains filtered or unexported fields
}
func (*HashingConfig) ClearBcrypt ¶
func (x *HashingConfig) ClearBcrypt()
func (*HashingConfig) ClearMethod ¶
func (x *HashingConfig) ClearMethod()
func (*HashingConfig) ClearScrypt ¶
func (x *HashingConfig) ClearScrypt()
func (*HashingConfig) GetBcrypt ¶
func (x *HashingConfig) GetBcrypt() *BcryptHashingConfig
func (*HashingConfig) GetMethod ¶
func (x *HashingConfig) GetMethod() isHashingConfig_Method
func (*HashingConfig) GetScrypt ¶
func (x *HashingConfig) GetScrypt() *ScryptHashingConfig
func (*HashingConfig) HasBcrypt ¶
func (x *HashingConfig) HasBcrypt() bool
func (*HashingConfig) HasMethod ¶
func (x *HashingConfig) HasMethod() bool
func (*HashingConfig) HasScrypt ¶
func (x *HashingConfig) HasScrypt() bool
func (*HashingConfig) ProtoMessage ¶
func (*HashingConfig) ProtoMessage()
func (*HashingConfig) ProtoReflect ¶
func (x *HashingConfig) ProtoReflect() protoreflect.Message
func (*HashingConfig) Reset ¶
func (x *HashingConfig) Reset()
func (*HashingConfig) SetBcrypt ¶
func (x *HashingConfig) SetBcrypt(v *BcryptHashingConfig)
func (*HashingConfig) SetScrypt ¶
func (x *HashingConfig) SetScrypt(v *ScryptHashingConfig)
func (*HashingConfig) String ¶
func (x *HashingConfig) String() string
func (*HashingConfig) WhichMethod ¶
func (x *HashingConfig) WhichMethod() case_HashingConfig_Method
type HashingConfig_Bcrypt ¶
type HashingConfig_Bcrypt struct {
Bcrypt *BcryptHashingConfig `protobuf:"bytes,1,opt,name=bcrypt,proto3,oneof"`
}
type HashingConfig_Scrypt ¶
type HashingConfig_Scrypt struct {
Scrypt *ScryptHashingConfig `protobuf:"bytes,2,opt,name=scrypt,proto3,oneof"`
}
type HashingConfig_builder ¶
type HashingConfig_builder struct {
// Fields of oneof Method:
Bcrypt *BcryptHashingConfig
Scrypt *ScryptHashingConfig
// contains filtered or unexported fields
}
func (HashingConfig_builder) Build ¶
func (b0 HashingConfig_builder) Build() *HashingConfig
type HashingInstance ¶
type HashingInstance struct {
Config *HashingConfig `protobuf:"bytes,1,opt,name=config,proto3" json:"config,omitempty"`
Hash []byte `protobuf:"bytes,2,opt,name=hash,proto3" json:"hash,omitempty"`
// Types that are valid to be assigned to Instance:
//
// *HashingInstance_Bcrypt
// *HashingInstance_Scrypt
Instance isHashingInstance_Instance `protobuf_oneof:"instance"`
// contains filtered or unexported fields
}
func (*HashingInstance) ClearBcrypt ¶
func (x *HashingInstance) ClearBcrypt()
func (*HashingInstance) ClearConfig ¶
func (x *HashingInstance) ClearConfig()
func (*HashingInstance) ClearInstance ¶
func (x *HashingInstance) ClearInstance()
func (*HashingInstance) ClearScrypt ¶
func (x *HashingInstance) ClearScrypt()
func (*HashingInstance) GetBcrypt ¶
func (x *HashingInstance) GetBcrypt() *BcryptHashingInstance
func (*HashingInstance) GetConfig ¶
func (x *HashingInstance) GetConfig() *HashingConfig
func (*HashingInstance) GetHash ¶
func (x *HashingInstance) GetHash() []byte
func (*HashingInstance) GetInstance ¶
func (x *HashingInstance) GetInstance() isHashingInstance_Instance
func (*HashingInstance) GetScrypt ¶
func (x *HashingInstance) GetScrypt() *ScryptHashingInstance
func (*HashingInstance) HasBcrypt ¶
func (x *HashingInstance) HasBcrypt() bool
func (*HashingInstance) HasConfig ¶
func (x *HashingInstance) HasConfig() bool
func (*HashingInstance) HasInstance ¶
func (x *HashingInstance) HasInstance() bool
func (*HashingInstance) HasScrypt ¶
func (x *HashingInstance) HasScrypt() bool
func (*HashingInstance) ProtoMessage ¶
func (*HashingInstance) ProtoMessage()
func (*HashingInstance) ProtoReflect ¶
func (x *HashingInstance) ProtoReflect() protoreflect.Message
func (*HashingInstance) Reset ¶
func (x *HashingInstance) Reset()
func (*HashingInstance) SetBcrypt ¶
func (x *HashingInstance) SetBcrypt(v *BcryptHashingInstance)
func (*HashingInstance) SetConfig ¶
func (x *HashingInstance) SetConfig(v *HashingConfig)
func (*HashingInstance) SetHash ¶
func (x *HashingInstance) SetHash(v []byte)
func (*HashingInstance) SetScrypt ¶
func (x *HashingInstance) SetScrypt(v *ScryptHashingInstance)
func (*HashingInstance) String ¶
func (x *HashingInstance) String() string
func (*HashingInstance) WhichInstance ¶
func (x *HashingInstance) WhichInstance() case_HashingInstance_Instance
type HashingInstance_Bcrypt ¶
type HashingInstance_Bcrypt struct {
Bcrypt *BcryptHashingInstance `protobuf:"bytes,3,opt,name=bcrypt,proto3,oneof"`
}
type HashingInstance_Scrypt ¶
type HashingInstance_Scrypt struct {
Scrypt *ScryptHashingInstance `protobuf:"bytes,4,opt,name=scrypt,proto3,oneof"`
}
type HashingInstance_builder ¶
type HashingInstance_builder struct {
Config *HashingConfig
Hash []byte
// Fields of oneof Instance:
Bcrypt *BcryptHashingInstance
Scrypt *ScryptHashingInstance
// contains filtered or unexported fields
}
func (HashingInstance_builder) Build ¶
func (b0 HashingInstance_builder) Build() *HashingInstance
type Image ¶
type Image struct {
Url string `protobuf:"bytes,1,opt,name=url,proto3" json:"url,omitempty"`
ExpiresAt *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=expires_at,json=expiresAt,proto3" json:"expires_at,omitempty"`
Expires bool `protobuf:"varint,3,opt,name=expires,proto3" json:"expires,omitempty"`
Key string `protobuf:"bytes,4,opt,name=key,proto3" json:"key,omitempty"`
// contains filtered or unexported fields
}
func (*Image) GetExpiresAt ¶
func (x *Image) GetExpiresAt() *timestamppb.Timestamp
func (*Image) ProtoReflect ¶
func (x *Image) ProtoReflect() protoreflect.Message
func (*Image) SetExpiresAt ¶
func (x *Image) SetExpiresAt(v *timestamppb.Timestamp)
type Image_builder ¶
type Image_builder struct {
Url string
ExpiresAt *timestamppb.Timestamp
Expires bool
Key string
// contains filtered or unexported fields
}
func (Image_builder) Build ¶
func (b0 Image_builder) Build() *Image
type Metadata ¶
type Metadata struct {
Key string `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
Value []byte `protobuf:"bytes,2,opt,name=value,proto3" json:"value,omitempty"`
// contains filtered or unexported fields
}
func (*Metadata) ProtoReflect ¶
func (x *Metadata) ProtoReflect() protoreflect.Message
type Metadata_builder ¶
func (Metadata_builder) Build ¶
func (b0 Metadata_builder) Build() *Metadata
type Pagination ¶
type Pagination struct {
Offset uint32 `protobuf:"varint,1,opt,name=offset,proto3" json:"offset,omitempty"`
Limit uint32 `protobuf:"varint,2,opt,name=limit,proto3" json:"limit,omitempty"`
Descending bool `protobuf:"varint,3,opt,name=descending,proto3" json:"descending,omitempty"`
// contains filtered or unexported fields
}
func (*Pagination) GetDescending ¶
func (x *Pagination) GetDescending() bool
func (*Pagination) GetLimit ¶
func (x *Pagination) GetLimit() uint32
func (*Pagination) GetOffset ¶
func (x *Pagination) GetOffset() uint32
func (*Pagination) ProtoMessage ¶
func (*Pagination) ProtoMessage()
func (*Pagination) ProtoReflect ¶
func (x *Pagination) ProtoReflect() protoreflect.Message
func (*Pagination) Reset ¶
func (x *Pagination) Reset()
func (*Pagination) SetDescending ¶
func (x *Pagination) SetDescending(v bool)
func (*Pagination) SetLimit ¶
func (x *Pagination) SetLimit(v uint32)
func (*Pagination) SetOffset ¶
func (x *Pagination) SetOffset(v uint32)
func (*Pagination) String ¶
func (x *Pagination) String() string
type Pagination_builder ¶
type Pagination_builder struct {
Offset uint32
Limit uint32
Descending bool
// contains filtered or unexported fields
}
func (Pagination_builder) Build ¶
func (b0 Pagination_builder) Build() *Pagination
type ScryptHashingConfig ¶
type ScryptHashingConfig struct {
SignerKey string `protobuf:"bytes,1,opt,name=signer_key,json=signerKey,proto3" json:"signer_key,omitempty"`
SaltSeparator string `protobuf:"bytes,2,opt,name=salt_separator,json=saltSeparator,proto3" json:"salt_separator,omitempty"`
Rounds int32 `protobuf:"varint,3,opt,name=rounds,proto3" json:"rounds,omitempty"`
MemCost int32 `protobuf:"varint,4,opt,name=mem_cost,json=memCost,proto3" json:"mem_cost,omitempty"`
P int32 `protobuf:"varint,5,opt,name=p,proto3" json:"p,omitempty"`
KeyLen int32 `protobuf:"varint,6,opt,name=key_len,json=keyLen,proto3" json:"key_len,omitempty"`
// contains filtered or unexported fields
}
func (*ScryptHashingConfig) GetKeyLen ¶
func (x *ScryptHashingConfig) GetKeyLen() int32
func (*ScryptHashingConfig) GetMemCost ¶
func (x *ScryptHashingConfig) GetMemCost() int32
func (*ScryptHashingConfig) GetP ¶
func (x *ScryptHashingConfig) GetP() int32
func (*ScryptHashingConfig) GetRounds ¶
func (x *ScryptHashingConfig) GetRounds() int32
func (*ScryptHashingConfig) GetSaltSeparator ¶
func (x *ScryptHashingConfig) GetSaltSeparator() string
func (*ScryptHashingConfig) GetSignerKey ¶
func (x *ScryptHashingConfig) GetSignerKey() string
func (*ScryptHashingConfig) ProtoMessage ¶
func (*ScryptHashingConfig) ProtoMessage()
func (*ScryptHashingConfig) ProtoReflect ¶
func (x *ScryptHashingConfig) ProtoReflect() protoreflect.Message
func (*ScryptHashingConfig) Reset ¶
func (x *ScryptHashingConfig) Reset()
func (*ScryptHashingConfig) SetKeyLen ¶
func (x *ScryptHashingConfig) SetKeyLen(v int32)
func (*ScryptHashingConfig) SetMemCost ¶
func (x *ScryptHashingConfig) SetMemCost(v int32)
func (*ScryptHashingConfig) SetP ¶
func (x *ScryptHashingConfig) SetP(v int32)
func (*ScryptHashingConfig) SetRounds ¶
func (x *ScryptHashingConfig) SetRounds(v int32)
func (*ScryptHashingConfig) SetSaltSeparator ¶
func (x *ScryptHashingConfig) SetSaltSeparator(v string)
func (*ScryptHashingConfig) SetSignerKey ¶
func (x *ScryptHashingConfig) SetSignerKey(v string)
func (*ScryptHashingConfig) String ¶
func (x *ScryptHashingConfig) String() string
type ScryptHashingConfig_builder ¶
type ScryptHashingConfig_builder struct {
SignerKey string
SaltSeparator string
Rounds int32
MemCost int32
P int32
KeyLen int32
// contains filtered or unexported fields
}
func (ScryptHashingConfig_builder) Build ¶
func (b0 ScryptHashingConfig_builder) Build() *ScryptHashingConfig
type ScryptHashingInstance ¶
type ScryptHashingInstance struct {
Salt []byte `protobuf:"bytes,1,opt,name=salt,proto3" json:"salt,omitempty"`
// contains filtered or unexported fields
}
func (*ScryptHashingInstance) GetSalt ¶
func (x *ScryptHashingInstance) GetSalt() []byte
func (*ScryptHashingInstance) ProtoMessage ¶
func (*ScryptHashingInstance) ProtoMessage()
func (*ScryptHashingInstance) ProtoReflect ¶
func (x *ScryptHashingInstance) ProtoReflect() protoreflect.Message
func (*ScryptHashingInstance) Reset ¶
func (x *ScryptHashingInstance) Reset()
func (*ScryptHashingInstance) SetSalt ¶
func (x *ScryptHashingInstance) SetSalt(v []byte)
func (*ScryptHashingInstance) String ¶
func (x *ScryptHashingInstance) String() string
type ScryptHashingInstance_builder ¶
type ScryptHashingInstance_builder struct {
Salt []byte
// contains filtered or unexported fields
}
func (ScryptHashingInstance_builder) Build ¶
func (b0 ScryptHashingInstance_builder) Build() *ScryptHashingInstance
Source Files
¶
- common.pb.go
Click to show internal directories.
Click to hide internal directories.