Documentation
¶
Index ¶
- Constants
- Variables
- type Credential
- func (x *Credential) GetClientId() string
- func (x *Credential) GetClientSecret() string
- func (*Credential) ProtoMessage()
- func (x *Credential) ProtoReflect() protoreflect.Message
- func (x *Credential) Reset()
- func (x *Credential) SetClientId(v string)
- func (x *Credential) SetClientSecret(v string)
- func (x *Credential) String() string
- type Credential_builder
- type DeleteRequest
- type DeleteRequest_builder
- type DeleteResponse
- type DeleteResponse_builder
- type GetAuthConfigRequest
- func (x *GetAuthConfigRequest) GetApiKey() string
- func (x *GetAuthConfigRequest) GetRedirectAddr() string
- func (*GetAuthConfigRequest) ProtoMessage()
- func (x *GetAuthConfigRequest) ProtoReflect() protoreflect.Message
- func (x *GetAuthConfigRequest) Reset()
- func (x *GetAuthConfigRequest) SetApiKey(v string)
- func (x *GetAuthConfigRequest) SetRedirectAddr(v string)
- func (x *GetAuthConfigRequest) String() string
- type GetAuthConfigRequest_builder
- type GetAuthConfigResponse
- func (x *GetAuthConfigResponse) GetAllowsRegister() bool
- func (x *GetAuthConfigResponse) GetLoginTypes() []auth.LoginType
- func (x *GetAuthConfigResponse) GetLogoUrl() string
- func (x *GetAuthConfigResponse) GetName() string
- func (x *GetAuthConfigResponse) GetOauthProviders() []*auth.OauthProvider
- func (x *GetAuthConfigResponse) GetValidatePassword() bool
- func (*GetAuthConfigResponse) ProtoMessage()
- func (x *GetAuthConfigResponse) ProtoReflect() protoreflect.Message
- func (x *GetAuthConfigResponse) Reset()
- func (x *GetAuthConfigResponse) SetAllowsRegister(v bool)
- func (x *GetAuthConfigResponse) SetLoginTypes(v []auth.LoginType)
- func (x *GetAuthConfigResponse) SetLogoUrl(v string)
- func (x *GetAuthConfigResponse) SetName(v string)
- func (x *GetAuthConfigResponse) SetOauthProviders(v []*auth.OauthProvider)
- func (x *GetAuthConfigResponse) SetValidatePassword(v bool)
- func (x *GetAuthConfigResponse) String() string
- type GetAuthConfigResponse_builder
- type GetRequest
- type GetRequest_builder
- type GetResponse
- func (x *GetResponse) ClearUserInfo()
- func (x *GetResponse) GetUserInfo() *auth.UserInfo
- func (x *GetResponse) HasUserInfo() bool
- func (*GetResponse) ProtoMessage()
- func (x *GetResponse) ProtoReflect() protoreflect.Message
- func (x *GetResponse) Reset()
- func (x *GetResponse) SetUserInfo(v *auth.UserInfo)
- func (x *GetResponse) String() string
- type GetResponse_builder
- type LoginRequest
- func (x *LoginRequest) ClearCredential()
- func (x *LoginRequest) ClearMethod()
- func (x *LoginRequest) ClearUserPassword()
- func (x *LoginRequest) GetCredential() *Credential
- func (x *LoginRequest) GetMethod() isLoginRequest_Method
- func (x *LoginRequest) GetUserPassword() *UserPassword
- func (x *LoginRequest) HasCredential() bool
- func (x *LoginRequest) HasMethod() bool
- func (x *LoginRequest) HasUserPassword() bool
- func (*LoginRequest) ProtoMessage()
- func (x *LoginRequest) ProtoReflect() protoreflect.Message
- func (x *LoginRequest) Reset()
- func (x *LoginRequest) SetCredential(v *Credential)
- func (x *LoginRequest) SetUserPassword(v *UserPassword)
- func (x *LoginRequest) String() string
- func (x *LoginRequest) WhichMethod() case_LoginRequest_Method
- type LoginRequest_Credential
- type LoginRequest_UserPassword
- type LoginRequest_builder
- type LoginResponse
- func (x *LoginResponse) ClearToken()
- func (x *LoginResponse) GetToken() *auth.Token
- func (x *LoginResponse) HasToken() bool
- func (*LoginResponse) ProtoMessage()
- func (x *LoginResponse) ProtoReflect() protoreflect.Message
- func (x *LoginResponse) Reset()
- func (x *LoginResponse) SetToken(v *auth.Token)
- func (x *LoginResponse) String() string
- type LoginResponse_builder
- type LogoutRequest
- type LogoutRequest_builder
- type LogoutResponse
- type LogoutResponse_builder
- type PingRequest
- type PingRequest_builder
- type PingResponse
- type PingResponse_builder
- type RefreshTokenRequest
- func (x *RefreshTokenRequest) GetRefreshToken() string
- func (*RefreshTokenRequest) ProtoMessage()
- func (x *RefreshTokenRequest) ProtoReflect() protoreflect.Message
- func (x *RefreshTokenRequest) Reset()
- func (x *RefreshTokenRequest) SetRefreshToken(v string)
- func (x *RefreshTokenRequest) String() string
- type RefreshTokenRequest_builder
- type RefreshTokenResponse
- func (x *RefreshTokenResponse) ClearToken()
- func (x *RefreshTokenResponse) GetToken() *auth.Token
- func (x *RefreshTokenResponse) HasToken() bool
- func (*RefreshTokenResponse) ProtoMessage()
- func (x *RefreshTokenResponse) ProtoReflect() protoreflect.Message
- func (x *RefreshTokenResponse) Reset()
- func (x *RefreshTokenResponse) SetToken(v *auth.Token)
- func (x *RefreshTokenResponse) String() string
- type RefreshTokenResponse_builder
- type RegisterRequest
- func (x *RegisterRequest) ClearMethod()
- func (x *RegisterRequest) ClearUserPassword()
- func (x *RegisterRequest) GetMethod() isRegisterRequest_Method
- func (x *RegisterRequest) GetUserPassword() *UserPassword
- func (x *RegisterRequest) HasMethod() bool
- func (x *RegisterRequest) HasUserPassword() bool
- func (*RegisterRequest) ProtoMessage()
- func (x *RegisterRequest) ProtoReflect() protoreflect.Message
- func (x *RegisterRequest) Reset()
- func (x *RegisterRequest) SetUserPassword(v *UserPassword)
- func (x *RegisterRequest) String() string
- func (x *RegisterRequest) WhichMethod() case_RegisterRequest_Method
- type RegisterRequest_UserPassword
- type RegisterRequest_builder
- type RegisterResponse
- func (x *RegisterResponse) ClearToken()
- func (x *RegisterResponse) GetToken() *auth.Token
- func (x *RegisterResponse) HasToken() bool
- func (*RegisterResponse) ProtoMessage()
- func (x *RegisterResponse) ProtoReflect() protoreflect.Message
- func (x *RegisterResponse) Reset()
- func (x *RegisterResponse) SetToken(v *auth.Token)
- func (x *RegisterResponse) String() string
- type RegisterResponse_builder
- type ResetPasswordRequest
- func (x *ResetPasswordRequest) ClearIdentifier()
- func (x *ResetPasswordRequest) GetApiKey() string
- func (x *ResetPasswordRequest) GetCode() string
- func (x *ResetPasswordRequest) GetIdentifier() *auth.UserIdentifier
- func (x *ResetPasswordRequest) GetNewPassword() string
- func (x *ResetPasswordRequest) HasIdentifier() bool
- func (*ResetPasswordRequest) ProtoMessage()
- func (x *ResetPasswordRequest) ProtoReflect() protoreflect.Message
- func (x *ResetPasswordRequest) Reset()
- func (x *ResetPasswordRequest) SetApiKey(v string)
- func (x *ResetPasswordRequest) SetCode(v string)
- func (x *ResetPasswordRequest) SetIdentifier(v *auth.UserIdentifier)
- func (x *ResetPasswordRequest) SetNewPassword(v string)
- func (x *ResetPasswordRequest) String() string
- type ResetPasswordRequest_builder
- type ResetPasswordResponse
- type ResetPasswordResponse_builder
- type SendPasswordResetRequest
- func (x *SendPasswordResetRequest) ClearIdentifier()
- func (x *SendPasswordResetRequest) GetApiKey() string
- func (x *SendPasswordResetRequest) GetIdentifier() *auth.UserIdentifier
- func (x *SendPasswordResetRequest) HasIdentifier() bool
- func (*SendPasswordResetRequest) ProtoMessage()
- func (x *SendPasswordResetRequest) ProtoReflect() protoreflect.Message
- func (x *SendPasswordResetRequest) Reset()
- func (x *SendPasswordResetRequest) SetApiKey(v string)
- func (x *SendPasswordResetRequest) SetIdentifier(v *auth.UserIdentifier)
- func (x *SendPasswordResetRequest) String() string
- type SendPasswordResetRequest_builder
- type SendPasswordResetResponse
- type SendPasswordResetResponse_builder
- type UserPassword
- func (x *UserPassword) ClearIdentifier()
- func (x *UserPassword) GetApiKey() string
- func (x *UserPassword) GetIdentifier() *auth.UserIdentifier
- func (x *UserPassword) GetPassword() string
- func (x *UserPassword) HasIdentifier() bool
- func (*UserPassword) ProtoMessage()
- func (x *UserPassword) ProtoReflect() protoreflect.Message
- func (x *UserPassword) Reset()
- func (x *UserPassword) SetApiKey(v string)
- func (x *UserPassword) SetIdentifier(v *auth.UserIdentifier)
- func (x *UserPassword) SetPassword(v string)
- func (x *UserPassword) String() string
- type UserPassword_builder
- type VerifyEmailRequest
- func (x *VerifyEmailRequest) GetApiKey() string
- func (x *VerifyEmailRequest) GetCode() string
- func (x *VerifyEmailRequest) GetEmail() string
- func (*VerifyEmailRequest) ProtoMessage()
- func (x *VerifyEmailRequest) ProtoReflect() protoreflect.Message
- func (x *VerifyEmailRequest) Reset()
- func (x *VerifyEmailRequest) SetApiKey(v string)
- func (x *VerifyEmailRequest) SetCode(v string)
- func (x *VerifyEmailRequest) SetEmail(v string)
- func (x *VerifyEmailRequest) String() string
- type VerifyEmailRequest_builder
- type VerifyEmailResponse
- type VerifyEmailResponse_builder
- type VerifyPhoneNumberRequest
- func (x *VerifyPhoneNumberRequest) GetApiKey() string
- func (x *VerifyPhoneNumberRequest) GetCode() string
- func (x *VerifyPhoneNumberRequest) GetPhoneNumber() string
- func (*VerifyPhoneNumberRequest) ProtoMessage()
- func (x *VerifyPhoneNumberRequest) ProtoReflect() protoreflect.Message
- func (x *VerifyPhoneNumberRequest) Reset()
- func (x *VerifyPhoneNumberRequest) SetApiKey(v string)
- func (x *VerifyPhoneNumberRequest) SetCode(v string)
- func (x *VerifyPhoneNumberRequest) SetPhoneNumber(v string)
- func (x *VerifyPhoneNumberRequest) String() string
- type VerifyPhoneNumberRequest_builder
- type VerifyPhoneNumberResponse
- type VerifyPhoneNumberResponse_builder
Constants ¶
const LoginRequest_Credential_case case_LoginRequest_Method = 3
const LoginRequest_Method_not_set_case case_LoginRequest_Method = 0
const LoginRequest_UserPassword_case case_LoginRequest_Method = 1
const RegisterRequest_Method_not_set_case case_RegisterRequest_Method = 0
const RegisterRequest_UserPassword_case case_RegisterRequest_Method = 1
Variables ¶
var File_nuntio_sdk_api_auth_service_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Credential ¶
type Credential struct {
ClientId string `protobuf:"bytes,1,opt,name=client_id,json=clientId,proto3" json:"client_id,omitempty"`
ClientSecret string `protobuf:"bytes,2,opt,name=client_secret,json=clientSecret,proto3" json:"client_secret,omitempty"`
// contains filtered or unexported fields
}
func (*Credential) GetClientId ¶
func (x *Credential) GetClientId() string
func (*Credential) GetClientSecret ¶
func (x *Credential) GetClientSecret() string
func (*Credential) ProtoMessage ¶
func (*Credential) ProtoMessage()
func (*Credential) ProtoReflect ¶
func (x *Credential) ProtoReflect() protoreflect.Message
func (*Credential) Reset ¶
func (x *Credential) Reset()
func (*Credential) SetClientId ¶
func (x *Credential) SetClientId(v string)
func (*Credential) SetClientSecret ¶
func (x *Credential) SetClientSecret(v string)
func (*Credential) String ¶
func (x *Credential) String() string
type Credential_builder ¶
type Credential_builder struct {
ClientId string
ClientSecret string
// contains filtered or unexported fields
}
func (Credential_builder) Build ¶
func (b0 Credential_builder) Build() *Credential
type DeleteRequest ¶
type DeleteRequest struct {
// contains filtered or unexported fields
}
The request of a Public.Delete RPC
func (*DeleteRequest) ProtoMessage ¶
func (*DeleteRequest) ProtoMessage()
func (*DeleteRequest) ProtoReflect ¶
func (x *DeleteRequest) ProtoReflect() protoreflect.Message
func (*DeleteRequest) Reset ¶
func (x *DeleteRequest) Reset()
func (*DeleteRequest) String ¶
func (x *DeleteRequest) String() string
type DeleteRequest_builder ¶
type DeleteRequest_builder struct {
// contains filtered or unexported fields
}
func (DeleteRequest_builder) Build ¶
func (b0 DeleteRequest_builder) Build() *DeleteRequest
type DeleteResponse ¶
type DeleteResponse struct {
// contains filtered or unexported fields
}
The response of a Public.Delete RPC
func (*DeleteResponse) ProtoMessage ¶
func (*DeleteResponse) ProtoMessage()
func (*DeleteResponse) ProtoReflect ¶
func (x *DeleteResponse) ProtoReflect() protoreflect.Message
func (*DeleteResponse) Reset ¶
func (x *DeleteResponse) Reset()
func (*DeleteResponse) String ¶
func (x *DeleteResponse) String() string
type DeleteResponse_builder ¶
type DeleteResponse_builder struct {
// contains filtered or unexported fields
}
func (DeleteResponse_builder) Build ¶
func (b0 DeleteResponse_builder) Build() *DeleteResponse
type GetAuthConfigRequest ¶
type GetAuthConfigRequest struct {
// Optional redirect address for OAuth2
RedirectAddr string `protobuf:"bytes,1,opt,name=redirect_addr,json=redirectAddr,proto3" json:"redirect_addr,omitempty"`
ApiKey string `protobuf:"bytes,2,opt,name=api_key,json=apiKey,proto3" json:"api_key,omitempty"`
// contains filtered or unexported fields
}
The request of a Public.AuthenticationServiceGetAuthConfigRequest RPC
func (*GetAuthConfigRequest) GetApiKey ¶
func (x *GetAuthConfigRequest) GetApiKey() string
func (*GetAuthConfigRequest) GetRedirectAddr ¶
func (x *GetAuthConfigRequest) GetRedirectAddr() string
func (*GetAuthConfigRequest) ProtoMessage ¶
func (*GetAuthConfigRequest) ProtoMessage()
func (*GetAuthConfigRequest) ProtoReflect ¶
func (x *GetAuthConfigRequest) ProtoReflect() protoreflect.Message
func (*GetAuthConfigRequest) Reset ¶
func (x *GetAuthConfigRequest) Reset()
func (*GetAuthConfigRequest) SetApiKey ¶
func (x *GetAuthConfigRequest) SetApiKey(v string)
func (*GetAuthConfigRequest) SetRedirectAddr ¶
func (x *GetAuthConfigRequest) SetRedirectAddr(v string)
func (*GetAuthConfigRequest) String ¶
func (x *GetAuthConfigRequest) String() string
type GetAuthConfigRequest_builder ¶
type GetAuthConfigRequest_builder struct {
// Optional redirect address for OAuth2
RedirectAddr string
ApiKey string
// contains filtered or unexported fields
}
func (GetAuthConfigRequest_builder) Build ¶
func (b0 GetAuthConfigRequest_builder) Build() *GetAuthConfigRequest
type GetAuthConfigResponse ¶
type GetAuthConfigResponse struct {
// The name of the project
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// The logo of the project
LogoUrl string `protobuf:"bytes,2,opt,name=logo_url,json=logoUrl,proto3" json:"logo_url,omitempty"`
// If to validate password
ValidatePassword bool `protobuf:"varint,3,opt,name=validate_password,json=validatePassword,proto3" json:"validate_password,omitempty"`
// Array of supported login methods.
LoginTypes []auth.LoginType `` /* 136-byte string literal not displayed */
// Array of supported oauth providers.
OauthProviders []*auth.OauthProvider `protobuf:"bytes,5,rep,name=oauth_providers,json=oauthProviders,proto3" json:"oauth_providers,omitempty"`
// True if new users can sign up.
AllowsRegister bool `protobuf:"varint,7,opt,name=allows_register,json=allowsRegister,proto3" json:"allows_register,omitempty"`
// contains filtered or unexported fields
}
The response of a Public.AuthenticationServiceGetAuthConfigRequest RPC
func (*GetAuthConfigResponse) GetAllowsRegister ¶
func (x *GetAuthConfigResponse) GetAllowsRegister() bool
func (*GetAuthConfigResponse) GetLoginTypes ¶
func (x *GetAuthConfigResponse) GetLoginTypes() []auth.LoginType
func (*GetAuthConfigResponse) GetLogoUrl ¶
func (x *GetAuthConfigResponse) GetLogoUrl() string
func (*GetAuthConfigResponse) GetName ¶
func (x *GetAuthConfigResponse) GetName() string
func (*GetAuthConfigResponse) GetOauthProviders ¶
func (x *GetAuthConfigResponse) GetOauthProviders() []*auth.OauthProvider
func (*GetAuthConfigResponse) GetValidatePassword ¶
func (x *GetAuthConfigResponse) GetValidatePassword() bool
func (*GetAuthConfigResponse) ProtoMessage ¶
func (*GetAuthConfigResponse) ProtoMessage()
func (*GetAuthConfigResponse) ProtoReflect ¶
func (x *GetAuthConfigResponse) ProtoReflect() protoreflect.Message
func (*GetAuthConfigResponse) Reset ¶
func (x *GetAuthConfigResponse) Reset()
func (*GetAuthConfigResponse) SetAllowsRegister ¶
func (x *GetAuthConfigResponse) SetAllowsRegister(v bool)
func (*GetAuthConfigResponse) SetLoginTypes ¶
func (x *GetAuthConfigResponse) SetLoginTypes(v []auth.LoginType)
func (*GetAuthConfigResponse) SetLogoUrl ¶
func (x *GetAuthConfigResponse) SetLogoUrl(v string)
func (*GetAuthConfigResponse) SetName ¶
func (x *GetAuthConfigResponse) SetName(v string)
func (*GetAuthConfigResponse) SetOauthProviders ¶
func (x *GetAuthConfigResponse) SetOauthProviders(v []*auth.OauthProvider)
func (*GetAuthConfigResponse) SetValidatePassword ¶
func (x *GetAuthConfigResponse) SetValidatePassword(v bool)
func (*GetAuthConfigResponse) String ¶
func (x *GetAuthConfigResponse) String() string
type GetAuthConfigResponse_builder ¶
type GetAuthConfigResponse_builder struct {
// The name of the project
Name string
// The logo of the project
LogoUrl string
// If to validate password
ValidatePassword bool
// Array of supported login methods.
LoginTypes []auth.LoginType
// Array of supported oauth providers.
OauthProviders []*auth.OauthProvider
// True if new users can sign up.
AllowsRegister bool
// contains filtered or unexported fields
}
func (GetAuthConfigResponse_builder) Build ¶
func (b0 GetAuthConfigResponse_builder) Build() *GetAuthConfigResponse
type GetRequest ¶
type GetRequest struct {
// contains filtered or unexported fields
}
The request of a Public.Get RPC
func (*GetRequest) ProtoMessage ¶
func (*GetRequest) ProtoMessage()
func (*GetRequest) ProtoReflect ¶
func (x *GetRequest) ProtoReflect() protoreflect.Message
func (*GetRequest) Reset ¶
func (x *GetRequest) Reset()
func (*GetRequest) String ¶
func (x *GetRequest) String() string
type GetRequest_builder ¶
type GetRequest_builder struct {
// contains filtered or unexported fields
}
func (GetRequest_builder) Build ¶
func (b0 GetRequest_builder) Build() *GetRequest
type GetResponse ¶
type GetResponse struct {
UserInfo *auth.UserInfo `protobuf:"bytes,1,opt,name=user_info,json=userInfo,proto3" json:"user_info,omitempty"`
// contains filtered or unexported fields
}
The response of a Public.Get RPC
func (*GetResponse) ClearUserInfo ¶
func (x *GetResponse) ClearUserInfo()
func (*GetResponse) GetUserInfo ¶
func (x *GetResponse) GetUserInfo() *auth.UserInfo
func (*GetResponse) HasUserInfo ¶
func (x *GetResponse) HasUserInfo() bool
func (*GetResponse) ProtoMessage ¶
func (*GetResponse) ProtoMessage()
func (*GetResponse) ProtoReflect ¶
func (x *GetResponse) ProtoReflect() protoreflect.Message
func (*GetResponse) Reset ¶
func (x *GetResponse) Reset()
func (*GetResponse) SetUserInfo ¶
func (x *GetResponse) SetUserInfo(v *auth.UserInfo)
func (*GetResponse) String ¶
func (x *GetResponse) String() string
type GetResponse_builder ¶
type GetResponse_builder struct {
UserInfo *auth.UserInfo
// contains filtered or unexported fields
}
func (GetResponse_builder) Build ¶
func (b0 GetResponse_builder) Build() *GetResponse
type LoginRequest ¶
type LoginRequest struct {
// Types that are valid to be assigned to Method:
//
// *LoginRequest_UserPassword
// *LoginRequest_Credential
Method isLoginRequest_Method `protobuf_oneof:"method"`
// contains filtered or unexported fields
}
The request of a Public.Login RPC
func (*LoginRequest) ClearCredential ¶
func (x *LoginRequest) ClearCredential()
func (*LoginRequest) ClearMethod ¶
func (x *LoginRequest) ClearMethod()
func (*LoginRequest) ClearUserPassword ¶
func (x *LoginRequest) ClearUserPassword()
func (*LoginRequest) GetCredential ¶
func (x *LoginRequest) GetCredential() *Credential
func (*LoginRequest) GetMethod ¶
func (x *LoginRequest) GetMethod() isLoginRequest_Method
func (*LoginRequest) GetUserPassword ¶
func (x *LoginRequest) GetUserPassword() *UserPassword
func (*LoginRequest) HasCredential ¶
func (x *LoginRequest) HasCredential() bool
func (*LoginRequest) HasMethod ¶
func (x *LoginRequest) HasMethod() bool
func (*LoginRequest) HasUserPassword ¶
func (x *LoginRequest) HasUserPassword() bool
func (*LoginRequest) ProtoMessage ¶
func (*LoginRequest) ProtoMessage()
func (*LoginRequest) ProtoReflect ¶
func (x *LoginRequest) ProtoReflect() protoreflect.Message
func (*LoginRequest) Reset ¶
func (x *LoginRequest) Reset()
func (*LoginRequest) SetCredential ¶
func (x *LoginRequest) SetCredential(v *Credential)
func (*LoginRequest) SetUserPassword ¶
func (x *LoginRequest) SetUserPassword(v *UserPassword)
func (*LoginRequest) String ¶
func (x *LoginRequest) String() string
func (*LoginRequest) WhichMethod ¶
func (x *LoginRequest) WhichMethod() case_LoginRequest_Method
type LoginRequest_Credential ¶
type LoginRequest_Credential struct {
Credential *Credential `protobuf:"bytes,3,opt,name=credential,proto3,oneof"`
}
type LoginRequest_UserPassword ¶
type LoginRequest_UserPassword struct {
UserPassword *UserPassword `protobuf:"bytes,1,opt,name=user_password,json=userPassword,proto3,oneof"`
}
type LoginRequest_builder ¶
type LoginRequest_builder struct {
// Fields of oneof Method:
UserPassword *UserPassword
Credential *Credential
// contains filtered or unexported fields
}
func (LoginRequest_builder) Build ¶
func (b0 LoginRequest_builder) Build() *LoginRequest
type LoginResponse ¶
type LoginResponse struct {
Token *auth.Token `protobuf:"bytes,1,opt,name=token,proto3" json:"token,omitempty"`
// contains filtered or unexported fields
}
The response of a Public.Login RPC
func (*LoginResponse) ClearToken ¶
func (x *LoginResponse) ClearToken()
func (*LoginResponse) GetToken ¶
func (x *LoginResponse) GetToken() *auth.Token
func (*LoginResponse) HasToken ¶
func (x *LoginResponse) HasToken() bool
func (*LoginResponse) ProtoMessage ¶
func (*LoginResponse) ProtoMessage()
func (*LoginResponse) ProtoReflect ¶
func (x *LoginResponse) ProtoReflect() protoreflect.Message
func (*LoginResponse) Reset ¶
func (x *LoginResponse) Reset()
func (*LoginResponse) SetToken ¶
func (x *LoginResponse) SetToken(v *auth.Token)
func (*LoginResponse) String ¶
func (x *LoginResponse) String() string
type LoginResponse_builder ¶
func (LoginResponse_builder) Build ¶
func (b0 LoginResponse_builder) Build() *LoginResponse
type LogoutRequest ¶
type LogoutRequest struct {
// contains filtered or unexported fields
}
The request of a Public.Logout RPC
func (*LogoutRequest) ProtoMessage ¶
func (*LogoutRequest) ProtoMessage()
func (*LogoutRequest) ProtoReflect ¶
func (x *LogoutRequest) ProtoReflect() protoreflect.Message
func (*LogoutRequest) Reset ¶
func (x *LogoutRequest) Reset()
func (*LogoutRequest) String ¶
func (x *LogoutRequest) String() string
type LogoutRequest_builder ¶
type LogoutRequest_builder struct {
// contains filtered or unexported fields
}
func (LogoutRequest_builder) Build ¶
func (b0 LogoutRequest_builder) Build() *LogoutRequest
type LogoutResponse ¶
type LogoutResponse struct {
// contains filtered or unexported fields
}
The response of a Public.Logout RPC
func (*LogoutResponse) ProtoMessage ¶
func (*LogoutResponse) ProtoMessage()
func (*LogoutResponse) ProtoReflect ¶
func (x *LogoutResponse) ProtoReflect() protoreflect.Message
func (*LogoutResponse) Reset ¶
func (x *LogoutResponse) Reset()
func (*LogoutResponse) String ¶
func (x *LogoutResponse) String() string
type LogoutResponse_builder ¶
type LogoutResponse_builder struct {
// contains filtered or unexported fields
}
func (LogoutResponse_builder) Build ¶
func (b0 LogoutResponse_builder) Build() *LogoutResponse
type PingRequest ¶
type PingRequest struct {
// contains filtered or unexported fields
}
The request of a Public.Ping RPC
func (*PingRequest) ProtoMessage ¶
func (*PingRequest) ProtoMessage()
func (*PingRequest) ProtoReflect ¶
func (x *PingRequest) ProtoReflect() protoreflect.Message
func (*PingRequest) Reset ¶
func (x *PingRequest) Reset()
func (*PingRequest) String ¶
func (x *PingRequest) String() string
type PingRequest_builder ¶
type PingRequest_builder struct {
// contains filtered or unexported fields
}
func (PingRequest_builder) Build ¶
func (b0 PingRequest_builder) Build() *PingRequest
type PingResponse ¶
type PingResponse struct {
// contains filtered or unexported fields
}
The response of a Public.Ping RPC
func (*PingResponse) ProtoMessage ¶
func (*PingResponse) ProtoMessage()
func (*PingResponse) ProtoReflect ¶
func (x *PingResponse) ProtoReflect() protoreflect.Message
func (*PingResponse) Reset ¶
func (x *PingResponse) Reset()
func (*PingResponse) String ¶
func (x *PingResponse) String() string
type PingResponse_builder ¶
type PingResponse_builder struct {
// contains filtered or unexported fields
}
func (PingResponse_builder) Build ¶
func (b0 PingResponse_builder) Build() *PingResponse
type RefreshTokenRequest ¶
type RefreshTokenRequest struct {
// The access token of the user
RefreshToken string `protobuf:"bytes,1,opt,name=refresh_token,json=refreshToken,proto3" json:"refresh_token,omitempty"`
// contains filtered or unexported fields
}
The request of a Public.Delete RPC
func (*RefreshTokenRequest) GetRefreshToken ¶
func (x *RefreshTokenRequest) GetRefreshToken() string
func (*RefreshTokenRequest) ProtoMessage ¶
func (*RefreshTokenRequest) ProtoMessage()
func (*RefreshTokenRequest) ProtoReflect ¶
func (x *RefreshTokenRequest) ProtoReflect() protoreflect.Message
func (*RefreshTokenRequest) Reset ¶
func (x *RefreshTokenRequest) Reset()
func (*RefreshTokenRequest) SetRefreshToken ¶
func (x *RefreshTokenRequest) SetRefreshToken(v string)
func (*RefreshTokenRequest) String ¶
func (x *RefreshTokenRequest) String() string
type RefreshTokenRequest_builder ¶
type RefreshTokenRequest_builder struct {
// The access token of the user
RefreshToken string
// contains filtered or unexported fields
}
func (RefreshTokenRequest_builder) Build ¶
func (b0 RefreshTokenRequest_builder) Build() *RefreshTokenRequest
type RefreshTokenResponse ¶
type RefreshTokenResponse struct {
Token *auth.Token `protobuf:"bytes,1,opt,name=token,proto3" json:"token,omitempty"`
// contains filtered or unexported fields
}
The response of a Public.Delete RPC
func (*RefreshTokenResponse) ClearToken ¶
func (x *RefreshTokenResponse) ClearToken()
func (*RefreshTokenResponse) GetToken ¶
func (x *RefreshTokenResponse) GetToken() *auth.Token
func (*RefreshTokenResponse) HasToken ¶
func (x *RefreshTokenResponse) HasToken() bool
func (*RefreshTokenResponse) ProtoMessage ¶
func (*RefreshTokenResponse) ProtoMessage()
func (*RefreshTokenResponse) ProtoReflect ¶
func (x *RefreshTokenResponse) ProtoReflect() protoreflect.Message
func (*RefreshTokenResponse) Reset ¶
func (x *RefreshTokenResponse) Reset()
func (*RefreshTokenResponse) SetToken ¶
func (x *RefreshTokenResponse) SetToken(v *auth.Token)
func (*RefreshTokenResponse) String ¶
func (x *RefreshTokenResponse) String() string
type RefreshTokenResponse_builder ¶
type RefreshTokenResponse_builder struct {
Token *auth.Token
// contains filtered or unexported fields
}
func (RefreshTokenResponse_builder) Build ¶
func (b0 RefreshTokenResponse_builder) Build() *RefreshTokenResponse
type RegisterRequest ¶
type RegisterRequest struct {
// Types that are valid to be assigned to Method:
//
// *RegisterRequest_UserPassword
Method isRegisterRequest_Method `protobuf_oneof:"method"`
// contains filtered or unexported fields
}
The request of a Public.Create RPC
func (*RegisterRequest) ClearMethod ¶
func (x *RegisterRequest) ClearMethod()
func (*RegisterRequest) ClearUserPassword ¶
func (x *RegisterRequest) ClearUserPassword()
func (*RegisterRequest) GetMethod ¶
func (x *RegisterRequest) GetMethod() isRegisterRequest_Method
func (*RegisterRequest) GetUserPassword ¶
func (x *RegisterRequest) GetUserPassword() *UserPassword
func (*RegisterRequest) HasMethod ¶
func (x *RegisterRequest) HasMethod() bool
func (*RegisterRequest) HasUserPassword ¶
func (x *RegisterRequest) HasUserPassword() bool
func (*RegisterRequest) ProtoMessage ¶
func (*RegisterRequest) ProtoMessage()
func (*RegisterRequest) ProtoReflect ¶
func (x *RegisterRequest) ProtoReflect() protoreflect.Message
func (*RegisterRequest) Reset ¶
func (x *RegisterRequest) Reset()
func (*RegisterRequest) SetUserPassword ¶
func (x *RegisterRequest) SetUserPassword(v *UserPassword)
func (*RegisterRequest) String ¶
func (x *RegisterRequest) String() string
func (*RegisterRequest) WhichMethod ¶
func (x *RegisterRequest) WhichMethod() case_RegisterRequest_Method
type RegisterRequest_UserPassword ¶
type RegisterRequest_UserPassword struct {
UserPassword *UserPassword `protobuf:"bytes,1,opt,name=user_password,json=userPassword,proto3,oneof"`
}
type RegisterRequest_builder ¶
type RegisterRequest_builder struct {
// Fields of oneof Method:
UserPassword *UserPassword
// contains filtered or unexported fields
}
func (RegisterRequest_builder) Build ¶
func (b0 RegisterRequest_builder) Build() *RegisterRequest
type RegisterResponse ¶
type RegisterResponse struct {
Token *auth.Token `protobuf:"bytes,1,opt,name=token,proto3" json:"token,omitempty"`
// contains filtered or unexported fields
}
The response of a Public.Create RPC
func (*RegisterResponse) ClearToken ¶
func (x *RegisterResponse) ClearToken()
func (*RegisterResponse) GetToken ¶
func (x *RegisterResponse) GetToken() *auth.Token
func (*RegisterResponse) HasToken ¶
func (x *RegisterResponse) HasToken() bool
func (*RegisterResponse) ProtoMessage ¶
func (*RegisterResponse) ProtoMessage()
func (*RegisterResponse) ProtoReflect ¶
func (x *RegisterResponse) ProtoReflect() protoreflect.Message
func (*RegisterResponse) Reset ¶
func (x *RegisterResponse) Reset()
func (*RegisterResponse) SetToken ¶
func (x *RegisterResponse) SetToken(v *auth.Token)
func (*RegisterResponse) String ¶
func (x *RegisterResponse) String() string
type RegisterResponse_builder ¶
type RegisterResponse_builder struct {
Token *auth.Token
// contains filtered or unexported fields
}
func (RegisterResponse_builder) Build ¶
func (b0 RegisterResponse_builder) Build() *RegisterResponse
type ResetPasswordRequest ¶
type ResetPasswordRequest struct {
Code string `protobuf:"bytes,1,opt,name=code,proto3" json:"code,omitempty"`
NewPassword string `protobuf:"bytes,2,opt,name=new_password,json=newPassword,proto3" json:"new_password,omitempty"`
Identifier *auth.UserIdentifier `protobuf:"bytes,3,opt,name=identifier,proto3" json:"identifier,omitempty"`
ApiKey string `protobuf:"bytes,4,opt,name=api_key,json=apiKey,proto3" json:"api_key,omitempty"`
// contains filtered or unexported fields
}
The request of a Public.ResetPassword RPC
func (*ResetPasswordRequest) ClearIdentifier ¶
func (x *ResetPasswordRequest) ClearIdentifier()
func (*ResetPasswordRequest) GetApiKey ¶
func (x *ResetPasswordRequest) GetApiKey() string
func (*ResetPasswordRequest) GetCode ¶
func (x *ResetPasswordRequest) GetCode() string
func (*ResetPasswordRequest) GetIdentifier ¶
func (x *ResetPasswordRequest) GetIdentifier() *auth.UserIdentifier
func (*ResetPasswordRequest) GetNewPassword ¶
func (x *ResetPasswordRequest) GetNewPassword() string
func (*ResetPasswordRequest) HasIdentifier ¶
func (x *ResetPasswordRequest) HasIdentifier() bool
func (*ResetPasswordRequest) ProtoMessage ¶
func (*ResetPasswordRequest) ProtoMessage()
func (*ResetPasswordRequest) ProtoReflect ¶
func (x *ResetPasswordRequest) ProtoReflect() protoreflect.Message
func (*ResetPasswordRequest) Reset ¶
func (x *ResetPasswordRequest) Reset()
func (*ResetPasswordRequest) SetApiKey ¶
func (x *ResetPasswordRequest) SetApiKey(v string)
func (*ResetPasswordRequest) SetCode ¶
func (x *ResetPasswordRequest) SetCode(v string)
func (*ResetPasswordRequest) SetIdentifier ¶
func (x *ResetPasswordRequest) SetIdentifier(v *auth.UserIdentifier)
func (*ResetPasswordRequest) SetNewPassword ¶
func (x *ResetPasswordRequest) SetNewPassword(v string)
func (*ResetPasswordRequest) String ¶
func (x *ResetPasswordRequest) String() string
type ResetPasswordRequest_builder ¶
type ResetPasswordRequest_builder struct {
Code string
NewPassword string
Identifier *auth.UserIdentifier
ApiKey string
// contains filtered or unexported fields
}
func (ResetPasswordRequest_builder) Build ¶
func (b0 ResetPasswordRequest_builder) Build() *ResetPasswordRequest
type ResetPasswordResponse ¶
type ResetPasswordResponse struct {
// contains filtered or unexported fields
}
The response of a Public.ResetPassword RPC
func (*ResetPasswordResponse) ProtoMessage ¶
func (*ResetPasswordResponse) ProtoMessage()
func (*ResetPasswordResponse) ProtoReflect ¶
func (x *ResetPasswordResponse) ProtoReflect() protoreflect.Message
func (*ResetPasswordResponse) Reset ¶
func (x *ResetPasswordResponse) Reset()
func (*ResetPasswordResponse) String ¶
func (x *ResetPasswordResponse) String() string
type ResetPasswordResponse_builder ¶
type ResetPasswordResponse_builder struct {
// contains filtered or unexported fields
}
func (ResetPasswordResponse_builder) Build ¶
func (b0 ResetPasswordResponse_builder) Build() *ResetPasswordResponse
type SendPasswordResetRequest ¶
type SendPasswordResetRequest struct {
Identifier *auth.UserIdentifier `protobuf:"bytes,1,opt,name=identifier,proto3" json:"identifier,omitempty"`
ApiKey string `protobuf:"bytes,2,opt,name=api_key,json=apiKey,proto3" json:"api_key,omitempty"`
// contains filtered or unexported fields
}
func (*SendPasswordResetRequest) ClearIdentifier ¶
func (x *SendPasswordResetRequest) ClearIdentifier()
func (*SendPasswordResetRequest) GetApiKey ¶
func (x *SendPasswordResetRequest) GetApiKey() string
func (*SendPasswordResetRequest) GetIdentifier ¶
func (x *SendPasswordResetRequest) GetIdentifier() *auth.UserIdentifier
func (*SendPasswordResetRequest) HasIdentifier ¶
func (x *SendPasswordResetRequest) HasIdentifier() bool
func (*SendPasswordResetRequest) ProtoMessage ¶
func (*SendPasswordResetRequest) ProtoMessage()
func (*SendPasswordResetRequest) ProtoReflect ¶
func (x *SendPasswordResetRequest) ProtoReflect() protoreflect.Message
func (*SendPasswordResetRequest) Reset ¶
func (x *SendPasswordResetRequest) Reset()
func (*SendPasswordResetRequest) SetApiKey ¶
func (x *SendPasswordResetRequest) SetApiKey(v string)
func (*SendPasswordResetRequest) SetIdentifier ¶
func (x *SendPasswordResetRequest) SetIdentifier(v *auth.UserIdentifier)
func (*SendPasswordResetRequest) String ¶
func (x *SendPasswordResetRequest) String() string
type SendPasswordResetRequest_builder ¶
type SendPasswordResetRequest_builder struct {
Identifier *auth.UserIdentifier
ApiKey string
// contains filtered or unexported fields
}
func (SendPasswordResetRequest_builder) Build ¶
func (b0 SendPasswordResetRequest_builder) Build() *SendPasswordResetRequest
type SendPasswordResetResponse ¶
type SendPasswordResetResponse struct {
// contains filtered or unexported fields
}
func (*SendPasswordResetResponse) ProtoMessage ¶
func (*SendPasswordResetResponse) ProtoMessage()
func (*SendPasswordResetResponse) ProtoReflect ¶
func (x *SendPasswordResetResponse) ProtoReflect() protoreflect.Message
func (*SendPasswordResetResponse) Reset ¶
func (x *SendPasswordResetResponse) Reset()
func (*SendPasswordResetResponse) String ¶
func (x *SendPasswordResetResponse) String() string
type SendPasswordResetResponse_builder ¶
type SendPasswordResetResponse_builder struct {
// contains filtered or unexported fields
}
func (SendPasswordResetResponse_builder) Build ¶
func (b0 SendPasswordResetResponse_builder) Build() *SendPasswordResetResponse
type UserPassword ¶
type UserPassword struct {
Identifier *auth.UserIdentifier `protobuf:"bytes,1,opt,name=identifier,proto3" json:"identifier,omitempty"`
Password string `protobuf:"bytes,2,opt,name=password,proto3" json:"password,omitempty"`
ApiKey string `protobuf:"bytes,3,opt,name=api_key,json=apiKey,proto3" json:"api_key,omitempty"`
// contains filtered or unexported fields
}
func (*UserPassword) ClearIdentifier ¶
func (x *UserPassword) ClearIdentifier()
func (*UserPassword) GetApiKey ¶
func (x *UserPassword) GetApiKey() string
func (*UserPassword) GetIdentifier ¶
func (x *UserPassword) GetIdentifier() *auth.UserIdentifier
func (*UserPassword) GetPassword ¶
func (x *UserPassword) GetPassword() string
func (*UserPassword) HasIdentifier ¶
func (x *UserPassword) HasIdentifier() bool
func (*UserPassword) ProtoMessage ¶
func (*UserPassword) ProtoMessage()
func (*UserPassword) ProtoReflect ¶
func (x *UserPassword) ProtoReflect() protoreflect.Message
func (*UserPassword) Reset ¶
func (x *UserPassword) Reset()
func (*UserPassword) SetApiKey ¶
func (x *UserPassword) SetApiKey(v string)
func (*UserPassword) SetIdentifier ¶
func (x *UserPassword) SetIdentifier(v *auth.UserIdentifier)
func (*UserPassword) SetPassword ¶
func (x *UserPassword) SetPassword(v string)
func (*UserPassword) String ¶
func (x *UserPassword) String() string
type UserPassword_builder ¶
type UserPassword_builder struct {
Identifier *auth.UserIdentifier
Password string
ApiKey string
// contains filtered or unexported fields
}
func (UserPassword_builder) Build ¶
func (b0 UserPassword_builder) Build() *UserPassword
type VerifyEmailRequest ¶
type VerifyEmailRequest struct {
Code string `protobuf:"bytes,1,opt,name=code,proto3" json:"code,omitempty"`
Email string `protobuf:"bytes,2,opt,name=email,proto3" json:"email,omitempty"`
ApiKey string `protobuf:"bytes,3,opt,name=api_key,json=apiKey,proto3" json:"api_key,omitempty"`
// contains filtered or unexported fields
}
the request of a Public.VerifyEmail RPC
func (*VerifyEmailRequest) GetApiKey ¶
func (x *VerifyEmailRequest) GetApiKey() string
func (*VerifyEmailRequest) GetCode ¶
func (x *VerifyEmailRequest) GetCode() string
func (*VerifyEmailRequest) GetEmail ¶
func (x *VerifyEmailRequest) GetEmail() string
func (*VerifyEmailRequest) ProtoMessage ¶
func (*VerifyEmailRequest) ProtoMessage()
func (*VerifyEmailRequest) ProtoReflect ¶
func (x *VerifyEmailRequest) ProtoReflect() protoreflect.Message
func (*VerifyEmailRequest) Reset ¶
func (x *VerifyEmailRequest) Reset()
func (*VerifyEmailRequest) SetApiKey ¶
func (x *VerifyEmailRequest) SetApiKey(v string)
func (*VerifyEmailRequest) SetCode ¶
func (x *VerifyEmailRequest) SetCode(v string)
func (*VerifyEmailRequest) SetEmail ¶
func (x *VerifyEmailRequest) SetEmail(v string)
func (*VerifyEmailRequest) String ¶
func (x *VerifyEmailRequest) String() string
type VerifyEmailRequest_builder ¶
type VerifyEmailRequest_builder struct {
Code string
Email string
ApiKey string
// contains filtered or unexported fields
}
func (VerifyEmailRequest_builder) Build ¶
func (b0 VerifyEmailRequest_builder) Build() *VerifyEmailRequest
type VerifyEmailResponse ¶
type VerifyEmailResponse struct {
// contains filtered or unexported fields
}
the response of a Public.VerifyEmail RPC
func (*VerifyEmailResponse) ProtoMessage ¶
func (*VerifyEmailResponse) ProtoMessage()
func (*VerifyEmailResponse) ProtoReflect ¶
func (x *VerifyEmailResponse) ProtoReflect() protoreflect.Message
func (*VerifyEmailResponse) Reset ¶
func (x *VerifyEmailResponse) Reset()
func (*VerifyEmailResponse) String ¶
func (x *VerifyEmailResponse) String() string
type VerifyEmailResponse_builder ¶
type VerifyEmailResponse_builder struct {
// contains filtered or unexported fields
}
func (VerifyEmailResponse_builder) Build ¶
func (b0 VerifyEmailResponse_builder) Build() *VerifyEmailResponse
type VerifyPhoneNumberRequest ¶
type VerifyPhoneNumberRequest struct {
Code string `protobuf:"bytes,1,opt,name=code,proto3" json:"code,omitempty"`
PhoneNumber string `protobuf:"bytes,2,opt,name=phone_number,json=phoneNumber,proto3" json:"phone_number,omitempty"`
ApiKey string `protobuf:"bytes,3,opt,name=api_key,json=apiKey,proto3" json:"api_key,omitempty"`
// contains filtered or unexported fields
}
the request of a Public.VerifyPhoneNumber RPC
func (*VerifyPhoneNumberRequest) GetApiKey ¶
func (x *VerifyPhoneNumberRequest) GetApiKey() string
func (*VerifyPhoneNumberRequest) GetCode ¶
func (x *VerifyPhoneNumberRequest) GetCode() string
func (*VerifyPhoneNumberRequest) GetPhoneNumber ¶
func (x *VerifyPhoneNumberRequest) GetPhoneNumber() string
func (*VerifyPhoneNumberRequest) ProtoMessage ¶
func (*VerifyPhoneNumberRequest) ProtoMessage()
func (*VerifyPhoneNumberRequest) ProtoReflect ¶
func (x *VerifyPhoneNumberRequest) ProtoReflect() protoreflect.Message
func (*VerifyPhoneNumberRequest) Reset ¶
func (x *VerifyPhoneNumberRequest) Reset()
func (*VerifyPhoneNumberRequest) SetApiKey ¶
func (x *VerifyPhoneNumberRequest) SetApiKey(v string)
func (*VerifyPhoneNumberRequest) SetCode ¶
func (x *VerifyPhoneNumberRequest) SetCode(v string)
func (*VerifyPhoneNumberRequest) SetPhoneNumber ¶
func (x *VerifyPhoneNumberRequest) SetPhoneNumber(v string)
func (*VerifyPhoneNumberRequest) String ¶
func (x *VerifyPhoneNumberRequest) String() string
type VerifyPhoneNumberRequest_builder ¶
type VerifyPhoneNumberRequest_builder struct {
Code string
PhoneNumber string
ApiKey string
// contains filtered or unexported fields
}
func (VerifyPhoneNumberRequest_builder) Build ¶
func (b0 VerifyPhoneNumberRequest_builder) Build() *VerifyPhoneNumberRequest
type VerifyPhoneNumberResponse ¶
type VerifyPhoneNumberResponse struct {
// contains filtered or unexported fields
}
the response of a Public.VerifyPhoneNumber RPC
func (*VerifyPhoneNumberResponse) ProtoMessage ¶
func (*VerifyPhoneNumberResponse) ProtoMessage()
func (*VerifyPhoneNumberResponse) ProtoReflect ¶
func (x *VerifyPhoneNumberResponse) ProtoReflect() protoreflect.Message
func (*VerifyPhoneNumberResponse) Reset ¶
func (x *VerifyPhoneNumberResponse) Reset()
func (*VerifyPhoneNumberResponse) String ¶
func (x *VerifyPhoneNumberResponse) String() string
type VerifyPhoneNumberResponse_builder ¶
type VerifyPhoneNumberResponse_builder struct {
// contains filtered or unexported fields
}
func (VerifyPhoneNumberResponse_builder) Build ¶
func (b0 VerifyPhoneNumberResponse_builder) Build() *VerifyPhoneNumberResponse
Source Files
¶
- service.pb.go