Documentation
¶
Index ¶
- Variables
- type CurrentLibraryConfig
- func (x *CurrentLibraryConfig) ClearConfig()
- func (x *CurrentLibraryConfig) ClearNode()
- func (x *CurrentLibraryConfig) GetConfig() *v11.TraceConfig
- func (x *CurrentLibraryConfig) GetNode() *v1.Node
- func (x *CurrentLibraryConfig) HasConfig() bool
- func (x *CurrentLibraryConfig) HasNode() bool
- func (*CurrentLibraryConfig) ProtoMessage()
- func (x *CurrentLibraryConfig) ProtoReflect() protoreflect.Message
- func (x *CurrentLibraryConfig) Reset()
- func (x *CurrentLibraryConfig) SetConfig(v *v11.TraceConfig)
- func (x *CurrentLibraryConfig) SetNode(v *v1.Node)
- func (x *CurrentLibraryConfig) String() string
- type CurrentLibraryConfig_builder
- type ExportTraceServiceRequest
- func (x *ExportTraceServiceRequest) ClearNode()
- func (x *ExportTraceServiceRequest) ClearResource()
- func (x *ExportTraceServiceRequest) GetNode() *v1.Node
- func (x *ExportTraceServiceRequest) GetResource() *v12.Resource
- func (x *ExportTraceServiceRequest) GetSpans() []*v11.Span
- func (x *ExportTraceServiceRequest) HasNode() bool
- func (x *ExportTraceServiceRequest) HasResource() bool
- func (*ExportTraceServiceRequest) ProtoMessage()
- func (x *ExportTraceServiceRequest) ProtoReflect() protoreflect.Message
- func (x *ExportTraceServiceRequest) Reset()
- func (x *ExportTraceServiceRequest) SetNode(v *v1.Node)
- func (x *ExportTraceServiceRequest) SetResource(v *v12.Resource)
- func (x *ExportTraceServiceRequest) SetSpans(v []*v11.Span)
- func (x *ExportTraceServiceRequest) String() string
- type ExportTraceServiceRequest_builder
- type ExportTraceServiceResponse
- type ExportTraceServiceResponse_builder
- type UpdatedLibraryConfig
- func (x *UpdatedLibraryConfig) ClearConfig()
- func (x *UpdatedLibraryConfig) ClearNode()
- func (x *UpdatedLibraryConfig) GetConfig() *v11.TraceConfig
- func (x *UpdatedLibraryConfig) GetNode() *v1.Node
- func (x *UpdatedLibraryConfig) HasConfig() bool
- func (x *UpdatedLibraryConfig) HasNode() bool
- func (*UpdatedLibraryConfig) ProtoMessage()
- func (x *UpdatedLibraryConfig) ProtoReflect() protoreflect.Message
- func (x *UpdatedLibraryConfig) Reset()
- func (x *UpdatedLibraryConfig) SetConfig(v *v11.TraceConfig)
- func (x *UpdatedLibraryConfig) SetNode(v *v1.Node)
- func (x *UpdatedLibraryConfig) String() string
- type UpdatedLibraryConfig_builder
Constants ¶
This section is empty.
Variables ¶
var File_opencensus_proto_agent_trace_v1_trace_service_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type CurrentLibraryConfig ¶
type CurrentLibraryConfig struct {
// This is required only in the first message on the stream or if the
// previous sent CurrentLibraryConfig message has a different Node (e.g.
// when the same RPC is used to configure multiple Applications).
Node *v1.Node `protobuf:"bytes,1,opt,name=node,proto3" json:"node,omitempty"`
// Current configuration.
Config *v11.TraceConfig `protobuf:"bytes,2,opt,name=config,proto3" json:"config,omitempty"`
// contains filtered or unexported fields
}
func (*CurrentLibraryConfig) ClearConfig ¶
func (x *CurrentLibraryConfig) ClearConfig()
func (*CurrentLibraryConfig) ClearNode ¶
func (x *CurrentLibraryConfig) ClearNode()
func (*CurrentLibraryConfig) GetConfig ¶
func (x *CurrentLibraryConfig) GetConfig() *v11.TraceConfig
func (*CurrentLibraryConfig) GetNode ¶
func (x *CurrentLibraryConfig) GetNode() *v1.Node
func (*CurrentLibraryConfig) HasConfig ¶
func (x *CurrentLibraryConfig) HasConfig() bool
func (*CurrentLibraryConfig) HasNode ¶
func (x *CurrentLibraryConfig) HasNode() bool
func (*CurrentLibraryConfig) ProtoMessage ¶
func (*CurrentLibraryConfig) ProtoMessage()
func (*CurrentLibraryConfig) ProtoReflect ¶
func (x *CurrentLibraryConfig) ProtoReflect() protoreflect.Message
func (*CurrentLibraryConfig) Reset ¶
func (x *CurrentLibraryConfig) Reset()
func (*CurrentLibraryConfig) SetConfig ¶
func (x *CurrentLibraryConfig) SetConfig(v *v11.TraceConfig)
func (*CurrentLibraryConfig) SetNode ¶
func (x *CurrentLibraryConfig) SetNode(v *v1.Node)
func (*CurrentLibraryConfig) String ¶
func (x *CurrentLibraryConfig) String() string
type CurrentLibraryConfig_builder ¶
type CurrentLibraryConfig_builder struct {
// This is required only in the first message on the stream or if the
// previous sent CurrentLibraryConfig message has a different Node (e.g.
// when the same RPC is used to configure multiple Applications).
Node *v1.Node
// Current configuration.
Config *v11.TraceConfig
// contains filtered or unexported fields
}
func (CurrentLibraryConfig_builder) Build ¶
func (b0 CurrentLibraryConfig_builder) Build() *CurrentLibraryConfig
type ExportTraceServiceRequest ¶
type ExportTraceServiceRequest struct {
// This is required only in the first message on the stream or if the
// previous sent ExportTraceServiceRequest message has a different Node (e.g.
// when the same RPC is used to send Spans from multiple Applications).
Node *v1.Node `protobuf:"bytes,1,opt,name=node,proto3" json:"node,omitempty"`
// A list of Spans that belong to the last received Node.
Spans []*v11.Span `protobuf:"bytes,2,rep,name=spans,proto3" json:"spans,omitempty"`
// The resource for the spans in this message that do not have an explicit
// resource set.
// If unset, the most recently set resource in the RPC stream applies. It is
// valid to never be set within a stream, e.g. when no resource info is known.
Resource *v12.Resource `protobuf:"bytes,3,opt,name=resource,proto3" json:"resource,omitempty"`
// contains filtered or unexported fields
}
func (*ExportTraceServiceRequest) ClearNode ¶
func (x *ExportTraceServiceRequest) ClearNode()
func (*ExportTraceServiceRequest) ClearResource ¶
func (x *ExportTraceServiceRequest) ClearResource()
func (*ExportTraceServiceRequest) GetNode ¶
func (x *ExportTraceServiceRequest) GetNode() *v1.Node
func (*ExportTraceServiceRequest) GetResource ¶
func (x *ExportTraceServiceRequest) GetResource() *v12.Resource
func (*ExportTraceServiceRequest) GetSpans ¶
func (x *ExportTraceServiceRequest) GetSpans() []*v11.Span
func (*ExportTraceServiceRequest) HasNode ¶
func (x *ExportTraceServiceRequest) HasNode() bool
func (*ExportTraceServiceRequest) HasResource ¶
func (x *ExportTraceServiceRequest) HasResource() bool
func (*ExportTraceServiceRequest) ProtoMessage ¶
func (*ExportTraceServiceRequest) ProtoMessage()
func (*ExportTraceServiceRequest) ProtoReflect ¶
func (x *ExportTraceServiceRequest) ProtoReflect() protoreflect.Message
func (*ExportTraceServiceRequest) Reset ¶
func (x *ExportTraceServiceRequest) Reset()
func (*ExportTraceServiceRequest) SetNode ¶
func (x *ExportTraceServiceRequest) SetNode(v *v1.Node)
func (*ExportTraceServiceRequest) SetResource ¶
func (x *ExportTraceServiceRequest) SetResource(v *v12.Resource)
func (*ExportTraceServiceRequest) SetSpans ¶
func (x *ExportTraceServiceRequest) SetSpans(v []*v11.Span)
func (*ExportTraceServiceRequest) String ¶
func (x *ExportTraceServiceRequest) String() string
type ExportTraceServiceRequest_builder ¶
type ExportTraceServiceRequest_builder struct {
// This is required only in the first message on the stream or if the
// previous sent ExportTraceServiceRequest message has a different Node (e.g.
// when the same RPC is used to send Spans from multiple Applications).
Node *v1.Node
// A list of Spans that belong to the last received Node.
Spans []*v11.Span
// The resource for the spans in this message that do not have an explicit
// resource set.
// If unset, the most recently set resource in the RPC stream applies. It is
// valid to never be set within a stream, e.g. when no resource info is known.
Resource *v12.Resource
// contains filtered or unexported fields
}
func (ExportTraceServiceRequest_builder) Build ¶
func (b0 ExportTraceServiceRequest_builder) Build() *ExportTraceServiceRequest
type ExportTraceServiceResponse ¶
type ExportTraceServiceResponse struct {
// contains filtered or unexported fields
}
func (*ExportTraceServiceResponse) ProtoMessage ¶
func (*ExportTraceServiceResponse) ProtoMessage()
func (*ExportTraceServiceResponse) ProtoReflect ¶
func (x *ExportTraceServiceResponse) ProtoReflect() protoreflect.Message
func (*ExportTraceServiceResponse) Reset ¶
func (x *ExportTraceServiceResponse) Reset()
func (*ExportTraceServiceResponse) String ¶
func (x *ExportTraceServiceResponse) String() string
type ExportTraceServiceResponse_builder ¶
type ExportTraceServiceResponse_builder struct {
// contains filtered or unexported fields
}
func (ExportTraceServiceResponse_builder) Build ¶
func (b0 ExportTraceServiceResponse_builder) Build() *ExportTraceServiceResponse
type UpdatedLibraryConfig ¶
type UpdatedLibraryConfig struct {
// This field is ignored when the RPC is used to configure only one Application.
// This is required only in the first message on the stream or if the
// previous sent UpdatedLibraryConfig message has a different Node.
Node *v1.Node `protobuf:"bytes,1,opt,name=node,proto3" json:"node,omitempty"`
// Requested updated configuration.
Config *v11.TraceConfig `protobuf:"bytes,2,opt,name=config,proto3" json:"config,omitempty"`
// contains filtered or unexported fields
}
func (*UpdatedLibraryConfig) ClearConfig ¶
func (x *UpdatedLibraryConfig) ClearConfig()
func (*UpdatedLibraryConfig) ClearNode ¶
func (x *UpdatedLibraryConfig) ClearNode()
func (*UpdatedLibraryConfig) GetConfig ¶
func (x *UpdatedLibraryConfig) GetConfig() *v11.TraceConfig
func (*UpdatedLibraryConfig) GetNode ¶
func (x *UpdatedLibraryConfig) GetNode() *v1.Node
func (*UpdatedLibraryConfig) HasConfig ¶
func (x *UpdatedLibraryConfig) HasConfig() bool
func (*UpdatedLibraryConfig) HasNode ¶
func (x *UpdatedLibraryConfig) HasNode() bool
func (*UpdatedLibraryConfig) ProtoMessage ¶
func (*UpdatedLibraryConfig) ProtoMessage()
func (*UpdatedLibraryConfig) ProtoReflect ¶
func (x *UpdatedLibraryConfig) ProtoReflect() protoreflect.Message
func (*UpdatedLibraryConfig) Reset ¶
func (x *UpdatedLibraryConfig) Reset()
func (*UpdatedLibraryConfig) SetConfig ¶
func (x *UpdatedLibraryConfig) SetConfig(v *v11.TraceConfig)
func (*UpdatedLibraryConfig) SetNode ¶
func (x *UpdatedLibraryConfig) SetNode(v *v1.Node)
func (*UpdatedLibraryConfig) String ¶
func (x *UpdatedLibraryConfig) String() string
type UpdatedLibraryConfig_builder ¶
type UpdatedLibraryConfig_builder struct {
// This field is ignored when the RPC is used to configure only one Application.
// This is required only in the first message on the stream or if the
// previous sent UpdatedLibraryConfig message has a different Node.
Node *v1.Node
// Requested updated configuration.
Config *v11.TraceConfig
// contains filtered or unexported fields
}
func (UpdatedLibraryConfig_builder) Build ¶
func (b0 UpdatedLibraryConfig_builder) Build() *UpdatedLibraryConfig
Source Files
¶
- trace_service.pb.go
Click to show internal directories.
Click to hide internal directories.