Documentation
¶
Index ¶
Constants ¶
const (
MetricsService_Export_FullMethodName = "/opentelemetry.proto.collector.metrics.v1.MetricsService/Export"
)
Variables ¶
var MetricsService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "opentelemetry.proto.collector.metrics.v1.MetricsService", HandlerType: (*MetricsServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "Export", Handler: _MetricsService_Export_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "opentelemetry/proto/collector/metrics/v1/metrics_service.proto", }
MetricsService_ServiceDesc is the grpc.ServiceDesc for MetricsService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterMetricsServiceServer ¶
func RegisterMetricsServiceServer(s grpc.ServiceRegistrar, srv MetricsServiceServer)
Types ¶
type MetricsServiceClient ¶
type MetricsServiceClient interface {
Export(ctx context.Context, in *v1.ExportMetricsServiceRequest, opts ...grpc.CallOption) (*v1.ExportMetricsServiceResponse, error)
}
MetricsServiceClient is the client API for MetricsService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
Service that can be used to push metrics between one Application instrumented with OpenTelemetry and a collector, or between a collector and a central collector.
func NewMetricsServiceClient ¶
func NewMetricsServiceClient(cc grpc.ClientConnInterface) MetricsServiceClient
type MetricsServiceServer ¶
type MetricsServiceServer interface {
Export(context.Context, *v1.ExportMetricsServiceRequest) (*v1.ExportMetricsServiceResponse, error)
}
MetricsServiceServer is the server API for MetricsService service. All implementations should embed UnimplementedMetricsServiceServer for forward compatibility.
Service that can be used to push metrics between one Application instrumented with OpenTelemetry and a collector, or between a collector and a central collector.
type UnimplementedMetricsServiceServer ¶
type UnimplementedMetricsServiceServer struct{}
UnimplementedMetricsServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedMetricsServiceServer) Export ¶
func (UnimplementedMetricsServiceServer) Export(context.Context, *v1.ExportMetricsServiceRequest) (*v1.ExportMetricsServiceResponse, error)
type UnsafeMetricsServiceServer ¶
type UnsafeMetricsServiceServer interface {
// contains filtered or unexported methods
}
UnsafeMetricsServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to MetricsServiceServer will result in compilation errors.
Source Files
¶
- metrics_service_grpc.pb.go