Documentation
¶
Index ¶
- Variables
- type ExportMetricsPartialSuccess
- func (x *ExportMetricsPartialSuccess) GetErrorMessage() string
- func (x *ExportMetricsPartialSuccess) GetRejectedDataPoints() int64
- func (*ExportMetricsPartialSuccess) ProtoMessage()
- func (x *ExportMetricsPartialSuccess) ProtoReflect() protoreflect.Message
- func (x *ExportMetricsPartialSuccess) Reset()
- func (x *ExportMetricsPartialSuccess) SetErrorMessage(v string)
- func (x *ExportMetricsPartialSuccess) SetRejectedDataPoints(v int64)
- func (x *ExportMetricsPartialSuccess) String() string
- type ExportMetricsPartialSuccess_builder
- type ExportMetricsServiceRequest
- func (x *ExportMetricsServiceRequest) GetResourceMetrics() []*v1.ResourceMetrics
- func (*ExportMetricsServiceRequest) ProtoMessage()
- func (x *ExportMetricsServiceRequest) ProtoReflect() protoreflect.Message
- func (x *ExportMetricsServiceRequest) Reset()
- func (x *ExportMetricsServiceRequest) SetResourceMetrics(v []*v1.ResourceMetrics)
- func (x *ExportMetricsServiceRequest) String() string
- type ExportMetricsServiceRequest_builder
- type ExportMetricsServiceResponse
- func (x *ExportMetricsServiceResponse) ClearPartialSuccess()
- func (x *ExportMetricsServiceResponse) GetPartialSuccess() *ExportMetricsPartialSuccess
- func (x *ExportMetricsServiceResponse) HasPartialSuccess() bool
- func (*ExportMetricsServiceResponse) ProtoMessage()
- func (x *ExportMetricsServiceResponse) ProtoReflect() protoreflect.Message
- func (x *ExportMetricsServiceResponse) Reset()
- func (x *ExportMetricsServiceResponse) SetPartialSuccess(v *ExportMetricsPartialSuccess)
- func (x *ExportMetricsServiceResponse) String() string
- type ExportMetricsServiceResponse_builder
Constants ¶
This section is empty.
Variables ¶
var File_opentelemetry_proto_collector_metrics_v1_metrics_service_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type ExportMetricsPartialSuccess ¶
type ExportMetricsPartialSuccess struct {
// The number of rejected data points.
//
// A `rejected_<signal>` field holding a `0` value indicates that the
// request was fully accepted.
RejectedDataPoints int64 `protobuf:"varint,1,opt,name=rejected_data_points,json=rejectedDataPoints,proto3" json:"rejected_data_points,omitempty"`
// A developer-facing human-readable message in English. It should be used
// either to explain why the server rejected parts of the data during a partial
// success or to convey warnings/suggestions during a full success. The message
// should offer guidance on how users can address such issues.
//
// error_message is an optional field. An error_message with an empty value
// is equivalent to it not being set.
ErrorMessage string `protobuf:"bytes,2,opt,name=error_message,json=errorMessage,proto3" json:"error_message,omitempty"`
// contains filtered or unexported fields
}
func (*ExportMetricsPartialSuccess) GetErrorMessage ¶
func (x *ExportMetricsPartialSuccess) GetErrorMessage() string
func (*ExportMetricsPartialSuccess) GetRejectedDataPoints ¶
func (x *ExportMetricsPartialSuccess) GetRejectedDataPoints() int64
func (*ExportMetricsPartialSuccess) ProtoMessage ¶
func (*ExportMetricsPartialSuccess) ProtoMessage()
func (*ExportMetricsPartialSuccess) ProtoReflect ¶
func (x *ExportMetricsPartialSuccess) ProtoReflect() protoreflect.Message
func (*ExportMetricsPartialSuccess) Reset ¶
func (x *ExportMetricsPartialSuccess) Reset()
func (*ExportMetricsPartialSuccess) SetErrorMessage ¶
func (x *ExportMetricsPartialSuccess) SetErrorMessage(v string)
func (*ExportMetricsPartialSuccess) SetRejectedDataPoints ¶
func (x *ExportMetricsPartialSuccess) SetRejectedDataPoints(v int64)
func (*ExportMetricsPartialSuccess) String ¶
func (x *ExportMetricsPartialSuccess) String() string
type ExportMetricsPartialSuccess_builder ¶
type ExportMetricsPartialSuccess_builder struct {
// The number of rejected data points.
//
// A `rejected_<signal>` field holding a `0` value indicates that the
// request was fully accepted.
RejectedDataPoints int64
// A developer-facing human-readable message in English. It should be used
// either to explain why the server rejected parts of the data during a partial
// success or to convey warnings/suggestions during a full success. The message
// should offer guidance on how users can address such issues.
//
// error_message is an optional field. An error_message with an empty value
// is equivalent to it not being set.
ErrorMessage string
// contains filtered or unexported fields
}
func (ExportMetricsPartialSuccess_builder) Build ¶
func (b0 ExportMetricsPartialSuccess_builder) Build() *ExportMetricsPartialSuccess
type ExportMetricsServiceRequest ¶
type ExportMetricsServiceRequest struct {
// An array of ResourceMetrics.
// For data coming from a single resource this array will typically contain one
// element. Intermediary nodes (such as OpenTelemetry Collector) that receive
// data from multiple origins typically batch the data before forwarding further and
// in that case this array will contain multiple elements.
ResourceMetrics []*v1.ResourceMetrics `protobuf:"bytes,1,rep,name=resource_metrics,json=resourceMetrics,proto3" json:"resource_metrics,omitempty"`
// contains filtered or unexported fields
}
func (*ExportMetricsServiceRequest) GetResourceMetrics ¶
func (x *ExportMetricsServiceRequest) GetResourceMetrics() []*v1.ResourceMetrics
func (*ExportMetricsServiceRequest) ProtoMessage ¶
func (*ExportMetricsServiceRequest) ProtoMessage()
func (*ExportMetricsServiceRequest) ProtoReflect ¶
func (x *ExportMetricsServiceRequest) ProtoReflect() protoreflect.Message
func (*ExportMetricsServiceRequest) Reset ¶
func (x *ExportMetricsServiceRequest) Reset()
func (*ExportMetricsServiceRequest) SetResourceMetrics ¶
func (x *ExportMetricsServiceRequest) SetResourceMetrics(v []*v1.ResourceMetrics)
func (*ExportMetricsServiceRequest) String ¶
func (x *ExportMetricsServiceRequest) String() string
type ExportMetricsServiceRequest_builder ¶
type ExportMetricsServiceRequest_builder struct {
// An array of ResourceMetrics.
// For data coming from a single resource this array will typically contain one
// element. Intermediary nodes (such as OpenTelemetry Collector) that receive
// data from multiple origins typically batch the data before forwarding further and
// in that case this array will contain multiple elements.
ResourceMetrics []*v1.ResourceMetrics
// contains filtered or unexported fields
}
func (ExportMetricsServiceRequest_builder) Build ¶
func (b0 ExportMetricsServiceRequest_builder) Build() *ExportMetricsServiceRequest
type ExportMetricsServiceResponse ¶
type ExportMetricsServiceResponse struct {
// The details of a partially successful export request.
//
// If the request is only partially accepted
// (i.e. when the server accepts only parts of the data and rejects the rest)
// the server MUST initialize the `partial_success` field and MUST
// set the `rejected_<signal>` with the number of items it rejected.
//
// Servers MAY also make use of the `partial_success` field to convey
// warnings/suggestions to senders even when the request was fully accepted.
// In such cases, the `rejected_<signal>` MUST have a value of `0` and
// the `error_message` MUST be non-empty.
//
// A `partial_success` message with an empty value (rejected_<signal> = 0 and
// `error_message` = "") is equivalent to it not being set/present. Senders
// SHOULD interpret it the same way as in the full success case.
PartialSuccess *ExportMetricsPartialSuccess `protobuf:"bytes,1,opt,name=partial_success,json=partialSuccess,proto3" json:"partial_success,omitempty"`
// contains filtered or unexported fields
}
func (*ExportMetricsServiceResponse) ClearPartialSuccess ¶
func (x *ExportMetricsServiceResponse) ClearPartialSuccess()
func (*ExportMetricsServiceResponse) GetPartialSuccess ¶
func (x *ExportMetricsServiceResponse) GetPartialSuccess() *ExportMetricsPartialSuccess
func (*ExportMetricsServiceResponse) HasPartialSuccess ¶
func (x *ExportMetricsServiceResponse) HasPartialSuccess() bool
func (*ExportMetricsServiceResponse) ProtoMessage ¶
func (*ExportMetricsServiceResponse) ProtoMessage()
func (*ExportMetricsServiceResponse) ProtoReflect ¶
func (x *ExportMetricsServiceResponse) ProtoReflect() protoreflect.Message
func (*ExportMetricsServiceResponse) Reset ¶
func (x *ExportMetricsServiceResponse) Reset()
func (*ExportMetricsServiceResponse) SetPartialSuccess ¶
func (x *ExportMetricsServiceResponse) SetPartialSuccess(v *ExportMetricsPartialSuccess)
func (*ExportMetricsServiceResponse) String ¶
func (x *ExportMetricsServiceResponse) String() string
type ExportMetricsServiceResponse_builder ¶
type ExportMetricsServiceResponse_builder struct {
// The details of a partially successful export request.
//
// If the request is only partially accepted
// (i.e. when the server accepts only parts of the data and rejects the rest)
// the server MUST initialize the `partial_success` field and MUST
// set the `rejected_<signal>` with the number of items it rejected.
//
// Servers MAY also make use of the `partial_success` field to convey
// warnings/suggestions to senders even when the request was fully accepted.
// In such cases, the `rejected_<signal>` MUST have a value of `0` and
// the `error_message` MUST be non-empty.
//
// A `partial_success` message with an empty value (rejected_<signal> = 0 and
// `error_message` = "") is equivalent to it not being set/present. Senders
// SHOULD interpret it the same way as in the full success case.
PartialSuccess *ExportMetricsPartialSuccess
// contains filtered or unexported fields
}
func (ExportMetricsServiceResponse_builder) Build ¶
func (b0 ExportMetricsServiceResponse_builder) Build() *ExportMetricsServiceResponse
Source Files
¶
- metrics_service.pb.go
Click to show internal directories.
Click to hide internal directories.