Documentation
¶
Index ¶
- Constants
- func NewMetastoreServiceHandler(svc MetastoreServiceHandler, opts ...connect_go.HandlerOption) (string, http.Handler)
- type MetastoreServiceClient
- type MetastoreServiceHandler
- type UnimplementedMetastoreServiceHandler
- func (UnimplementedMetastoreServiceHandler) CreateLocationLines(context.Context, *connect_go.Request[v1alpha1.CreateLocationLinesRequest]) (*connect_go.Response[v1alpha1.CreateLocationLinesResponse], error)
- func (UnimplementedMetastoreServiceHandler) Functions(context.Context, *connect_go.Request[v1alpha1.FunctionsRequest]) (*connect_go.Response[v1alpha1.FunctionsResponse], error)
- func (UnimplementedMetastoreServiceHandler) GetOrCreateFunctions(context.Context, *connect_go.Request[v1alpha1.GetOrCreateFunctionsRequest]) (*connect_go.Response[v1alpha1.GetOrCreateFunctionsResponse], error)
- func (UnimplementedMetastoreServiceHandler) GetOrCreateLocations(context.Context, *connect_go.Request[v1alpha1.GetOrCreateLocationsRequest]) (*connect_go.Response[v1alpha1.GetOrCreateLocationsResponse], error)
- func (UnimplementedMetastoreServiceHandler) GetOrCreateMappings(context.Context, *connect_go.Request[v1alpha1.GetOrCreateMappingsRequest]) (*connect_go.Response[v1alpha1.GetOrCreateMappingsResponse], error)
- func (UnimplementedMetastoreServiceHandler) GetOrCreateStacktraces(context.Context, *connect_go.Request[v1alpha1.GetOrCreateStacktracesRequest]) (*connect_go.Response[v1alpha1.GetOrCreateStacktracesResponse], error)
- func (UnimplementedMetastoreServiceHandler) Locations(context.Context, *connect_go.Request[v1alpha1.LocationsRequest]) (*connect_go.Response[v1alpha1.LocationsResponse], error)
- func (UnimplementedMetastoreServiceHandler) Mappings(context.Context, *connect_go.Request[v1alpha1.MappingsRequest]) (*connect_go.Response[v1alpha1.MappingsResponse], error)
- func (UnimplementedMetastoreServiceHandler) Stacktraces(context.Context, *connect_go.Request[v1alpha1.StacktracesRequest]) (*connect_go.Response[v1alpha1.StacktracesResponse], error)
- func (UnimplementedMetastoreServiceHandler) UnsymbolizedLocations(context.Context, *connect_go.Request[v1alpha1.UnsymbolizedLocationsRequest]) (*connect_go.Response[v1alpha1.UnsymbolizedLocationsResponse], error)
Constants ¶
const ( // MetastoreServiceGetOrCreateMappingsProcedure is the fully-qualified name of the // MetastoreService's GetOrCreateMappings RPC. MetastoreServiceGetOrCreateMappingsProcedure = "/parca.metastore.v1alpha1.MetastoreService/GetOrCreateMappings" // MetastoreServiceGetOrCreateFunctionsProcedure is the fully-qualified name of the // MetastoreService's GetOrCreateFunctions RPC. MetastoreServiceGetOrCreateFunctionsProcedure = "/parca.metastore.v1alpha1.MetastoreService/GetOrCreateFunctions" // MetastoreServiceGetOrCreateLocationsProcedure is the fully-qualified name of the // MetastoreService's GetOrCreateLocations RPC. MetastoreServiceGetOrCreateLocationsProcedure = "/parca.metastore.v1alpha1.MetastoreService/GetOrCreateLocations" // MetastoreServiceGetOrCreateStacktracesProcedure is the fully-qualified name of the // MetastoreService's GetOrCreateStacktraces RPC. MetastoreServiceGetOrCreateStacktracesProcedure = "/parca.metastore.v1alpha1.MetastoreService/GetOrCreateStacktraces" // MetastoreServiceUnsymbolizedLocationsProcedure is the fully-qualified name of the // MetastoreService's UnsymbolizedLocations RPC. MetastoreServiceUnsymbolizedLocationsProcedure = "/parca.metastore.v1alpha1.MetastoreService/UnsymbolizedLocations" // MetastoreServiceCreateLocationLinesProcedure is the fully-qualified name of the // MetastoreService's CreateLocationLines RPC. MetastoreServiceCreateLocationLinesProcedure = "/parca.metastore.v1alpha1.MetastoreService/CreateLocationLines" // MetastoreServiceLocationsProcedure is the fully-qualified name of the MetastoreService's // Locations RPC. MetastoreServiceLocationsProcedure = "/parca.metastore.v1alpha1.MetastoreService/Locations" // MetastoreServiceFunctionsProcedure is the fully-qualified name of the MetastoreService's // Functions RPC. MetastoreServiceFunctionsProcedure = "/parca.metastore.v1alpha1.MetastoreService/Functions" // MetastoreServiceMappingsProcedure is the fully-qualified name of the MetastoreService's Mappings // RPC. MetastoreServiceMappingsProcedure = "/parca.metastore.v1alpha1.MetastoreService/Mappings" // MetastoreServiceStacktracesProcedure is the fully-qualified name of the MetastoreService's // Stacktraces RPC. MetastoreServiceStacktracesProcedure = "/parca.metastore.v1alpha1.MetastoreService/Stacktraces" )
These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.
Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.
const (
// MetastoreServiceName is the fully-qualified name of the MetastoreService service.
MetastoreServiceName = "parca.metastore.v1alpha1.MetastoreService"
)
Variables ¶
This section is empty.
Functions ¶
func NewMetastoreServiceHandler ¶
func NewMetastoreServiceHandler(svc MetastoreServiceHandler, opts ...connect_go.HandlerOption) (string, http.Handler)
NewMetastoreServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.
By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.
Types ¶
type MetastoreServiceClient ¶
type MetastoreServiceClient interface {
// GetOrCreateMappings checks if the mappings in the request are already
// known and returns the known mapping (including its ID) if so. If a mapping
// does not already exist, it is written to the backing metastore.
GetOrCreateMappings(context.Context, *connect_go.Request[v1alpha1.GetOrCreateMappingsRequest]) (*connect_go.Response[v1alpha1.GetOrCreateMappingsResponse], error)
// GetOrCreateFunctions checks if the functions in the request are already
// known and returns the known function (including its ID) if so. If a
// function does not already exist, it is written to the backing metastore.
GetOrCreateFunctions(context.Context, *connect_go.Request[v1alpha1.GetOrCreateFunctionsRequest]) (*connect_go.Response[v1alpha1.GetOrCreateFunctionsResponse], error)
// GetOrCreateLocations checks if the locations in the request are already
// known and returns the known location (including its ID) if so. If a
// location does not already exist, it is written to the backing metastore.
GetOrCreateLocations(context.Context, *connect_go.Request[v1alpha1.GetOrCreateLocationsRequest]) (*connect_go.Response[v1alpha1.GetOrCreateLocationsResponse], error)
// GetOrCreateStacktraces checks if the stacktraces in the request are
// already known and returns the known stacktrace (including its ID) if so.
// If a stacktrace does not already exist, it is written to the backing
// metastore.
GetOrCreateStacktraces(context.Context, *connect_go.Request[v1alpha1.GetOrCreateStacktracesRequest]) (*connect_go.Response[v1alpha1.GetOrCreateStacktracesResponse], error)
// UnsymbolizedLocations returns locations that can be symbolized but haven't
// been asynchronously symbolized yet.
UnsymbolizedLocations(context.Context, *connect_go.Request[v1alpha1.UnsymbolizedLocationsRequest]) (*connect_go.Response[v1alpha1.UnsymbolizedLocationsResponse], error)
// CreateLocationLines creates the location lines contained in the provided
// locations.
CreateLocationLines(context.Context, *connect_go.Request[v1alpha1.CreateLocationLinesRequest]) (*connect_go.Response[v1alpha1.CreateLocationLinesResponse], error)
// Locations retrieves locations.
Locations(context.Context, *connect_go.Request[v1alpha1.LocationsRequest]) (*connect_go.Response[v1alpha1.LocationsResponse], error)
// Functions retrieves functions.
Functions(context.Context, *connect_go.Request[v1alpha1.FunctionsRequest]) (*connect_go.Response[v1alpha1.FunctionsResponse], error)
// Mappings retrieves mappings.
Mappings(context.Context, *connect_go.Request[v1alpha1.MappingsRequest]) (*connect_go.Response[v1alpha1.MappingsResponse], error)
// Stacktraces retrieves mappings.
Stacktraces(context.Context, *connect_go.Request[v1alpha1.StacktracesRequest]) (*connect_go.Response[v1alpha1.StacktracesResponse], error)
}
MetastoreServiceClient is a client for the parca.metastore.v1alpha1.MetastoreService service.
func NewMetastoreServiceClient ¶
func NewMetastoreServiceClient(httpClient connect_go.HTTPClient, baseURL string, opts ...connect_go.ClientOption) MetastoreServiceClient
NewMetastoreServiceClient constructs a client for the parca.metastore.v1alpha1.MetastoreService service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.
The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).
type MetastoreServiceHandler ¶
type MetastoreServiceHandler interface {
// GetOrCreateMappings checks if the mappings in the request are already
// known and returns the known mapping (including its ID) if so. If a mapping
// does not already exist, it is written to the backing metastore.
GetOrCreateMappings(context.Context, *connect_go.Request[v1alpha1.GetOrCreateMappingsRequest]) (*connect_go.Response[v1alpha1.GetOrCreateMappingsResponse], error)
// GetOrCreateFunctions checks if the functions in the request are already
// known and returns the known function (including its ID) if so. If a
// function does not already exist, it is written to the backing metastore.
GetOrCreateFunctions(context.Context, *connect_go.Request[v1alpha1.GetOrCreateFunctionsRequest]) (*connect_go.Response[v1alpha1.GetOrCreateFunctionsResponse], error)
// GetOrCreateLocations checks if the locations in the request are already
// known and returns the known location (including its ID) if so. If a
// location does not already exist, it is written to the backing metastore.
GetOrCreateLocations(context.Context, *connect_go.Request[v1alpha1.GetOrCreateLocationsRequest]) (*connect_go.Response[v1alpha1.GetOrCreateLocationsResponse], error)
// GetOrCreateStacktraces checks if the stacktraces in the request are
// already known and returns the known stacktrace (including its ID) if so.
// If a stacktrace does not already exist, it is written to the backing
// metastore.
GetOrCreateStacktraces(context.Context, *connect_go.Request[v1alpha1.GetOrCreateStacktracesRequest]) (*connect_go.Response[v1alpha1.GetOrCreateStacktracesResponse], error)
// UnsymbolizedLocations returns locations that can be symbolized but haven't
// been asynchronously symbolized yet.
UnsymbolizedLocations(context.Context, *connect_go.Request[v1alpha1.UnsymbolizedLocationsRequest]) (*connect_go.Response[v1alpha1.UnsymbolizedLocationsResponse], error)
// CreateLocationLines creates the location lines contained in the provided
// locations.
CreateLocationLines(context.Context, *connect_go.Request[v1alpha1.CreateLocationLinesRequest]) (*connect_go.Response[v1alpha1.CreateLocationLinesResponse], error)
// Locations retrieves locations.
Locations(context.Context, *connect_go.Request[v1alpha1.LocationsRequest]) (*connect_go.Response[v1alpha1.LocationsResponse], error)
// Functions retrieves functions.
Functions(context.Context, *connect_go.Request[v1alpha1.FunctionsRequest]) (*connect_go.Response[v1alpha1.FunctionsResponse], error)
// Mappings retrieves mappings.
Mappings(context.Context, *connect_go.Request[v1alpha1.MappingsRequest]) (*connect_go.Response[v1alpha1.MappingsResponse], error)
// Stacktraces retrieves mappings.
Stacktraces(context.Context, *connect_go.Request[v1alpha1.StacktracesRequest]) (*connect_go.Response[v1alpha1.StacktracesResponse], error)
}
MetastoreServiceHandler is an implementation of the parca.metastore.v1alpha1.MetastoreService service.
type UnimplementedMetastoreServiceHandler ¶
type UnimplementedMetastoreServiceHandler struct{}
UnimplementedMetastoreServiceHandler returns CodeUnimplemented from all methods.
func (UnimplementedMetastoreServiceHandler) CreateLocationLines ¶
func (UnimplementedMetastoreServiceHandler) CreateLocationLines(context.Context, *connect_go.Request[v1alpha1.CreateLocationLinesRequest]) (*connect_go.Response[v1alpha1.CreateLocationLinesResponse], error)
func (UnimplementedMetastoreServiceHandler) Functions ¶
func (UnimplementedMetastoreServiceHandler) Functions(context.Context, *connect_go.Request[v1alpha1.FunctionsRequest]) (*connect_go.Response[v1alpha1.FunctionsResponse], error)
func (UnimplementedMetastoreServiceHandler) GetOrCreateFunctions ¶
func (UnimplementedMetastoreServiceHandler) GetOrCreateFunctions(context.Context, *connect_go.Request[v1alpha1.GetOrCreateFunctionsRequest]) (*connect_go.Response[v1alpha1.GetOrCreateFunctionsResponse], error)
func (UnimplementedMetastoreServiceHandler) GetOrCreateLocations ¶
func (UnimplementedMetastoreServiceHandler) GetOrCreateLocations(context.Context, *connect_go.Request[v1alpha1.GetOrCreateLocationsRequest]) (*connect_go.Response[v1alpha1.GetOrCreateLocationsResponse], error)
func (UnimplementedMetastoreServiceHandler) GetOrCreateMappings ¶
func (UnimplementedMetastoreServiceHandler) GetOrCreateMappings(context.Context, *connect_go.Request[v1alpha1.GetOrCreateMappingsRequest]) (*connect_go.Response[v1alpha1.GetOrCreateMappingsResponse], error)
func (UnimplementedMetastoreServiceHandler) GetOrCreateStacktraces ¶
func (UnimplementedMetastoreServiceHandler) GetOrCreateStacktraces(context.Context, *connect_go.Request[v1alpha1.GetOrCreateStacktracesRequest]) (*connect_go.Response[v1alpha1.GetOrCreateStacktracesResponse], error)
func (UnimplementedMetastoreServiceHandler) Locations ¶
func (UnimplementedMetastoreServiceHandler) Locations(context.Context, *connect_go.Request[v1alpha1.LocationsRequest]) (*connect_go.Response[v1alpha1.LocationsResponse], error)
func (UnimplementedMetastoreServiceHandler) Mappings ¶
func (UnimplementedMetastoreServiceHandler) Mappings(context.Context, *connect_go.Request[v1alpha1.MappingsRequest]) (*connect_go.Response[v1alpha1.MappingsResponse], error)
func (UnimplementedMetastoreServiceHandler) Stacktraces ¶
func (UnimplementedMetastoreServiceHandler) Stacktraces(context.Context, *connect_go.Request[v1alpha1.StacktracesRequest]) (*connect_go.Response[v1alpha1.StacktracesResponse], error)
func (UnimplementedMetastoreServiceHandler) UnsymbolizedLocations ¶
func (UnimplementedMetastoreServiceHandler) UnsymbolizedLocations(context.Context, *connect_go.Request[v1alpha1.UnsymbolizedLocationsRequest]) (*connect_go.Response[v1alpha1.UnsymbolizedLocationsResponse], error)
Source Files
¶
- metastore.connect.go