Documentation
¶
Index ¶
- Constants
- func NewShareServiceHandler(svc ShareServiceHandler, opts ...connect_go.HandlerOption) (string, http.Handler)
- type ShareServiceClient
- type ShareServiceHandler
- type UnimplementedShareServiceHandler
- func (UnimplementedShareServiceHandler) ProfileTypes(context.Context, *connect_go.Request[v1alpha1.ProfileTypesRequest]) (*connect_go.Response[v1alpha1.ProfileTypesResponse], error)
- func (UnimplementedShareServiceHandler) Query(context.Context, *connect_go.Request[v1alpha1.QueryRequest]) (*connect_go.Response[v1alpha1.QueryResponse], error)
- func (UnimplementedShareServiceHandler) Upload(context.Context, *connect_go.Request[v1alpha1.UploadRequest]) (*connect_go.Response[v1alpha1.UploadResponse], error)
Constants ¶
const ( ShareServiceUploadProcedure = "/parca.share.v1alpha1.ShareService/Upload" ShareServiceQueryProcedure = "/parca.share.v1alpha1.ShareService/Query" // RPC. ShareServiceProfileTypesProcedure = "/parca.share.v1alpha1.ShareService/ProfileTypes" )
These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.
Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.
const (
ShareServiceName = "parca.share.v1alpha1.ShareService"
)
Variables ¶
This section is empty.
Functions ¶
func NewShareServiceHandler ¶
func NewShareServiceHandler(svc ShareServiceHandler, opts ...connect_go.HandlerOption) (string, http.Handler)
NewShareServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.
By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.
Types ¶
type ShareServiceClient ¶
type ShareServiceClient interface {
Upload(context.Context, *connect_go.Request[v1alpha1.UploadRequest]) (*connect_go.Response[v1alpha1.UploadResponse], error)
Query(context.Context, *connect_go.Request[v1alpha1.QueryRequest]) (*connect_go.Response[v1alpha1.QueryResponse], error)
ProfileTypes(context.Context, *connect_go.Request[v1alpha1.ProfileTypesRequest]) (*connect_go.Response[v1alpha1.ProfileTypesResponse], error)
}
ShareServiceClient is a client for the parca.share.v1alpha1.ShareService service.
func NewShareServiceClient ¶
func NewShareServiceClient(httpClient connect_go.HTTPClient, baseURL string, opts ...connect_go.ClientOption) ShareServiceClient
NewShareServiceClient constructs a client for the parca.share.v1alpha1.ShareService service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.
The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).
type ShareServiceHandler ¶
type ShareServiceHandler interface {
Upload(context.Context, *connect_go.Request[v1alpha1.UploadRequest]) (*connect_go.Response[v1alpha1.UploadResponse], error)
Query(context.Context, *connect_go.Request[v1alpha1.QueryRequest]) (*connect_go.Response[v1alpha1.QueryResponse], error)
ProfileTypes(context.Context, *connect_go.Request[v1alpha1.ProfileTypesRequest]) (*connect_go.Response[v1alpha1.ProfileTypesResponse], error)
}
ShareServiceHandler is an implementation of the parca.share.v1alpha1.ShareService service.
type UnimplementedShareServiceHandler ¶
type UnimplementedShareServiceHandler struct{}
UnimplementedShareServiceHandler returns CodeUnimplemented from all methods.
func (UnimplementedShareServiceHandler) ProfileTypes ¶
func (UnimplementedShareServiceHandler) ProfileTypes(context.Context, *connect_go.Request[v1alpha1.ProfileTypesRequest]) (*connect_go.Response[v1alpha1.ProfileTypesResponse], error)
func (UnimplementedShareServiceHandler) Query ¶
func (UnimplementedShareServiceHandler) Query(context.Context, *connect_go.Request[v1alpha1.QueryRequest]) (*connect_go.Response[v1alpha1.QueryResponse], error)
func (UnimplementedShareServiceHandler) Upload ¶
func (UnimplementedShareServiceHandler) Upload(context.Context, *connect_go.Request[v1alpha1.UploadRequest]) (*connect_go.Response[v1alpha1.UploadResponse], error)
Source Files
¶
- share.connect.go