Documentation
¶
Index ¶
- Variables
- type DeploymentFlags
- func (x *DeploymentFlags) GetCancelUpdates() bool
- func (x *DeploymentFlags) GetDbOnly() bool
- func (x *DeploymentFlags) GetImportResources() bool
- func (x *DeploymentFlags) GetInfraOnly() bool
- func (x *DeploymentFlags) GetQuickMode() bool
- func (x *DeploymentFlags) GetRotateCredentials() bool
- func (*DeploymentFlags) ProtoMessage()
- func (x *DeploymentFlags) ProtoReflect() protoreflect.Message
- func (x *DeploymentFlags) Reset()
- func (x *DeploymentFlags) SetCancelUpdates(v bool)
- func (x *DeploymentFlags) SetDbOnly(v bool)
- func (x *DeploymentFlags) SetImportResources(v bool)
- func (x *DeploymentFlags) SetInfraOnly(v bool)
- func (x *DeploymentFlags) SetQuickMode(v bool)
- func (x *DeploymentFlags) SetRotateCredentials(v bool)
- func (x *DeploymentFlags) String() string
- type DeploymentFlags_builder
Constants ¶
This section is empty.
Variables ¶
var File_o5_deployer_v1_deployer_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type DeploymentFlags ¶
type DeploymentFlags struct {
// Skips scale up/down, directly applying the updates in one infra call.
QuickMode bool `protobuf:"varint,1,opt,name=quick_mode,json=quickMode,proto3" json:"quick_mode,omitempty"`
// Rotates database credentials
RotateCredentials bool `protobuf:"varint,2,opt,name=rotate_credentials,json=rotateCredentials,proto3" json:"rotate_credentials,omitempty"`
CancelUpdates bool `protobuf:"varint,3,opt,name=cancel_updates,json=cancelUpdates,proto3" json:"cancel_updates,omitempty"`
DbOnly bool `protobuf:"varint,4,opt,name=db_only,json=dbOnly,proto3" json:"db_only,omitempty"`
InfraOnly bool `protobuf:"varint,5,opt,name=infra_only,json=infraOnly,proto3" json:"infra_only,omitempty"`
ImportResources bool `protobuf:"varint,6,opt,name=import_resources,json=importResources,proto3" json:"import_resources,omitempty"`
// contains filtered or unexported fields
}
func (*DeploymentFlags) GetCancelUpdates ¶
func (x *DeploymentFlags) GetCancelUpdates() bool
func (*DeploymentFlags) GetDbOnly ¶
func (x *DeploymentFlags) GetDbOnly() bool
func (*DeploymentFlags) GetImportResources ¶
func (x *DeploymentFlags) GetImportResources() bool
func (*DeploymentFlags) GetInfraOnly ¶
func (x *DeploymentFlags) GetInfraOnly() bool
func (*DeploymentFlags) GetQuickMode ¶
func (x *DeploymentFlags) GetQuickMode() bool
func (*DeploymentFlags) GetRotateCredentials ¶
func (x *DeploymentFlags) GetRotateCredentials() bool
func (*DeploymentFlags) ProtoMessage ¶
func (*DeploymentFlags) ProtoMessage()
func (*DeploymentFlags) ProtoReflect ¶
func (x *DeploymentFlags) ProtoReflect() protoreflect.Message
func (*DeploymentFlags) Reset ¶
func (x *DeploymentFlags) Reset()
func (*DeploymentFlags) SetCancelUpdates ¶
func (x *DeploymentFlags) SetCancelUpdates(v bool)
func (*DeploymentFlags) SetDbOnly ¶
func (x *DeploymentFlags) SetDbOnly(v bool)
func (*DeploymentFlags) SetImportResources ¶
func (x *DeploymentFlags) SetImportResources(v bool)
func (*DeploymentFlags) SetInfraOnly ¶
func (x *DeploymentFlags) SetInfraOnly(v bool)
func (*DeploymentFlags) SetQuickMode ¶
func (x *DeploymentFlags) SetQuickMode(v bool)
func (*DeploymentFlags) SetRotateCredentials ¶
func (x *DeploymentFlags) SetRotateCredentials(v bool)
func (*DeploymentFlags) String ¶
func (x *DeploymentFlags) String() string
type DeploymentFlags_builder ¶
type DeploymentFlags_builder struct {
// Skips scale up/down, directly applying the updates in one infra call.
QuickMode bool
// Rotates database credentials
RotateCredentials bool
CancelUpdates bool
DbOnly bool
InfraOnly bool
ImportResources bool
// contains filtered or unexported fields
}
func (DeploymentFlags_builder) Build ¶
func (b0 DeploymentFlags_builder) Build() *DeploymentFlags
Source Files
¶
- deployer.pb.go
Click to show internal directories.
Click to hide internal directories.