Documentation
¶
Index ¶
- Variables
- type CloseSessionRequest
- func (x *CloseSessionRequest) ClearSession()
- func (x *CloseSessionRequest) GetSession() *Session
- func (x *CloseSessionRequest) HasSession() bool
- func (*CloseSessionRequest) ProtoMessage()
- func (x *CloseSessionRequest) ProtoReflect() protoreflect.Message
- func (x *CloseSessionRequest) Reset()
- func (x *CloseSessionRequest) SetSession(v *Session)
- func (x *CloseSessionRequest) String() string
- type CloseSessionRequest_builder
- type CloseSessionResponse
- func (x *CloseSessionResponse) ClearError()
- func (x *CloseSessionResponse) ClearSession()
- func (x *CloseSessionResponse) GetError() *v211.RPCError
- func (x *CloseSessionResponse) GetSession() *Session
- func (x *CloseSessionResponse) HasError() bool
- func (x *CloseSessionResponse) HasSession() bool
- func (*CloseSessionResponse) ProtoMessage()
- func (x *CloseSessionResponse) ProtoReflect() protoreflect.Message
- func (x *CloseSessionResponse) Reset()
- func (x *CloseSessionResponse) SetError(v *v211.RPCError)
- func (x *CloseSessionResponse) SetSession(v *Session)
- func (x *CloseSessionResponse) String() string
- type CloseSessionResponse_builder
- type CreateSessionRequest
- type CreateSessionRequest_builder
- type CreateSessionResponse
- func (x *CreateSessionResponse) ClearSession()
- func (x *CreateSessionResponse) ClearUser()
- func (x *CreateSessionResponse) GetBranch() string
- func (x *CreateSessionResponse) GetSession() *Session
- func (x *CreateSessionResponse) GetUser() *User
- func (x *CreateSessionResponse) HasSession() bool
- func (x *CreateSessionResponse) HasUser() bool
- func (*CreateSessionResponse) ProtoMessage()
- func (x *CreateSessionResponse) ProtoReflect() protoreflect.Message
- func (x *CreateSessionResponse) Reset()
- func (x *CreateSessionResponse) SetBranch(v string)
- func (x *CreateSessionResponse) SetSession(v *Session)
- func (x *CreateSessionResponse) SetUser(v *User)
- func (x *CreateSessionResponse) String() string
- type CreateSessionResponse_builder
- type ExecuteRequest
- func (x *ExecuteRequest) ClearSession()
- func (x *ExecuteRequest) GetBindVariables() map[string]*v21.BindVariable
- func (x *ExecuteRequest) GetQuery() string
- func (x *ExecuteRequest) GetSession() *Session
- func (x *ExecuteRequest) HasSession() bool
- func (*ExecuteRequest) ProtoMessage()
- func (x *ExecuteRequest) ProtoReflect() protoreflect.Message
- func (x *ExecuteRequest) Reset()
- func (x *ExecuteRequest) SetBindVariables(v map[string]*v21.BindVariable)
- func (x *ExecuteRequest) SetQuery(v string)
- func (x *ExecuteRequest) SetSession(v *Session)
- func (x *ExecuteRequest) String() string
- type ExecuteRequest_builder
- type ExecuteResponse
- func (x *ExecuteResponse) ClearError()
- func (x *ExecuteResponse) ClearResult()
- func (x *ExecuteResponse) ClearSession()
- func (x *ExecuteResponse) GetError() *v211.RPCError
- func (x *ExecuteResponse) GetResult() *v21.QueryResult
- func (x *ExecuteResponse) GetSession() *Session
- func (x *ExecuteResponse) GetTiming() float64
- func (x *ExecuteResponse) HasError() bool
- func (x *ExecuteResponse) HasResult() bool
- func (x *ExecuteResponse) HasSession() bool
- func (*ExecuteResponse) ProtoMessage()
- func (x *ExecuteResponse) ProtoReflect() protoreflect.Message
- func (x *ExecuteResponse) Reset()
- func (x *ExecuteResponse) SetError(v *v211.RPCError)
- func (x *ExecuteResponse) SetResult(v *v21.QueryResult)
- func (x *ExecuteResponse) SetSession(v *Session)
- func (x *ExecuteResponse) SetTiming(v float64)
- func (x *ExecuteResponse) String() string
- type ExecuteResponse_builder
- type PrepareRequest
- func (x *PrepareRequest) ClearSession()
- func (x *PrepareRequest) GetBindVariables() map[string]*v21.BindVariable
- func (x *PrepareRequest) GetQuery() string
- func (x *PrepareRequest) GetSession() *Session
- func (x *PrepareRequest) HasSession() bool
- func (*PrepareRequest) ProtoMessage()
- func (x *PrepareRequest) ProtoReflect() protoreflect.Message
- func (x *PrepareRequest) Reset()
- func (x *PrepareRequest) SetBindVariables(v map[string]*v21.BindVariable)
- func (x *PrepareRequest) SetQuery(v string)
- func (x *PrepareRequest) SetSession(v *Session)
- func (x *PrepareRequest) String() string
- type PrepareRequest_builder
- type PrepareResponse
- func (x *PrepareResponse) ClearError()
- func (x *PrepareResponse) ClearSession()
- func (x *PrepareResponse) GetError() *v211.RPCError
- func (x *PrepareResponse) GetFields() []*v21.Field
- func (x *PrepareResponse) GetSession() *Session
- func (x *PrepareResponse) HasError() bool
- func (x *PrepareResponse) HasSession() bool
- func (*PrepareResponse) ProtoMessage()
- func (x *PrepareResponse) ProtoReflect() protoreflect.Message
- func (x *PrepareResponse) Reset()
- func (x *PrepareResponse) SetError(v *v211.RPCError)
- func (x *PrepareResponse) SetFields(v []*v21.Field)
- func (x *PrepareResponse) SetSession(v *Session)
- func (x *PrepareResponse) String() string
- type PrepareResponse_builder
- type Session
- func (x *Session) ClearVitessSession()
- func (x *Session) GetSignature() []byte
- func (x *Session) GetVitessSession() *v212.Session
- func (x *Session) HasVitessSession() bool
- func (*Session) ProtoMessage()
- func (x *Session) ProtoReflect() protoreflect.Message
- func (x *Session) Reset()
- func (x *Session) SetSignature(v []byte)
- func (x *Session) SetVitessSession(v *v212.Session)
- func (x *Session) String() string
- type Session_builder
- type User
- func (x *User) GetPsid() string
- func (x *User) GetRole() v1.Role
- func (x *User) GetUsername() string
- func (*User) ProtoMessage()
- func (x *User) ProtoReflect() protoreflect.Message
- func (x *User) Reset()
- func (x *User) SetPsid(v string)
- func (x *User) SetRole(v v1.Role)
- func (x *User) SetUsername(v string)
- func (x *User) String() string
- type User_builder
Constants ¶
This section is empty.
Variables ¶
var File_psdb_v1alpha1_database_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type CloseSessionRequest ¶
type CloseSessionRequest struct {
Session *Session `protobuf:"bytes,1,opt,name=session,proto3" json:"session,omitempty"`
// contains filtered or unexported fields
}
func (*CloseSessionRequest) ClearSession ¶
func (x *CloseSessionRequest) ClearSession()
func (*CloseSessionRequest) GetSession ¶
func (x *CloseSessionRequest) GetSession() *Session
func (*CloseSessionRequest) HasSession ¶
func (x *CloseSessionRequest) HasSession() bool
func (*CloseSessionRequest) ProtoMessage ¶
func (*CloseSessionRequest) ProtoMessage()
func (*CloseSessionRequest) ProtoReflect ¶
func (x *CloseSessionRequest) ProtoReflect() protoreflect.Message
func (*CloseSessionRequest) Reset ¶
func (x *CloseSessionRequest) Reset()
func (*CloseSessionRequest) SetSession ¶
func (x *CloseSessionRequest) SetSession(v *Session)
func (*CloseSessionRequest) String ¶
func (x *CloseSessionRequest) String() string
type CloseSessionRequest_builder ¶
type CloseSessionRequest_builder struct {
Session *Session
// contains filtered or unexported fields
}
func (CloseSessionRequest_builder) Build ¶
func (b0 CloseSessionRequest_builder) Build() *CloseSessionRequest
type CloseSessionResponse ¶
type CloseSessionResponse struct {
Session *Session `protobuf:"bytes,1,opt,name=session,proto3" json:"session,omitempty"`
Error *v211.RPCError `protobuf:"bytes,2,opt,name=error,proto3" json:"error,omitempty"`
// contains filtered or unexported fields
}
func (*CloseSessionResponse) ClearError ¶
func (x *CloseSessionResponse) ClearError()
func (*CloseSessionResponse) ClearSession ¶
func (x *CloseSessionResponse) ClearSession()
func (*CloseSessionResponse) GetError ¶
func (x *CloseSessionResponse) GetError() *v211.RPCError
func (*CloseSessionResponse) GetSession ¶
func (x *CloseSessionResponse) GetSession() *Session
func (*CloseSessionResponse) HasError ¶
func (x *CloseSessionResponse) HasError() bool
func (*CloseSessionResponse) HasSession ¶
func (x *CloseSessionResponse) HasSession() bool
func (*CloseSessionResponse) ProtoMessage ¶
func (*CloseSessionResponse) ProtoMessage()
func (*CloseSessionResponse) ProtoReflect ¶
func (x *CloseSessionResponse) ProtoReflect() protoreflect.Message
func (*CloseSessionResponse) Reset ¶
func (x *CloseSessionResponse) Reset()
func (*CloseSessionResponse) SetError ¶
func (x *CloseSessionResponse) SetError(v *v211.RPCError)
func (*CloseSessionResponse) SetSession ¶
func (x *CloseSessionResponse) SetSession(v *Session)
func (*CloseSessionResponse) String ¶
func (x *CloseSessionResponse) String() string
type CloseSessionResponse_builder ¶
type CloseSessionResponse_builder struct {
Session *Session
Error *v211.RPCError
// contains filtered or unexported fields
}
func (CloseSessionResponse_builder) Build ¶
func (b0 CloseSessionResponse_builder) Build() *CloseSessionResponse
type CreateSessionRequest ¶
type CreateSessionRequest struct {
// contains filtered or unexported fields
}
func (*CreateSessionRequest) ProtoMessage ¶
func (*CreateSessionRequest) ProtoMessage()
func (*CreateSessionRequest) ProtoReflect ¶
func (x *CreateSessionRequest) ProtoReflect() protoreflect.Message
func (*CreateSessionRequest) Reset ¶
func (x *CreateSessionRequest) Reset()
func (*CreateSessionRequest) String ¶
func (x *CreateSessionRequest) String() string
type CreateSessionRequest_builder ¶
type CreateSessionRequest_builder struct {
// contains filtered or unexported fields
}
func (CreateSessionRequest_builder) Build ¶
func (b0 CreateSessionRequest_builder) Build() *CreateSessionRequest
type CreateSessionResponse ¶
type CreateSessionResponse struct {
Branch string `protobuf:"bytes,1,opt,name=branch,proto3" json:"branch,omitempty"`
User *User `protobuf:"bytes,2,opt,name=user,proto3" json:"user,omitempty"`
Session *Session `protobuf:"bytes,4,opt,name=session,proto3" json:"session,omitempty"`
// contains filtered or unexported fields
}
func (*CreateSessionResponse) ClearSession ¶
func (x *CreateSessionResponse) ClearSession()
func (*CreateSessionResponse) ClearUser ¶
func (x *CreateSessionResponse) ClearUser()
func (*CreateSessionResponse) GetBranch ¶
func (x *CreateSessionResponse) GetBranch() string
func (*CreateSessionResponse) GetSession ¶
func (x *CreateSessionResponse) GetSession() *Session
func (*CreateSessionResponse) GetUser ¶
func (x *CreateSessionResponse) GetUser() *User
func (*CreateSessionResponse) HasSession ¶
func (x *CreateSessionResponse) HasSession() bool
func (*CreateSessionResponse) HasUser ¶
func (x *CreateSessionResponse) HasUser() bool
func (*CreateSessionResponse) ProtoMessage ¶
func (*CreateSessionResponse) ProtoMessage()
func (*CreateSessionResponse) ProtoReflect ¶
func (x *CreateSessionResponse) ProtoReflect() protoreflect.Message
func (*CreateSessionResponse) Reset ¶
func (x *CreateSessionResponse) Reset()
func (*CreateSessionResponse) SetBranch ¶
func (x *CreateSessionResponse) SetBranch(v string)
func (*CreateSessionResponse) SetSession ¶
func (x *CreateSessionResponse) SetSession(v *Session)
func (*CreateSessionResponse) SetUser ¶
func (x *CreateSessionResponse) SetUser(v *User)
func (*CreateSessionResponse) String ¶
func (x *CreateSessionResponse) String() string
type CreateSessionResponse_builder ¶
type CreateSessionResponse_builder struct {
Branch string
User *User
Session *Session
// contains filtered or unexported fields
}
func (CreateSessionResponse_builder) Build ¶
func (b0 CreateSessionResponse_builder) Build() *CreateSessionResponse
type ExecuteRequest ¶
type ExecuteRequest struct {
Session *Session `protobuf:"bytes,1,opt,name=session,proto3" json:"session,omitempty"`
Query string `protobuf:"bytes,2,opt,name=query,proto3" json:"query,omitempty"`
BindVariables map[string]*v21.BindVariable `` /* 174-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*ExecuteRequest) ClearSession ¶
func (x *ExecuteRequest) ClearSession()
func (*ExecuteRequest) GetBindVariables ¶
func (x *ExecuteRequest) GetBindVariables() map[string]*v21.BindVariable
func (*ExecuteRequest) GetQuery ¶
func (x *ExecuteRequest) GetQuery() string
func (*ExecuteRequest) GetSession ¶
func (x *ExecuteRequest) GetSession() *Session
func (*ExecuteRequest) HasSession ¶
func (x *ExecuteRequest) HasSession() bool
func (*ExecuteRequest) ProtoMessage ¶
func (*ExecuteRequest) ProtoMessage()
func (*ExecuteRequest) ProtoReflect ¶
func (x *ExecuteRequest) ProtoReflect() protoreflect.Message
func (*ExecuteRequest) Reset ¶
func (x *ExecuteRequest) Reset()
func (*ExecuteRequest) SetBindVariables ¶
func (x *ExecuteRequest) SetBindVariables(v map[string]*v21.BindVariable)
func (*ExecuteRequest) SetQuery ¶
func (x *ExecuteRequest) SetQuery(v string)
func (*ExecuteRequest) SetSession ¶
func (x *ExecuteRequest) SetSession(v *Session)
func (*ExecuteRequest) String ¶
func (x *ExecuteRequest) String() string
type ExecuteRequest_builder ¶
type ExecuteRequest_builder struct {
Session *Session
Query string
BindVariables map[string]*v21.BindVariable
// contains filtered or unexported fields
}
func (ExecuteRequest_builder) Build ¶
func (b0 ExecuteRequest_builder) Build() *ExecuteRequest
type ExecuteResponse ¶
type ExecuteResponse struct {
Session *Session `protobuf:"bytes,1,opt,name=session,proto3" json:"session,omitempty"`
Result *v21.QueryResult `protobuf:"bytes,2,opt,name=result,proto3" json:"result,omitempty"`
Error *v211.RPCError `protobuf:"bytes,3,opt,name=error,proto3" json:"error,omitempty"`
// optional timing, in seconds, for the response, if empty or 0, this wasn't set
// does not exist in the response from a StreamExecute.
Timing float64 `protobuf:"fixed64,4,opt,name=timing,proto3" json:"timing,omitempty"`
// contains filtered or unexported fields
}
func (*ExecuteResponse) ClearError ¶
func (x *ExecuteResponse) ClearError()
func (*ExecuteResponse) ClearResult ¶
func (x *ExecuteResponse) ClearResult()
func (*ExecuteResponse) ClearSession ¶
func (x *ExecuteResponse) ClearSession()
func (*ExecuteResponse) GetError ¶
func (x *ExecuteResponse) GetError() *v211.RPCError
func (*ExecuteResponse) GetResult ¶
func (x *ExecuteResponse) GetResult() *v21.QueryResult
func (*ExecuteResponse) GetSession ¶
func (x *ExecuteResponse) GetSession() *Session
func (*ExecuteResponse) GetTiming ¶
func (x *ExecuteResponse) GetTiming() float64
func (*ExecuteResponse) HasError ¶
func (x *ExecuteResponse) HasError() bool
func (*ExecuteResponse) HasResult ¶
func (x *ExecuteResponse) HasResult() bool
func (*ExecuteResponse) HasSession ¶
func (x *ExecuteResponse) HasSession() bool
func (*ExecuteResponse) ProtoMessage ¶
func (*ExecuteResponse) ProtoMessage()
func (*ExecuteResponse) ProtoReflect ¶
func (x *ExecuteResponse) ProtoReflect() protoreflect.Message
func (*ExecuteResponse) Reset ¶
func (x *ExecuteResponse) Reset()
func (*ExecuteResponse) SetError ¶
func (x *ExecuteResponse) SetError(v *v211.RPCError)
func (*ExecuteResponse) SetResult ¶
func (x *ExecuteResponse) SetResult(v *v21.QueryResult)
func (*ExecuteResponse) SetSession ¶
func (x *ExecuteResponse) SetSession(v *Session)
func (*ExecuteResponse) SetTiming ¶
func (x *ExecuteResponse) SetTiming(v float64)
func (*ExecuteResponse) String ¶
func (x *ExecuteResponse) String() string
type ExecuteResponse_builder ¶
type ExecuteResponse_builder struct {
Session *Session
Result *v21.QueryResult
Error *v211.RPCError
// optional timing, in seconds, for the response, if empty or 0, this wasn't set
// does not exist in the response from a StreamExecute.
Timing float64
// contains filtered or unexported fields
}
func (ExecuteResponse_builder) Build ¶
func (b0 ExecuteResponse_builder) Build() *ExecuteResponse
type PrepareRequest ¶
type PrepareRequest struct {
Session *Session `protobuf:"bytes,1,opt,name=session,proto3" json:"session,omitempty"`
Query string `protobuf:"bytes,2,opt,name=query,proto3" json:"query,omitempty"`
BindVariables map[string]*v21.BindVariable `` /* 174-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*PrepareRequest) ClearSession ¶
func (x *PrepareRequest) ClearSession()
func (*PrepareRequest) GetBindVariables ¶
func (x *PrepareRequest) GetBindVariables() map[string]*v21.BindVariable
func (*PrepareRequest) GetQuery ¶
func (x *PrepareRequest) GetQuery() string
func (*PrepareRequest) GetSession ¶
func (x *PrepareRequest) GetSession() *Session
func (*PrepareRequest) HasSession ¶
func (x *PrepareRequest) HasSession() bool
func (*PrepareRequest) ProtoMessage ¶
func (*PrepareRequest) ProtoMessage()
func (*PrepareRequest) ProtoReflect ¶
func (x *PrepareRequest) ProtoReflect() protoreflect.Message
func (*PrepareRequest) Reset ¶
func (x *PrepareRequest) Reset()
func (*PrepareRequest) SetBindVariables ¶
func (x *PrepareRequest) SetBindVariables(v map[string]*v21.BindVariable)
func (*PrepareRequest) SetQuery ¶
func (x *PrepareRequest) SetQuery(v string)
func (*PrepareRequest) SetSession ¶
func (x *PrepareRequest) SetSession(v *Session)
func (*PrepareRequest) String ¶
func (x *PrepareRequest) String() string
type PrepareRequest_builder ¶
type PrepareRequest_builder struct {
Session *Session
Query string
BindVariables map[string]*v21.BindVariable
// contains filtered or unexported fields
}
func (PrepareRequest_builder) Build ¶
func (b0 PrepareRequest_builder) Build() *PrepareRequest
type PrepareResponse ¶
type PrepareResponse struct {
Session *Session `protobuf:"bytes,1,opt,name=session,proto3" json:"session,omitempty"`
Fields []*v21.Field `protobuf:"bytes,2,rep,name=fields,proto3" json:"fields,omitempty"`
Error *v211.RPCError `protobuf:"bytes,3,opt,name=error,proto3" json:"error,omitempty"`
// contains filtered or unexported fields
}
func (*PrepareResponse) ClearError ¶
func (x *PrepareResponse) ClearError()
func (*PrepareResponse) ClearSession ¶
func (x *PrepareResponse) ClearSession()
func (*PrepareResponse) GetError ¶
func (x *PrepareResponse) GetError() *v211.RPCError
func (*PrepareResponse) GetFields ¶
func (x *PrepareResponse) GetFields() []*v21.Field
func (*PrepareResponse) GetSession ¶
func (x *PrepareResponse) GetSession() *Session
func (*PrepareResponse) HasError ¶
func (x *PrepareResponse) HasError() bool
func (*PrepareResponse) HasSession ¶
func (x *PrepareResponse) HasSession() bool
func (*PrepareResponse) ProtoMessage ¶
func (*PrepareResponse) ProtoMessage()
func (*PrepareResponse) ProtoReflect ¶
func (x *PrepareResponse) ProtoReflect() protoreflect.Message
func (*PrepareResponse) Reset ¶
func (x *PrepareResponse) Reset()
func (*PrepareResponse) SetError ¶
func (x *PrepareResponse) SetError(v *v211.RPCError)
func (*PrepareResponse) SetFields ¶
func (x *PrepareResponse) SetFields(v []*v21.Field)
func (*PrepareResponse) SetSession ¶
func (x *PrepareResponse) SetSession(v *Session)
func (*PrepareResponse) String ¶
func (x *PrepareResponse) String() string
type PrepareResponse_builder ¶
type PrepareResponse_builder struct {
Session *Session
Fields []*v21.Field
Error *v211.RPCError
// contains filtered or unexported fields
}
func (PrepareResponse_builder) Build ¶
func (b0 PrepareResponse_builder) Build() *PrepareResponse
type Session ¶
type Session struct {
Signature []byte `protobuf:"bytes,1,opt,name=signature,proto3" json:"signature,omitempty"`
VitessSession *v212.Session `protobuf:"bytes,2,opt,name=vitess_session,json=vitessSession,proto3" json:"vitess_session,omitempty"`
// contains filtered or unexported fields
}
func (*Session) ProtoReflect ¶
func (x *Session) ProtoReflect() protoreflect.Message
type Session_builder ¶
type Session_builder struct {
Signature []byte
VitessSession *v212.Session
// contains filtered or unexported fields
}
func (Session_builder) Build ¶
func (b0 Session_builder) Build() *Session
type User ¶
type User struct {
Username string `protobuf:"bytes,1,opt,name=username,proto3" json:"username,omitempty"`
Psid string `protobuf:"bytes,2,opt,name=psid,proto3" json:"psid,omitempty"`
Role v1.Role `protobuf:"varint,3,opt,name=role,proto3,enum=psdb.data.v1.Role" json:"role,omitempty"`
// contains filtered or unexported fields
}
func (*User) ProtoReflect ¶
func (x *User) ProtoReflect() protoreflect.Message
Source Files
¶
- database.pb.go
Click to show internal directories.
Click to hide internal directories.