Documentation
¶
Index ¶
- Variables
- type PushRequest
- type PushRequest_builder
- type PushResponse
- type PushResponse_builder
- type RawProfileSeries
- func (x *RawProfileSeries) GetLabels() []*v1.LabelPair
- func (x *RawProfileSeries) GetSamples() []*RawSample
- func (*RawProfileSeries) ProtoMessage()
- func (x *RawProfileSeries) ProtoReflect() protoreflect.Message
- func (x *RawProfileSeries) Reset()
- func (x *RawProfileSeries) SetLabels(v []*v1.LabelPair)
- func (x *RawProfileSeries) SetSamples(v []*RawSample)
- func (x *RawProfileSeries) String() string
- type RawProfileSeries_builder
- type RawSample
- func (x *RawSample) GetID() string
- func (x *RawSample) GetRawProfile() []byte
- func (*RawSample) ProtoMessage()
- func (x *RawSample) ProtoReflect() protoreflect.Message
- func (x *RawSample) Reset()
- func (x *RawSample) SetID(v string)
- func (x *RawSample) SetRawProfile(v []byte)
- func (x *RawSample) String() string
- type RawSample_builder
Constants ¶
This section is empty.
Variables ¶
var File_push_v1_push_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type PushRequest ¶
type PushRequest struct {
// series is a set raw pprof profiles and accompanying labels
Series []*RawProfileSeries `protobuf:"bytes,1,rep,name=series,proto3" json:"series,omitempty"`
// contains filtered or unexported fields
}
WriteRawRequest writes a pprof profile
func (*PushRequest) GetSeries ¶
func (x *PushRequest) GetSeries() []*RawProfileSeries
func (*PushRequest) ProtoMessage ¶
func (*PushRequest) ProtoMessage()
func (*PushRequest) ProtoReflect ¶
func (x *PushRequest) ProtoReflect() protoreflect.Message
func (*PushRequest) Reset ¶
func (x *PushRequest) Reset()
func (*PushRequest) SetSeries ¶
func (x *PushRequest) SetSeries(v []*RawProfileSeries)
func (*PushRequest) String ¶
func (x *PushRequest) String() string
type PushRequest_builder ¶
type PushRequest_builder struct {
// series is a set raw pprof profiles and accompanying labels
Series []*RawProfileSeries
// contains filtered or unexported fields
}
func (PushRequest_builder) Build ¶
func (b0 PushRequest_builder) Build() *PushRequest
type PushResponse ¶
type PushResponse struct {
// contains filtered or unexported fields
}
func (*PushResponse) ProtoMessage ¶
func (*PushResponse) ProtoMessage()
func (*PushResponse) ProtoReflect ¶
func (x *PushResponse) ProtoReflect() protoreflect.Message
func (*PushResponse) Reset ¶
func (x *PushResponse) Reset()
func (*PushResponse) String ¶
func (x *PushResponse) String() string
type PushResponse_builder ¶
type PushResponse_builder struct {
// contains filtered or unexported fields
}
func (PushResponse_builder) Build ¶
func (b0 PushResponse_builder) Build() *PushResponse
type RawProfileSeries ¶
type RawProfileSeries struct {
// LabelPair is the key value pairs to identify the corresponding profile
Labels []*v1.LabelPair `protobuf:"bytes,1,rep,name=labels,proto3" json:"labels,omitempty"`
// samples are the set of profile bytes
Samples []*RawSample `protobuf:"bytes,2,rep,name=samples,proto3" json:"samples,omitempty"`
// contains filtered or unexported fields
}
RawProfileSeries represents the pprof profile and its associated labels
func (*RawProfileSeries) GetLabels ¶
func (x *RawProfileSeries) GetLabels() []*v1.LabelPair
func (*RawProfileSeries) GetSamples ¶
func (x *RawProfileSeries) GetSamples() []*RawSample
func (*RawProfileSeries) ProtoMessage ¶
func (*RawProfileSeries) ProtoMessage()
func (*RawProfileSeries) ProtoReflect ¶
func (x *RawProfileSeries) ProtoReflect() protoreflect.Message
func (*RawProfileSeries) Reset ¶
func (x *RawProfileSeries) Reset()
func (*RawProfileSeries) SetLabels ¶
func (x *RawProfileSeries) SetLabels(v []*v1.LabelPair)
func (*RawProfileSeries) SetSamples ¶
func (x *RawProfileSeries) SetSamples(v []*RawSample)
func (*RawProfileSeries) String ¶
func (x *RawProfileSeries) String() string
type RawProfileSeries_builder ¶
type RawProfileSeries_builder struct {
// LabelPair is the key value pairs to identify the corresponding profile
Labels []*v1.LabelPair
// samples are the set of profile bytes
Samples []*RawSample
// contains filtered or unexported fields
}
func (RawProfileSeries_builder) Build ¶
func (b0 RawProfileSeries_builder) Build() *RawProfileSeries
type RawSample ¶
type RawSample struct {
// raw_profile is the set of bytes of the pprof profile
RawProfile []byte `protobuf:"bytes,1,opt,name=raw_profile,json=rawProfile,proto3" json:"raw_profile,omitempty"`
// unique ID of the profile
ID string `protobuf:"bytes,2,opt,name=ID,proto3" json:"ID,omitempty"`
// contains filtered or unexported fields
}
RawSample is the set of bytes that correspond to a pprof profile
func (*RawSample) ProtoReflect ¶
func (x *RawSample) ProtoReflect() protoreflect.Message
Source Files
¶
- push.pb.go
Click to show internal directories.
Click to hide internal directories.