Documentation
¶
Index ¶
- Variables
- type Diagnostics
- func (x *Diagnostics) ClearQueryPlan()
- func (x *Diagnostics) GetQueryPlan() *QueryPlan
- func (x *Diagnostics) HasQueryPlan() bool
- func (*Diagnostics) ProtoMessage()
- func (x *Diagnostics) ProtoReflect() protoreflect.Message
- func (x *Diagnostics) Reset()
- func (x *Diagnostics) SetQueryPlan(v *QueryPlan)
- func (x *Diagnostics) String() string
- type Diagnostics_builder
- type InvokeOptions
- type InvokeOptions_builder
- type InvokeRequest
- func (x *InvokeRequest) ClearOptions()
- func (x *InvokeRequest) ClearQueryPlan()
- func (x *InvokeRequest) GetEndTime() int64
- func (x *InvokeRequest) GetLabelSelector() string
- func (x *InvokeRequest) GetOptions() *InvokeOptions
- func (x *InvokeRequest) GetQuery() []*Query
- func (x *InvokeRequest) GetQueryPlan() *QueryPlan
- func (x *InvokeRequest) GetStartTime() int64
- func (x *InvokeRequest) GetTenant() []string
- func (x *InvokeRequest) HasOptions() bool
- func (x *InvokeRequest) HasQueryPlan() bool
- func (*InvokeRequest) ProtoMessage()
- func (x *InvokeRequest) ProtoReflect() protoreflect.Message
- func (x *InvokeRequest) Reset()
- func (x *InvokeRequest) SetEndTime(v int64)
- func (x *InvokeRequest) SetLabelSelector(v string)
- func (x *InvokeRequest) SetOptions(v *InvokeOptions)
- func (x *InvokeRequest) SetQuery(v []*Query)
- func (x *InvokeRequest) SetQueryPlan(v *QueryPlan)
- func (x *InvokeRequest) SetStartTime(v int64)
- func (x *InvokeRequest) SetTenant(v []string)
- func (x *InvokeRequest) String() string
- type InvokeRequest_builder
- type InvokeResponse
- func (x *InvokeResponse) ClearDiagnostics()
- func (x *InvokeResponse) GetDiagnostics() *Diagnostics
- func (x *InvokeResponse) GetReports() []*Report
- func (x *InvokeResponse) HasDiagnostics() bool
- func (*InvokeResponse) ProtoMessage()
- func (x *InvokeResponse) ProtoReflect() protoreflect.Message
- func (x *InvokeResponse) Reset()
- func (x *InvokeResponse) SetDiagnostics(v *Diagnostics)
- func (x *InvokeResponse) SetReports(v []*Report)
- func (x *InvokeResponse) String() string
- type InvokeResponse_builder
- type LabelNamesQuery
- type LabelNamesQuery_builder
- type LabelNamesReport
- func (x *LabelNamesReport) ClearQuery()
- func (x *LabelNamesReport) GetLabelNames() []string
- func (x *LabelNamesReport) GetQuery() *LabelNamesQuery
- func (x *LabelNamesReport) HasQuery() bool
- func (*LabelNamesReport) ProtoMessage()
- func (x *LabelNamesReport) ProtoReflect() protoreflect.Message
- func (x *LabelNamesReport) Reset()
- func (x *LabelNamesReport) SetLabelNames(v []string)
- func (x *LabelNamesReport) SetQuery(v *LabelNamesQuery)
- func (x *LabelNamesReport) String() string
- type LabelNamesReport_builder
- type LabelValuesQuery
- type LabelValuesQuery_builder
- type LabelValuesReport
- func (x *LabelValuesReport) ClearQuery()
- func (x *LabelValuesReport) GetLabelValues() []string
- func (x *LabelValuesReport) GetQuery() *LabelValuesQuery
- func (x *LabelValuesReport) HasQuery() bool
- func (*LabelValuesReport) ProtoMessage()
- func (x *LabelValuesReport) ProtoReflect() protoreflect.Message
- func (x *LabelValuesReport) Reset()
- func (x *LabelValuesReport) SetLabelValues(v []string)
- func (x *LabelValuesReport) SetQuery(v *LabelValuesQuery)
- func (x *LabelValuesReport) String() string
- type LabelValuesReport_builder
- type PprofQuery
- func (x *PprofQuery) ClearStackTraceSelector()
- func (x *PprofQuery) GetMaxNodes() int64
- func (x *PprofQuery) GetStackTraceSelector() *v11.StackTraceSelector
- func (x *PprofQuery) HasStackTraceSelector() bool
- func (*PprofQuery) ProtoMessage()
- func (x *PprofQuery) ProtoReflect() protoreflect.Message
- func (x *PprofQuery) Reset()
- func (x *PprofQuery) SetMaxNodes(v int64)
- func (x *PprofQuery) SetStackTraceSelector(v *v11.StackTraceSelector)
- func (x *PprofQuery) String() string
- type PprofQuery_builder
- type PprofReport
- func (x *PprofReport) ClearQuery()
- func (x *PprofReport) GetPprof() []byte
- func (x *PprofReport) GetQuery() *PprofQuery
- func (x *PprofReport) HasQuery() bool
- func (*PprofReport) ProtoMessage()
- func (x *PprofReport) ProtoReflect() protoreflect.Message
- func (x *PprofReport) Reset()
- func (x *PprofReport) SetPprof(v []byte)
- func (x *PprofReport) SetQuery(v *PprofQuery)
- func (x *PprofReport) String() string
- type PprofReport_builder
- type Query
- func (x *Query) ClearLabelNames()
- func (x *Query) ClearLabelValues()
- func (x *Query) ClearPprof()
- func (x *Query) ClearSeriesLabels()
- func (x *Query) ClearTimeSeries()
- func (x *Query) ClearTree()
- func (x *Query) GetLabelNames() *LabelNamesQuery
- func (x *Query) GetLabelValues() *LabelValuesQuery
- func (x *Query) GetPprof() *PprofQuery
- func (x *Query) GetQueryType() QueryType
- func (x *Query) GetSeriesLabels() *SeriesLabelsQuery
- func (x *Query) GetTimeSeries() *TimeSeriesQuery
- func (x *Query) GetTree() *TreeQuery
- func (x *Query) HasLabelNames() bool
- func (x *Query) HasLabelValues() bool
- func (x *Query) HasPprof() bool
- func (x *Query) HasSeriesLabels() bool
- func (x *Query) HasTimeSeries() bool
- func (x *Query) HasTree() bool
- func (*Query) ProtoMessage()
- func (x *Query) ProtoReflect() protoreflect.Message
- func (x *Query) Reset()
- func (x *Query) SetLabelNames(v *LabelNamesQuery)
- func (x *Query) SetLabelValues(v *LabelValuesQuery)
- func (x *Query) SetPprof(v *PprofQuery)
- func (x *Query) SetQueryType(v QueryType)
- func (x *Query) SetSeriesLabels(v *SeriesLabelsQuery)
- func (x *Query) SetTimeSeries(v *TimeSeriesQuery)
- func (x *Query) SetTree(v *TreeQuery)
- func (x *Query) String() string
- type QueryNode
- func (x *QueryNode) GetBlocks() []*v1.BlockMeta
- func (x *QueryNode) GetChildren() []*QueryNode
- func (x *QueryNode) GetType() QueryNode_Type
- func (*QueryNode) ProtoMessage()
- func (x *QueryNode) ProtoReflect() protoreflect.Message
- func (x *QueryNode) Reset()
- func (x *QueryNode) SetBlocks(v []*v1.BlockMeta)
- func (x *QueryNode) SetChildren(v []*QueryNode)
- func (x *QueryNode) SetType(v QueryNode_Type)
- func (x *QueryNode) String() string
- type QueryNode_Type
- type QueryNode_builder
- type QueryPlan
- func (x *QueryPlan) ClearRoot()
- func (x *QueryPlan) GetRoot() *QueryNode
- func (x *QueryPlan) HasRoot() bool
- func (*QueryPlan) ProtoMessage()
- func (x *QueryPlan) ProtoReflect() protoreflect.Message
- func (x *QueryPlan) Reset()
- func (x *QueryPlan) SetRoot(v *QueryNode)
- func (x *QueryPlan) String() string
- type QueryPlan_builder
- type QueryRequest
- func (x *QueryRequest) GetEndTime() int64
- func (x *QueryRequest) GetLabelSelector() string
- func (x *QueryRequest) GetQuery() []*Query
- func (x *QueryRequest) GetStartTime() int64
- func (*QueryRequest) ProtoMessage()
- func (x *QueryRequest) ProtoReflect() protoreflect.Message
- func (x *QueryRequest) Reset()
- func (x *QueryRequest) SetEndTime(v int64)
- func (x *QueryRequest) SetLabelSelector(v string)
- func (x *QueryRequest) SetQuery(v []*Query)
- func (x *QueryRequest) SetStartTime(v int64)
- func (x *QueryRequest) String() string
- type QueryRequest_builder
- type QueryResponse
- type QueryResponse_builder
- type QueryType
- type Query_builder
- type Report
- func (x *Report) ClearLabelNames()
- func (x *Report) ClearLabelValues()
- func (x *Report) ClearPprof()
- func (x *Report) ClearSeriesLabels()
- func (x *Report) ClearTimeSeries()
- func (x *Report) ClearTree()
- func (x *Report) GetLabelNames() *LabelNamesReport
- func (x *Report) GetLabelValues() *LabelValuesReport
- func (x *Report) GetPprof() *PprofReport
- func (x *Report) GetReportType() ReportType
- func (x *Report) GetSeriesLabels() *SeriesLabelsReport
- func (x *Report) GetTimeSeries() *TimeSeriesReport
- func (x *Report) GetTree() *TreeReport
- func (x *Report) HasLabelNames() bool
- func (x *Report) HasLabelValues() bool
- func (x *Report) HasPprof() bool
- func (x *Report) HasSeriesLabels() bool
- func (x *Report) HasTimeSeries() bool
- func (x *Report) HasTree() bool
- func (*Report) ProtoMessage()
- func (x *Report) ProtoReflect() protoreflect.Message
- func (x *Report) Reset()
- func (x *Report) SetLabelNames(v *LabelNamesReport)
- func (x *Report) SetLabelValues(v *LabelValuesReport)
- func (x *Report) SetPprof(v *PprofReport)
- func (x *Report) SetReportType(v ReportType)
- func (x *Report) SetSeriesLabels(v *SeriesLabelsReport)
- func (x *Report) SetTimeSeries(v *TimeSeriesReport)
- func (x *Report) SetTree(v *TreeReport)
- func (x *Report) String() string
- type ReportType
- type Report_builder
- type SeriesLabelsQuery
- type SeriesLabelsQuery_builder
- type SeriesLabelsReport
- func (x *SeriesLabelsReport) ClearQuery()
- func (x *SeriesLabelsReport) GetQuery() *SeriesLabelsQuery
- func (x *SeriesLabelsReport) GetSeriesLabels() []*v11.Labels
- func (x *SeriesLabelsReport) HasQuery() bool
- func (*SeriesLabelsReport) ProtoMessage()
- func (x *SeriesLabelsReport) ProtoReflect() protoreflect.Message
- func (x *SeriesLabelsReport) Reset()
- func (x *SeriesLabelsReport) SetQuery(v *SeriesLabelsQuery)
- func (x *SeriesLabelsReport) SetSeriesLabels(v []*v11.Labels)
- func (x *SeriesLabelsReport) String() string
- type SeriesLabelsReport_builder
- type TimeSeriesQuery
- func (x *TimeSeriesQuery) GetGroupBy() []string
- func (x *TimeSeriesQuery) GetLimit() int64
- func (x *TimeSeriesQuery) GetStep() float64
- func (*TimeSeriesQuery) ProtoMessage()
- func (x *TimeSeriesQuery) ProtoReflect() protoreflect.Message
- func (x *TimeSeriesQuery) Reset()
- func (x *TimeSeriesQuery) SetGroupBy(v []string)
- func (x *TimeSeriesQuery) SetLimit(v int64)
- func (x *TimeSeriesQuery) SetStep(v float64)
- func (x *TimeSeriesQuery) String() string
- type TimeSeriesQuery_builder
- type TimeSeriesReport
- func (x *TimeSeriesReport) ClearQuery()
- func (x *TimeSeriesReport) GetQuery() *TimeSeriesQuery
- func (x *TimeSeriesReport) GetTimeSeries() []*v11.Series
- func (x *TimeSeriesReport) HasQuery() bool
- func (*TimeSeriesReport) ProtoMessage()
- func (x *TimeSeriesReport) ProtoReflect() protoreflect.Message
- func (x *TimeSeriesReport) Reset()
- func (x *TimeSeriesReport) SetQuery(v *TimeSeriesQuery)
- func (x *TimeSeriesReport) SetTimeSeries(v []*v11.Series)
- func (x *TimeSeriesReport) String() string
- type TimeSeriesReport_builder
- type TreeQuery
- func (x *TreeQuery) GetMaxNodes() int64
- func (x *TreeQuery) GetSpanSelector() []string
- func (*TreeQuery) ProtoMessage()
- func (x *TreeQuery) ProtoReflect() protoreflect.Message
- func (x *TreeQuery) Reset()
- func (x *TreeQuery) SetMaxNodes(v int64)
- func (x *TreeQuery) SetSpanSelector(v []string)
- func (x *TreeQuery) String() string
- type TreeQuery_builder
- type TreeReport
- func (x *TreeReport) ClearQuery()
- func (x *TreeReport) GetQuery() *TreeQuery
- func (x *TreeReport) GetTree() []byte
- func (x *TreeReport) HasQuery() bool
- func (*TreeReport) ProtoMessage()
- func (x *TreeReport) ProtoReflect() protoreflect.Message
- func (x *TreeReport) Reset()
- func (x *TreeReport) SetQuery(v *TreeQuery)
- func (x *TreeReport) SetTree(v []byte)
- func (x *TreeReport) String() string
- type TreeReport_builder
Constants ¶
This section is empty.
Variables ¶
var ( QueryType_name = map[int32]string{ 0: "QUERY_UNSPECIFIED", 1: "QUERY_LABEL_NAMES", 2: "QUERY_LABEL_VALUES", 3: "QUERY_SERIES_LABELS", 4: "QUERY_TIME_SERIES", 5: "QUERY_TREE", 6: "QUERY_PPROF", } QueryType_value = map[string]int32{ "QUERY_UNSPECIFIED": 0, "QUERY_LABEL_NAMES": 1, "QUERY_LABEL_VALUES": 2, "QUERY_SERIES_LABELS": 3, "QUERY_TIME_SERIES": 4, "QUERY_TREE": 5, "QUERY_PPROF": 6, } )
Enum value maps for QueryType.
var ( ReportType_name = map[int32]string{ 0: "REPORT_UNSPECIFIED", 1: "REPORT_LABEL_NAMES", 2: "REPORT_LABEL_VALUES", 3: "REPORT_SERIES_LABELS", 4: "REPORT_TIME_SERIES", 5: "REPORT_TREE", 6: "REPORT_PPROF", } ReportType_value = map[string]int32{ "REPORT_UNSPECIFIED": 0, "REPORT_LABEL_NAMES": 1, "REPORT_LABEL_VALUES": 2, "REPORT_SERIES_LABELS": 3, "REPORT_TIME_SERIES": 4, "REPORT_TREE": 5, "REPORT_PPROF": 6, } )
Enum value maps for ReportType.
var ( QueryNode_Type_name = map[int32]string{ 0: "UNKNOWN", 1: "MERGE", 2: "READ", } QueryNode_Type_value = map[string]int32{ "UNKNOWN": 0, "MERGE": 1, "READ": 2, } )
Enum value maps for QueryNode_Type.
var File_query_v1_query_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Diagnostics ¶
type Diagnostics struct {
QueryPlan *QueryPlan `protobuf:"bytes,1,opt,name=query_plan,json=queryPlan,proto3" json:"query_plan,omitempty"`
// contains filtered or unexported fields
}
Diagnostic messages, events, statistics, analytics, etc.
func (*Diagnostics) ClearQueryPlan ¶
func (x *Diagnostics) ClearQueryPlan()
func (*Diagnostics) GetQueryPlan ¶
func (x *Diagnostics) GetQueryPlan() *QueryPlan
func (*Diagnostics) HasQueryPlan ¶
func (x *Diagnostics) HasQueryPlan() bool
func (*Diagnostics) ProtoMessage ¶
func (*Diagnostics) ProtoMessage()
func (*Diagnostics) ProtoReflect ¶
func (x *Diagnostics) ProtoReflect() protoreflect.Message
func (*Diagnostics) Reset ¶
func (x *Diagnostics) Reset()
func (*Diagnostics) SetQueryPlan ¶
func (x *Diagnostics) SetQueryPlan(v *QueryPlan)
func (*Diagnostics) String ¶
func (x *Diagnostics) String() string
type Diagnostics_builder ¶
type Diagnostics_builder struct {
QueryPlan *QueryPlan
// contains filtered or unexported fields
}
func (Diagnostics_builder) Build ¶
func (b0 Diagnostics_builder) Build() *Diagnostics
type InvokeOptions ¶
type InvokeOptions struct {
// contains filtered or unexported fields
}
func (*InvokeOptions) ProtoMessage ¶
func (*InvokeOptions) ProtoMessage()
func (*InvokeOptions) ProtoReflect ¶
func (x *InvokeOptions) ProtoReflect() protoreflect.Message
func (*InvokeOptions) Reset ¶
func (x *InvokeOptions) Reset()
func (*InvokeOptions) String ¶
func (x *InvokeOptions) String() string
type InvokeOptions_builder ¶
type InvokeOptions_builder struct {
// contains filtered or unexported fields
}
func (InvokeOptions_builder) Build ¶
func (b0 InvokeOptions_builder) Build() *InvokeOptions
type InvokeRequest ¶
type InvokeRequest struct {
Tenant []string `protobuf:"bytes,1,rep,name=tenant,proto3" json:"tenant,omitempty"`
StartTime int64 `protobuf:"varint,2,opt,name=start_time,json=startTime,proto3" json:"start_time,omitempty"`
EndTime int64 `protobuf:"varint,3,opt,name=end_time,json=endTime,proto3" json:"end_time,omitempty"`
LabelSelector string `protobuf:"bytes,4,opt,name=label_selector,json=labelSelector,proto3" json:"label_selector,omitempty"`
Query []*Query `protobuf:"bytes,5,rep,name=query,proto3" json:"query,omitempty"`
QueryPlan *QueryPlan `protobuf:"bytes,6,opt,name=query_plan,json=queryPlan,proto3" json:"query_plan,omitempty"`
Options *InvokeOptions `protobuf:"bytes,7,opt,name=options,proto3" json:"options,omitempty"`
// contains filtered or unexported fields
}
func (*InvokeRequest) ClearOptions ¶
func (x *InvokeRequest) ClearOptions()
func (*InvokeRequest) ClearQueryPlan ¶
func (x *InvokeRequest) ClearQueryPlan()
func (*InvokeRequest) GetEndTime ¶
func (x *InvokeRequest) GetEndTime() int64
func (*InvokeRequest) GetLabelSelector ¶
func (x *InvokeRequest) GetLabelSelector() string
func (*InvokeRequest) GetOptions ¶
func (x *InvokeRequest) GetOptions() *InvokeOptions
func (*InvokeRequest) GetQuery ¶
func (x *InvokeRequest) GetQuery() []*Query
func (*InvokeRequest) GetQueryPlan ¶
func (x *InvokeRequest) GetQueryPlan() *QueryPlan
func (*InvokeRequest) GetStartTime ¶
func (x *InvokeRequest) GetStartTime() int64
func (*InvokeRequest) GetTenant ¶
func (x *InvokeRequest) GetTenant() []string
func (*InvokeRequest) HasOptions ¶
func (x *InvokeRequest) HasOptions() bool
func (*InvokeRequest) HasQueryPlan ¶
func (x *InvokeRequest) HasQueryPlan() bool
func (*InvokeRequest) ProtoMessage ¶
func (*InvokeRequest) ProtoMessage()
func (*InvokeRequest) ProtoReflect ¶
func (x *InvokeRequest) ProtoReflect() protoreflect.Message
func (*InvokeRequest) Reset ¶
func (x *InvokeRequest) Reset()
func (*InvokeRequest) SetEndTime ¶
func (x *InvokeRequest) SetEndTime(v int64)
func (*InvokeRequest) SetLabelSelector ¶
func (x *InvokeRequest) SetLabelSelector(v string)
func (*InvokeRequest) SetOptions ¶
func (x *InvokeRequest) SetOptions(v *InvokeOptions)
func (*InvokeRequest) SetQuery ¶
func (x *InvokeRequest) SetQuery(v []*Query)
func (*InvokeRequest) SetQueryPlan ¶
func (x *InvokeRequest) SetQueryPlan(v *QueryPlan)
func (*InvokeRequest) SetStartTime ¶
func (x *InvokeRequest) SetStartTime(v int64)
func (*InvokeRequest) SetTenant ¶
func (x *InvokeRequest) SetTenant(v []string)
func (*InvokeRequest) String ¶
func (x *InvokeRequest) String() string
type InvokeRequest_builder ¶
type InvokeRequest_builder struct {
Tenant []string
StartTime int64
EndTime int64
LabelSelector string
Query []*Query
QueryPlan *QueryPlan
Options *InvokeOptions
// contains filtered or unexported fields
}
func (InvokeRequest_builder) Build ¶
func (b0 InvokeRequest_builder) Build() *InvokeRequest
type InvokeResponse ¶
type InvokeResponse struct {
Reports []*Report `protobuf:"bytes,1,rep,name=reports,proto3" json:"reports,omitempty"`
Diagnostics *Diagnostics `protobuf:"bytes,2,opt,name=diagnostics,proto3" json:"diagnostics,omitempty"`
// contains filtered or unexported fields
}
func (*InvokeResponse) ClearDiagnostics ¶
func (x *InvokeResponse) ClearDiagnostics()
func (*InvokeResponse) GetDiagnostics ¶
func (x *InvokeResponse) GetDiagnostics() *Diagnostics
func (*InvokeResponse) GetReports ¶
func (x *InvokeResponse) GetReports() []*Report
func (*InvokeResponse) HasDiagnostics ¶
func (x *InvokeResponse) HasDiagnostics() bool
func (*InvokeResponse) ProtoMessage ¶
func (*InvokeResponse) ProtoMessage()
func (*InvokeResponse) ProtoReflect ¶
func (x *InvokeResponse) ProtoReflect() protoreflect.Message
func (*InvokeResponse) Reset ¶
func (x *InvokeResponse) Reset()
func (*InvokeResponse) SetDiagnostics ¶
func (x *InvokeResponse) SetDiagnostics(v *Diagnostics)
func (*InvokeResponse) SetReports ¶
func (x *InvokeResponse) SetReports(v []*Report)
func (*InvokeResponse) String ¶
func (x *InvokeResponse) String() string
type InvokeResponse_builder ¶
type InvokeResponse_builder struct {
Reports []*Report
Diagnostics *Diagnostics
// contains filtered or unexported fields
}
func (InvokeResponse_builder) Build ¶
func (b0 InvokeResponse_builder) Build() *InvokeResponse
type LabelNamesQuery ¶
type LabelNamesQuery struct {
// contains filtered or unexported fields
}
func (*LabelNamesQuery) ProtoMessage ¶
func (*LabelNamesQuery) ProtoMessage()
func (*LabelNamesQuery) ProtoReflect ¶
func (x *LabelNamesQuery) ProtoReflect() protoreflect.Message
func (*LabelNamesQuery) Reset ¶
func (x *LabelNamesQuery) Reset()
func (*LabelNamesQuery) String ¶
func (x *LabelNamesQuery) String() string
type LabelNamesQuery_builder ¶
type LabelNamesQuery_builder struct {
// contains filtered or unexported fields
}
func (LabelNamesQuery_builder) Build ¶
func (b0 LabelNamesQuery_builder) Build() *LabelNamesQuery
type LabelNamesReport ¶
type LabelNamesReport struct {
Query *LabelNamesQuery `protobuf:"bytes,1,opt,name=query,proto3" json:"query,omitempty"`
LabelNames []string `protobuf:"bytes,2,rep,name=label_names,json=labelNames,proto3" json:"label_names,omitempty"`
// contains filtered or unexported fields
}
func (*LabelNamesReport) ClearQuery ¶
func (x *LabelNamesReport) ClearQuery()
func (*LabelNamesReport) GetLabelNames ¶
func (x *LabelNamesReport) GetLabelNames() []string
func (*LabelNamesReport) GetQuery ¶
func (x *LabelNamesReport) GetQuery() *LabelNamesQuery
func (*LabelNamesReport) HasQuery ¶
func (x *LabelNamesReport) HasQuery() bool
func (*LabelNamesReport) ProtoMessage ¶
func (*LabelNamesReport) ProtoMessage()
func (*LabelNamesReport) ProtoReflect ¶
func (x *LabelNamesReport) ProtoReflect() protoreflect.Message
func (*LabelNamesReport) Reset ¶
func (x *LabelNamesReport) Reset()
func (*LabelNamesReport) SetLabelNames ¶
func (x *LabelNamesReport) SetLabelNames(v []string)
func (*LabelNamesReport) SetQuery ¶
func (x *LabelNamesReport) SetQuery(v *LabelNamesQuery)
func (*LabelNamesReport) String ¶
func (x *LabelNamesReport) String() string
type LabelNamesReport_builder ¶
type LabelNamesReport_builder struct {
Query *LabelNamesQuery
LabelNames []string
// contains filtered or unexported fields
}
func (LabelNamesReport_builder) Build ¶
func (b0 LabelNamesReport_builder) Build() *LabelNamesReport
type LabelValuesQuery ¶
type LabelValuesQuery struct {
LabelName string `protobuf:"bytes,1,opt,name=label_name,json=labelName,proto3" json:"label_name,omitempty"`
// contains filtered or unexported fields
}
func (*LabelValuesQuery) GetLabelName ¶
func (x *LabelValuesQuery) GetLabelName() string
func (*LabelValuesQuery) ProtoMessage ¶
func (*LabelValuesQuery) ProtoMessage()
func (*LabelValuesQuery) ProtoReflect ¶
func (x *LabelValuesQuery) ProtoReflect() protoreflect.Message
func (*LabelValuesQuery) Reset ¶
func (x *LabelValuesQuery) Reset()
func (*LabelValuesQuery) SetLabelName ¶
func (x *LabelValuesQuery) SetLabelName(v string)
func (*LabelValuesQuery) String ¶
func (x *LabelValuesQuery) String() string
type LabelValuesQuery_builder ¶
type LabelValuesQuery_builder struct {
LabelName string
// contains filtered or unexported fields
}
func (LabelValuesQuery_builder) Build ¶
func (b0 LabelValuesQuery_builder) Build() *LabelValuesQuery
type LabelValuesReport ¶
type LabelValuesReport struct {
Query *LabelValuesQuery `protobuf:"bytes,1,opt,name=query,proto3" json:"query,omitempty"`
LabelValues []string `protobuf:"bytes,2,rep,name=label_values,json=labelValues,proto3" json:"label_values,omitempty"`
// contains filtered or unexported fields
}
func (*LabelValuesReport) ClearQuery ¶
func (x *LabelValuesReport) ClearQuery()
func (*LabelValuesReport) GetLabelValues ¶
func (x *LabelValuesReport) GetLabelValues() []string
func (*LabelValuesReport) GetQuery ¶
func (x *LabelValuesReport) GetQuery() *LabelValuesQuery
func (*LabelValuesReport) HasQuery ¶
func (x *LabelValuesReport) HasQuery() bool
func (*LabelValuesReport) ProtoMessage ¶
func (*LabelValuesReport) ProtoMessage()
func (*LabelValuesReport) ProtoReflect ¶
func (x *LabelValuesReport) ProtoReflect() protoreflect.Message
func (*LabelValuesReport) Reset ¶
func (x *LabelValuesReport) Reset()
func (*LabelValuesReport) SetLabelValues ¶
func (x *LabelValuesReport) SetLabelValues(v []string)
func (*LabelValuesReport) SetQuery ¶
func (x *LabelValuesReport) SetQuery(v *LabelValuesQuery)
func (*LabelValuesReport) String ¶
func (x *LabelValuesReport) String() string
type LabelValuesReport_builder ¶
type LabelValuesReport_builder struct {
Query *LabelValuesQuery
LabelValues []string
// contains filtered or unexported fields
}
func (LabelValuesReport_builder) Build ¶
func (b0 LabelValuesReport_builder) Build() *LabelValuesReport
type PprofQuery ¶
type PprofQuery struct {
MaxNodes int64 `protobuf:"varint,1,opt,name=max_nodes,json=maxNodes,proto3" json:"max_nodes,omitempty"`
StackTraceSelector *v11.StackTraceSelector `protobuf:"bytes,2,opt,name=stack_trace_selector,json=stackTraceSelector,proto3,oneof" json:"stack_trace_selector,omitempty"` // TODO(kolesnikovae): Go PGO options.
// contains filtered or unexported fields
}
func (*PprofQuery) ClearStackTraceSelector ¶
func (x *PprofQuery) ClearStackTraceSelector()
func (*PprofQuery) GetMaxNodes ¶
func (x *PprofQuery) GetMaxNodes() int64
func (*PprofQuery) GetStackTraceSelector ¶
func (x *PprofQuery) GetStackTraceSelector() *v11.StackTraceSelector
func (*PprofQuery) HasStackTraceSelector ¶
func (x *PprofQuery) HasStackTraceSelector() bool
func (*PprofQuery) ProtoMessage ¶
func (*PprofQuery) ProtoMessage()
func (*PprofQuery) ProtoReflect ¶
func (x *PprofQuery) ProtoReflect() protoreflect.Message
func (*PprofQuery) Reset ¶
func (x *PprofQuery) Reset()
func (*PprofQuery) SetMaxNodes ¶
func (x *PprofQuery) SetMaxNodes(v int64)
func (*PprofQuery) SetStackTraceSelector ¶
func (x *PprofQuery) SetStackTraceSelector(v *v11.StackTraceSelector)
func (*PprofQuery) String ¶
func (x *PprofQuery) String() string
type PprofQuery_builder ¶
type PprofQuery_builder struct {
MaxNodes int64
StackTraceSelector *v11.StackTraceSelector
// contains filtered or unexported fields
}
func (PprofQuery_builder) Build ¶
func (b0 PprofQuery_builder) Build() *PprofQuery
type PprofReport ¶
type PprofReport struct {
Query *PprofQuery `protobuf:"bytes,1,opt,name=query,proto3" json:"query,omitempty"`
Pprof []byte `protobuf:"bytes,2,opt,name=pprof,proto3" json:"pprof,omitempty"`
// contains filtered or unexported fields
}
func (*PprofReport) ClearQuery ¶
func (x *PprofReport) ClearQuery()
func (*PprofReport) GetPprof ¶
func (x *PprofReport) GetPprof() []byte
func (*PprofReport) GetQuery ¶
func (x *PprofReport) GetQuery() *PprofQuery
func (*PprofReport) HasQuery ¶
func (x *PprofReport) HasQuery() bool
func (*PprofReport) ProtoMessage ¶
func (*PprofReport) ProtoMessage()
func (*PprofReport) ProtoReflect ¶
func (x *PprofReport) ProtoReflect() protoreflect.Message
func (*PprofReport) Reset ¶
func (x *PprofReport) Reset()
func (*PprofReport) SetPprof ¶
func (x *PprofReport) SetPprof(v []byte)
func (*PprofReport) SetQuery ¶
func (x *PprofReport) SetQuery(v *PprofQuery)
func (*PprofReport) String ¶
func (x *PprofReport) String() string
type PprofReport_builder ¶
type PprofReport_builder struct {
Query *PprofQuery
Pprof []byte
// contains filtered or unexported fields
}
func (PprofReport_builder) Build ¶
func (b0 PprofReport_builder) Build() *PprofReport
type Query ¶
type Query struct {
QueryType QueryType `protobuf:"varint,1,opt,name=query_type,json=queryType,proto3,enum=query.v1.QueryType" json:"query_type,omitempty"`
// Exactly one of the following fields should be set,
// depending on the query type.
LabelNames *LabelNamesQuery `protobuf:"bytes,2,opt,name=label_names,json=labelNames,proto3" json:"label_names,omitempty"`
LabelValues *LabelValuesQuery `protobuf:"bytes,3,opt,name=label_values,json=labelValues,proto3" json:"label_values,omitempty"`
SeriesLabels *SeriesLabelsQuery `protobuf:"bytes,4,opt,name=series_labels,json=seriesLabels,proto3" json:"series_labels,omitempty"`
TimeSeries *TimeSeriesQuery `protobuf:"bytes,5,opt,name=time_series,json=timeSeries,proto3" json:"time_series,omitempty"`
Tree *TreeQuery `protobuf:"bytes,6,opt,name=tree,proto3" json:"tree,omitempty"`
Pprof *PprofQuery `protobuf:"bytes,7,opt,name=pprof,proto3" json:"pprof,omitempty"`
// contains filtered or unexported fields
}
func (*Query) GetLabelNames ¶
func (x *Query) GetLabelNames() *LabelNamesQuery
func (*Query) GetLabelValues ¶
func (x *Query) GetLabelValues() *LabelValuesQuery
func (*Query) GetPprof ¶
func (x *Query) GetPprof() *PprofQuery
func (*Query) GetSeriesLabels ¶
func (x *Query) GetSeriesLabels() *SeriesLabelsQuery
func (*Query) GetTimeSeries ¶
func (x *Query) GetTimeSeries() *TimeSeriesQuery
func (*Query) ProtoReflect ¶
func (x *Query) ProtoReflect() protoreflect.Message
func (*Query) SetLabelNames ¶
func (x *Query) SetLabelNames(v *LabelNamesQuery)
func (*Query) SetLabelValues ¶
func (x *Query) SetLabelValues(v *LabelValuesQuery)
func (*Query) SetPprof ¶
func (x *Query) SetPprof(v *PprofQuery)
func (*Query) SetSeriesLabels ¶
func (x *Query) SetSeriesLabels(v *SeriesLabelsQuery)
func (*Query) SetTimeSeries ¶
func (x *Query) SetTimeSeries(v *TimeSeriesQuery)
type QueryNode ¶
type QueryNode struct {
Type QueryNode_Type `protobuf:"varint,1,opt,name=type,proto3,enum=query.v1.QueryNode_Type" json:"type,omitempty"`
Children []*QueryNode `protobuf:"bytes,2,rep,name=children,proto3" json:"children,omitempty"`
Blocks []*v1.BlockMeta `protobuf:"bytes,3,rep,name=blocks,proto3" json:"blocks,omitempty"`
// contains filtered or unexported fields
}
func (*QueryNode) GetType ¶
func (x *QueryNode) GetType() QueryNode_Type
func (*QueryNode) ProtoReflect ¶
func (x *QueryNode) ProtoReflect() protoreflect.Message
func (*QueryNode) SetType ¶
func (x *QueryNode) SetType(v QueryNode_Type)
type QueryNode_Type ¶
type QueryNode_Type int32
const ( QueryNode_UNKNOWN QueryNode_Type = 0 QueryNode_MERGE QueryNode_Type = 1 QueryNode_READ QueryNode_Type = 2 )
func (QueryNode_Type) Descriptor ¶
func (QueryNode_Type) Descriptor() protoreflect.EnumDescriptor
func (QueryNode_Type) Enum ¶
func (x QueryNode_Type) Enum() *QueryNode_Type
func (QueryNode_Type) Number ¶
func (x QueryNode_Type) Number() protoreflect.EnumNumber
func (QueryNode_Type) String ¶
func (x QueryNode_Type) String() string
func (QueryNode_Type) Type ¶
func (QueryNode_Type) Type() protoreflect.EnumType
type QueryNode_builder ¶
type QueryNode_builder struct {
Type QueryNode_Type
Children []*QueryNode
Blocks []*v1.BlockMeta
// contains filtered or unexported fields
}
func (QueryNode_builder) Build ¶
func (b0 QueryNode_builder) Build() *QueryNode
type QueryPlan ¶
type QueryPlan struct {
Root *QueryNode `protobuf:"bytes,1,opt,name=root,proto3" json:"root,omitempty"`
// contains filtered or unexported fields
}
A query plan is represented by a directed acyclic graph (DAG), where each node is either a "merge" node or a "read" node.
Merge nodes reference other nodes in the plan as their "children". Read nodes reference the blocks which contain the actual data to be processed.
func (*QueryPlan) ProtoReflect ¶
func (x *QueryPlan) ProtoReflect() protoreflect.Message
type QueryPlan_builder ¶
type QueryPlan_builder struct {
Root *QueryNode
// contains filtered or unexported fields
}
func (QueryPlan_builder) Build ¶
func (b0 QueryPlan_builder) Build() *QueryPlan
type QueryRequest ¶
type QueryRequest struct {
StartTime int64 `protobuf:"varint,1,opt,name=start_time,json=startTime,proto3" json:"start_time,omitempty"`
EndTime int64 `protobuf:"varint,2,opt,name=end_time,json=endTime,proto3" json:"end_time,omitempty"`
LabelSelector string `protobuf:"bytes,3,opt,name=label_selector,json=labelSelector,proto3" json:"label_selector,omitempty"`
Query []*Query `protobuf:"bytes,4,rep,name=query,proto3" json:"query,omitempty"`
// contains filtered or unexported fields
}
func (*QueryRequest) GetEndTime ¶
func (x *QueryRequest) GetEndTime() int64
func (*QueryRequest) GetLabelSelector ¶
func (x *QueryRequest) GetLabelSelector() string
func (*QueryRequest) GetQuery ¶
func (x *QueryRequest) GetQuery() []*Query
func (*QueryRequest) GetStartTime ¶
func (x *QueryRequest) GetStartTime() int64
func (*QueryRequest) ProtoMessage ¶
func (*QueryRequest) ProtoMessage()
func (*QueryRequest) ProtoReflect ¶
func (x *QueryRequest) ProtoReflect() protoreflect.Message
func (*QueryRequest) Reset ¶
func (x *QueryRequest) Reset()
func (*QueryRequest) SetEndTime ¶
func (x *QueryRequest) SetEndTime(v int64)
func (*QueryRequest) SetLabelSelector ¶
func (x *QueryRequest) SetLabelSelector(v string)
func (*QueryRequest) SetQuery ¶
func (x *QueryRequest) SetQuery(v []*Query)
func (*QueryRequest) SetStartTime ¶
func (x *QueryRequest) SetStartTime(v int64)
func (*QueryRequest) String ¶
func (x *QueryRequest) String() string
type QueryRequest_builder ¶
type QueryRequest_builder struct {
StartTime int64
EndTime int64
LabelSelector string
Query []*Query
// contains filtered or unexported fields
}
func (QueryRequest_builder) Build ¶
func (b0 QueryRequest_builder) Build() *QueryRequest
type QueryResponse ¶
type QueryResponse struct {
Reports []*Report `protobuf:"bytes,1,rep,name=reports,proto3" json:"reports,omitempty"`
// contains filtered or unexported fields
}
func (*QueryResponse) GetReports ¶
func (x *QueryResponse) GetReports() []*Report
func (*QueryResponse) ProtoMessage ¶
func (*QueryResponse) ProtoMessage()
func (*QueryResponse) ProtoReflect ¶
func (x *QueryResponse) ProtoReflect() protoreflect.Message
func (*QueryResponse) Reset ¶
func (x *QueryResponse) Reset()
func (*QueryResponse) SetReports ¶
func (x *QueryResponse) SetReports(v []*Report)
func (*QueryResponse) String ¶
func (x *QueryResponse) String() string
type QueryResponse_builder ¶
type QueryResponse_builder struct {
Reports []*Report
// contains filtered or unexported fields
}
func (QueryResponse_builder) Build ¶
func (b0 QueryResponse_builder) Build() *QueryResponse
type QueryType ¶
type QueryType int32
func (QueryType) Descriptor ¶
func (QueryType) Descriptor() protoreflect.EnumDescriptor
func (QueryType) Number ¶
func (x QueryType) Number() protoreflect.EnumNumber
func (QueryType) Type ¶
func (QueryType) Type() protoreflect.EnumType
type Query_builder ¶
type Query_builder struct {
QueryType QueryType
// Exactly one of the following fields should be set,
// depending on the query type.
LabelNames *LabelNamesQuery
LabelValues *LabelValuesQuery
SeriesLabels *SeriesLabelsQuery
TimeSeries *TimeSeriesQuery
Tree *TreeQuery
Pprof *PprofQuery
// contains filtered or unexported fields
}
func (Query_builder) Build ¶
func (b0 Query_builder) Build() *Query
type Report ¶
type Report struct {
ReportType ReportType `protobuf:"varint,1,opt,name=report_type,json=reportType,proto3,enum=query.v1.ReportType" json:"report_type,omitempty"`
// Exactly one of the following fields should be set,
// depending on the report type.
LabelNames *LabelNamesReport `protobuf:"bytes,2,opt,name=label_names,json=labelNames,proto3" json:"label_names,omitempty"`
LabelValues *LabelValuesReport `protobuf:"bytes,3,opt,name=label_values,json=labelValues,proto3" json:"label_values,omitempty"`
SeriesLabels *SeriesLabelsReport `protobuf:"bytes,4,opt,name=series_labels,json=seriesLabels,proto3" json:"series_labels,omitempty"`
TimeSeries *TimeSeriesReport `protobuf:"bytes,5,opt,name=time_series,json=timeSeries,proto3" json:"time_series,omitempty"`
Tree *TreeReport `protobuf:"bytes,6,opt,name=tree,proto3" json:"tree,omitempty"`
Pprof *PprofReport `protobuf:"bytes,7,opt,name=pprof,proto3" json:"pprof,omitempty"`
// contains filtered or unexported fields
}
func (*Report) GetLabelNames ¶
func (x *Report) GetLabelNames() *LabelNamesReport
func (*Report) GetLabelValues ¶
func (x *Report) GetLabelValues() *LabelValuesReport
func (*Report) GetPprof ¶
func (x *Report) GetPprof() *PprofReport
func (*Report) GetReportType ¶
func (x *Report) GetReportType() ReportType
func (*Report) GetSeriesLabels ¶
func (x *Report) GetSeriesLabels() *SeriesLabelsReport
func (*Report) GetTimeSeries ¶
func (x *Report) GetTimeSeries() *TimeSeriesReport
func (*Report) GetTree ¶
func (x *Report) GetTree() *TreeReport
func (*Report) ProtoReflect ¶
func (x *Report) ProtoReflect() protoreflect.Message
func (*Report) SetLabelNames ¶
func (x *Report) SetLabelNames(v *LabelNamesReport)
func (*Report) SetLabelValues ¶
func (x *Report) SetLabelValues(v *LabelValuesReport)
func (*Report) SetPprof ¶
func (x *Report) SetPprof(v *PprofReport)
func (*Report) SetReportType ¶
func (x *Report) SetReportType(v ReportType)
func (*Report) SetSeriesLabels ¶
func (x *Report) SetSeriesLabels(v *SeriesLabelsReport)
func (*Report) SetTimeSeries ¶
func (x *Report) SetTimeSeries(v *TimeSeriesReport)
func (*Report) SetTree ¶
func (x *Report) SetTree(v *TreeReport)
type ReportType ¶
type ReportType int32
const ( ReportType_REPORT_UNSPECIFIED ReportType = 0 ReportType_REPORT_LABEL_NAMES ReportType = 1 ReportType_REPORT_LABEL_VALUES ReportType = 2 ReportType_REPORT_SERIES_LABELS ReportType = 3 ReportType_REPORT_TIME_SERIES ReportType = 4 ReportType_REPORT_TREE ReportType = 5 ReportType_REPORT_PPROF ReportType = 6 )
func (ReportType) Descriptor ¶
func (ReportType) Descriptor() protoreflect.EnumDescriptor
func (ReportType) Enum ¶
func (x ReportType) Enum() *ReportType
func (ReportType) Number ¶
func (x ReportType) Number() protoreflect.EnumNumber
func (ReportType) String ¶
func (x ReportType) String() string
func (ReportType) Type ¶
func (ReportType) Type() protoreflect.EnumType
type Report_builder ¶
type Report_builder struct {
ReportType ReportType
// Exactly one of the following fields should be set,
// depending on the report type.
LabelNames *LabelNamesReport
LabelValues *LabelValuesReport
SeriesLabels *SeriesLabelsReport
TimeSeries *TimeSeriesReport
Tree *TreeReport
Pprof *PprofReport
// contains filtered or unexported fields
}
func (Report_builder) Build ¶
func (b0 Report_builder) Build() *Report
type SeriesLabelsQuery ¶
type SeriesLabelsQuery struct {
LabelNames []string `protobuf:"bytes,1,rep,name=label_names,json=labelNames,proto3" json:"label_names,omitempty"`
// contains filtered or unexported fields
}
func (*SeriesLabelsQuery) GetLabelNames ¶
func (x *SeriesLabelsQuery) GetLabelNames() []string
func (*SeriesLabelsQuery) ProtoMessage ¶
func (*SeriesLabelsQuery) ProtoMessage()
func (*SeriesLabelsQuery) ProtoReflect ¶
func (x *SeriesLabelsQuery) ProtoReflect() protoreflect.Message
func (*SeriesLabelsQuery) Reset ¶
func (x *SeriesLabelsQuery) Reset()
func (*SeriesLabelsQuery) SetLabelNames ¶
func (x *SeriesLabelsQuery) SetLabelNames(v []string)
func (*SeriesLabelsQuery) String ¶
func (x *SeriesLabelsQuery) String() string
type SeriesLabelsQuery_builder ¶
type SeriesLabelsQuery_builder struct {
LabelNames []string
// contains filtered or unexported fields
}
func (SeriesLabelsQuery_builder) Build ¶
func (b0 SeriesLabelsQuery_builder) Build() *SeriesLabelsQuery
type SeriesLabelsReport ¶
type SeriesLabelsReport struct {
Query *SeriesLabelsQuery `protobuf:"bytes,1,opt,name=query,proto3" json:"query,omitempty"`
SeriesLabels []*v11.Labels `protobuf:"bytes,2,rep,name=series_labels,json=seriesLabels,proto3" json:"series_labels,omitempty"`
// contains filtered or unexported fields
}
func (*SeriesLabelsReport) ClearQuery ¶
func (x *SeriesLabelsReport) ClearQuery()
func (*SeriesLabelsReport) GetQuery ¶
func (x *SeriesLabelsReport) GetQuery() *SeriesLabelsQuery
func (*SeriesLabelsReport) GetSeriesLabels ¶
func (x *SeriesLabelsReport) GetSeriesLabels() []*v11.Labels
func (*SeriesLabelsReport) HasQuery ¶
func (x *SeriesLabelsReport) HasQuery() bool
func (*SeriesLabelsReport) ProtoMessage ¶
func (*SeriesLabelsReport) ProtoMessage()
func (*SeriesLabelsReport) ProtoReflect ¶
func (x *SeriesLabelsReport) ProtoReflect() protoreflect.Message
func (*SeriesLabelsReport) Reset ¶
func (x *SeriesLabelsReport) Reset()
func (*SeriesLabelsReport) SetQuery ¶
func (x *SeriesLabelsReport) SetQuery(v *SeriesLabelsQuery)
func (*SeriesLabelsReport) SetSeriesLabels ¶
func (x *SeriesLabelsReport) SetSeriesLabels(v []*v11.Labels)
func (*SeriesLabelsReport) String ¶
func (x *SeriesLabelsReport) String() string
type SeriesLabelsReport_builder ¶
type SeriesLabelsReport_builder struct {
Query *SeriesLabelsQuery
SeriesLabels []*v11.Labels
// contains filtered or unexported fields
}
func (SeriesLabelsReport_builder) Build ¶
func (b0 SeriesLabelsReport_builder) Build() *SeriesLabelsReport
type TimeSeriesQuery ¶
type TimeSeriesQuery struct {
Step float64 `protobuf:"fixed64,1,opt,name=step,proto3" json:"step,omitempty"`
GroupBy []string `protobuf:"bytes,2,rep,name=group_by,json=groupBy,proto3" json:"group_by,omitempty"`
Limit int64 `protobuf:"varint,3,opt,name=limit,proto3" json:"limit,omitempty"`
// contains filtered or unexported fields
}
func (*TimeSeriesQuery) GetGroupBy ¶
func (x *TimeSeriesQuery) GetGroupBy() []string
func (*TimeSeriesQuery) GetLimit ¶
func (x *TimeSeriesQuery) GetLimit() int64
func (*TimeSeriesQuery) GetStep ¶
func (x *TimeSeriesQuery) GetStep() float64
func (*TimeSeriesQuery) ProtoMessage ¶
func (*TimeSeriesQuery) ProtoMessage()
func (*TimeSeriesQuery) ProtoReflect ¶
func (x *TimeSeriesQuery) ProtoReflect() protoreflect.Message
func (*TimeSeriesQuery) Reset ¶
func (x *TimeSeriesQuery) Reset()
func (*TimeSeriesQuery) SetGroupBy ¶
func (x *TimeSeriesQuery) SetGroupBy(v []string)
func (*TimeSeriesQuery) SetLimit ¶
func (x *TimeSeriesQuery) SetLimit(v int64)
func (*TimeSeriesQuery) SetStep ¶
func (x *TimeSeriesQuery) SetStep(v float64)
func (*TimeSeriesQuery) String ¶
func (x *TimeSeriesQuery) String() string
type TimeSeriesQuery_builder ¶
type TimeSeriesQuery_builder struct {
Step float64
GroupBy []string
Limit int64
// contains filtered or unexported fields
}
func (TimeSeriesQuery_builder) Build ¶
func (b0 TimeSeriesQuery_builder) Build() *TimeSeriesQuery
type TimeSeriesReport ¶
type TimeSeriesReport struct {
Query *TimeSeriesQuery `protobuf:"bytes,1,opt,name=query,proto3" json:"query,omitempty"`
TimeSeries []*v11.Series `protobuf:"bytes,2,rep,name=time_series,json=timeSeries,proto3" json:"time_series,omitempty"`
// contains filtered or unexported fields
}
func (*TimeSeriesReport) ClearQuery ¶
func (x *TimeSeriesReport) ClearQuery()
func (*TimeSeriesReport) GetQuery ¶
func (x *TimeSeriesReport) GetQuery() *TimeSeriesQuery
func (*TimeSeriesReport) GetTimeSeries ¶
func (x *TimeSeriesReport) GetTimeSeries() []*v11.Series
func (*TimeSeriesReport) HasQuery ¶
func (x *TimeSeriesReport) HasQuery() bool
func (*TimeSeriesReport) ProtoMessage ¶
func (*TimeSeriesReport) ProtoMessage()
func (*TimeSeriesReport) ProtoReflect ¶
func (x *TimeSeriesReport) ProtoReflect() protoreflect.Message
func (*TimeSeriesReport) Reset ¶
func (x *TimeSeriesReport) Reset()
func (*TimeSeriesReport) SetQuery ¶
func (x *TimeSeriesReport) SetQuery(v *TimeSeriesQuery)
func (*TimeSeriesReport) SetTimeSeries ¶
func (x *TimeSeriesReport) SetTimeSeries(v []*v11.Series)
func (*TimeSeriesReport) String ¶
func (x *TimeSeriesReport) String() string
type TimeSeriesReport_builder ¶
type TimeSeriesReport_builder struct {
Query *TimeSeriesQuery
TimeSeries []*v11.Series
// contains filtered or unexported fields
}
func (TimeSeriesReport_builder) Build ¶
func (b0 TimeSeriesReport_builder) Build() *TimeSeriesReport
type TreeQuery ¶
type TreeQuery struct {
MaxNodes int64 `protobuf:"varint,1,opt,name=max_nodes,json=maxNodes,proto3" json:"max_nodes,omitempty"`
SpanSelector []string `protobuf:"bytes,2,rep,name=span_selector,json=spanSelector,proto3" json:"span_selector,omitempty"`
// contains filtered or unexported fields
}
func (*TreeQuery) ProtoReflect ¶
func (x *TreeQuery) ProtoReflect() protoreflect.Message
type TreeQuery_builder ¶
type TreeQuery_builder struct {
MaxNodes int64
SpanSelector []string
// contains filtered or unexported fields
}
func (TreeQuery_builder) Build ¶
func (b0 TreeQuery_builder) Build() *TreeQuery
type TreeReport ¶
type TreeReport struct {
Query *TreeQuery `protobuf:"bytes,1,opt,name=query,proto3" json:"query,omitempty"`
Tree []byte `protobuf:"bytes,2,opt,name=tree,proto3" json:"tree,omitempty"`
// contains filtered or unexported fields
}
func (*TreeReport) ClearQuery ¶
func (x *TreeReport) ClearQuery()
func (*TreeReport) GetQuery ¶
func (x *TreeReport) GetQuery() *TreeQuery
func (*TreeReport) GetTree ¶
func (x *TreeReport) GetTree() []byte
func (*TreeReport) HasQuery ¶
func (x *TreeReport) HasQuery() bool
func (*TreeReport) ProtoMessage ¶
func (*TreeReport) ProtoMessage()
func (*TreeReport) ProtoReflect ¶
func (x *TreeReport) ProtoReflect() protoreflect.Message
func (*TreeReport) Reset ¶
func (x *TreeReport) Reset()
func (*TreeReport) SetQuery ¶
func (x *TreeReport) SetQuery(v *TreeQuery)
func (*TreeReport) SetTree ¶
func (x *TreeReport) SetTree(v []byte)
func (*TreeReport) String ¶
func (x *TreeReport) String() string
type TreeReport_builder ¶
type TreeReport_builder struct {
Query *TreeQuery
Tree []byte
// contains filtered or unexported fields
}
func (TreeReport_builder) Build ¶
func (b0 TreeReport_builder) Build() *TreeReport
Source Files
¶
- query.pb.go
Click to show internal directories.
Click to hide internal directories.