Documentation
¶
Index ¶
- Variables
- type PushRequest
- func (x *PushRequest) GetLabels() []*v1.LabelPair
- func (x *PushRequest) GetProfile() []byte
- func (x *PushRequest) GetProfileId() []byte
- func (x *PushRequest) GetShard() uint32
- func (x *PushRequest) GetTenantId() string
- func (*PushRequest) ProtoMessage()
- func (x *PushRequest) ProtoReflect() protoreflect.Message
- func (x *PushRequest) Reset()
- func (x *PushRequest) SetLabels(v []*v1.LabelPair)
- func (x *PushRequest) SetProfile(v []byte)
- func (x *PushRequest) SetProfileId(v []byte)
- func (x *PushRequest) SetShard(v uint32)
- func (x *PushRequest) SetTenantId(v string)
- func (x *PushRequest) String() string
- type PushRequest_builder
- type PushResponse
- type PushResponse_builder
Constants ¶
This section is empty.
Variables ¶
var File_segmentwriter_v1_push_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type PushRequest ¶
type PushRequest struct {
// Unique identifier for the tenant submitting the request.
TenantId string `protobuf:"bytes,1,opt,name=tenant_id,json=tenantId,proto3" json:"tenant_id,omitempty"`
// Label KV pairs of the series the profile belongs to.
Labels []*v1.LabelPair `protobuf:"bytes,2,rep,name=labels,proto3" json:"labels,omitempty"`
// Profile data in binary format. Default format is pprof.
Profile []byte `protobuf:"bytes,4,opt,name=profile,proto3" json:"profile,omitempty"`
// Unique identifier of the profile.
ProfileId []byte `protobuf:"bytes,5,opt,name=profile_id,json=profileId,proto3" json:"profile_id,omitempty"`
// Shard identifier the profile belongs to.
Shard uint32 `protobuf:"varint,6,opt,name=shard,proto3" json:"shard,omitempty"`
// contains filtered or unexported fields
}
func (*PushRequest) GetLabels ¶
func (x *PushRequest) GetLabels() []*v1.LabelPair
func (*PushRequest) GetProfile ¶
func (x *PushRequest) GetProfile() []byte
func (*PushRequest) GetProfileId ¶
func (x *PushRequest) GetProfileId() []byte
func (*PushRequest) GetShard ¶
func (x *PushRequest) GetShard() uint32
func (*PushRequest) GetTenantId ¶
func (x *PushRequest) GetTenantId() string
func (*PushRequest) ProtoMessage ¶
func (*PushRequest) ProtoMessage()
func (*PushRequest) ProtoReflect ¶
func (x *PushRequest) ProtoReflect() protoreflect.Message
func (*PushRequest) Reset ¶
func (x *PushRequest) Reset()
func (*PushRequest) SetLabels ¶
func (x *PushRequest) SetLabels(v []*v1.LabelPair)
func (*PushRequest) SetProfile ¶
func (x *PushRequest) SetProfile(v []byte)
func (*PushRequest) SetProfileId ¶
func (x *PushRequest) SetProfileId(v []byte)
func (*PushRequest) SetShard ¶
func (x *PushRequest) SetShard(v uint32)
func (*PushRequest) SetTenantId ¶
func (x *PushRequest) SetTenantId(v string)
func (*PushRequest) String ¶
func (x *PushRequest) String() string
type PushRequest_builder ¶
type PushRequest_builder struct {
// Unique identifier for the tenant submitting the request.
TenantId string
// Label KV pairs of the series the profile belongs to.
Labels []*v1.LabelPair
// Profile data in binary format. Default format is pprof.
Profile []byte
// Unique identifier of the profile.
ProfileId []byte
// Shard identifier the profile belongs to.
Shard uint32
// contains filtered or unexported fields
}
func (PushRequest_builder) Build ¶
func (b0 PushRequest_builder) Build() *PushRequest
type PushResponse ¶
type PushResponse struct {
// contains filtered or unexported fields
}
func (*PushResponse) ProtoMessage ¶
func (*PushResponse) ProtoMessage()
func (*PushResponse) ProtoReflect ¶
func (x *PushResponse) ProtoReflect() protoreflect.Message
func (*PushResponse) Reset ¶
func (x *PushResponse) Reset()
func (*PushResponse) String ¶
func (x *PushResponse) String() string
type PushResponse_builder ¶
type PushResponse_builder struct {
// contains filtered or unexported fields
}
func (PushResponse_builder) Build ¶
func (b0 PushResponse_builder) Build() *PushResponse
Source Files
¶
- push.pb.go
Click to show internal directories.
Click to hide internal directories.