Documentation
¶
Index ¶
- Variables
- type BlockCompaction
- func (x *BlockCompaction) GetLevel() int32
- func (x *BlockCompaction) GetParents() []string
- func (x *BlockCompaction) GetSources() []string
- func (*BlockCompaction) ProtoMessage()
- func (x *BlockCompaction) ProtoReflect() protoreflect.Message
- func (x *BlockCompaction) Reset()
- func (x *BlockCompaction) SetLevel(v int32)
- func (x *BlockCompaction) SetParents(v []string)
- func (x *BlockCompaction) SetSources(v []string)
- func (x *BlockCompaction) String() string
- type BlockCompaction_builder
- type BlockInfo
- func (x *BlockInfo) ClearCompaction()
- func (x *BlockInfo) GetCompaction() *BlockCompaction
- func (x *BlockInfo) GetLabels() []*LabelPair
- func (x *BlockInfo) GetMaxTime() int64
- func (x *BlockInfo) GetMinTime() int64
- func (x *BlockInfo) GetUlid() string
- func (x *BlockInfo) HasCompaction() bool
- func (*BlockInfo) ProtoMessage()
- func (x *BlockInfo) ProtoReflect() protoreflect.Message
- func (x *BlockInfo) Reset()
- func (x *BlockInfo) SetCompaction(v *BlockCompaction)
- func (x *BlockInfo) SetLabels(v []*LabelPair)
- func (x *BlockInfo) SetMaxTime(v int64)
- func (x *BlockInfo) SetMinTime(v int64)
- func (x *BlockInfo) SetUlid(v string)
- func (x *BlockInfo) String() string
- type BlockInfo_builder
- type GetProfileStatsRequest
- type GetProfileStatsRequest_builder
- type GetProfileStatsResponse
- func (x *GetProfileStatsResponse) GetDataIngested() bool
- func (x *GetProfileStatsResponse) GetNewestProfileTime() int64
- func (x *GetProfileStatsResponse) GetOldestProfileTime() int64
- func (*GetProfileStatsResponse) ProtoMessage()
- func (x *GetProfileStatsResponse) ProtoReflect() protoreflect.Message
- func (x *GetProfileStatsResponse) Reset()
- func (x *GetProfileStatsResponse) SetDataIngested(v bool)
- func (x *GetProfileStatsResponse) SetNewestProfileTime(v int64)
- func (x *GetProfileStatsResponse) SetOldestProfileTime(v int64)
- func (x *GetProfileStatsResponse) String() string
- type GetProfileStatsResponse_builder
- type GoPGO
- func (x *GoPGO) GetAggregateCallees() bool
- func (x *GoPGO) GetKeepLocations() uint32
- func (*GoPGO) ProtoMessage()
- func (x *GoPGO) ProtoReflect() protoreflect.Message
- func (x *GoPGO) Reset()
- func (x *GoPGO) SetAggregateCallees(v bool)
- func (x *GoPGO) SetKeepLocations(v uint32)
- func (x *GoPGO) String() string
- type GoPGO_builder
- type LabelNamesRequest
- func (x *LabelNamesRequest) GetEnd() int64
- func (x *LabelNamesRequest) GetMatchers() []string
- func (x *LabelNamesRequest) GetStart() int64
- func (*LabelNamesRequest) ProtoMessage()
- func (x *LabelNamesRequest) ProtoReflect() protoreflect.Message
- func (x *LabelNamesRequest) Reset()
- func (x *LabelNamesRequest) SetEnd(v int64)
- func (x *LabelNamesRequest) SetMatchers(v []string)
- func (x *LabelNamesRequest) SetStart(v int64)
- func (x *LabelNamesRequest) String() string
- type LabelNamesRequest_builder
- type LabelNamesResponse
- type LabelNamesResponse_builder
- type LabelPair
- func (x *LabelPair) GetName() string
- func (x *LabelPair) GetValue() string
- func (*LabelPair) ProtoMessage()
- func (x *LabelPair) ProtoReflect() protoreflect.Message
- func (x *LabelPair) Reset()
- func (x *LabelPair) SetName(v string)
- func (x *LabelPair) SetValue(v string)
- func (x *LabelPair) String() string
- type LabelPair_builder
- type LabelValuesRequest
- func (x *LabelValuesRequest) GetEnd() int64
- func (x *LabelValuesRequest) GetMatchers() []string
- func (x *LabelValuesRequest) GetName() string
- func (x *LabelValuesRequest) GetStart() int64
- func (*LabelValuesRequest) ProtoMessage()
- func (x *LabelValuesRequest) ProtoReflect() protoreflect.Message
- func (x *LabelValuesRequest) Reset()
- func (x *LabelValuesRequest) SetEnd(v int64)
- func (x *LabelValuesRequest) SetMatchers(v []string)
- func (x *LabelValuesRequest) SetName(v string)
- func (x *LabelValuesRequest) SetStart(v int64)
- func (x *LabelValuesRequest) String() string
- type LabelValuesRequest_builder
- type LabelValuesResponse
- type LabelValuesResponse_builder
- type Labels
- type Labels_builder
- type Location
- type Location_builder
- type Point
- type Point_builder
- type ProfileType
- func (x *ProfileType) GetID() string
- func (x *ProfileType) GetName() string
- func (x *ProfileType) GetPeriodType() string
- func (x *ProfileType) GetPeriodUnit() string
- func (x *ProfileType) GetSampleType() string
- func (x *ProfileType) GetSampleUnit() string
- func (*ProfileType) ProtoMessage()
- func (x *ProfileType) ProtoReflect() protoreflect.Message
- func (x *ProfileType) Reset()
- func (x *ProfileType) SetID(v string)
- func (x *ProfileType) SetName(v string)
- func (x *ProfileType) SetPeriodType(v string)
- func (x *ProfileType) SetPeriodUnit(v string)
- func (x *ProfileType) SetSampleType(v string)
- func (x *ProfileType) SetSampleUnit(v string)
- func (x *ProfileType) String() string
- type ProfileType_builder
- type Series
- func (x *Series) GetLabels() []*LabelPair
- func (x *Series) GetPoints() []*Point
- func (*Series) ProtoMessage()
- func (x *Series) ProtoReflect() protoreflect.Message
- func (x *Series) Reset()
- func (x *Series) SetLabels(v []*LabelPair)
- func (x *Series) SetPoints(v []*Point)
- func (x *Series) String() string
- type Series_builder
- type StackTraceSelector
- func (x *StackTraceSelector) ClearGoPgo()
- func (x *StackTraceSelector) GetCallSite() []*Location
- func (x *StackTraceSelector) GetGoPgo() *GoPGO
- func (x *StackTraceSelector) HasGoPgo() bool
- func (*StackTraceSelector) ProtoMessage()
- func (x *StackTraceSelector) ProtoReflect() protoreflect.Message
- func (x *StackTraceSelector) Reset()
- func (x *StackTraceSelector) SetCallSite(v []*Location)
- func (x *StackTraceSelector) SetGoPgo(v *GoPGO)
- func (x *StackTraceSelector) String() string
- type StackTraceSelector_builder
- type TimeSeriesAggregationType
- func (TimeSeriesAggregationType) Descriptor() protoreflect.EnumDescriptor
- func (x TimeSeriesAggregationType) Enum() *TimeSeriesAggregationType
- func (x TimeSeriesAggregationType) Number() protoreflect.EnumNumber
- func (x TimeSeriesAggregationType) String() string
- func (TimeSeriesAggregationType) Type() protoreflect.EnumType
Constants ¶
This section is empty.
Variables ¶
var ( TimeSeriesAggregationType_name = map[int32]string{ 0: "TIME_SERIES_AGGREGATION_TYPE_SUM", 1: "TIME_SERIES_AGGREGATION_TYPE_AVERAGE", } TimeSeriesAggregationType_value = map[string]int32{ "TIME_SERIES_AGGREGATION_TYPE_SUM": 0, "TIME_SERIES_AGGREGATION_TYPE_AVERAGE": 1, } )
Enum value maps for TimeSeriesAggregationType.
var File_types_v1_types_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type BlockCompaction ¶
type BlockCompaction struct {
Level int32 `protobuf:"varint,1,opt,name=level,proto3" json:"level,omitempty"`
Sources []string `protobuf:"bytes,2,rep,name=sources,proto3" json:"sources,omitempty"`
Parents []string `protobuf:"bytes,3,rep,name=parents,proto3" json:"parents,omitempty"`
// contains filtered or unexported fields
}
func (*BlockCompaction) GetLevel ¶
func (x *BlockCompaction) GetLevel() int32
func (*BlockCompaction) GetParents ¶
func (x *BlockCompaction) GetParents() []string
func (*BlockCompaction) GetSources ¶
func (x *BlockCompaction) GetSources() []string
func (*BlockCompaction) ProtoMessage ¶
func (*BlockCompaction) ProtoMessage()
func (*BlockCompaction) ProtoReflect ¶
func (x *BlockCompaction) ProtoReflect() protoreflect.Message
func (*BlockCompaction) Reset ¶
func (x *BlockCompaction) Reset()
func (*BlockCompaction) SetLevel ¶
func (x *BlockCompaction) SetLevel(v int32)
func (*BlockCompaction) SetParents ¶
func (x *BlockCompaction) SetParents(v []string)
func (*BlockCompaction) SetSources ¶
func (x *BlockCompaction) SetSources(v []string)
func (*BlockCompaction) String ¶
func (x *BlockCompaction) String() string
type BlockCompaction_builder ¶
type BlockCompaction_builder struct {
Level int32
Sources []string
Parents []string
// contains filtered or unexported fields
}
func (BlockCompaction_builder) Build ¶
func (b0 BlockCompaction_builder) Build() *BlockCompaction
type BlockInfo ¶
type BlockInfo struct {
Ulid string `protobuf:"bytes,1,opt,name=ulid,proto3" json:"ulid,omitempty"`
MinTime int64 `protobuf:"varint,2,opt,name=min_time,json=minTime,proto3" json:"min_time,omitempty"`
MaxTime int64 `protobuf:"varint,3,opt,name=max_time,json=maxTime,proto3" json:"max_time,omitempty"`
Compaction *BlockCompaction `protobuf:"bytes,4,opt,name=compaction,proto3" json:"compaction,omitempty"`
Labels []*LabelPair `protobuf:"bytes,5,rep,name=labels,proto3" json:"labels,omitempty"`
// contains filtered or unexported fields
}
func (*BlockInfo) GetCompaction ¶
func (x *BlockInfo) GetCompaction() *BlockCompaction
func (*BlockInfo) ProtoReflect ¶
func (x *BlockInfo) ProtoReflect() protoreflect.Message
func (*BlockInfo) SetCompaction ¶
func (x *BlockInfo) SetCompaction(v *BlockCompaction)
type BlockInfo_builder ¶
type BlockInfo_builder struct {
Ulid string
MinTime int64
MaxTime int64
Compaction *BlockCompaction
Labels []*LabelPair
// contains filtered or unexported fields
}
func (BlockInfo_builder) Build ¶
func (b0 BlockInfo_builder) Build() *BlockInfo
type GetProfileStatsRequest ¶
type GetProfileStatsRequest struct {
// contains filtered or unexported fields
}
func (*GetProfileStatsRequest) ProtoMessage ¶
func (*GetProfileStatsRequest) ProtoMessage()
func (*GetProfileStatsRequest) ProtoReflect ¶
func (x *GetProfileStatsRequest) ProtoReflect() protoreflect.Message
func (*GetProfileStatsRequest) Reset ¶
func (x *GetProfileStatsRequest) Reset()
func (*GetProfileStatsRequest) String ¶
func (x *GetProfileStatsRequest) String() string
type GetProfileStatsRequest_builder ¶
type GetProfileStatsRequest_builder struct {
// contains filtered or unexported fields
}
func (GetProfileStatsRequest_builder) Build ¶
func (b0 GetProfileStatsRequest_builder) Build() *GetProfileStatsRequest
type GetProfileStatsResponse ¶
type GetProfileStatsResponse struct {
// Whether we received any data at any time in the past.
DataIngested bool `protobuf:"varint,1,opt,name=data_ingested,json=dataIngested,proto3" json:"data_ingested,omitempty"`
// Milliseconds since epoch.
OldestProfileTime int64 `protobuf:"varint,2,opt,name=oldest_profile_time,json=oldestProfileTime,proto3" json:"oldest_profile_time,omitempty"`
// Milliseconds since epoch.
NewestProfileTime int64 `protobuf:"varint,3,opt,name=newest_profile_time,json=newestProfileTime,proto3" json:"newest_profile_time,omitempty"`
// contains filtered or unexported fields
}
func (*GetProfileStatsResponse) GetDataIngested ¶
func (x *GetProfileStatsResponse) GetDataIngested() bool
func (*GetProfileStatsResponse) GetNewestProfileTime ¶
func (x *GetProfileStatsResponse) GetNewestProfileTime() int64
func (*GetProfileStatsResponse) GetOldestProfileTime ¶
func (x *GetProfileStatsResponse) GetOldestProfileTime() int64
func (*GetProfileStatsResponse) ProtoMessage ¶
func (*GetProfileStatsResponse) ProtoMessage()
func (*GetProfileStatsResponse) ProtoReflect ¶
func (x *GetProfileStatsResponse) ProtoReflect() protoreflect.Message
func (*GetProfileStatsResponse) Reset ¶
func (x *GetProfileStatsResponse) Reset()
func (*GetProfileStatsResponse) SetDataIngested ¶
func (x *GetProfileStatsResponse) SetDataIngested(v bool)
func (*GetProfileStatsResponse) SetNewestProfileTime ¶
func (x *GetProfileStatsResponse) SetNewestProfileTime(v int64)
func (*GetProfileStatsResponse) SetOldestProfileTime ¶
func (x *GetProfileStatsResponse) SetOldestProfileTime(v int64)
func (*GetProfileStatsResponse) String ¶
func (x *GetProfileStatsResponse) String() string
type GetProfileStatsResponse_builder ¶
type GetProfileStatsResponse_builder struct {
// Whether we received any data at any time in the past.
DataIngested bool
// Milliseconds since epoch.
OldestProfileTime int64
// Milliseconds since epoch.
NewestProfileTime int64
// contains filtered or unexported fields
}
func (GetProfileStatsResponse_builder) Build ¶
func (b0 GetProfileStatsResponse_builder) Build() *GetProfileStatsResponse
type GoPGO ¶
type GoPGO struct {
// Specifies the number of leaf locations to keep.
KeepLocations uint32 `protobuf:"varint,1,opt,name=keep_locations,json=keepLocations,proto3" json:"keep_locations,omitempty"`
// Aggregate callees causes the leaf location line number to be ignored,
// thus aggregating all callee samples (but not callers).
AggregateCallees bool `protobuf:"varint,2,opt,name=aggregate_callees,json=aggregateCallees,proto3" json:"aggregate_callees,omitempty"`
// contains filtered or unexported fields
}
func (*GoPGO) ProtoReflect ¶
func (x *GoPGO) ProtoReflect() protoreflect.Message
type GoPGO_builder ¶
type GoPGO_builder struct {
// Specifies the number of leaf locations to keep.
KeepLocations uint32
// Aggregate callees causes the leaf location line number to be ignored,
// thus aggregating all callee samples (but not callers).
AggregateCallees bool
// contains filtered or unexported fields
}
func (GoPGO_builder) Build ¶
func (b0 GoPGO_builder) Build() *GoPGO
type LabelNamesRequest ¶
type LabelNamesRequest struct {
Matchers []string `protobuf:"bytes,1,rep,name=matchers,proto3" json:"matchers,omitempty"`
Start int64 `protobuf:"varint,2,opt,name=start,proto3" json:"start,omitempty"`
End int64 `protobuf:"varint,3,opt,name=end,proto3" json:"end,omitempty"`
// contains filtered or unexported fields
}
func (*LabelNamesRequest) GetEnd ¶
func (x *LabelNamesRequest) GetEnd() int64
func (*LabelNamesRequest) GetMatchers ¶
func (x *LabelNamesRequest) GetMatchers() []string
func (*LabelNamesRequest) GetStart ¶
func (x *LabelNamesRequest) GetStart() int64
func (*LabelNamesRequest) ProtoMessage ¶
func (*LabelNamesRequest) ProtoMessage()
func (*LabelNamesRequest) ProtoReflect ¶
func (x *LabelNamesRequest) ProtoReflect() protoreflect.Message
func (*LabelNamesRequest) Reset ¶
func (x *LabelNamesRequest) Reset()
func (*LabelNamesRequest) SetEnd ¶
func (x *LabelNamesRequest) SetEnd(v int64)
func (*LabelNamesRequest) SetMatchers ¶
func (x *LabelNamesRequest) SetMatchers(v []string)
func (*LabelNamesRequest) SetStart ¶
func (x *LabelNamesRequest) SetStart(v int64)
func (*LabelNamesRequest) String ¶
func (x *LabelNamesRequest) String() string
type LabelNamesRequest_builder ¶
type LabelNamesRequest_builder struct {
Matchers []string
Start int64
End int64
// contains filtered or unexported fields
}
func (LabelNamesRequest_builder) Build ¶
func (b0 LabelNamesRequest_builder) Build() *LabelNamesRequest
type LabelNamesResponse ¶
type LabelNamesResponse struct {
Names []string `protobuf:"bytes,1,rep,name=names,proto3" json:"names,omitempty"`
// contains filtered or unexported fields
}
func (*LabelNamesResponse) GetNames ¶
func (x *LabelNamesResponse) GetNames() []string
func (*LabelNamesResponse) ProtoMessage ¶
func (*LabelNamesResponse) ProtoMessage()
func (*LabelNamesResponse) ProtoReflect ¶
func (x *LabelNamesResponse) ProtoReflect() protoreflect.Message
func (*LabelNamesResponse) Reset ¶
func (x *LabelNamesResponse) Reset()
func (*LabelNamesResponse) SetNames ¶
func (x *LabelNamesResponse) SetNames(v []string)
func (*LabelNamesResponse) String ¶
func (x *LabelNamesResponse) String() string
type LabelNamesResponse_builder ¶
type LabelNamesResponse_builder struct {
Names []string
// contains filtered or unexported fields
}
func (LabelNamesResponse_builder) Build ¶
func (b0 LabelNamesResponse_builder) Build() *LabelNamesResponse
type LabelPair ¶
type LabelPair struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
Value string `protobuf:"bytes,2,opt,name=value,proto3" json:"value,omitempty"`
// contains filtered or unexported fields
}
func (*LabelPair) ProtoReflect ¶
func (x *LabelPair) ProtoReflect() protoreflect.Message
type LabelPair_builder ¶
type LabelPair_builder struct {
Name string
Value string
// contains filtered or unexported fields
}
func (LabelPair_builder) Build ¶
func (b0 LabelPair_builder) Build() *LabelPair
type LabelValuesRequest ¶
type LabelValuesRequest struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
Matchers []string `protobuf:"bytes,2,rep,name=matchers,proto3" json:"matchers,omitempty"`
Start int64 `protobuf:"varint,3,opt,name=start,proto3" json:"start,omitempty"`
End int64 `protobuf:"varint,4,opt,name=end,proto3" json:"end,omitempty"`
// contains filtered or unexported fields
}
func (*LabelValuesRequest) GetEnd ¶
func (x *LabelValuesRequest) GetEnd() int64
func (*LabelValuesRequest) GetMatchers ¶
func (x *LabelValuesRequest) GetMatchers() []string
func (*LabelValuesRequest) GetName ¶
func (x *LabelValuesRequest) GetName() string
func (*LabelValuesRequest) GetStart ¶
func (x *LabelValuesRequest) GetStart() int64
func (*LabelValuesRequest) ProtoMessage ¶
func (*LabelValuesRequest) ProtoMessage()
func (*LabelValuesRequest) ProtoReflect ¶
func (x *LabelValuesRequest) ProtoReflect() protoreflect.Message
func (*LabelValuesRequest) Reset ¶
func (x *LabelValuesRequest) Reset()
func (*LabelValuesRequest) SetEnd ¶
func (x *LabelValuesRequest) SetEnd(v int64)
func (*LabelValuesRequest) SetMatchers ¶
func (x *LabelValuesRequest) SetMatchers(v []string)
func (*LabelValuesRequest) SetName ¶
func (x *LabelValuesRequest) SetName(v string)
func (*LabelValuesRequest) SetStart ¶
func (x *LabelValuesRequest) SetStart(v int64)
func (*LabelValuesRequest) String ¶
func (x *LabelValuesRequest) String() string
type LabelValuesRequest_builder ¶
type LabelValuesRequest_builder struct {
Name string
Matchers []string
Start int64
End int64
// contains filtered or unexported fields
}
func (LabelValuesRequest_builder) Build ¶
func (b0 LabelValuesRequest_builder) Build() *LabelValuesRequest
type LabelValuesResponse ¶
type LabelValuesResponse struct {
Names []string `protobuf:"bytes,1,rep,name=names,proto3" json:"names,omitempty"`
// contains filtered or unexported fields
}
func (*LabelValuesResponse) GetNames ¶
func (x *LabelValuesResponse) GetNames() []string
func (*LabelValuesResponse) ProtoMessage ¶
func (*LabelValuesResponse) ProtoMessage()
func (*LabelValuesResponse) ProtoReflect ¶
func (x *LabelValuesResponse) ProtoReflect() protoreflect.Message
func (*LabelValuesResponse) Reset ¶
func (x *LabelValuesResponse) Reset()
func (*LabelValuesResponse) SetNames ¶
func (x *LabelValuesResponse) SetNames(v []string)
func (*LabelValuesResponse) String ¶
func (x *LabelValuesResponse) String() string
type LabelValuesResponse_builder ¶
type LabelValuesResponse_builder struct {
Names []string
// contains filtered or unexported fields
}
func (LabelValuesResponse_builder) Build ¶
func (b0 LabelValuesResponse_builder) Build() *LabelValuesResponse
type Labels ¶
type Labels struct {
// LabelPair is the key value pairs to identify the corresponding profile
Labels []*LabelPair `protobuf:"bytes,1,rep,name=labels,proto3" json:"labels,omitempty"`
// contains filtered or unexported fields
}
func (*Labels) ProtoReflect ¶
func (x *Labels) ProtoReflect() protoreflect.Message
type Labels_builder ¶
type Labels_builder struct {
// LabelPair is the key value pairs to identify the corresponding profile
Labels []*LabelPair
// contains filtered or unexported fields
}
func (Labels_builder) Build ¶
func (b0 Labels_builder) Build() *Labels
type Location ¶
type Location struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
func (*Location) ProtoReflect ¶
func (x *Location) ProtoReflect() protoreflect.Message
type Location_builder ¶
type Location_builder struct {
Name string
// contains filtered or unexported fields
}
func (Location_builder) Build ¶
func (b0 Location_builder) Build() *Location
type Point ¶
type Point struct {
Value float64 `protobuf:"fixed64,1,opt,name=value,proto3" json:"value,omitempty"`
// Milliseconds unix timestamp
Timestamp int64 `protobuf:"varint,2,opt,name=timestamp,proto3" json:"timestamp,omitempty"`
// contains filtered or unexported fields
}
func (*Point) ProtoReflect ¶
func (x *Point) ProtoReflect() protoreflect.Message
type Point_builder ¶
type Point_builder struct {
Value float64
// Milliseconds unix timestamp
Timestamp int64
// contains filtered or unexported fields
}
func (Point_builder) Build ¶
func (b0 Point_builder) Build() *Point
type ProfileType ¶
type ProfileType struct {
ID string `protobuf:"bytes,1,opt,name=ID,proto3" json:"ID,omitempty"`
Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
SampleType string `protobuf:"bytes,4,opt,name=sample_type,json=sampleType,proto3" json:"sample_type,omitempty"`
SampleUnit string `protobuf:"bytes,5,opt,name=sample_unit,json=sampleUnit,proto3" json:"sample_unit,omitempty"`
PeriodType string `protobuf:"bytes,6,opt,name=period_type,json=periodType,proto3" json:"period_type,omitempty"`
PeriodUnit string `protobuf:"bytes,7,opt,name=period_unit,json=periodUnit,proto3" json:"period_unit,omitempty"`
// contains filtered or unexported fields
}
func (*ProfileType) GetID ¶
func (x *ProfileType) GetID() string
func (*ProfileType) GetName ¶
func (x *ProfileType) GetName() string
func (*ProfileType) GetPeriodType ¶
func (x *ProfileType) GetPeriodType() string
func (*ProfileType) GetPeriodUnit ¶
func (x *ProfileType) GetPeriodUnit() string
func (*ProfileType) GetSampleType ¶
func (x *ProfileType) GetSampleType() string
func (*ProfileType) GetSampleUnit ¶
func (x *ProfileType) GetSampleUnit() string
func (*ProfileType) ProtoMessage ¶
func (*ProfileType) ProtoMessage()
func (*ProfileType) ProtoReflect ¶
func (x *ProfileType) ProtoReflect() protoreflect.Message
func (*ProfileType) Reset ¶
func (x *ProfileType) Reset()
func (*ProfileType) SetID ¶
func (x *ProfileType) SetID(v string)
func (*ProfileType) SetName ¶
func (x *ProfileType) SetName(v string)
func (*ProfileType) SetPeriodType ¶
func (x *ProfileType) SetPeriodType(v string)
func (*ProfileType) SetPeriodUnit ¶
func (x *ProfileType) SetPeriodUnit(v string)
func (*ProfileType) SetSampleType ¶
func (x *ProfileType) SetSampleType(v string)
func (*ProfileType) SetSampleUnit ¶
func (x *ProfileType) SetSampleUnit(v string)
func (*ProfileType) String ¶
func (x *ProfileType) String() string
type ProfileType_builder ¶
type ProfileType_builder struct {
ID string
Name string
SampleType string
SampleUnit string
PeriodType string
PeriodUnit string
// contains filtered or unexported fields
}
func (ProfileType_builder) Build ¶
func (b0 ProfileType_builder) Build() *ProfileType
type Series ¶
type Series struct {
Labels []*LabelPair `protobuf:"bytes,1,rep,name=labels,proto3" json:"labels,omitempty"`
Points []*Point `protobuf:"bytes,2,rep,name=points,proto3" json:"points,omitempty"`
// contains filtered or unexported fields
}
func (*Series) ProtoReflect ¶
func (x *Series) ProtoReflect() protoreflect.Message
type Series_builder ¶
type Series_builder struct {
Labels []*LabelPair
Points []*Point
// contains filtered or unexported fields
}
func (Series_builder) Build ¶
func (b0 Series_builder) Build() *Series
type StackTraceSelector ¶
type StackTraceSelector struct {
// Stack trace of the call site. Root at call_site[0].
// Only stack traces having the prefix provided will be selected.
// If empty, the filter is ignored.
CallSite []*Location `protobuf:"bytes,1,rep,name=call_site,json=callSite,proto3" json:"call_site,omitempty"`
// Stack trace selector for profiles purposed for Go PGO.
// If set, call_site is ignored.
GoPgo *GoPGO `protobuf:"bytes,2,opt,name=go_pgo,json=goPgo,proto3" json:"go_pgo,omitempty"`
// contains filtered or unexported fields
}
StackTraceSelector is used for filtering stack traces by locations.
func (*StackTraceSelector) ClearGoPgo ¶
func (x *StackTraceSelector) ClearGoPgo()
func (*StackTraceSelector) GetCallSite ¶
func (x *StackTraceSelector) GetCallSite() []*Location
func (*StackTraceSelector) GetGoPgo ¶
func (x *StackTraceSelector) GetGoPgo() *GoPGO
func (*StackTraceSelector) HasGoPgo ¶
func (x *StackTraceSelector) HasGoPgo() bool
func (*StackTraceSelector) ProtoMessage ¶
func (*StackTraceSelector) ProtoMessage()
func (*StackTraceSelector) ProtoReflect ¶
func (x *StackTraceSelector) ProtoReflect() protoreflect.Message
func (*StackTraceSelector) Reset ¶
func (x *StackTraceSelector) Reset()
func (*StackTraceSelector) SetCallSite ¶
func (x *StackTraceSelector) SetCallSite(v []*Location)
func (*StackTraceSelector) SetGoPgo ¶
func (x *StackTraceSelector) SetGoPgo(v *GoPGO)
func (*StackTraceSelector) String ¶
func (x *StackTraceSelector) String() string
type StackTraceSelector_builder ¶
type StackTraceSelector_builder struct {
// Stack trace of the call site. Root at call_site[0].
// Only stack traces having the prefix provided will be selected.
// If empty, the filter is ignored.
CallSite []*Location
// Stack trace selector for profiles purposed for Go PGO.
// If set, call_site is ignored.
GoPgo *GoPGO
// contains filtered or unexported fields
}
func (StackTraceSelector_builder) Build ¶
func (b0 StackTraceSelector_builder) Build() *StackTraceSelector
type TimeSeriesAggregationType ¶
type TimeSeriesAggregationType int32
const ( TimeSeriesAggregationType_TIME_SERIES_AGGREGATION_TYPE_SUM TimeSeriesAggregationType = 0 TimeSeriesAggregationType_TIME_SERIES_AGGREGATION_TYPE_AVERAGE TimeSeriesAggregationType = 1 )
func (TimeSeriesAggregationType) Descriptor ¶
func (TimeSeriesAggregationType) Descriptor() protoreflect.EnumDescriptor
func (TimeSeriesAggregationType) Enum ¶
func (x TimeSeriesAggregationType) Enum() *TimeSeriesAggregationType
func (TimeSeriesAggregationType) Number ¶
func (x TimeSeriesAggregationType) Number() protoreflect.EnumNumber
func (TimeSeriesAggregationType) String ¶
func (x TimeSeriesAggregationType) String() string
func (TimeSeriesAggregationType) Type ¶
func (TimeSeriesAggregationType) Type() protoreflect.EnumType
Source Files
¶
- types.pb.go
Click to show internal directories.
Click to hide internal directories.