Documentation
¶
Index ¶
Constants ¶
const ( PubSubService_Subscribe_FullMethodName = "/simplecloud.pubsub.v1.PubSubService/Subscribe" PubSubService_Publish_FullMethodName = "/simplecloud.pubsub.v1.PubSubService/Publish" )
Variables ¶
var PubSubService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "simplecloud.pubsub.v1.PubSubService", HandlerType: (*PubSubServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "Publish", Handler: _PubSubService_Publish_Handler, }, }, Streams: []grpc.StreamDesc{ { StreamName: "Subscribe", Handler: _PubSubService_Subscribe_Handler, ServerStreams: true, }, }, Metadata: "simplecloud/pubsub/v1/pubsub_api.proto", }
PubSubService_ServiceDesc is the grpc.ServiceDesc for PubSubService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterPubSubServiceServer ¶
func RegisterPubSubServiceServer(s grpc.ServiceRegistrar, srv PubSubServiceServer)
Types ¶
type PubSubServiceClient ¶
type PubSubServiceClient interface {
Subscribe(ctx context.Context, in *v1.SubscriptionRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[v1.Message], error)
Publish(ctx context.Context, in *v1.PublishRequest, opts ...grpc.CallOption) (*v1.PublishResponse, error)
}
PubSubServiceClient is the client API for PubSubService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewPubSubServiceClient ¶
func NewPubSubServiceClient(cc grpc.ClientConnInterface) PubSubServiceClient
type PubSubServiceServer ¶
type PubSubServiceServer interface {
Subscribe(*v1.SubscriptionRequest, grpc.ServerStreamingServer[v1.Message]) error
Publish(context.Context, *v1.PublishRequest) (*v1.PublishResponse, error)
}
PubSubServiceServer is the server API for PubSubService service. All implementations should embed UnimplementedPubSubServiceServer for forward compatibility.
type PubSubService_SubscribeClient ¶
type PubSubService_SubscribeClient = grpc.ServerStreamingClient[v1.Message]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type PubSubService_SubscribeServer ¶
type PubSubService_SubscribeServer = grpc.ServerStreamingServer[v1.Message]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type UnimplementedPubSubServiceServer ¶
type UnimplementedPubSubServiceServer struct{}
UnimplementedPubSubServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedPubSubServiceServer) Publish ¶
func (UnimplementedPubSubServiceServer) Publish(context.Context, *v1.PublishRequest) (*v1.PublishResponse, error)
func (UnimplementedPubSubServiceServer) Subscribe ¶
func (UnimplementedPubSubServiceServer) Subscribe(*v1.SubscriptionRequest, grpc.ServerStreamingServer[v1.Message]) error
type UnsafePubSubServiceServer ¶
type UnsafePubSubServiceServer interface {
// contains filtered or unexported methods
}
UnsafePubSubServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to PubSubServiceServer will result in compilation errors.
Source Files
¶
- pubsub_api_grpc.pb.go