Documentation
¶
Overview ¶
Package fragmentv1gateway is a reverse proxy.
It translates gRPC into RESTful JSON APIs.
Index ¶
- func RegisterStageServiceHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error
- func RegisterStageServiceHandlerClient(ctx context.Context, mux *runtime.ServeMux, ...) error
- func RegisterStageServiceHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, ...) (err error)
- func RegisterStageServiceHandlerServer(ctx context.Context, mux *runtime.ServeMux, ...) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func RegisterStageServiceHandler ¶
func RegisterStageServiceHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error
RegisterStageServiceHandler registers the http handlers for service StageService to "mux". The handlers forward requests to the grpc endpoint over "conn".
func RegisterStageServiceHandlerClient ¶
func RegisterStageServiceHandlerClient(ctx context.Context, mux *runtime.ServeMux, client fragmentv1grpc.StageServiceClient) error
RegisterStageServiceHandlerClient registers the http handlers for service StageService to "mux". The handlers forward requests to the grpc endpoint over the given implementation of "fragmentv1grpc.StageServiceClient". Note: the gRPC framework executes interceptors within the gRPC handler. If the passed in "fragmentv1grpc.StageServiceClient" doesn't go through the normal gRPC flow (creating a gRPC client etc.) then it will be up to the passed in "fragmentv1grpc.StageServiceClient" to call the correct interceptors. This client ignores the HTTP middlewares.
func RegisterStageServiceHandlerFromEndpoint ¶
func RegisterStageServiceHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, opts []grpc.DialOption) (err error)
RegisterStageServiceHandlerFromEndpoint is same as RegisterStageServiceHandler but automatically dials to "endpoint" and closes the connection when "ctx" gets done.
func RegisterStageServiceHandlerServer ¶
func RegisterStageServiceHandlerServer(ctx context.Context, mux *runtime.ServeMux, server fragmentv1grpc.StageServiceServer) error
RegisterStageServiceHandlerServer registers the http handlers for service StageService to "mux". UnaryRPC :call StageServiceServer directly. StreamingRPC :currently unsupported pending https://github.com/grpc/grpc-go/issues/906. Note that using this registration option will cause many gRPC library features to stop working. Consider using RegisterStageServiceHandlerFromEndpoint instead. GRPC interceptors will not work for this type of registration. To use interceptors, you must use the "runtime.WithMiddlewares" option in the "runtime.NewServeMux" call.
Types ¶
This section is empty.
Source Files
¶
- stage_service.pb.gw.go