Documentation
¶
Overview ¶
Package navigationv1gateway is a reverse proxy.
It translates gRPC into RESTful JSON APIs.
Index ¶
- func RegisterNavigationServiceHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error
- func RegisterNavigationServiceHandlerClient(ctx context.Context, mux *runtime.ServeMux, ...) error
- func RegisterNavigationServiceHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, ...) (err error)
- func RegisterNavigationServiceHandlerServer(ctx context.Context, mux *runtime.ServeMux, ...) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func RegisterNavigationServiceHandler ¶
func RegisterNavigationServiceHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error
RegisterNavigationServiceHandler registers the http handlers for service NavigationService to "mux". The handlers forward requests to the grpc endpoint over "conn".
func RegisterNavigationServiceHandlerClient ¶
func RegisterNavigationServiceHandlerClient(ctx context.Context, mux *runtime.ServeMux, client navigationv1grpc.NavigationServiceClient) error
RegisterNavigationServiceHandlerClient registers the http handlers for service NavigationService to "mux". The handlers forward requests to the grpc endpoint over the given implementation of "navigationv1grpc.NavigationServiceClient". Note: the gRPC framework executes interceptors within the gRPC handler. If the passed in "navigationv1grpc.NavigationServiceClient" doesn't go through the normal gRPC flow (creating a gRPC client etc.) then it will be up to the passed in "navigationv1grpc.NavigationServiceClient" to call the correct interceptors. This client ignores the HTTP middlewares.
func RegisterNavigationServiceHandlerFromEndpoint ¶
func RegisterNavigationServiceHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, opts []grpc.DialOption) (err error)
RegisterNavigationServiceHandlerFromEndpoint is same as RegisterNavigationServiceHandler but automatically dials to "endpoint" and closes the connection when "ctx" gets done.
func RegisterNavigationServiceHandlerServer ¶
func RegisterNavigationServiceHandlerServer(ctx context.Context, mux *runtime.ServeMux, server navigationv1grpc.NavigationServiceServer) error
RegisterNavigationServiceHandlerServer registers the http handlers for service NavigationService to "mux". UnaryRPC :call NavigationServiceServer directly. StreamingRPC :currently unsupported pending https://github.com/grpc/grpc-go/issues/906. Note that using this registration option will cause many gRPC library features to stop working. Consider using RegisterNavigationServiceHandlerFromEndpoint instead. GRPC interceptors will not work for this type of registration. To use interceptors, you must use the "runtime.WithMiddlewares" option in the "runtime.NewServeMux" call.
Types ¶
This section is empty.
Source Files
¶
- navigation_service.pb.gw.go