Documentation
¶
Overview ¶
Package articlev1gateway is a reverse proxy.
It translates gRPC into RESTful JSON APIs.
Index ¶
- func RegisterArticlePageServiceHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error
- func RegisterArticlePageServiceHandlerClient(ctx context.Context, mux *runtime.ServeMux, ...) error
- func RegisterArticlePageServiceHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, ...) (err error)
- func RegisterArticlePageServiceHandlerServer(ctx context.Context, mux *runtime.ServeMux, ...) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func RegisterArticlePageServiceHandler ¶
func RegisterArticlePageServiceHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error
RegisterArticlePageServiceHandler registers the http handlers for service ArticlePageService to "mux". The handlers forward requests to the grpc endpoint over "conn".
func RegisterArticlePageServiceHandlerClient ¶
func RegisterArticlePageServiceHandlerClient(ctx context.Context, mux *runtime.ServeMux, client articlev1grpc.ArticlePageServiceClient) error
RegisterArticlePageServiceHandlerClient registers the http handlers for service ArticlePageService to "mux". The handlers forward requests to the grpc endpoint over the given implementation of "articlev1grpc.ArticlePageServiceClient". Note: the gRPC framework executes interceptors within the gRPC handler. If the passed in "articlev1grpc.ArticlePageServiceClient" doesn't go through the normal gRPC flow (creating a gRPC client etc.) then it will be up to the passed in "articlev1grpc.ArticlePageServiceClient" to call the correct interceptors. This client ignores the HTTP middlewares.
func RegisterArticlePageServiceHandlerFromEndpoint ¶
func RegisterArticlePageServiceHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, opts []grpc.DialOption) (err error)
RegisterArticlePageServiceHandlerFromEndpoint is same as RegisterArticlePageServiceHandler but automatically dials to "endpoint" and closes the connection when "ctx" gets done.
func RegisterArticlePageServiceHandlerServer ¶
func RegisterArticlePageServiceHandlerServer(ctx context.Context, mux *runtime.ServeMux, server articlev1grpc.ArticlePageServiceServer) error
RegisterArticlePageServiceHandlerServer registers the http handlers for service ArticlePageService to "mux". UnaryRPC :call ArticlePageServiceServer directly. StreamingRPC :currently unsupported pending https://github.com/grpc/grpc-go/issues/906. Note that using this registration option will cause many gRPC library features to stop working. Consider using RegisterArticlePageServiceHandlerFromEndpoint instead. GRPC interceptors will not work for this type of registration. To use interceptors, you must use the "runtime.WithMiddlewares" option in the "runtime.NewServeMux" call.
Types ¶
This section is empty.
Source Files
¶
- article_page_service.pb.gw.go