Documentation
¶
Overview ¶
Package sectionv1gateway is a reverse proxy.
It translates gRPC into RESTful JSON APIs.
Index ¶
- func RegisterSectionPageServiceHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error
- func RegisterSectionPageServiceHandlerClient(ctx context.Context, mux *runtime.ServeMux, ...) error
- func RegisterSectionPageServiceHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, ...) (err error)
- func RegisterSectionPageServiceHandlerServer(ctx context.Context, mux *runtime.ServeMux, ...) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func RegisterSectionPageServiceHandler ¶
func RegisterSectionPageServiceHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error
RegisterSectionPageServiceHandler registers the http handlers for service SectionPageService to "mux". The handlers forward requests to the grpc endpoint over "conn".
func RegisterSectionPageServiceHandlerClient ¶
func RegisterSectionPageServiceHandlerClient(ctx context.Context, mux *runtime.ServeMux, client sectionv1grpc.SectionPageServiceClient) error
RegisterSectionPageServiceHandlerClient registers the http handlers for service SectionPageService to "mux". The handlers forward requests to the grpc endpoint over the given implementation of "sectionv1grpc.SectionPageServiceClient". Note: the gRPC framework executes interceptors within the gRPC handler. If the passed in "sectionv1grpc.SectionPageServiceClient" doesn't go through the normal gRPC flow (creating a gRPC client etc.) then it will be up to the passed in "sectionv1grpc.SectionPageServiceClient" to call the correct interceptors. This client ignores the HTTP middlewares.
func RegisterSectionPageServiceHandlerFromEndpoint ¶
func RegisterSectionPageServiceHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, opts []grpc.DialOption) (err error)
RegisterSectionPageServiceHandlerFromEndpoint is same as RegisterSectionPageServiceHandler but automatically dials to "endpoint" and closes the connection when "ctx" gets done.
func RegisterSectionPageServiceHandlerServer ¶
func RegisterSectionPageServiceHandlerServer(ctx context.Context, mux *runtime.ServeMux, server sectionv1grpc.SectionPageServiceServer) error
RegisterSectionPageServiceHandlerServer registers the http handlers for service SectionPageService to "mux". UnaryRPC :call SectionPageServiceServer directly. StreamingRPC :currently unsupported pending https://github.com/grpc/grpc-go/issues/906. Note that using this registration option will cause many gRPC library features to stop working. Consider using RegisterSectionPageServiceHandlerFromEndpoint instead. GRPC interceptors will not work for this type of registration. To use interceptors, you must use the "runtime.WithMiddlewares" option in the "runtime.NewServeMux" call.
Types ¶
This section is empty.
Source Files
¶
- section_page_service.pb.gw.go