Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterArticleExtenderServiceServer(s grpc.ServiceRegistrar, srv ArticleExtenderServiceServer)
- func RegisterArticlePageServiceServer(s grpc.ServiceRegistrar, srv ArticlePageServiceServer)
- type ArticleExtenderServiceClient
- type ArticleExtenderServiceServer
- type ArticlePageServiceClient
- type ArticlePageServiceServer
- type UnimplementedArticleExtenderServiceServer
- type UnimplementedArticlePageServiceServer
- type UnsafeArticleExtenderServiceServer
- type UnsafeArticlePageServiceServer
Constants ¶
const ( ArticleExtenderService_GetQuestions_FullMethodName = "/stroeer.page.article.v1.ArticleExtenderService/GetQuestions" ArticleExtenderService_GetAnswer_FullMethodName = "/stroeer.page.article.v1.ArticleExtenderService/GetAnswer" )
const (
ArticlePageService_GetArticlePage_FullMethodName = "/stroeer.page.article.v1.ArticlePageService/GetArticlePage"
)
Variables ¶
var ArticleExtenderService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "stroeer.page.article.v1.ArticleExtenderService", HandlerType: (*ArticleExtenderServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "GetQuestions", Handler: _ArticleExtenderService_GetQuestions_Handler, }, { MethodName: "GetAnswer", Handler: _ArticleExtenderService_GetAnswer_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "stroeer/page/article/v1/article_extender_service.proto", }
ArticleExtenderService_ServiceDesc is the grpc.ServiceDesc for ArticleExtenderService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var ArticlePageService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "stroeer.page.article.v1.ArticlePageService", HandlerType: (*ArticlePageServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "GetArticlePage", Handler: _ArticlePageService_GetArticlePage_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "stroeer/page/article/v1/article_page_service.proto", }
ArticlePageService_ServiceDesc is the grpc.ServiceDesc for ArticlePageService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterArticleExtenderServiceServer ¶
func RegisterArticleExtenderServiceServer(s grpc.ServiceRegistrar, srv ArticleExtenderServiceServer)
func RegisterArticlePageServiceServer ¶
func RegisterArticlePageServiceServer(s grpc.ServiceRegistrar, srv ArticlePageServiceServer)
Types ¶
type ArticleExtenderServiceClient ¶
type ArticleExtenderServiceClient interface {
GetQuestions(ctx context.Context, in *v1.GetQuestionsRequest, opts ...grpc.CallOption) (*v1.GetQuestionsResponse, error)
GetAnswer(ctx context.Context, in *v1.GetAnswerRequest, opts ...grpc.CallOption) (*v1.GetAnswerResponse, error)
}
ArticleExtenderServiceClient is the client API for ArticleExtenderService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
* The ArticleExtenderService provides methods to extend an article with additional information. Its main purpose is to retrieve questions for a given article so that the ArticleExtender Widget on ArticlePages can render them alongside any server-provided answers.
```protobuf
service ArticleExtenderService {
rpc GetQuestions(GetQuestionsRequest) returns (GetQuestionsResponse) {}
rpc GetAnswer(GetAnswerRequest) returns (GetAnswerResponse) {}
}
```
func NewArticleExtenderServiceClient ¶
func NewArticleExtenderServiceClient(cc grpc.ClientConnInterface) ArticleExtenderServiceClient
type ArticleExtenderServiceServer ¶
type ArticleExtenderServiceServer interface {
GetQuestions(context.Context, *v1.GetQuestionsRequest) (*v1.GetQuestionsResponse, error)
GetAnswer(context.Context, *v1.GetAnswerRequest) (*v1.GetAnswerResponse, error)
}
ArticleExtenderServiceServer is the server API for ArticleExtenderService service. All implementations should embed UnimplementedArticleExtenderServiceServer for forward compatibility.
* The ArticleExtenderService provides methods to extend an article with additional information. Its main purpose is to retrieve questions for a given article so that the ArticleExtender Widget on ArticlePages can render them alongside any server-provided answers.
```protobuf
service ArticleExtenderService {
rpc GetQuestions(GetQuestionsRequest) returns (GetQuestionsResponse) {}
rpc GetAnswer(GetAnswerRequest) returns (GetAnswerResponse) {}
}
```
type ArticlePageServiceClient ¶
type ArticlePageServiceClient interface {
GetArticlePage(ctx context.Context, in *v1.GetArticlePageRequest, opts ...grpc.CallOption) (*v1.GetArticlePageResponse, error)
}
ArticlePageServiceClient is the client API for ArticlePageService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
* ```protobuf
service ArticlePageService {
# turns the requested article with editorial render relevant data for the user and SEO bots.
rpc GetArticlePage (GetArticlePageRequest) returns (GetArticlePageResponse) {}
}
``` # Description
func NewArticlePageServiceClient ¶
func NewArticlePageServiceClient(cc grpc.ClientConnInterface) ArticlePageServiceClient
type ArticlePageServiceServer ¶
type ArticlePageServiceServer interface {
GetArticlePage(context.Context, *v1.GetArticlePageRequest) (*v1.GetArticlePageResponse, error)
}
ArticlePageServiceServer is the server API for ArticlePageService service. All implementations should embed UnimplementedArticlePageServiceServer for forward compatibility.
* ```protobuf
service ArticlePageService {
# turns the requested article with editorial render relevant data for the user and SEO bots.
rpc GetArticlePage (GetArticlePageRequest) returns (GetArticlePageResponse) {}
}
``` # Description
type UnimplementedArticleExtenderServiceServer ¶
type UnimplementedArticleExtenderServiceServer struct{}
UnimplementedArticleExtenderServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedArticleExtenderServiceServer) GetAnswer ¶
func (UnimplementedArticleExtenderServiceServer) GetAnswer(context.Context, *v1.GetAnswerRequest) (*v1.GetAnswerResponse, error)
func (UnimplementedArticleExtenderServiceServer) GetQuestions ¶
func (UnimplementedArticleExtenderServiceServer) GetQuestions(context.Context, *v1.GetQuestionsRequest) (*v1.GetQuestionsResponse, error)
type UnimplementedArticlePageServiceServer ¶
type UnimplementedArticlePageServiceServer struct{}
UnimplementedArticlePageServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedArticlePageServiceServer) GetArticlePage ¶
func (UnimplementedArticlePageServiceServer) GetArticlePage(context.Context, *v1.GetArticlePageRequest) (*v1.GetArticlePageResponse, error)
type UnsafeArticleExtenderServiceServer ¶
type UnsafeArticleExtenderServiceServer interface {
// contains filtered or unexported methods
}
UnsafeArticleExtenderServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ArticleExtenderServiceServer will result in compilation errors.
type UnsafeArticlePageServiceServer ¶
type UnsafeArticlePageServiceServer interface {
// contains filtered or unexported methods
}
UnsafeArticlePageServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ArticlePageServiceServer will result in compilation errors.
Source Files
¶
- article_extender_service_grpc.pb.go
- article_page_service_grpc.pb.go