Documentation
¶
Index ¶
- Variables
- type GetArticleCompanionsRequest
- func (x *GetArticleCompanionsRequest) GetToken() []string
- func (*GetArticleCompanionsRequest) ProtoMessage()
- func (x *GetArticleCompanionsRequest) ProtoReflect() protoreflect.Message
- func (x *GetArticleCompanionsRequest) Reset()
- func (x *GetArticleCompanionsRequest) SetToken(v []string)
- func (x *GetArticleCompanionsRequest) String() string
- type GetArticleCompanionsRequest_builder
- type GetArticleCompanionsResponse
- func (x *GetArticleCompanionsResponse) GetCompanions() []*v1.Stage_Item
- func (*GetArticleCompanionsResponse) ProtoMessage()
- func (x *GetArticleCompanionsResponse) ProtoReflect() protoreflect.Message
- func (x *GetArticleCompanionsResponse) Reset()
- func (x *GetArticleCompanionsResponse) SetCompanions(v []*v1.Stage_Item)
- func (x *GetArticleCompanionsResponse) String() string
- type GetArticleCompanionsResponse_builder
- type GetStagesRequest
- type GetStagesRequest_builder
- type GetStagesResponse
- type GetStagesResponse_builder
Constants ¶
This section is empty.
Variables ¶
var File_stroeer_fragment_v1_stage_service_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type GetArticleCompanionsRequest ¶
type GetArticleCompanionsRequest struct {
Token []string `protobuf:"bytes,1,rep,name=token,proto3" json:"token,omitempty"`
// contains filtered or unexported fields
}
token is base64 encoded and contains an index and a section path
func (*GetArticleCompanionsRequest) GetToken ¶
func (x *GetArticleCompanionsRequest) GetToken() []string
func (*GetArticleCompanionsRequest) ProtoMessage ¶
func (*GetArticleCompanionsRequest) ProtoMessage()
func (*GetArticleCompanionsRequest) ProtoReflect ¶
func (x *GetArticleCompanionsRequest) ProtoReflect() protoreflect.Message
func (*GetArticleCompanionsRequest) Reset ¶
func (x *GetArticleCompanionsRequest) Reset()
func (*GetArticleCompanionsRequest) SetToken ¶
func (x *GetArticleCompanionsRequest) SetToken(v []string)
func (*GetArticleCompanionsRequest) String ¶
func (x *GetArticleCompanionsRequest) String() string
type GetArticleCompanionsRequest_builder ¶
type GetArticleCompanionsRequest_builder struct {
Token []string
// contains filtered or unexported fields
}
func (GetArticleCompanionsRequest_builder) Build ¶
func (b0 GetArticleCompanionsRequest_builder) Build() *GetArticleCompanionsRequest
type GetArticleCompanionsResponse ¶
type GetArticleCompanionsResponse struct {
Companions []*v1.Stage_Item `protobuf:"bytes,1,rep,name=companions,proto3" json:"companions,omitempty"`
// contains filtered or unexported fields
}
contains the actual companions (stages with content), that resulted out of the parameters index and section path
func (*GetArticleCompanionsResponse) GetCompanions ¶
func (x *GetArticleCompanionsResponse) GetCompanions() []*v1.Stage_Item
func (*GetArticleCompanionsResponse) ProtoMessage ¶
func (*GetArticleCompanionsResponse) ProtoMessage()
func (*GetArticleCompanionsResponse) ProtoReflect ¶
func (x *GetArticleCompanionsResponse) ProtoReflect() protoreflect.Message
func (*GetArticleCompanionsResponse) Reset ¶
func (x *GetArticleCompanionsResponse) Reset()
func (*GetArticleCompanionsResponse) SetCompanions ¶
func (x *GetArticleCompanionsResponse) SetCompanions(v []*v1.Stage_Item)
func (*GetArticleCompanionsResponse) String ¶
func (x *GetArticleCompanionsResponse) String() string
type GetArticleCompanionsResponse_builder ¶
type GetArticleCompanionsResponse_builder struct {
Companions []*v1.Stage_Item
// contains filtered or unexported fields
}
func (GetArticleCompanionsResponse_builder) Build ¶
func (b0 GetArticleCompanionsResponse_builder) Build() *GetArticleCompanionsResponse
type GetStagesRequest ¶
type GetStagesRequest struct {
// ids must be well-known to the frontend and backend, for example "schlagzeilen"
Ids []string `protobuf:"bytes,1,rep,name=ids,proto3" json:"ids,omitempty"`
// contains filtered or unexported fields
}
Message to request stages independent of SectionPages, for client side rendering or ESIs
func (*GetStagesRequest) GetIds ¶
func (x *GetStagesRequest) GetIds() []string
func (*GetStagesRequest) ProtoMessage ¶
func (*GetStagesRequest) ProtoMessage()
func (*GetStagesRequest) ProtoReflect ¶
func (x *GetStagesRequest) ProtoReflect() protoreflect.Message
func (*GetStagesRequest) Reset ¶
func (x *GetStagesRequest) Reset()
func (*GetStagesRequest) SetIds ¶
func (x *GetStagesRequest) SetIds(v []string)
func (*GetStagesRequest) String ¶
func (x *GetStagesRequest) String() string
type GetStagesRequest_builder ¶
type GetStagesRequest_builder struct {
// ids must be well-known to the frontend and backend, for example "schlagzeilen"
Ids []string
// contains filtered or unexported fields
}
func (GetStagesRequest_builder) Build ¶
func (b0 GetStagesRequest_builder) Build() *GetStagesRequest
type GetStagesResponse ¶
type GetStagesResponse struct {
Stages []*v1.Stage `protobuf:"bytes,1,rep,name=stages,proto3" json:"stages,omitempty"`
// contains filtered or unexported fields
}
Message for requesting data for single stages All provided ids that could be resolved to stages are part of the response, others are omitted.
func (*GetStagesResponse) GetStages ¶
func (x *GetStagesResponse) GetStages() []*v1.Stage
func (*GetStagesResponse) ProtoMessage ¶
func (*GetStagesResponse) ProtoMessage()
func (*GetStagesResponse) ProtoReflect ¶
func (x *GetStagesResponse) ProtoReflect() protoreflect.Message
func (*GetStagesResponse) Reset ¶
func (x *GetStagesResponse) Reset()
func (*GetStagesResponse) SetStages ¶
func (x *GetStagesResponse) SetStages(v []*v1.Stage)
func (*GetStagesResponse) String ¶
func (x *GetStagesResponse) String() string
type GetStagesResponse_builder ¶
type GetStagesResponse_builder struct {
Stages []*v1.Stage
// contains filtered or unexported fields
}
func (GetStagesResponse_builder) Build ¶
func (b0 GetStagesResponse_builder) Build() *GetStagesResponse
Source Files
¶
- stage_service.pb.go
Click to show internal directories.
Click to hide internal directories.