Documentation
¶
Index ¶
- Variables
- type Access
- func (x *Access) ClearAccountAccess()
- func (x *Access) GetAccountAccess() *AccountAccess
- func (x *Access) GetNamespaceAccesses() map[string]*NamespaceAccess
- func (x *Access) HasAccountAccess() bool
- func (*Access) ProtoMessage()
- func (x *Access) ProtoReflect() protoreflect.Message
- func (x *Access) Reset()
- func (x *Access) SetAccountAccess(v *AccountAccess)
- func (x *Access) SetNamespaceAccesses(v map[string]*NamespaceAccess)
- func (x *Access) String() string
- type Access_builder
- type AccountAccess
- type AccountAccess_builder
- type ApiKey
- func (x *ApiKey) ClearCreatedTime()
- func (x *ApiKey) ClearLastModifiedTime()
- func (x *ApiKey) ClearSpec()
- func (x *ApiKey) GetAsyncOperationId() string
- func (x *ApiKey) GetCreatedTime() *timestamppb.Timestamp
- func (x *ApiKey) GetId() string
- func (x *ApiKey) GetLastModifiedTime() *timestamppb.Timestamp
- func (x *ApiKey) GetResourceVersion() string
- func (x *ApiKey) GetSpec() *ApiKeySpec
- func (x *ApiKey) GetState() string
- func (x *ApiKey) HasCreatedTime() bool
- func (x *ApiKey) HasLastModifiedTime() bool
- func (x *ApiKey) HasSpec() bool
- func (*ApiKey) ProtoMessage()
- func (x *ApiKey) ProtoReflect() protoreflect.Message
- func (x *ApiKey) Reset()
- func (x *ApiKey) SetAsyncOperationId(v string)
- func (x *ApiKey) SetCreatedTime(v *timestamppb.Timestamp)
- func (x *ApiKey) SetId(v string)
- func (x *ApiKey) SetLastModifiedTime(v *timestamppb.Timestamp)
- func (x *ApiKey) SetResourceVersion(v string)
- func (x *ApiKey) SetSpec(v *ApiKeySpec)
- func (x *ApiKey) SetState(v string)
- func (x *ApiKey) String() string
- type ApiKeySpec
- func (x *ApiKeySpec) ClearExpiryTime()
- func (x *ApiKeySpec) GetDescription() string
- func (x *ApiKeySpec) GetDisabled() bool
- func (x *ApiKeySpec) GetDisplayName() string
- func (x *ApiKeySpec) GetExpiryTime() *timestamppb.Timestamp
- func (x *ApiKeySpec) GetOwnerId() string
- func (x *ApiKeySpec) GetOwnerType() string
- func (x *ApiKeySpec) HasExpiryTime() bool
- func (*ApiKeySpec) ProtoMessage()
- func (x *ApiKeySpec) ProtoReflect() protoreflect.Message
- func (x *ApiKeySpec) Reset()
- func (x *ApiKeySpec) SetDescription(v string)
- func (x *ApiKeySpec) SetDisabled(v bool)
- func (x *ApiKeySpec) SetDisplayName(v string)
- func (x *ApiKeySpec) SetExpiryTime(v *timestamppb.Timestamp)
- func (x *ApiKeySpec) SetOwnerId(v string)
- func (x *ApiKeySpec) SetOwnerType(v string)
- func (x *ApiKeySpec) String() string
- type ApiKeySpec_builder
- type ApiKey_builder
- type Invitation
- func (x *Invitation) ClearCreatedTime()
- func (x *Invitation) ClearExpiredTime()
- func (x *Invitation) GetCreatedTime() *timestamppb.Timestamp
- func (x *Invitation) GetExpiredTime() *timestamppb.Timestamp
- func (x *Invitation) HasCreatedTime() bool
- func (x *Invitation) HasExpiredTime() bool
- func (*Invitation) ProtoMessage()
- func (x *Invitation) ProtoReflect() protoreflect.Message
- func (x *Invitation) Reset()
- func (x *Invitation) SetCreatedTime(v *timestamppb.Timestamp)
- func (x *Invitation) SetExpiredTime(v *timestamppb.Timestamp)
- func (x *Invitation) String() string
- type Invitation_builder
- type NamespaceAccess
- type NamespaceAccess_builder
- type ServiceAccount
- func (x *ServiceAccount) ClearCreatedTime()
- func (x *ServiceAccount) ClearLastModifiedTime()
- func (x *ServiceAccount) ClearSpec()
- func (x *ServiceAccount) GetAsyncOperationId() string
- func (x *ServiceAccount) GetCreatedTime() *timestamppb.Timestamp
- func (x *ServiceAccount) GetId() string
- func (x *ServiceAccount) GetLastModifiedTime() *timestamppb.Timestamp
- func (x *ServiceAccount) GetResourceVersion() string
- func (x *ServiceAccount) GetSpec() *ServiceAccountSpec
- func (x *ServiceAccount) GetState() string
- func (x *ServiceAccount) HasCreatedTime() bool
- func (x *ServiceAccount) HasLastModifiedTime() bool
- func (x *ServiceAccount) HasSpec() bool
- func (*ServiceAccount) ProtoMessage()
- func (x *ServiceAccount) ProtoReflect() protoreflect.Message
- func (x *ServiceAccount) Reset()
- func (x *ServiceAccount) SetAsyncOperationId(v string)
- func (x *ServiceAccount) SetCreatedTime(v *timestamppb.Timestamp)
- func (x *ServiceAccount) SetId(v string)
- func (x *ServiceAccount) SetLastModifiedTime(v *timestamppb.Timestamp)
- func (x *ServiceAccount) SetResourceVersion(v string)
- func (x *ServiceAccount) SetSpec(v *ServiceAccountSpec)
- func (x *ServiceAccount) SetState(v string)
- func (x *ServiceAccount) String() string
- type ServiceAccountSpec
- func (x *ServiceAccountSpec) ClearAccess()
- func (x *ServiceAccountSpec) GetAccess() *Access
- func (x *ServiceAccountSpec) GetDescription() string
- func (x *ServiceAccountSpec) GetName() string
- func (x *ServiceAccountSpec) HasAccess() bool
- func (*ServiceAccountSpec) ProtoMessage()
- func (x *ServiceAccountSpec) ProtoReflect() protoreflect.Message
- func (x *ServiceAccountSpec) Reset()
- func (x *ServiceAccountSpec) SetAccess(v *Access)
- func (x *ServiceAccountSpec) SetDescription(v string)
- func (x *ServiceAccountSpec) SetName(v string)
- func (x *ServiceAccountSpec) String() string
- type ServiceAccountSpec_builder
- type ServiceAccount_builder
- type User
- func (x *User) ClearCreatedTime()
- func (x *User) ClearInvitation()
- func (x *User) ClearLastModifiedTime()
- func (x *User) ClearSpec()
- func (x *User) GetAsyncOperationId() string
- func (x *User) GetCreatedTime() *timestamppb.Timestamp
- func (x *User) GetId() string
- func (x *User) GetInvitation() *Invitation
- func (x *User) GetLastModifiedTime() *timestamppb.Timestamp
- func (x *User) GetResourceVersion() string
- func (x *User) GetSpec() *UserSpec
- func (x *User) GetState() string
- func (x *User) HasCreatedTime() bool
- func (x *User) HasInvitation() bool
- func (x *User) HasLastModifiedTime() bool
- func (x *User) HasSpec() bool
- func (*User) ProtoMessage()
- func (x *User) ProtoReflect() protoreflect.Message
- func (x *User) Reset()
- func (x *User) SetAsyncOperationId(v string)
- func (x *User) SetCreatedTime(v *timestamppb.Timestamp)
- func (x *User) SetId(v string)
- func (x *User) SetInvitation(v *Invitation)
- func (x *User) SetLastModifiedTime(v *timestamppb.Timestamp)
- func (x *User) SetResourceVersion(v string)
- func (x *User) SetSpec(v *UserSpec)
- func (x *User) SetState(v string)
- func (x *User) String() string
- type UserGroup
- func (x *UserGroup) ClearCreatedTime()
- func (x *UserGroup) ClearLastModifiedTime()
- func (x *UserGroup) ClearSpec()
- func (x *UserGroup) GetAsyncOperationId() string
- func (x *UserGroup) GetCreatedTime() *timestamppb.Timestamp
- func (x *UserGroup) GetId() string
- func (x *UserGroup) GetLastModifiedTime() *timestamppb.Timestamp
- func (x *UserGroup) GetResourceVersion() string
- func (x *UserGroup) GetSpec() *UserGroupSpec
- func (x *UserGroup) GetState() string
- func (x *UserGroup) HasCreatedTime() bool
- func (x *UserGroup) HasLastModifiedTime() bool
- func (x *UserGroup) HasSpec() bool
- func (*UserGroup) ProtoMessage()
- func (x *UserGroup) ProtoReflect() protoreflect.Message
- func (x *UserGroup) Reset()
- func (x *UserGroup) SetAsyncOperationId(v string)
- func (x *UserGroup) SetCreatedTime(v *timestamppb.Timestamp)
- func (x *UserGroup) SetId(v string)
- func (x *UserGroup) SetLastModifiedTime(v *timestamppb.Timestamp)
- func (x *UserGroup) SetResourceVersion(v string)
- func (x *UserGroup) SetSpec(v *UserGroupSpec)
- func (x *UserGroup) SetState(v string)
- func (x *UserGroup) String() string
- type UserGroupSpec
- func (x *UserGroupSpec) ClearAccess()
- func (x *UserGroupSpec) GetAccess() *Access
- func (x *UserGroupSpec) GetName() string
- func (x *UserGroupSpec) HasAccess() bool
- func (*UserGroupSpec) ProtoMessage()
- func (x *UserGroupSpec) ProtoReflect() protoreflect.Message
- func (x *UserGroupSpec) Reset()
- func (x *UserGroupSpec) SetAccess(v *Access)
- func (x *UserGroupSpec) SetName(v string)
- func (x *UserGroupSpec) String() string
- type UserGroupSpec_builder
- type UserGroup_builder
- type UserSpec
- func (x *UserSpec) ClearAccess()
- func (x *UserSpec) GetAccess() *Access
- func (x *UserSpec) GetEmail() string
- func (x *UserSpec) HasAccess() bool
- func (*UserSpec) ProtoMessage()
- func (x *UserSpec) ProtoReflect() protoreflect.Message
- func (x *UserSpec) Reset()
- func (x *UserSpec) SetAccess(v *Access)
- func (x *UserSpec) SetEmail(v string)
- func (x *UserSpec) String() string
- type UserSpec_builder
- type User_builder
Constants ¶
This section is empty.
Variables ¶
var File_temporal_api_cloud_identity_v1_message_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Access ¶
type Access struct {
// The account access
AccountAccess *AccountAccess `protobuf:"bytes,1,opt,name=account_access,json=accountAccess,proto3" json:"account_access,omitempty"`
// The map of namespace accesses
// The key is the namespace name and the value is the access to the namespace
NamespaceAccesses map[string]*NamespaceAccess `` /* 186-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*Access) GetAccountAccess ¶
func (x *Access) GetAccountAccess() *AccountAccess
func (*Access) GetNamespaceAccesses ¶
func (x *Access) GetNamespaceAccesses() map[string]*NamespaceAccess
func (*Access) ProtoReflect ¶
func (x *Access) ProtoReflect() protoreflect.Message
func (*Access) SetAccountAccess ¶
func (x *Access) SetAccountAccess(v *AccountAccess)
func (*Access) SetNamespaceAccesses ¶
func (x *Access) SetNamespaceAccesses(v map[string]*NamespaceAccess)
type Access_builder ¶
type Access_builder struct {
// The account access
AccountAccess *AccountAccess
// The map of namespace accesses
// The key is the namespace name and the value is the access to the namespace
NamespaceAccesses map[string]*NamespaceAccess
// contains filtered or unexported fields
}
func (Access_builder) Build ¶
func (b0 Access_builder) Build() *Access
type AccountAccess ¶
type AccountAccess struct {
// The role on the account, should be one of [admin, developer, read]
// admin - gives full access the account, including users and namespaces
// developer - gives access to create namespaces on the account
// read - gives read only access to the account
Role string `protobuf:"bytes,1,opt,name=role,proto3" json:"role,omitempty"`
// contains filtered or unexported fields
}
func (*AccountAccess) GetRole ¶
func (x *AccountAccess) GetRole() string
func (*AccountAccess) ProtoMessage ¶
func (*AccountAccess) ProtoMessage()
func (*AccountAccess) ProtoReflect ¶
func (x *AccountAccess) ProtoReflect() protoreflect.Message
func (*AccountAccess) Reset ¶
func (x *AccountAccess) Reset()
func (*AccountAccess) SetRole ¶
func (x *AccountAccess) SetRole(v string)
func (*AccountAccess) String ¶
func (x *AccountAccess) String() string
type AccountAccess_builder ¶
type AccountAccess_builder struct {
// The role on the account, should be one of [admin, developer, read]
// admin - gives full access the account, including users and namespaces
// developer - gives access to create namespaces on the account
// read - gives read only access to the account
Role string
// contains filtered or unexported fields
}
func (AccountAccess_builder) Build ¶
func (b0 AccountAccess_builder) Build() *AccountAccess
type ApiKey ¶
type ApiKey struct {
// The id of the API Key.
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
// The current version of the API key specification.
// The next update operation will have to include this version.
ResourceVersion string `protobuf:"bytes,2,opt,name=resource_version,json=resourceVersion,proto3" json:"resource_version,omitempty"`
// The API key specification.
Spec *ApiKeySpec `protobuf:"bytes,3,opt,name=spec,proto3" json:"spec,omitempty"`
// The current state of the API key.
// Possible values: activating, activationfailed, active, updating, updatefailed, deleting, deletefailed, deleted, suspending, suspendfailed, suspended.
// For any failed state, reach out to Temporal Cloud support for remediation.
State string `protobuf:"bytes,4,opt,name=state,proto3" json:"state,omitempty"`
// The id of the async operation that is creating/updating/deleting the API key, if any.
AsyncOperationId string `protobuf:"bytes,5,opt,name=async_operation_id,json=asyncOperationId,proto3" json:"async_operation_id,omitempty"`
// The date and time when the API key was created.
CreatedTime *timestamppb.Timestamp `protobuf:"bytes,6,opt,name=created_time,json=createdTime,proto3" json:"created_time,omitempty"`
// The date and time when the API key was last modified.
// Will not be set if the API key has never been modified.
LastModifiedTime *timestamppb.Timestamp `protobuf:"bytes,7,opt,name=last_modified_time,json=lastModifiedTime,proto3" json:"last_modified_time,omitempty"`
// contains filtered or unexported fields
}
func (*ApiKey) GetCreatedTime ¶
func (x *ApiKey) GetCreatedTime() *timestamppb.Timestamp
func (*ApiKey) GetLastModifiedTime ¶
func (x *ApiKey) GetLastModifiedTime() *timestamppb.Timestamp
func (*ApiKey) GetSpec ¶
func (x *ApiKey) GetSpec() *ApiKeySpec
func (*ApiKey) ProtoReflect ¶
func (x *ApiKey) ProtoReflect() protoreflect.Message
func (*ApiKey) SetCreatedTime ¶
func (x *ApiKey) SetCreatedTime(v *timestamppb.Timestamp)
func (*ApiKey) SetLastModifiedTime ¶
func (x *ApiKey) SetLastModifiedTime(v *timestamppb.Timestamp)
func (*ApiKey) SetSpec ¶
func (x *ApiKey) SetSpec(v *ApiKeySpec)
type ApiKeySpec ¶
type ApiKeySpec struct {
// The id of the owner to create the API key for.
// The owner id is immutable. Once set during creation, it cannot be changed.
// The owner id is the id of the user when the owner type is 'user'.
// The owner id is the id of the service account when the owner type is 'service-account'.
OwnerId string `protobuf:"bytes,1,opt,name=owner_id,json=ownerId,proto3" json:"owner_id,omitempty"`
// The type of the owner to create the API key for.
// The owner type is immutable. Once set during creation, it cannot be changed.
// Possible values: user, service-account.
OwnerType string `protobuf:"bytes,2,opt,name=owner_type,json=ownerType,proto3" json:"owner_type,omitempty"`
// The display name of the API key.
DisplayName string `protobuf:"bytes,3,opt,name=display_name,json=displayName,proto3" json:"display_name,omitempty"`
// The description of the API key.
Description string `protobuf:"bytes,4,opt,name=description,proto3" json:"description,omitempty"`
// The expiry time of the API key.
ExpiryTime *timestamppb.Timestamp `protobuf:"bytes,5,opt,name=expiry_time,json=expiryTime,proto3" json:"expiry_time,omitempty"`
// True if the API key is disabled.
Disabled bool `protobuf:"varint,6,opt,name=disabled,proto3" json:"disabled,omitempty"`
// contains filtered or unexported fields
}
func (*ApiKeySpec) ClearExpiryTime ¶
func (x *ApiKeySpec) ClearExpiryTime()
func (*ApiKeySpec) GetDescription ¶
func (x *ApiKeySpec) GetDescription() string
func (*ApiKeySpec) GetDisabled ¶
func (x *ApiKeySpec) GetDisabled() bool
func (*ApiKeySpec) GetDisplayName ¶
func (x *ApiKeySpec) GetDisplayName() string
func (*ApiKeySpec) GetExpiryTime ¶
func (x *ApiKeySpec) GetExpiryTime() *timestamppb.Timestamp
func (*ApiKeySpec) GetOwnerId ¶
func (x *ApiKeySpec) GetOwnerId() string
func (*ApiKeySpec) GetOwnerType ¶
func (x *ApiKeySpec) GetOwnerType() string
func (*ApiKeySpec) HasExpiryTime ¶
func (x *ApiKeySpec) HasExpiryTime() bool
func (*ApiKeySpec) ProtoMessage ¶
func (*ApiKeySpec) ProtoMessage()
func (*ApiKeySpec) ProtoReflect ¶
func (x *ApiKeySpec) ProtoReflect() protoreflect.Message
func (*ApiKeySpec) Reset ¶
func (x *ApiKeySpec) Reset()
func (*ApiKeySpec) SetDescription ¶
func (x *ApiKeySpec) SetDescription(v string)
func (*ApiKeySpec) SetDisabled ¶
func (x *ApiKeySpec) SetDisabled(v bool)
func (*ApiKeySpec) SetDisplayName ¶
func (x *ApiKeySpec) SetDisplayName(v string)
func (*ApiKeySpec) SetExpiryTime ¶
func (x *ApiKeySpec) SetExpiryTime(v *timestamppb.Timestamp)
func (*ApiKeySpec) SetOwnerId ¶
func (x *ApiKeySpec) SetOwnerId(v string)
func (*ApiKeySpec) SetOwnerType ¶
func (x *ApiKeySpec) SetOwnerType(v string)
func (*ApiKeySpec) String ¶
func (x *ApiKeySpec) String() string
type ApiKeySpec_builder ¶
type ApiKeySpec_builder struct {
// The id of the owner to create the API key for.
// The owner id is immutable. Once set during creation, it cannot be changed.
// The owner id is the id of the user when the owner type is 'user'.
// The owner id is the id of the service account when the owner type is 'service-account'.
OwnerId string
// The type of the owner to create the API key for.
// The owner type is immutable. Once set during creation, it cannot be changed.
// Possible values: user, service-account.
OwnerType string
// The display name of the API key.
DisplayName string
// The description of the API key.
Description string
// The expiry time of the API key.
ExpiryTime *timestamppb.Timestamp
// True if the API key is disabled.
Disabled bool
// contains filtered or unexported fields
}
func (ApiKeySpec_builder) Build ¶
func (b0 ApiKeySpec_builder) Build() *ApiKeySpec
type ApiKey_builder ¶
type ApiKey_builder struct {
// The id of the API Key.
Id string
// The current version of the API key specification.
// The next update operation will have to include this version.
ResourceVersion string
// The API key specification.
Spec *ApiKeySpec
// The current state of the API key.
// Possible values: activating, activationfailed, active, updating, updatefailed, deleting, deletefailed, deleted, suspending, suspendfailed, suspended.
// For any failed state, reach out to Temporal Cloud support for remediation.
State string
// The id of the async operation that is creating/updating/deleting the API key, if any.
AsyncOperationId string
// The date and time when the API key was created.
CreatedTime *timestamppb.Timestamp
// The date and time when the API key was last modified.
// Will not be set if the API key has never been modified.
LastModifiedTime *timestamppb.Timestamp
// contains filtered or unexported fields
}
func (ApiKey_builder) Build ¶
func (b0 ApiKey_builder) Build() *ApiKey
type Invitation ¶
type Invitation struct {
// The date and time when the user was created
CreatedTime *timestamppb.Timestamp `protobuf:"bytes,1,opt,name=created_time,json=createdTime,proto3" json:"created_time,omitempty"`
// The date and time when the invitation expires or has expired
ExpiredTime *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=expired_time,json=expiredTime,proto3" json:"expired_time,omitempty"`
// contains filtered or unexported fields
}
func (*Invitation) ClearCreatedTime ¶
func (x *Invitation) ClearCreatedTime()
func (*Invitation) ClearExpiredTime ¶
func (x *Invitation) ClearExpiredTime()
func (*Invitation) GetCreatedTime ¶
func (x *Invitation) GetCreatedTime() *timestamppb.Timestamp
func (*Invitation) GetExpiredTime ¶
func (x *Invitation) GetExpiredTime() *timestamppb.Timestamp
func (*Invitation) HasCreatedTime ¶
func (x *Invitation) HasCreatedTime() bool
func (*Invitation) HasExpiredTime ¶
func (x *Invitation) HasExpiredTime() bool
func (*Invitation) ProtoMessage ¶
func (*Invitation) ProtoMessage()
func (*Invitation) ProtoReflect ¶
func (x *Invitation) ProtoReflect() protoreflect.Message
func (*Invitation) Reset ¶
func (x *Invitation) Reset()
func (*Invitation) SetCreatedTime ¶
func (x *Invitation) SetCreatedTime(v *timestamppb.Timestamp)
func (*Invitation) SetExpiredTime ¶
func (x *Invitation) SetExpiredTime(v *timestamppb.Timestamp)
func (*Invitation) String ¶
func (x *Invitation) String() string
type Invitation_builder ¶
type Invitation_builder struct {
// The date and time when the user was created
CreatedTime *timestamppb.Timestamp
// The date and time when the invitation expires or has expired
ExpiredTime *timestamppb.Timestamp
// contains filtered or unexported fields
}
func (Invitation_builder) Build ¶
func (b0 Invitation_builder) Build() *Invitation
type NamespaceAccess ¶
type NamespaceAccess struct {
// The permission to the namespace, should be one of [admin, write, read]
// admin - gives full access to the namespace, including assigning namespace access to other users
// write - gives write access to the namespace configuration and workflows within the namespace
// read - gives read only access to the namespace configuration and workflows within the namespace
Permission string `protobuf:"bytes,1,opt,name=permission,proto3" json:"permission,omitempty"`
// contains filtered or unexported fields
}
func (*NamespaceAccess) GetPermission ¶
func (x *NamespaceAccess) GetPermission() string
func (*NamespaceAccess) ProtoMessage ¶
func (*NamespaceAccess) ProtoMessage()
func (*NamespaceAccess) ProtoReflect ¶
func (x *NamespaceAccess) ProtoReflect() protoreflect.Message
func (*NamespaceAccess) Reset ¶
func (x *NamespaceAccess) Reset()
func (*NamespaceAccess) SetPermission ¶
func (x *NamespaceAccess) SetPermission(v string)
func (*NamespaceAccess) String ¶
func (x *NamespaceAccess) String() string
type NamespaceAccess_builder ¶
type NamespaceAccess_builder struct {
// The permission to the namespace, should be one of [admin, write, read]
// admin - gives full access to the namespace, including assigning namespace access to other users
// write - gives write access to the namespace configuration and workflows within the namespace
// read - gives read only access to the namespace configuration and workflows within the namespace
Permission string
// contains filtered or unexported fields
}
func (NamespaceAccess_builder) Build ¶
func (b0 NamespaceAccess_builder) Build() *NamespaceAccess
type ServiceAccount ¶
type ServiceAccount struct {
// The id of the service account.
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
// The current version of the service account specification.
// The next update operation will have to include this version.
ResourceVersion string `protobuf:"bytes,2,opt,name=resource_version,json=resourceVersion,proto3" json:"resource_version,omitempty"`
// The service account specification.
Spec *ServiceAccountSpec `protobuf:"bytes,3,opt,name=spec,proto3" json:"spec,omitempty"`
// The current state of the service account.
// Possible values: activating, activationfailed, active, updating, updatefailed, deleting, deletefailed, deleted, suspending, suspendfailed, suspended.
// For any failed state, reach out to Temporal Cloud support for remediation.
State string `protobuf:"bytes,4,opt,name=state,proto3" json:"state,omitempty"`
// The id of the async operation that is creating/updating/deleting the service account, if any.
AsyncOperationId string `protobuf:"bytes,5,opt,name=async_operation_id,json=asyncOperationId,proto3" json:"async_operation_id,omitempty"`
// The date and time when the service account was created.
CreatedTime *timestamppb.Timestamp `protobuf:"bytes,6,opt,name=created_time,json=createdTime,proto3" json:"created_time,omitempty"`
// The date and time when the service account was last modified
// Will not be set if the service account has never been modified.
LastModifiedTime *timestamppb.Timestamp `protobuf:"bytes,7,opt,name=last_modified_time,json=lastModifiedTime,proto3" json:"last_modified_time,omitempty"`
// contains filtered or unexported fields
}
func (*ServiceAccount) ClearCreatedTime ¶
func (x *ServiceAccount) ClearCreatedTime()
func (*ServiceAccount) ClearLastModifiedTime ¶
func (x *ServiceAccount) ClearLastModifiedTime()
func (*ServiceAccount) ClearSpec ¶
func (x *ServiceAccount) ClearSpec()
func (*ServiceAccount) GetAsyncOperationId ¶
func (x *ServiceAccount) GetAsyncOperationId() string
func (*ServiceAccount) GetCreatedTime ¶
func (x *ServiceAccount) GetCreatedTime() *timestamppb.Timestamp
func (*ServiceAccount) GetId ¶
func (x *ServiceAccount) GetId() string
func (*ServiceAccount) GetLastModifiedTime ¶
func (x *ServiceAccount) GetLastModifiedTime() *timestamppb.Timestamp
func (*ServiceAccount) GetResourceVersion ¶
func (x *ServiceAccount) GetResourceVersion() string
func (*ServiceAccount) GetSpec ¶
func (x *ServiceAccount) GetSpec() *ServiceAccountSpec
func (*ServiceAccount) GetState ¶
func (x *ServiceAccount) GetState() string
func (*ServiceAccount) HasCreatedTime ¶
func (x *ServiceAccount) HasCreatedTime() bool
func (*ServiceAccount) HasLastModifiedTime ¶
func (x *ServiceAccount) HasLastModifiedTime() bool
func (*ServiceAccount) HasSpec ¶
func (x *ServiceAccount) HasSpec() bool
func (*ServiceAccount) ProtoMessage ¶
func (*ServiceAccount) ProtoMessage()
func (*ServiceAccount) ProtoReflect ¶
func (x *ServiceAccount) ProtoReflect() protoreflect.Message
func (*ServiceAccount) Reset ¶
func (x *ServiceAccount) Reset()
func (*ServiceAccount) SetAsyncOperationId ¶
func (x *ServiceAccount) SetAsyncOperationId(v string)
func (*ServiceAccount) SetCreatedTime ¶
func (x *ServiceAccount) SetCreatedTime(v *timestamppb.Timestamp)
func (*ServiceAccount) SetId ¶
func (x *ServiceAccount) SetId(v string)
func (*ServiceAccount) SetLastModifiedTime ¶
func (x *ServiceAccount) SetLastModifiedTime(v *timestamppb.Timestamp)
func (*ServiceAccount) SetResourceVersion ¶
func (x *ServiceAccount) SetResourceVersion(v string)
func (*ServiceAccount) SetSpec ¶
func (x *ServiceAccount) SetSpec(v *ServiceAccountSpec)
func (*ServiceAccount) SetState ¶
func (x *ServiceAccount) SetState(v string)
func (*ServiceAccount) String ¶
func (x *ServiceAccount) String() string
type ServiceAccountSpec ¶
type ServiceAccountSpec struct {
// The name associated with the service account.
// The name is mutable, but must be unique across all your active service accounts.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// The access assigned to the service account.
// The access is mutable.
Access *Access `protobuf:"bytes,2,opt,name=access,proto3" json:"access,omitempty"`
// The description associated with the service account - optional.
// The description is mutable.
Description string `protobuf:"bytes,3,opt,name=description,proto3" json:"description,omitempty"`
// contains filtered or unexported fields
}
func (*ServiceAccountSpec) ClearAccess ¶
func (x *ServiceAccountSpec) ClearAccess()
func (*ServiceAccountSpec) GetAccess ¶
func (x *ServiceAccountSpec) GetAccess() *Access
func (*ServiceAccountSpec) GetDescription ¶
func (x *ServiceAccountSpec) GetDescription() string
func (*ServiceAccountSpec) GetName ¶
func (x *ServiceAccountSpec) GetName() string
func (*ServiceAccountSpec) HasAccess ¶
func (x *ServiceAccountSpec) HasAccess() bool
func (*ServiceAccountSpec) ProtoMessage ¶
func (*ServiceAccountSpec) ProtoMessage()
func (*ServiceAccountSpec) ProtoReflect ¶
func (x *ServiceAccountSpec) ProtoReflect() protoreflect.Message
func (*ServiceAccountSpec) Reset ¶
func (x *ServiceAccountSpec) Reset()
func (*ServiceAccountSpec) SetAccess ¶
func (x *ServiceAccountSpec) SetAccess(v *Access)
func (*ServiceAccountSpec) SetDescription ¶
func (x *ServiceAccountSpec) SetDescription(v string)
func (*ServiceAccountSpec) SetName ¶
func (x *ServiceAccountSpec) SetName(v string)
func (*ServiceAccountSpec) String ¶
func (x *ServiceAccountSpec) String() string
type ServiceAccountSpec_builder ¶
type ServiceAccountSpec_builder struct {
// The name associated with the service account.
// The name is mutable, but must be unique across all your active service accounts.
Name string
// The access assigned to the service account.
// The access is mutable.
Access *Access
// The description associated with the service account - optional.
// The description is mutable.
Description string
// contains filtered or unexported fields
}
func (ServiceAccountSpec_builder) Build ¶
func (b0 ServiceAccountSpec_builder) Build() *ServiceAccountSpec
type ServiceAccount_builder ¶
type ServiceAccount_builder struct {
// The id of the service account.
Id string
// The current version of the service account specification.
// The next update operation will have to include this version.
ResourceVersion string
// The service account specification.
Spec *ServiceAccountSpec
// The current state of the service account.
// Possible values: activating, activationfailed, active, updating, updatefailed, deleting, deletefailed, deleted, suspending, suspendfailed, suspended.
// For any failed state, reach out to Temporal Cloud support for remediation.
State string
// The id of the async operation that is creating/updating/deleting the service account, if any.
AsyncOperationId string
// The date and time when the service account was created.
CreatedTime *timestamppb.Timestamp
// The date and time when the service account was last modified
// Will not be set if the service account has never been modified.
LastModifiedTime *timestamppb.Timestamp
// contains filtered or unexported fields
}
func (ServiceAccount_builder) Build ¶
func (b0 ServiceAccount_builder) Build() *ServiceAccount
type User ¶
type User struct {
// The id of the user
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
// The current version of the user specification
// The next update operation will have to include this version
ResourceVersion string `protobuf:"bytes,2,opt,name=resource_version,json=resourceVersion,proto3" json:"resource_version,omitempty"`
// The user specification
Spec *UserSpec `protobuf:"bytes,3,opt,name=spec,proto3" json:"spec,omitempty"`
// The current state of the user
State string `protobuf:"bytes,4,opt,name=state,proto3" json:"state,omitempty"`
// The id of the async operation that is creating/updating/deleting the user, if any
AsyncOperationId string `protobuf:"bytes,5,opt,name=async_operation_id,json=asyncOperationId,proto3" json:"async_operation_id,omitempty"`
// The details of the open invitation sent to the user, if any
Invitation *Invitation `protobuf:"bytes,6,opt,name=invitation,proto3" json:"invitation,omitempty"`
// The date and time when the user was created
CreatedTime *timestamppb.Timestamp `protobuf:"bytes,7,opt,name=created_time,json=createdTime,proto3" json:"created_time,omitempty"`
// The date and time when the user was last modified
// Will not be set if the user has never been modified
LastModifiedTime *timestamppb.Timestamp `protobuf:"bytes,8,opt,name=last_modified_time,json=lastModifiedTime,proto3" json:"last_modified_time,omitempty"`
// contains filtered or unexported fields
}
func (*User) GetCreatedTime ¶
func (x *User) GetCreatedTime() *timestamppb.Timestamp
func (*User) GetInvitation ¶
func (x *User) GetInvitation() *Invitation
func (*User) GetLastModifiedTime ¶
func (x *User) GetLastModifiedTime() *timestamppb.Timestamp
func (*User) ProtoReflect ¶
func (x *User) ProtoReflect() protoreflect.Message
func (*User) SetCreatedTime ¶
func (x *User) SetCreatedTime(v *timestamppb.Timestamp)
func (*User) SetInvitation ¶
func (x *User) SetInvitation(v *Invitation)
func (*User) SetLastModifiedTime ¶
func (x *User) SetLastModifiedTime(v *timestamppb.Timestamp)
type UserGroup ¶
type UserGroup struct {
// The id of the group
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
// The current version of the group specification
// The next update operation will have to include this version
ResourceVersion string `protobuf:"bytes,2,opt,name=resource_version,json=resourceVersion,proto3" json:"resource_version,omitempty"`
// The group specification
Spec *UserGroupSpec `protobuf:"bytes,3,opt,name=spec,proto3" json:"spec,omitempty"`
// The current state of the group
State string `protobuf:"bytes,4,opt,name=state,proto3" json:"state,omitempty"`
// The id of the async operation that is creating/updating/deleting the group, if any
AsyncOperationId string `protobuf:"bytes,5,opt,name=async_operation_id,json=asyncOperationId,proto3" json:"async_operation_id,omitempty"`
// The date and time when the group was created
CreatedTime *timestamppb.Timestamp `protobuf:"bytes,6,opt,name=created_time,json=createdTime,proto3" json:"created_time,omitempty"`
// The date and time when the group was last modified
// Will not be set if the group has never been modified
LastModifiedTime *timestamppb.Timestamp `protobuf:"bytes,7,opt,name=last_modified_time,json=lastModifiedTime,proto3" json:"last_modified_time,omitempty"`
// contains filtered or unexported fields
}
func (*UserGroup) GetCreatedTime ¶
func (x *UserGroup) GetCreatedTime() *timestamppb.Timestamp
func (*UserGroup) GetLastModifiedTime ¶
func (x *UserGroup) GetLastModifiedTime() *timestamppb.Timestamp
func (*UserGroup) GetSpec ¶
func (x *UserGroup) GetSpec() *UserGroupSpec
func (*UserGroup) ProtoReflect ¶
func (x *UserGroup) ProtoReflect() protoreflect.Message
func (*UserGroup) SetCreatedTime ¶
func (x *UserGroup) SetCreatedTime(v *timestamppb.Timestamp)
func (*UserGroup) SetLastModifiedTime ¶
func (x *UserGroup) SetLastModifiedTime(v *timestamppb.Timestamp)
func (*UserGroup) SetSpec ¶
func (x *UserGroup) SetSpec(v *UserGroupSpec)
type UserGroupSpec ¶
type UserGroupSpec struct {
// The name of the group as defined in the customer's IdP (e.g. Google group name in Google Workspace)
// The name is immutable. Once set, it cannot be changed
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// The access assigned to the group
Access *Access `protobuf:"bytes,2,opt,name=access,proto3" json:"access,omitempty"`
// contains filtered or unexported fields
}
func (*UserGroupSpec) ClearAccess ¶
func (x *UserGroupSpec) ClearAccess()
func (*UserGroupSpec) GetAccess ¶
func (x *UserGroupSpec) GetAccess() *Access
func (*UserGroupSpec) GetName ¶
func (x *UserGroupSpec) GetName() string
func (*UserGroupSpec) HasAccess ¶
func (x *UserGroupSpec) HasAccess() bool
func (*UserGroupSpec) ProtoMessage ¶
func (*UserGroupSpec) ProtoMessage()
func (*UserGroupSpec) ProtoReflect ¶
func (x *UserGroupSpec) ProtoReflect() protoreflect.Message
func (*UserGroupSpec) Reset ¶
func (x *UserGroupSpec) Reset()
func (*UserGroupSpec) SetAccess ¶
func (x *UserGroupSpec) SetAccess(v *Access)
func (*UserGroupSpec) SetName ¶
func (x *UserGroupSpec) SetName(v string)
func (*UserGroupSpec) String ¶
func (x *UserGroupSpec) String() string
type UserGroupSpec_builder ¶
type UserGroupSpec_builder struct {
// The name of the group as defined in the customer's IdP (e.g. Google group name in Google Workspace)
// The name is immutable. Once set, it cannot be changed
Name string
// The access assigned to the group
Access *Access
// contains filtered or unexported fields
}
func (UserGroupSpec_builder) Build ¶
func (b0 UserGroupSpec_builder) Build() *UserGroupSpec
type UserGroup_builder ¶
type UserGroup_builder struct {
// The id of the group
Id string
// The current version of the group specification
// The next update operation will have to include this version
ResourceVersion string
// The group specification
Spec *UserGroupSpec
// The current state of the group
State string
// The id of the async operation that is creating/updating/deleting the group, if any
AsyncOperationId string
// The date and time when the group was created
CreatedTime *timestamppb.Timestamp
// The date and time when the group was last modified
// Will not be set if the group has never been modified
LastModifiedTime *timestamppb.Timestamp
// contains filtered or unexported fields
}
func (UserGroup_builder) Build ¶
func (b0 UserGroup_builder) Build() *UserGroup
type UserSpec ¶
type UserSpec struct {
// The email address associated to the user
Email string `protobuf:"bytes,1,opt,name=email,proto3" json:"email,omitempty"`
// The access to assigned to the user
Access *Access `protobuf:"bytes,2,opt,name=access,proto3" json:"access,omitempty"`
// contains filtered or unexported fields
}
func (*UserSpec) ProtoReflect ¶
func (x *UserSpec) ProtoReflect() protoreflect.Message
type UserSpec_builder ¶
type UserSpec_builder struct {
// The email address associated to the user
Email string
// The access to assigned to the user
Access *Access
// contains filtered or unexported fields
}
func (UserSpec_builder) Build ¶
func (b0 UserSpec_builder) Build() *UserSpec
type User_builder ¶
type User_builder struct {
// The id of the user
Id string
// The current version of the user specification
// The next update operation will have to include this version
ResourceVersion string
// The user specification
Spec *UserSpec
// The current state of the user
State string
// The id of the async operation that is creating/updating/deleting the user, if any
AsyncOperationId string
// The details of the open invitation sent to the user, if any
Invitation *Invitation
// The date and time when the user was created
CreatedTime *timestamppb.Timestamp
// The date and time when the user was last modified
// Will not be set if the user has never been modified
LastModifiedTime *timestamppb.Timestamp
// contains filtered or unexported fields
}
func (User_builder) Build ¶
func (b0 User_builder) Build() *User
Source Files
¶
- message.pb.go
Click to show internal directories.
Click to hide internal directories.