Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterObjectStoreServiceServer(s grpc.ServiceRegistrar, srv ObjectStoreServiceServer)
- type ObjectStoreServiceClient
- type ObjectStoreServiceServer
- type ObjectStoreService_CreateLargeObjectDownloadLinkClient
- type ObjectStoreService_CreateLargeObjectDownloadLinkServer
- type ObjectStoreService_CreateLargeObjectUploadLocationClient
- type ObjectStoreService_CreateLargeObjectUploadLocationServer
- type ObjectStoreService_DownloadPartClient
- type ObjectStoreService_DownloadPartServer
- type ObjectStoreService_UploadPartClient
- type ObjectStoreService_UploadPartServer
- type UnimplementedObjectStoreServiceServer
- func (UnimplementedObjectStoreServiceServer) CreateLargeObjectDownloadLink(*objectstore.CreateLargeObjectDownloadLinkRequest, ...) error
- func (UnimplementedObjectStoreServiceServer) CreateLargeObjectUploadLocation(*objectstore.CreateLargeObjectUploadLocationRequest, ...) error
- func (UnimplementedObjectStoreServiceServer) Delete(context.Context, *objectstore.DeleteRequest) (*objectstore.DeleteResponse, error)
- func (UnimplementedObjectStoreServiceServer) DownloadPart(*objectstore.DownloadPartRequest, ...) error
- func (UnimplementedObjectStoreServiceServer) Get(context.Context, *objectstore.GetRequest) (*objectstore.GetResponse, error)
- func (UnimplementedObjectStoreServiceServer) Head(context.Context, *objectstore.HeadRequest) (*objectstore.HeadResponse, error)
- func (UnimplementedObjectStoreServiceServer) ListInProgressLargeObjectUploads(context.Context, *objectstore.ListInProgressLargeObjectUploadsRequest) (*objectstore.ListInProgressLargeObjectUploadsResponse, error)
- func (UnimplementedObjectStoreServiceServer) Metadata(context.Context, *objectstore.MetadataRequest) (*objectstore.MetadataResponse, error)
- func (UnimplementedObjectStoreServiceServer) Put(context.Context, *objectstore.PutRequest) (*objectstore.PutResponse, error)
- func (UnimplementedObjectStoreServiceServer) StartLargeObjectUpload(context.Context, *objectstore.StartLargeObjectUploadRequest) (*objectstore.StartLargeObjectUploadResponse, error)
- func (UnimplementedObjectStoreServiceServer) TerminateLargeObjectUpload(context.Context, *objectstore.TerminateLargeObjectUploadRequest) (*objectstore.TerminateLargeObjectUploadResponse, error)
- func (UnimplementedObjectStoreServiceServer) UploadPart(...) error
- type UnsafeObjectStoreServiceServer
Constants ¶
const ( ObjectStoreService_Metadata_FullMethodName = "/cloudidl.objectstore.v1.ObjectStoreService/Metadata" ObjectStoreService_Head_FullMethodName = "/cloudidl.objectstore.v1.ObjectStoreService/Head" ObjectStoreService_Put_FullMethodName = "/cloudidl.objectstore.v1.ObjectStoreService/Put" ObjectStoreService_Get_FullMethodName = "/cloudidl.objectstore.v1.ObjectStoreService/Get" ObjectStoreService_Delete_FullMethodName = "/cloudidl.objectstore.v1.ObjectStoreService/Delete" ObjectStoreService_CreateLargeObjectUploadLocation_FullMethodName = "/cloudidl.objectstore.v1.ObjectStoreService/CreateLargeObjectUploadLocation" ObjectStoreService_TerminateLargeObjectUpload_FullMethodName = "/cloudidl.objectstore.v1.ObjectStoreService/TerminateLargeObjectUpload" ObjectStoreService_CreateLargeObjectDownloadLink_FullMethodName = "/cloudidl.objectstore.v1.ObjectStoreService/CreateLargeObjectDownloadLink" ObjectStoreService_StartLargeObjectUpload_FullMethodName = "/cloudidl.objectstore.v1.ObjectStoreService/StartLargeObjectUpload" ObjectStoreService_UploadPart_FullMethodName = "/cloudidl.objectstore.v1.ObjectStoreService/UploadPart" ObjectStoreService_ListInProgressLargeObjectUploads_FullMethodName = "/cloudidl.objectstore.v1.ObjectStoreService/ListInProgressLargeObjectUploads" ObjectStoreService_DownloadPart_FullMethodName = "/cloudidl.objectstore.v1.ObjectStoreService/DownloadPart" )
Variables ¶
var ObjectStoreService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "cloudidl.objectstore.v1.ObjectStoreService", HandlerType: (*ObjectStoreServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "Metadata", Handler: _ObjectStoreService_Metadata_Handler, }, { MethodName: "Head", Handler: _ObjectStoreService_Head_Handler, }, { MethodName: "Put", Handler: _ObjectStoreService_Put_Handler, }, { MethodName: "Get", Handler: _ObjectStoreService_Get_Handler, }, { MethodName: "Delete", Handler: _ObjectStoreService_Delete_Handler, }, { MethodName: "TerminateLargeObjectUpload", Handler: _ObjectStoreService_TerminateLargeObjectUpload_Handler, }, { MethodName: "StartLargeObjectUpload", Handler: _ObjectStoreService_StartLargeObjectUpload_Handler, }, { MethodName: "ListInProgressLargeObjectUploads", Handler: _ObjectStoreService_ListInProgressLargeObjectUploads_Handler, }, }, Streams: []grpc.StreamDesc{ { StreamName: "CreateLargeObjectUploadLocation", Handler: _ObjectStoreService_CreateLargeObjectUploadLocation_Handler, ServerStreams: true, }, { StreamName: "CreateLargeObjectDownloadLink", Handler: _ObjectStoreService_CreateLargeObjectDownloadLink_Handler, ServerStreams: true, }, { StreamName: "UploadPart", Handler: _ObjectStoreService_UploadPart_Handler, ClientStreams: true, }, { StreamName: "DownloadPart", Handler: _ObjectStoreService_DownloadPart_Handler, ServerStreams: true, }, }, Metadata: "objectstore/service.proto", }
ObjectStoreService_ServiceDesc is the grpc.ServiceDesc for ObjectStoreService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterObjectStoreServiceServer ¶
func RegisterObjectStoreServiceServer(s grpc.ServiceRegistrar, srv ObjectStoreServiceServer)
Types ¶
type ObjectStoreServiceClient ¶
type ObjectStoreServiceClient interface {
// Metadata returns the metadata for the object store
Metadata(ctx context.Context, in *objectstore.MetadataRequest, opts ...grpc.CallOption) (*objectstore.MetadataResponse, error)
// Head returns the metadata for an object
Head(ctx context.Context, in *objectstore.HeadRequest, opts ...grpc.CallOption) (*objectstore.HeadResponse, error)
// Put creates or updates an object. The maximum size of an object is 1GB.
Put(ctx context.Context, in *objectstore.PutRequest, opts ...grpc.CallOption) (*objectstore.PutResponse, error)
// Get returns the contents of an object
Get(ctx context.Context, in *objectstore.GetRequest, opts ...grpc.CallOption) (*objectstore.GetResponse, error)
// Delete deletes an object
Delete(ctx context.Context, in *objectstore.DeleteRequest, opts ...grpc.CallOption) (*objectstore.DeleteResponse, error)
// Using Signed URLs
CreateLargeObjectUploadLocation(ctx context.Context, in *objectstore.CreateLargeObjectUploadLocationRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[objectstore.CreateLargeObjectUploadLocationResponse], error)
TerminateLargeObjectUpload(ctx context.Context, in *objectstore.TerminateLargeObjectUploadRequest, opts ...grpc.CallOption) (*objectstore.TerminateLargeObjectUploadResponse, error)
CreateLargeObjectDownloadLink(ctx context.Context, in *objectstore.CreateLargeObjectDownloadLinkRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[objectstore.CreateLargeObjectDownloadLinkResponse], error)
// Using straight proxying
StartLargeObjectUpload(ctx context.Context, in *objectstore.StartLargeObjectUploadRequest, opts ...grpc.CallOption) (*objectstore.StartLargeObjectUploadResponse, error)
UploadPart(ctx context.Context, opts ...grpc.CallOption) (grpc.ClientStreamingClient[objectstore.UploadPartRequest, objectstore.UploadPartResponse], error)
ListInProgressLargeObjectUploads(ctx context.Context, in *objectstore.ListInProgressLargeObjectUploadsRequest, opts ...grpc.CallOption) (*objectstore.ListInProgressLargeObjectUploadsResponse, error)
DownloadPart(ctx context.Context, in *objectstore.DownloadPartRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[objectstore.DownloadPartResponse], error)
}
ObjectStoreServiceClient is the client API for ObjectStoreService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewObjectStoreServiceClient ¶
func NewObjectStoreServiceClient(cc grpc.ClientConnInterface) ObjectStoreServiceClient
type ObjectStoreServiceServer ¶
type ObjectStoreServiceServer interface {
// Metadata returns the metadata for the object store
Metadata(context.Context, *objectstore.MetadataRequest) (*objectstore.MetadataResponse, error)
// Head returns the metadata for an object
Head(context.Context, *objectstore.HeadRequest) (*objectstore.HeadResponse, error)
// Put creates or updates an object. The maximum size of an object is 1GB.
Put(context.Context, *objectstore.PutRequest) (*objectstore.PutResponse, error)
// Get returns the contents of an object
Get(context.Context, *objectstore.GetRequest) (*objectstore.GetResponse, error)
// Delete deletes an object
Delete(context.Context, *objectstore.DeleteRequest) (*objectstore.DeleteResponse, error)
// Using Signed URLs
CreateLargeObjectUploadLocation(*objectstore.CreateLargeObjectUploadLocationRequest, grpc.ServerStreamingServer[objectstore.CreateLargeObjectUploadLocationResponse]) error
TerminateLargeObjectUpload(context.Context, *objectstore.TerminateLargeObjectUploadRequest) (*objectstore.TerminateLargeObjectUploadResponse, error)
CreateLargeObjectDownloadLink(*objectstore.CreateLargeObjectDownloadLinkRequest, grpc.ServerStreamingServer[objectstore.CreateLargeObjectDownloadLinkResponse]) error
// Using straight proxying
StartLargeObjectUpload(context.Context, *objectstore.StartLargeObjectUploadRequest) (*objectstore.StartLargeObjectUploadResponse, error)
UploadPart(grpc.ClientStreamingServer[objectstore.UploadPartRequest, objectstore.UploadPartResponse]) error
ListInProgressLargeObjectUploads(context.Context, *objectstore.ListInProgressLargeObjectUploadsRequest) (*objectstore.ListInProgressLargeObjectUploadsResponse, error)
DownloadPart(*objectstore.DownloadPartRequest, grpc.ServerStreamingServer[objectstore.DownloadPartResponse]) error
}
ObjectStoreServiceServer is the server API for ObjectStoreService service. All implementations should embed UnimplementedObjectStoreServiceServer for forward compatibility.
type ObjectStoreService_CreateLargeObjectDownloadLinkClient ¶
type ObjectStoreService_CreateLargeObjectDownloadLinkClient = grpc.ServerStreamingClient[objectstore.CreateLargeObjectDownloadLinkResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type ObjectStoreService_CreateLargeObjectDownloadLinkServer ¶
type ObjectStoreService_CreateLargeObjectDownloadLinkServer = grpc.ServerStreamingServer[objectstore.CreateLargeObjectDownloadLinkResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type ObjectStoreService_CreateLargeObjectUploadLocationClient ¶
type ObjectStoreService_CreateLargeObjectUploadLocationClient = grpc.ServerStreamingClient[objectstore.CreateLargeObjectUploadLocationResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type ObjectStoreService_CreateLargeObjectUploadLocationServer ¶
type ObjectStoreService_CreateLargeObjectUploadLocationServer = grpc.ServerStreamingServer[objectstore.CreateLargeObjectUploadLocationResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type ObjectStoreService_DownloadPartClient ¶
type ObjectStoreService_DownloadPartClient = grpc.ServerStreamingClient[objectstore.DownloadPartResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type ObjectStoreService_DownloadPartServer ¶
type ObjectStoreService_DownloadPartServer = grpc.ServerStreamingServer[objectstore.DownloadPartResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type ObjectStoreService_UploadPartClient ¶
type ObjectStoreService_UploadPartClient = grpc.ClientStreamingClient[objectstore.UploadPartRequest, objectstore.UploadPartResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type ObjectStoreService_UploadPartServer ¶
type ObjectStoreService_UploadPartServer = grpc.ClientStreamingServer[objectstore.UploadPartRequest, objectstore.UploadPartResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type UnimplementedObjectStoreServiceServer ¶
type UnimplementedObjectStoreServiceServer struct{}
UnimplementedObjectStoreServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedObjectStoreServiceServer) CreateLargeObjectDownloadLink ¶
func (UnimplementedObjectStoreServiceServer) CreateLargeObjectDownloadLink(*objectstore.CreateLargeObjectDownloadLinkRequest, grpc.ServerStreamingServer[objectstore.CreateLargeObjectDownloadLinkResponse]) error
func (UnimplementedObjectStoreServiceServer) CreateLargeObjectUploadLocation ¶
func (UnimplementedObjectStoreServiceServer) CreateLargeObjectUploadLocation(*objectstore.CreateLargeObjectUploadLocationRequest, grpc.ServerStreamingServer[objectstore.CreateLargeObjectUploadLocationResponse]) error
func (UnimplementedObjectStoreServiceServer) Delete ¶
func (UnimplementedObjectStoreServiceServer) Delete(context.Context, *objectstore.DeleteRequest) (*objectstore.DeleteResponse, error)
func (UnimplementedObjectStoreServiceServer) DownloadPart ¶
func (UnimplementedObjectStoreServiceServer) Get ¶
func (UnimplementedObjectStoreServiceServer) Get(context.Context, *objectstore.GetRequest) (*objectstore.GetResponse, error)
func (UnimplementedObjectStoreServiceServer) Head ¶
func (UnimplementedObjectStoreServiceServer) Head(context.Context, *objectstore.HeadRequest) (*objectstore.HeadResponse, error)
func (UnimplementedObjectStoreServiceServer) ListInProgressLargeObjectUploads ¶
func (UnimplementedObjectStoreServiceServer) ListInProgressLargeObjectUploads(context.Context, *objectstore.ListInProgressLargeObjectUploadsRequest) (*objectstore.ListInProgressLargeObjectUploadsResponse, error)
func (UnimplementedObjectStoreServiceServer) Metadata ¶
func (UnimplementedObjectStoreServiceServer) Metadata(context.Context, *objectstore.MetadataRequest) (*objectstore.MetadataResponse, error)
func (UnimplementedObjectStoreServiceServer) Put ¶
func (UnimplementedObjectStoreServiceServer) Put(context.Context, *objectstore.PutRequest) (*objectstore.PutResponse, error)
func (UnimplementedObjectStoreServiceServer) StartLargeObjectUpload ¶
func (UnimplementedObjectStoreServiceServer) StartLargeObjectUpload(context.Context, *objectstore.StartLargeObjectUploadRequest) (*objectstore.StartLargeObjectUploadResponse, error)
func (UnimplementedObjectStoreServiceServer) TerminateLargeObjectUpload ¶
func (UnimplementedObjectStoreServiceServer) TerminateLargeObjectUpload(context.Context, *objectstore.TerminateLargeObjectUploadRequest) (*objectstore.TerminateLargeObjectUploadResponse, error)
func (UnimplementedObjectStoreServiceServer) UploadPart ¶
type UnsafeObjectStoreServiceServer ¶
type UnsafeObjectStoreServiceServer interface {
// contains filtered or unexported methods
}
UnsafeObjectStoreServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ObjectStoreServiceServer will result in compilation errors.
Source Files
¶
- service_grpc.pb.go