Documentation
¶
Index ¶
- Variables
- type ExtensionAttribute
- func (x *ExtensionAttribute) GetCamelCaseName() string
- func (x *ExtensionAttribute) GetDescription() string
- func (x *ExtensionAttribute) GetName() string
- func (*ExtensionAttribute) ProtoMessage()
- func (x *ExtensionAttribute) ProtoReflect() protoreflect.Message
- func (x *ExtensionAttribute) Reset()
- func (x *ExtensionAttribute) SetCamelCaseName(v string)
- func (x *ExtensionAttribute) SetDescription(v string)
- func (x *ExtensionAttribute) SetName(v string)
- func (x *ExtensionAttribute) String() string
- type ExtensionAttribute_builder
Constants ¶
This section is empty.
Variables ¶
var ( // The CloudEvent type (e.g. "google.cloud.storage.object.v1.finalized") // that relates to this message. // // optional string cloud_event_type = 11716486; E_CloudEventType = &file_google_events_cloudevent_proto_extTypes[0] // The name of an extension attribute populated for this event. The extension // attribute should be more fully described within the file options. // // repeated string cloud_event_extension_name = 11716489; E_CloudEventExtensionName = &file_google_events_cloudevent_proto_extTypes[3] )
Extension fields to descriptorpb.MessageOptions.
var ( // The product (e.g. "Cloud Firestore") that owns the CloudEvents described // in this file. // // optional string cloud_event_product = 11716487; E_CloudEventProduct = &file_google_events_cloudevent_proto_extTypes[1] // An extension attribute used within the CloudEvents described in this file. // // repeated google.events.ExtensionAttribute cloud_event_extension_attribute = 11716488; E_CloudEventExtensionAttribute = &file_google_events_cloudevent_proto_extTypes[2] )
Extension fields to descriptorpb.FileOptions.
var File_google_events_cloudevent_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type ExtensionAttribute ¶
type ExtensionAttribute struct {
// Name of the CloudEvents attribute, e.g. "topic".
// This must be all lower-case, to satisfy CloudEvent requirements.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// Description of the attribute.
Description string `protobuf:"bytes,2,opt,name=description,proto3" json:"description,omitempty"`
// The name of the CloudEvents attribute in lower Camel case, e.g. "firebaseDatabaseHost".
// This only needs to be populated if the name would otherwise be mis-represented.
CamelCaseName string `protobuf:"bytes,3,opt,name=camel_case_name,json=camelCaseName,proto3" json:"camel_case_name,omitempty"`
// contains filtered or unexported fields
}
Description of an extension attribute.
func (*ExtensionAttribute) GetCamelCaseName ¶
func (x *ExtensionAttribute) GetCamelCaseName() string
func (*ExtensionAttribute) GetDescription ¶
func (x *ExtensionAttribute) GetDescription() string
func (*ExtensionAttribute) GetName ¶
func (x *ExtensionAttribute) GetName() string
func (*ExtensionAttribute) ProtoMessage ¶
func (*ExtensionAttribute) ProtoMessage()
func (*ExtensionAttribute) ProtoReflect ¶
func (x *ExtensionAttribute) ProtoReflect() protoreflect.Message
func (*ExtensionAttribute) Reset ¶
func (x *ExtensionAttribute) Reset()
func (*ExtensionAttribute) SetCamelCaseName ¶
func (x *ExtensionAttribute) SetCamelCaseName(v string)
func (*ExtensionAttribute) SetDescription ¶
func (x *ExtensionAttribute) SetDescription(v string)
func (*ExtensionAttribute) SetName ¶
func (x *ExtensionAttribute) SetName(v string)
func (*ExtensionAttribute) String ¶
func (x *ExtensionAttribute) String() string
type ExtensionAttribute_builder ¶
type ExtensionAttribute_builder struct {
// Name of the CloudEvents attribute, e.g. "topic".
// This must be all lower-case, to satisfy CloudEvent requirements.
Name string
// Description of the attribute.
Description string
// The name of the CloudEvents attribute in lower Camel case, e.g. "firebaseDatabaseHost".
// This only needs to be populated if the name would otherwise be mis-represented.
CamelCaseName string
// contains filtered or unexported fields
}
func (ExtensionAttribute_builder) Build ¶
func (b0 ExtensionAttribute_builder) Build() *ExtensionAttribute
Source Files
¶
- cloudevent.pb.go
Click to show internal directories.
Click to hide internal directories.