Documentation
¶
Index ¶
- Variables
- type AppGateway
- func (x *AppGateway) ClearCreateTime()
- func (x *AppGateway) ClearUpdateTime()
- func (x *AppGateway) GetAllocatedConnections() []*AppGateway_AllocatedConnection
- func (x *AppGateway) GetCreateTime() *timestamppb.Timestamp
- func (x *AppGateway) GetDisplayName() string
- func (x *AppGateway) GetHostType() AppGateway_HostType
- func (x *AppGateway) GetLabels() map[string]string
- func (x *AppGateway) GetName() string
- func (x *AppGateway) GetState() AppGateway_State
- func (x *AppGateway) GetType() AppGateway_Type
- func (x *AppGateway) GetUid() string
- func (x *AppGateway) GetUpdateTime() *timestamppb.Timestamp
- func (x *AppGateway) GetUri() string
- func (x *AppGateway) HasCreateTime() bool
- func (x *AppGateway) HasUpdateTime() bool
- func (*AppGateway) ProtoMessage()
- func (x *AppGateway) ProtoReflect() protoreflect.Message
- func (x *AppGateway) Reset()
- func (x *AppGateway) SetAllocatedConnections(v []*AppGateway_AllocatedConnection)
- func (x *AppGateway) SetCreateTime(v *timestamppb.Timestamp)
- func (x *AppGateway) SetDisplayName(v string)
- func (x *AppGateway) SetHostType(v AppGateway_HostType)
- func (x *AppGateway) SetLabels(v map[string]string)
- func (x *AppGateway) SetName(v string)
- func (x *AppGateway) SetState(v AppGateway_State)
- func (x *AppGateway) SetType(v AppGateway_Type)
- func (x *AppGateway) SetUid(v string)
- func (x *AppGateway) SetUpdateTime(v *timestamppb.Timestamp)
- func (x *AppGateway) SetUri(v string)
- func (x *AppGateway) String() string
- type AppGatewayCreatedEvent
- func (x *AppGatewayCreatedEvent) ClearData()
- func (x *AppGatewayCreatedEvent) GetData() *AppGatewayEventData
- func (x *AppGatewayCreatedEvent) HasData() bool
- func (*AppGatewayCreatedEvent) ProtoMessage()
- func (x *AppGatewayCreatedEvent) ProtoReflect() protoreflect.Message
- func (x *AppGatewayCreatedEvent) Reset()
- func (x *AppGatewayCreatedEvent) SetData(v *AppGatewayEventData)
- func (x *AppGatewayCreatedEvent) String() string
- type AppGatewayCreatedEvent_builder
- type AppGatewayDeletedEvent
- func (x *AppGatewayDeletedEvent) ClearData()
- func (x *AppGatewayDeletedEvent) GetData() *AppGatewayEventData
- func (x *AppGatewayDeletedEvent) HasData() bool
- func (*AppGatewayDeletedEvent) ProtoMessage()
- func (x *AppGatewayDeletedEvent) ProtoReflect() protoreflect.Message
- func (x *AppGatewayDeletedEvent) Reset()
- func (x *AppGatewayDeletedEvent) SetData(v *AppGatewayEventData)
- func (x *AppGatewayDeletedEvent) String() string
- type AppGatewayDeletedEvent_builder
- type AppGatewayEventData
- func (x *AppGatewayEventData) ClearPayload()
- func (x *AppGatewayEventData) GetPayload() *AppGateway
- func (x *AppGatewayEventData) HasPayload() bool
- func (*AppGatewayEventData) ProtoMessage()
- func (x *AppGatewayEventData) ProtoReflect() protoreflect.Message
- func (x *AppGatewayEventData) Reset()
- func (x *AppGatewayEventData) SetPayload(v *AppGateway)
- func (x *AppGatewayEventData) String() string
- type AppGatewayEventData_builder
- type AppGateway_AllocatedConnection
- func (x *AppGateway_AllocatedConnection) GetIngressPort() int32
- func (x *AppGateway_AllocatedConnection) GetPscUri() string
- func (*AppGateway_AllocatedConnection) ProtoMessage()
- func (x *AppGateway_AllocatedConnection) ProtoReflect() protoreflect.Message
- func (x *AppGateway_AllocatedConnection) Reset()
- func (x *AppGateway_AllocatedConnection) SetIngressPort(v int32)
- func (x *AppGateway_AllocatedConnection) SetPscUri(v string)
- func (x *AppGateway_AllocatedConnection) String() string
- type AppGateway_AllocatedConnection_builder
- type AppGateway_HostType
- type AppGateway_State
- type AppGateway_Type
- type AppGateway_builder
Constants ¶
This section is empty.
Variables ¶
var ( AppGateway_Type_name = map[int32]string{ 0: "TYPE_UNSPECIFIED", 1: "TCP_PROXY", } AppGateway_Type_value = map[string]int32{ "TYPE_UNSPECIFIED": 0, "TCP_PROXY": 1, } )
Enum value maps for AppGateway_Type.
var ( AppGateway_State_name = map[int32]string{ 0: "STATE_UNSPECIFIED", 1: "CREATING", 2: "CREATED", 3: "UPDATING", 4: "DELETING", 5: "DOWN", } AppGateway_State_value = map[string]int32{ "STATE_UNSPECIFIED": 0, "CREATING": 1, "CREATED": 2, "UPDATING": 3, "DELETING": 4, "DOWN": 5, } )
Enum value maps for AppGateway_State.
var ( AppGateway_HostType_name = map[int32]string{ 0: "HOST_TYPE_UNSPECIFIED", 1: "GCP_REGIONAL_MIG", } AppGateway_HostType_value = map[string]int32{ "HOST_TYPE_UNSPECIFIED": 0, "GCP_REGIONAL_MIG": 1, } )
Enum value maps for AppGateway_HostType.
var File_google_events_cloud_beyondcorp_appgateways_v1_data_proto protoreflect.FileDescriptor
var File_google_events_cloud_beyondcorp_appgateways_v1_events_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type AppGateway ¶
type AppGateway struct {
// Required. Unique resource name of the AppGateway.
// The name is ignored when creating an AppGateway.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// Output only. Timestamp when the resource was created.
CreateTime *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
// Output only. Timestamp when the resource was last modified.
UpdateTime *timestamppb.Timestamp `protobuf:"bytes,3,opt,name=update_time,json=updateTime,proto3" json:"update_time,omitempty"`
// Optional. Resource labels to represent user provided metadata.
Labels map[string]string `` /* 139-byte string literal not displayed */
// Optional. An arbitrary user-provided name for the AppGateway. Cannot exceed
// 64 characters.
DisplayName string `protobuf:"bytes,5,opt,name=display_name,json=displayName,proto3" json:"display_name,omitempty"`
// Output only. A unique identifier for the instance generated by the
// system.
Uid string `protobuf:"bytes,6,opt,name=uid,proto3" json:"uid,omitempty"`
// Required. The type of network connectivity used by the AppGateway.
Type AppGateway_Type `` /* 129-byte string literal not displayed */
// Output only. The current state of the AppGateway.
State AppGateway_State `` /* 132-byte string literal not displayed */
// Output only. Server-defined URI for this resource.
Uri string `protobuf:"bytes,9,opt,name=uri,proto3" json:"uri,omitempty"`
// Output only. A list of connections allocated for the Gateway
AllocatedConnections []*AppGateway_AllocatedConnection `protobuf:"bytes,10,rep,name=allocated_connections,json=allocatedConnections,proto3" json:"allocated_connections,omitempty"`
// Required. The type of hosting used by the AppGateway.
HostType AppGateway_HostType `` /* 158-byte string literal not displayed */
// contains filtered or unexported fields
}
A BeyondCorp AppGateway resource represents a BeyondCorp protected AppGateway to a remote application. It creates all the necessary GCP components needed for creating a BeyondCorp protected AppGateway. Multiple connectors can be authorised for a single AppGateway.
func (*AppGateway) ClearCreateTime ¶
func (x *AppGateway) ClearCreateTime()
func (*AppGateway) ClearUpdateTime ¶
func (x *AppGateway) ClearUpdateTime()
func (*AppGateway) GetAllocatedConnections ¶
func (x *AppGateway) GetAllocatedConnections() []*AppGateway_AllocatedConnection
func (*AppGateway) GetCreateTime ¶
func (x *AppGateway) GetCreateTime() *timestamppb.Timestamp
func (*AppGateway) GetDisplayName ¶
func (x *AppGateway) GetDisplayName() string
func (*AppGateway) GetHostType ¶
func (x *AppGateway) GetHostType() AppGateway_HostType
func (*AppGateway) GetLabels ¶
func (x *AppGateway) GetLabels() map[string]string
func (*AppGateway) GetName ¶
func (x *AppGateway) GetName() string
func (*AppGateway) GetState ¶
func (x *AppGateway) GetState() AppGateway_State
func (*AppGateway) GetType ¶
func (x *AppGateway) GetType() AppGateway_Type
func (*AppGateway) GetUid ¶
func (x *AppGateway) GetUid() string
func (*AppGateway) GetUpdateTime ¶
func (x *AppGateway) GetUpdateTime() *timestamppb.Timestamp
func (*AppGateway) GetUri ¶
func (x *AppGateway) GetUri() string
func (*AppGateway) HasCreateTime ¶
func (x *AppGateway) HasCreateTime() bool
func (*AppGateway) HasUpdateTime ¶
func (x *AppGateway) HasUpdateTime() bool
func (*AppGateway) ProtoMessage ¶
func (*AppGateway) ProtoMessage()
func (*AppGateway) ProtoReflect ¶
func (x *AppGateway) ProtoReflect() protoreflect.Message
func (*AppGateway) Reset ¶
func (x *AppGateway) Reset()
func (*AppGateway) SetAllocatedConnections ¶
func (x *AppGateway) SetAllocatedConnections(v []*AppGateway_AllocatedConnection)
func (*AppGateway) SetCreateTime ¶
func (x *AppGateway) SetCreateTime(v *timestamppb.Timestamp)
func (*AppGateway) SetDisplayName ¶
func (x *AppGateway) SetDisplayName(v string)
func (*AppGateway) SetHostType ¶
func (x *AppGateway) SetHostType(v AppGateway_HostType)
func (*AppGateway) SetLabels ¶
func (x *AppGateway) SetLabels(v map[string]string)
func (*AppGateway) SetName ¶
func (x *AppGateway) SetName(v string)
func (*AppGateway) SetState ¶
func (x *AppGateway) SetState(v AppGateway_State)
func (*AppGateway) SetType ¶
func (x *AppGateway) SetType(v AppGateway_Type)
func (*AppGateway) SetUid ¶
func (x *AppGateway) SetUid(v string)
func (*AppGateway) SetUpdateTime ¶
func (x *AppGateway) SetUpdateTime(v *timestamppb.Timestamp)
func (*AppGateway) SetUri ¶
func (x *AppGateway) SetUri(v string)
func (*AppGateway) String ¶
func (x *AppGateway) String() string
type AppGatewayCreatedEvent ¶
type AppGatewayCreatedEvent struct {
// The data associated with the event.
Data *AppGatewayEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
// contains filtered or unexported fields
}
The CloudEvent raised when an AppGateway is created.
func (*AppGatewayCreatedEvent) ClearData ¶
func (x *AppGatewayCreatedEvent) ClearData()
func (*AppGatewayCreatedEvent) GetData ¶
func (x *AppGatewayCreatedEvent) GetData() *AppGatewayEventData
func (*AppGatewayCreatedEvent) HasData ¶
func (x *AppGatewayCreatedEvent) HasData() bool
func (*AppGatewayCreatedEvent) ProtoMessage ¶
func (*AppGatewayCreatedEvent) ProtoMessage()
func (*AppGatewayCreatedEvent) ProtoReflect ¶
func (x *AppGatewayCreatedEvent) ProtoReflect() protoreflect.Message
func (*AppGatewayCreatedEvent) Reset ¶
func (x *AppGatewayCreatedEvent) Reset()
func (*AppGatewayCreatedEvent) SetData ¶
func (x *AppGatewayCreatedEvent) SetData(v *AppGatewayEventData)
func (*AppGatewayCreatedEvent) String ¶
func (x *AppGatewayCreatedEvent) String() string
type AppGatewayCreatedEvent_builder ¶
type AppGatewayCreatedEvent_builder struct {
// The data associated with the event.
Data *AppGatewayEventData
// contains filtered or unexported fields
}
func (AppGatewayCreatedEvent_builder) Build ¶
func (b0 AppGatewayCreatedEvent_builder) Build() *AppGatewayCreatedEvent
type AppGatewayDeletedEvent ¶
type AppGatewayDeletedEvent struct {
// The data associated with the event.
Data *AppGatewayEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
// contains filtered or unexported fields
}
The CloudEvent raised when an AppGateway is deleted.
func (*AppGatewayDeletedEvent) ClearData ¶
func (x *AppGatewayDeletedEvent) ClearData()
func (*AppGatewayDeletedEvent) GetData ¶
func (x *AppGatewayDeletedEvent) GetData() *AppGatewayEventData
func (*AppGatewayDeletedEvent) HasData ¶
func (x *AppGatewayDeletedEvent) HasData() bool
func (*AppGatewayDeletedEvent) ProtoMessage ¶
func (*AppGatewayDeletedEvent) ProtoMessage()
func (*AppGatewayDeletedEvent) ProtoReflect ¶
func (x *AppGatewayDeletedEvent) ProtoReflect() protoreflect.Message
func (*AppGatewayDeletedEvent) Reset ¶
func (x *AppGatewayDeletedEvent) Reset()
func (*AppGatewayDeletedEvent) SetData ¶
func (x *AppGatewayDeletedEvent) SetData(v *AppGatewayEventData)
func (*AppGatewayDeletedEvent) String ¶
func (x *AppGatewayDeletedEvent) String() string
type AppGatewayDeletedEvent_builder ¶
type AppGatewayDeletedEvent_builder struct {
// The data associated with the event.
Data *AppGatewayEventData
// contains filtered or unexported fields
}
func (AppGatewayDeletedEvent_builder) Build ¶
func (b0 AppGatewayDeletedEvent_builder) Build() *AppGatewayDeletedEvent
type AppGatewayEventData ¶
type AppGatewayEventData struct {
// Optional. The AppGateway event payload. Unset for deletion events.
Payload *AppGateway `protobuf:"bytes,1,opt,name=payload,proto3,oneof" json:"payload,omitempty"`
// contains filtered or unexported fields
}
The data within all AppGateway events.
func (*AppGatewayEventData) ClearPayload ¶
func (x *AppGatewayEventData) ClearPayload()
func (*AppGatewayEventData) GetPayload ¶
func (x *AppGatewayEventData) GetPayload() *AppGateway
func (*AppGatewayEventData) HasPayload ¶
func (x *AppGatewayEventData) HasPayload() bool
func (*AppGatewayEventData) ProtoMessage ¶
func (*AppGatewayEventData) ProtoMessage()
func (*AppGatewayEventData) ProtoReflect ¶
func (x *AppGatewayEventData) ProtoReflect() protoreflect.Message
func (*AppGatewayEventData) Reset ¶
func (x *AppGatewayEventData) Reset()
func (*AppGatewayEventData) SetPayload ¶
func (x *AppGatewayEventData) SetPayload(v *AppGateway)
func (*AppGatewayEventData) String ¶
func (x *AppGatewayEventData) String() string
type AppGatewayEventData_builder ¶
type AppGatewayEventData_builder struct {
// Optional. The AppGateway event payload. Unset for deletion events.
Payload *AppGateway
// contains filtered or unexported fields
}
func (AppGatewayEventData_builder) Build ¶
func (b0 AppGatewayEventData_builder) Build() *AppGatewayEventData
type AppGateway_AllocatedConnection ¶
type AppGateway_AllocatedConnection struct {
// Required. The PSC uri of an allocated connection
PscUri string `protobuf:"bytes,1,opt,name=psc_uri,json=pscUri,proto3" json:"psc_uri,omitempty"`
// Required. The ingress port of an allocated connection
IngressPort int32 `protobuf:"varint,2,opt,name=ingress_port,json=ingressPort,proto3" json:"ingress_port,omitempty"`
// contains filtered or unexported fields
}
Allocated connection of the AppGateway.
func (*AppGateway_AllocatedConnection) GetIngressPort ¶
func (x *AppGateway_AllocatedConnection) GetIngressPort() int32
func (*AppGateway_AllocatedConnection) GetPscUri ¶
func (x *AppGateway_AllocatedConnection) GetPscUri() string
func (*AppGateway_AllocatedConnection) ProtoMessage ¶
func (*AppGateway_AllocatedConnection) ProtoMessage()
func (*AppGateway_AllocatedConnection) ProtoReflect ¶
func (x *AppGateway_AllocatedConnection) ProtoReflect() protoreflect.Message
func (*AppGateway_AllocatedConnection) Reset ¶
func (x *AppGateway_AllocatedConnection) Reset()
func (*AppGateway_AllocatedConnection) SetIngressPort ¶
func (x *AppGateway_AllocatedConnection) SetIngressPort(v int32)
func (*AppGateway_AllocatedConnection) SetPscUri ¶
func (x *AppGateway_AllocatedConnection) SetPscUri(v string)
func (*AppGateway_AllocatedConnection) String ¶
func (x *AppGateway_AllocatedConnection) String() string
type AppGateway_AllocatedConnection_builder ¶
type AppGateway_AllocatedConnection_builder struct {
// Required. The PSC uri of an allocated connection
PscUri string
// Required. The ingress port of an allocated connection
IngressPort int32
// contains filtered or unexported fields
}
func (AppGateway_AllocatedConnection_builder) Build ¶
func (b0 AppGateway_AllocatedConnection_builder) Build() *AppGateway_AllocatedConnection
type AppGateway_HostType ¶
type AppGateway_HostType int32
Enum containing list of all possible host types supported by BeyondCorp Connection.
const ( // Default value. This value is unused. AppGateway_HOST_TYPE_UNSPECIFIED AppGateway_HostType = 0 // AppGateway hosted in a GCP regional managed instance group. AppGateway_GCP_REGIONAL_MIG AppGateway_HostType = 1 )
func (AppGateway_HostType) Descriptor ¶
func (AppGateway_HostType) Descriptor() protoreflect.EnumDescriptor
func (AppGateway_HostType) Enum ¶
func (x AppGateway_HostType) Enum() *AppGateway_HostType
func (AppGateway_HostType) Number ¶
func (x AppGateway_HostType) Number() protoreflect.EnumNumber
func (AppGateway_HostType) String ¶
func (x AppGateway_HostType) String() string
func (AppGateway_HostType) Type ¶
func (AppGateway_HostType) Type() protoreflect.EnumType
type AppGateway_State ¶
type AppGateway_State int32
Represents the different states of an AppGateway.
const ( // Default value. This value is unused. AppGateway_STATE_UNSPECIFIED AppGateway_State = 0 // AppGateway is being created. AppGateway_CREATING AppGateway_State = 1 // AppGateway has been created. AppGateway_CREATED AppGateway_State = 2 // AppGateway's configuration is being updated. AppGateway_UPDATING AppGateway_State = 3 // AppGateway is being deleted. AppGateway_DELETING AppGateway_State = 4 // AppGateway is down and may be restored in the future. // This happens when CCFE sends ProjectState = OFF. AppGateway_DOWN AppGateway_State = 5 )
func (AppGateway_State) Descriptor ¶
func (AppGateway_State) Descriptor() protoreflect.EnumDescriptor
func (AppGateway_State) Enum ¶
func (x AppGateway_State) Enum() *AppGateway_State
func (AppGateway_State) Number ¶
func (x AppGateway_State) Number() protoreflect.EnumNumber
func (AppGateway_State) String ¶
func (x AppGateway_State) String() string
func (AppGateway_State) Type ¶
func (AppGateway_State) Type() protoreflect.EnumType
type AppGateway_Type ¶
type AppGateway_Type int32
Enum containing list of all possible network connectivity options supported by BeyondCorp AppGateway.
const ( // Default value. This value is unused. AppGateway_TYPE_UNSPECIFIED AppGateway_Type = 0 // TCP Proxy based BeyondCorp Connection. API will default to this if unset. AppGateway_TCP_PROXY AppGateway_Type = 1 )
func (AppGateway_Type) Descriptor ¶
func (AppGateway_Type) Descriptor() protoreflect.EnumDescriptor
func (AppGateway_Type) Enum ¶
func (x AppGateway_Type) Enum() *AppGateway_Type
func (AppGateway_Type) Number ¶
func (x AppGateway_Type) Number() protoreflect.EnumNumber
func (AppGateway_Type) String ¶
func (x AppGateway_Type) String() string
func (AppGateway_Type) Type ¶
func (AppGateway_Type) Type() protoreflect.EnumType
type AppGateway_builder ¶
type AppGateway_builder struct {
// Required. Unique resource name of the AppGateway.
// The name is ignored when creating an AppGateway.
Name string
// Output only. Timestamp when the resource was created.
CreateTime *timestamppb.Timestamp
// Output only. Timestamp when the resource was last modified.
UpdateTime *timestamppb.Timestamp
// Optional. Resource labels to represent user provided metadata.
Labels map[string]string
// Optional. An arbitrary user-provided name for the AppGateway. Cannot exceed
// 64 characters.
DisplayName string
// Output only. A unique identifier for the instance generated by the
// system.
Uid string
// Required. The type of network connectivity used by the AppGateway.
Type AppGateway_Type
// Output only. The current state of the AppGateway.
State AppGateway_State
// Output only. Server-defined URI for this resource.
Uri string
// Output only. A list of connections allocated for the Gateway
AllocatedConnections []*AppGateway_AllocatedConnection
// Required. The type of hosting used by the AppGateway.
HostType AppGateway_HostType
// contains filtered or unexported fields
}
func (AppGateway_builder) Build ¶
func (b0 AppGateway_builder) Build() *AppGateway
Source Files
¶
- data.pb.go
- events.pb.go