Documentation
¶
Index ¶
- Constants
- Variables
- type ArrayValue
- type ArrayValue_builder
- type Entity
- func (x *Entity) ClearKey()
- func (x *Entity) GetKey() *Key
- func (x *Entity) GetProperties() map[string]*Value
- func (x *Entity) HasKey() bool
- func (*Entity) ProtoMessage()
- func (x *Entity) ProtoReflect() protoreflect.Message
- func (x *Entity) Reset()
- func (x *Entity) SetKey(v *Key)
- func (x *Entity) SetProperties(v map[string]*Value)
- func (x *Entity) String() string
- type EntityCreatedEvent
- func (x *EntityCreatedEvent) ClearData()
- func (x *EntityCreatedEvent) GetData() *EntityEventData
- func (x *EntityCreatedEvent) HasData() bool
- func (*EntityCreatedEvent) ProtoMessage()
- func (x *EntityCreatedEvent) ProtoReflect() protoreflect.Message
- func (x *EntityCreatedEvent) Reset()
- func (x *EntityCreatedEvent) SetData(v *EntityEventData)
- func (x *EntityCreatedEvent) String() string
- type EntityCreatedEventWithAuthContext
- func (x *EntityCreatedEventWithAuthContext) ClearData()
- func (x *EntityCreatedEventWithAuthContext) GetData() *EntityEventData
- func (x *EntityCreatedEventWithAuthContext) HasData() bool
- func (*EntityCreatedEventWithAuthContext) ProtoMessage()
- func (x *EntityCreatedEventWithAuthContext) ProtoReflect() protoreflect.Message
- func (x *EntityCreatedEventWithAuthContext) Reset()
- func (x *EntityCreatedEventWithAuthContext) SetData(v *EntityEventData)
- func (x *EntityCreatedEventWithAuthContext) String() string
- type EntityCreatedEventWithAuthContext_builder
- type EntityCreatedEvent_builder
- type EntityDeletedEvent
- func (x *EntityDeletedEvent) ClearData()
- func (x *EntityDeletedEvent) GetData() *EntityEventData
- func (x *EntityDeletedEvent) HasData() bool
- func (*EntityDeletedEvent) ProtoMessage()
- func (x *EntityDeletedEvent) ProtoReflect() protoreflect.Message
- func (x *EntityDeletedEvent) Reset()
- func (x *EntityDeletedEvent) SetData(v *EntityEventData)
- func (x *EntityDeletedEvent) String() string
- type EntityDeletedEventWithAuthContext
- func (x *EntityDeletedEventWithAuthContext) ClearData()
- func (x *EntityDeletedEventWithAuthContext) GetData() *EntityEventData
- func (x *EntityDeletedEventWithAuthContext) HasData() bool
- func (*EntityDeletedEventWithAuthContext) ProtoMessage()
- func (x *EntityDeletedEventWithAuthContext) ProtoReflect() protoreflect.Message
- func (x *EntityDeletedEventWithAuthContext) Reset()
- func (x *EntityDeletedEventWithAuthContext) SetData(v *EntityEventData)
- func (x *EntityDeletedEventWithAuthContext) String() string
- type EntityDeletedEventWithAuthContext_builder
- type EntityDeletedEvent_builder
- type EntityEventData
- func (x *EntityEventData) ClearOldValue()
- func (x *EntityEventData) ClearUpdateMask()
- func (x *EntityEventData) ClearValue()
- func (x *EntityEventData) GetOldValue() *EntityResult
- func (x *EntityEventData) GetUpdateMask() *PropertyMask
- func (x *EntityEventData) GetValue() *EntityResult
- func (x *EntityEventData) HasOldValue() bool
- func (x *EntityEventData) HasUpdateMask() bool
- func (x *EntityEventData) HasValue() bool
- func (*EntityEventData) ProtoMessage()
- func (x *EntityEventData) ProtoReflect() protoreflect.Message
- func (x *EntityEventData) Reset()
- func (x *EntityEventData) SetOldValue(v *EntityResult)
- func (x *EntityEventData) SetUpdateMask(v *PropertyMask)
- func (x *EntityEventData) SetValue(v *EntityResult)
- func (x *EntityEventData) String() string
- type EntityEventData_builder
- type EntityResult
- func (x *EntityResult) ClearCreateTime()
- func (x *EntityResult) ClearEntity()
- func (x *EntityResult) ClearUpdateTime()
- func (x *EntityResult) GetCreateTime() *timestamppb.Timestamp
- func (x *EntityResult) GetCursor() []byte
- func (x *EntityResult) GetEntity() *Entity
- func (x *EntityResult) GetUpdateTime() *timestamppb.Timestamp
- func (x *EntityResult) GetVersion() int64
- func (x *EntityResult) HasCreateTime() bool
- func (x *EntityResult) HasEntity() bool
- func (x *EntityResult) HasUpdateTime() bool
- func (*EntityResult) ProtoMessage()
- func (x *EntityResult) ProtoReflect() protoreflect.Message
- func (x *EntityResult) Reset()
- func (x *EntityResult) SetCreateTime(v *timestamppb.Timestamp)
- func (x *EntityResult) SetCursor(v []byte)
- func (x *EntityResult) SetEntity(v *Entity)
- func (x *EntityResult) SetUpdateTime(v *timestamppb.Timestamp)
- func (x *EntityResult) SetVersion(v int64)
- func (x *EntityResult) String() string
- type EntityResult_ResultType
- func (EntityResult_ResultType) Descriptor() protoreflect.EnumDescriptor
- func (x EntityResult_ResultType) Enum() *EntityResult_ResultType
- func (x EntityResult_ResultType) Number() protoreflect.EnumNumber
- func (x EntityResult_ResultType) String() string
- func (EntityResult_ResultType) Type() protoreflect.EnumType
- type EntityResult_builder
- type EntityUpdatedEvent
- func (x *EntityUpdatedEvent) ClearData()
- func (x *EntityUpdatedEvent) GetData() *EntityEventData
- func (x *EntityUpdatedEvent) HasData() bool
- func (*EntityUpdatedEvent) ProtoMessage()
- func (x *EntityUpdatedEvent) ProtoReflect() protoreflect.Message
- func (x *EntityUpdatedEvent) Reset()
- func (x *EntityUpdatedEvent) SetData(v *EntityEventData)
- func (x *EntityUpdatedEvent) String() string
- type EntityUpdatedEventWithAuthContext
- func (x *EntityUpdatedEventWithAuthContext) ClearData()
- func (x *EntityUpdatedEventWithAuthContext) GetData() *EntityEventData
- func (x *EntityUpdatedEventWithAuthContext) HasData() bool
- func (*EntityUpdatedEventWithAuthContext) ProtoMessage()
- func (x *EntityUpdatedEventWithAuthContext) ProtoReflect() protoreflect.Message
- func (x *EntityUpdatedEventWithAuthContext) Reset()
- func (x *EntityUpdatedEventWithAuthContext) SetData(v *EntityEventData)
- func (x *EntityUpdatedEventWithAuthContext) String() string
- type EntityUpdatedEventWithAuthContext_builder
- type EntityUpdatedEvent_builder
- type EntityWrittenEvent
- func (x *EntityWrittenEvent) ClearData()
- func (x *EntityWrittenEvent) GetData() *EntityEventData
- func (x *EntityWrittenEvent) HasData() bool
- func (*EntityWrittenEvent) ProtoMessage()
- func (x *EntityWrittenEvent) ProtoReflect() protoreflect.Message
- func (x *EntityWrittenEvent) Reset()
- func (x *EntityWrittenEvent) SetData(v *EntityEventData)
- func (x *EntityWrittenEvent) String() string
- type EntityWrittenEventWithAuthContext
- func (x *EntityWrittenEventWithAuthContext) ClearData()
- func (x *EntityWrittenEventWithAuthContext) GetData() *EntityEventData
- func (x *EntityWrittenEventWithAuthContext) HasData() bool
- func (*EntityWrittenEventWithAuthContext) ProtoMessage()
- func (x *EntityWrittenEventWithAuthContext) ProtoReflect() protoreflect.Message
- func (x *EntityWrittenEventWithAuthContext) Reset()
- func (x *EntityWrittenEventWithAuthContext) SetData(v *EntityEventData)
- func (x *EntityWrittenEventWithAuthContext) String() string
- type EntityWrittenEventWithAuthContext_builder
- type EntityWrittenEvent_builder
- type Entity_builder
- type Key
- func (x *Key) ClearPartitionId()
- func (x *Key) GetPartitionId() *PartitionId
- func (x *Key) GetPath() []*Key_PathElement
- func (x *Key) HasPartitionId() bool
- func (*Key) ProtoMessage()
- func (x *Key) ProtoReflect() protoreflect.Message
- func (x *Key) Reset()
- func (x *Key) SetPartitionId(v *PartitionId)
- func (x *Key) SetPath(v []*Key_PathElement)
- func (x *Key) String() string
- type Key_PathElement
- func (x *Key_PathElement) ClearId()
- func (x *Key_PathElement) ClearIdType()
- func (x *Key_PathElement) ClearName()
- func (x *Key_PathElement) GetId() int64
- func (x *Key_PathElement) GetIdType() isKey_PathElement_IdType
- func (x *Key_PathElement) GetKind() string
- func (x *Key_PathElement) GetName() string
- func (x *Key_PathElement) HasId() bool
- func (x *Key_PathElement) HasIdType() bool
- func (x *Key_PathElement) HasName() bool
- func (*Key_PathElement) ProtoMessage()
- func (x *Key_PathElement) ProtoReflect() protoreflect.Message
- func (x *Key_PathElement) Reset()
- func (x *Key_PathElement) SetId(v int64)
- func (x *Key_PathElement) SetKind(v string)
- func (x *Key_PathElement) SetName(v string)
- func (x *Key_PathElement) String() string
- func (x *Key_PathElement) WhichIdType() case_Key_PathElement_IdType
- type Key_PathElement_Id
- type Key_PathElement_Name
- type Key_PathElement_builder
- type Key_builder
- type PartitionId
- func (x *PartitionId) GetDatabaseId() string
- func (x *PartitionId) GetNamespaceId() string
- func (x *PartitionId) GetProjectId() string
- func (*PartitionId) ProtoMessage()
- func (x *PartitionId) ProtoReflect() protoreflect.Message
- func (x *PartitionId) Reset()
- func (x *PartitionId) SetDatabaseId(v string)
- func (x *PartitionId) SetNamespaceId(v string)
- func (x *PartitionId) SetProjectId(v string)
- func (x *PartitionId) String() string
- type PartitionId_builder
- type PropertyMask
- type PropertyMask_builder
- type Value
- func (x *Value) ClearArrayValue()
- func (x *Value) ClearBlobValue()
- func (x *Value) ClearBooleanValue()
- func (x *Value) ClearDoubleValue()
- func (x *Value) ClearEntityValue()
- func (x *Value) ClearGeoPointValue()
- func (x *Value) ClearIntegerValue()
- func (x *Value) ClearKeyValue()
- func (x *Value) ClearNullValue()
- func (x *Value) ClearStringValue()
- func (x *Value) ClearTimestampValue()
- func (x *Value) ClearValueType()
- func (x *Value) GetArrayValue() *ArrayValue
- func (x *Value) GetBlobValue() []byte
- func (x *Value) GetBooleanValue() bool
- func (x *Value) GetDoubleValue() float64
- func (x *Value) GetEntityValue() *Entity
- func (x *Value) GetExcludeFromIndexes() bool
- func (x *Value) GetGeoPointValue() *latlng.LatLng
- func (x *Value) GetIntegerValue() int64
- func (x *Value) GetKeyValue() *Key
- func (x *Value) GetMeaning() int32
- func (x *Value) GetNullValue() structpb.NullValue
- func (x *Value) GetStringValue() string
- func (x *Value) GetTimestampValue() *timestamppb.Timestamp
- func (x *Value) GetValueType() isValue_ValueType
- func (x *Value) HasArrayValue() bool
- func (x *Value) HasBlobValue() bool
- func (x *Value) HasBooleanValue() bool
- func (x *Value) HasDoubleValue() bool
- func (x *Value) HasEntityValue() bool
- func (x *Value) HasGeoPointValue() bool
- func (x *Value) HasIntegerValue() bool
- func (x *Value) HasKeyValue() bool
- func (x *Value) HasNullValue() bool
- func (x *Value) HasStringValue() bool
- func (x *Value) HasTimestampValue() bool
- func (x *Value) HasValueType() bool
- func (*Value) ProtoMessage()
- func (x *Value) ProtoReflect() protoreflect.Message
- func (x *Value) Reset()
- func (x *Value) SetArrayValue(v *ArrayValue)
- func (x *Value) SetBlobValue(v []byte)
- func (x *Value) SetBooleanValue(v bool)
- func (x *Value) SetDoubleValue(v float64)
- func (x *Value) SetEntityValue(v *Entity)
- func (x *Value) SetExcludeFromIndexes(v bool)
- func (x *Value) SetGeoPointValue(v *latlng.LatLng)
- func (x *Value) SetIntegerValue(v int64)
- func (x *Value) SetKeyValue(v *Key)
- func (x *Value) SetMeaning(v int32)
- func (x *Value) SetNullValue(v structpb.NullValue)
- func (x *Value) SetStringValue(v string)
- func (x *Value) SetTimestampValue(v *timestamppb.Timestamp)
- func (x *Value) String() string
- func (x *Value) WhichValueType() case_Value_ValueType
- type Value_ArrayValue
- type Value_BlobValue
- type Value_BooleanValue
- type Value_DoubleValue
- type Value_EntityValue
- type Value_GeoPointValue
- type Value_IntegerValue
- type Value_KeyValue
- type Value_NullValue
- type Value_StringValue
- type Value_TimestampValue
- type Value_builder
Constants ¶
const Key_PathElement_IdType_not_set_case case_Key_PathElement_IdType = 0
const Key_PathElement_Id_case case_Key_PathElement_IdType = 2
const Key_PathElement_Name_case case_Key_PathElement_IdType = 3
const Value_ArrayValue_case case_Value_ValueType = 9
const Value_BlobValue_case case_Value_ValueType = 18
const Value_BooleanValue_case case_Value_ValueType = 1
const Value_DoubleValue_case case_Value_ValueType = 3
const Value_EntityValue_case case_Value_ValueType = 6
const Value_GeoPointValue_case case_Value_ValueType = 8
const Value_IntegerValue_case case_Value_ValueType = 2
const Value_KeyValue_case case_Value_ValueType = 5
const Value_NullValue_case case_Value_ValueType = 11
const Value_StringValue_case case_Value_ValueType = 17
const Value_TimestampValue_case case_Value_ValueType = 10
const Value_ValueType_not_set_case case_Value_ValueType = 0
Variables ¶
var ( EntityResult_ResultType_name = map[int32]string{ 0: "RESULT_TYPE_UNSPECIFIED", 1: "FULL", 2: "PROJECTION", 3: "KEY_ONLY", } EntityResult_ResultType_value = map[string]int32{ "RESULT_TYPE_UNSPECIFIED": 0, "FULL": 1, "PROJECTION": 2, "KEY_ONLY": 3, } )
Enum value maps for EntityResult_ResultType.
var File_google_events_cloud_datastore_v1_data_proto protoreflect.FileDescriptor
var File_google_events_cloud_datastore_v1_events_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type ArrayValue ¶
type ArrayValue struct {
// Values in the array.
// The order of values in an array is preserved as long as all values have
// identical settings for 'exclude_from_indexes'.
Values []*Value `protobuf:"bytes,1,rep,name=values,proto3" json:"values,omitempty"`
// contains filtered or unexported fields
}
An array value.
func (*ArrayValue) GetValues ¶
func (x *ArrayValue) GetValues() []*Value
func (*ArrayValue) ProtoMessage ¶
func (*ArrayValue) ProtoMessage()
func (*ArrayValue) ProtoReflect ¶
func (x *ArrayValue) ProtoReflect() protoreflect.Message
func (*ArrayValue) Reset ¶
func (x *ArrayValue) Reset()
func (*ArrayValue) SetValues ¶
func (x *ArrayValue) SetValues(v []*Value)
func (*ArrayValue) String ¶
func (x *ArrayValue) String() string
type ArrayValue_builder ¶
type ArrayValue_builder struct {
// Values in the array.
// The order of values in an array is preserved as long as all values have
// identical settings for 'exclude_from_indexes'.
Values []*Value
// contains filtered or unexported fields
}
func (ArrayValue_builder) Build ¶
func (b0 ArrayValue_builder) Build() *ArrayValue
type Entity ¶
type Entity struct {
// The entity's key.
//
// An entity must have a key, unless otherwise documented (for example,
// an entity in `Value.entity_value` may have no key).
// An entity's kind is its key path's last element's kind,
// or null if it has no key.
Key *Key `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
// The entity's properties.
// The map's keys are property names.
// A property name matching regex `__.*__` is reserved.
// A reserved property name is forbidden in certain documented contexts.
// The map keys, represented as UTF-8, must not exceed 1,500 bytes and cannot
// be empty.
Properties map[string]*Value `` /* 147-byte string literal not displayed */
// contains filtered or unexported fields
}
A Datastore data object.
Must not exceed 1 MiB - 4 bytes.
func (*Entity) ProtoReflect ¶
func (x *Entity) ProtoReflect() protoreflect.Message
type EntityCreatedEvent ¶
type EntityCreatedEvent struct {
// The data associated with the event.
Data *EntityEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
// contains filtered or unexported fields
}
The CloudEvent is raised when a Firestore entity is created.
func (*EntityCreatedEvent) ClearData ¶
func (x *EntityCreatedEvent) ClearData()
func (*EntityCreatedEvent) GetData ¶
func (x *EntityCreatedEvent) GetData() *EntityEventData
func (*EntityCreatedEvent) HasData ¶
func (x *EntityCreatedEvent) HasData() bool
func (*EntityCreatedEvent) ProtoMessage ¶
func (*EntityCreatedEvent) ProtoMessage()
func (*EntityCreatedEvent) ProtoReflect ¶
func (x *EntityCreatedEvent) ProtoReflect() protoreflect.Message
func (*EntityCreatedEvent) Reset ¶
func (x *EntityCreatedEvent) Reset()
func (*EntityCreatedEvent) SetData ¶
func (x *EntityCreatedEvent) SetData(v *EntityEventData)
func (*EntityCreatedEvent) String ¶
func (x *EntityCreatedEvent) String() string
type EntityCreatedEventWithAuthContext ¶
type EntityCreatedEventWithAuthContext struct {
// The data associated with the event.
Data *EntityEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
// contains filtered or unexported fields
}
The CloudEvent with Auth Context is raised when a Firestore entity is created.
func (*EntityCreatedEventWithAuthContext) ClearData ¶
func (x *EntityCreatedEventWithAuthContext) ClearData()
func (*EntityCreatedEventWithAuthContext) GetData ¶
func (x *EntityCreatedEventWithAuthContext) GetData() *EntityEventData
func (*EntityCreatedEventWithAuthContext) HasData ¶
func (x *EntityCreatedEventWithAuthContext) HasData() bool
func (*EntityCreatedEventWithAuthContext) ProtoMessage ¶
func (*EntityCreatedEventWithAuthContext) ProtoMessage()
func (*EntityCreatedEventWithAuthContext) ProtoReflect ¶
func (x *EntityCreatedEventWithAuthContext) ProtoReflect() protoreflect.Message
func (*EntityCreatedEventWithAuthContext) Reset ¶
func (x *EntityCreatedEventWithAuthContext) Reset()
func (*EntityCreatedEventWithAuthContext) SetData ¶
func (x *EntityCreatedEventWithAuthContext) SetData(v *EntityEventData)
func (*EntityCreatedEventWithAuthContext) String ¶
func (x *EntityCreatedEventWithAuthContext) String() string
type EntityCreatedEventWithAuthContext_builder ¶
type EntityCreatedEventWithAuthContext_builder struct {
// The data associated with the event.
Data *EntityEventData
// contains filtered or unexported fields
}
func (EntityCreatedEventWithAuthContext_builder) Build ¶
func (b0 EntityCreatedEventWithAuthContext_builder) Build() *EntityCreatedEventWithAuthContext
type EntityCreatedEvent_builder ¶
type EntityCreatedEvent_builder struct {
// The data associated with the event.
Data *EntityEventData
// contains filtered or unexported fields
}
func (EntityCreatedEvent_builder) Build ¶
func (b0 EntityCreatedEvent_builder) Build() *EntityCreatedEvent
type EntityDeletedEvent ¶
type EntityDeletedEvent struct {
// The data associated with the event.
Data *EntityEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
// contains filtered or unexported fields
}
The CloudEvent is raised when a Firestore entity is deleted.
func (*EntityDeletedEvent) ClearData ¶
func (x *EntityDeletedEvent) ClearData()
func (*EntityDeletedEvent) GetData ¶
func (x *EntityDeletedEvent) GetData() *EntityEventData
func (*EntityDeletedEvent) HasData ¶
func (x *EntityDeletedEvent) HasData() bool
func (*EntityDeletedEvent) ProtoMessage ¶
func (*EntityDeletedEvent) ProtoMessage()
func (*EntityDeletedEvent) ProtoReflect ¶
func (x *EntityDeletedEvent) ProtoReflect() protoreflect.Message
func (*EntityDeletedEvent) Reset ¶
func (x *EntityDeletedEvent) Reset()
func (*EntityDeletedEvent) SetData ¶
func (x *EntityDeletedEvent) SetData(v *EntityEventData)
func (*EntityDeletedEvent) String ¶
func (x *EntityDeletedEvent) String() string
type EntityDeletedEventWithAuthContext ¶
type EntityDeletedEventWithAuthContext struct {
// The data associated with the event.
Data *EntityEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
// contains filtered or unexported fields
}
The CloudEvent with Auth Context is raised when a Firestore entity is deleted.
func (*EntityDeletedEventWithAuthContext) ClearData ¶
func (x *EntityDeletedEventWithAuthContext) ClearData()
func (*EntityDeletedEventWithAuthContext) GetData ¶
func (x *EntityDeletedEventWithAuthContext) GetData() *EntityEventData
func (*EntityDeletedEventWithAuthContext) HasData ¶
func (x *EntityDeletedEventWithAuthContext) HasData() bool
func (*EntityDeletedEventWithAuthContext) ProtoMessage ¶
func (*EntityDeletedEventWithAuthContext) ProtoMessage()
func (*EntityDeletedEventWithAuthContext) ProtoReflect ¶
func (x *EntityDeletedEventWithAuthContext) ProtoReflect() protoreflect.Message
func (*EntityDeletedEventWithAuthContext) Reset ¶
func (x *EntityDeletedEventWithAuthContext) Reset()
func (*EntityDeletedEventWithAuthContext) SetData ¶
func (x *EntityDeletedEventWithAuthContext) SetData(v *EntityEventData)
func (*EntityDeletedEventWithAuthContext) String ¶
func (x *EntityDeletedEventWithAuthContext) String() string
type EntityDeletedEventWithAuthContext_builder ¶
type EntityDeletedEventWithAuthContext_builder struct {
// The data associated with the event.
Data *EntityEventData
// contains filtered or unexported fields
}
func (EntityDeletedEventWithAuthContext_builder) Build ¶
func (b0 EntityDeletedEventWithAuthContext_builder) Build() *EntityDeletedEventWithAuthContext
type EntityDeletedEvent_builder ¶
type EntityDeletedEvent_builder struct {
// The data associated with the event.
Data *EntityEventData
// contains filtered or unexported fields
}
func (EntityDeletedEvent_builder) Build ¶
func (b0 EntityDeletedEvent_builder) Build() *EntityDeletedEvent
type EntityEventData ¶
type EntityEventData struct {
// An EntityResult object containing a post-operation entity snapshot.
// This is not populated for delete events.
Value *EntityResult `protobuf:"bytes,1,opt,name=value,proto3" json:"value,omitempty"`
// An EntityResult object containing a pre-operation entity snapshot.
// This is only populated for update and delete events.
OldValue *EntityResult `protobuf:"bytes,2,opt,name=old_value,json=oldValue,proto3" json:"old_value,omitempty"`
// A PropertyMask object that lists changed properties.
// This is only populated for update events..
UpdateMask *PropertyMask `protobuf:"bytes,3,opt,name=update_mask,json=updateMask,proto3" json:"update_mask,omitempty"`
// contains filtered or unexported fields
}
The data within all Firestore in Datastore Mode entity events.
func (*EntityEventData) ClearOldValue ¶
func (x *EntityEventData) ClearOldValue()
func (*EntityEventData) ClearUpdateMask ¶
func (x *EntityEventData) ClearUpdateMask()
func (*EntityEventData) ClearValue ¶
func (x *EntityEventData) ClearValue()
func (*EntityEventData) GetOldValue ¶
func (x *EntityEventData) GetOldValue() *EntityResult
func (*EntityEventData) GetUpdateMask ¶
func (x *EntityEventData) GetUpdateMask() *PropertyMask
func (*EntityEventData) GetValue ¶
func (x *EntityEventData) GetValue() *EntityResult
func (*EntityEventData) HasOldValue ¶
func (x *EntityEventData) HasOldValue() bool
func (*EntityEventData) HasUpdateMask ¶
func (x *EntityEventData) HasUpdateMask() bool
func (*EntityEventData) HasValue ¶
func (x *EntityEventData) HasValue() bool
func (*EntityEventData) ProtoMessage ¶
func (*EntityEventData) ProtoMessage()
func (*EntityEventData) ProtoReflect ¶
func (x *EntityEventData) ProtoReflect() protoreflect.Message
func (*EntityEventData) Reset ¶
func (x *EntityEventData) Reset()
func (*EntityEventData) SetOldValue ¶
func (x *EntityEventData) SetOldValue(v *EntityResult)
func (*EntityEventData) SetUpdateMask ¶
func (x *EntityEventData) SetUpdateMask(v *PropertyMask)
func (*EntityEventData) SetValue ¶
func (x *EntityEventData) SetValue(v *EntityResult)
func (*EntityEventData) String ¶
func (x *EntityEventData) String() string
type EntityEventData_builder ¶
type EntityEventData_builder struct {
// An EntityResult object containing a post-operation entity snapshot.
// This is not populated for delete events.
Value *EntityResult
// An EntityResult object containing a pre-operation entity snapshot.
// This is only populated for update and delete events.
OldValue *EntityResult
// A PropertyMask object that lists changed properties.
// This is only populated for update events..
UpdateMask *PropertyMask
// contains filtered or unexported fields
}
func (EntityEventData_builder) Build ¶
func (b0 EntityEventData_builder) Build() *EntityEventData
type EntityResult ¶
type EntityResult struct {
// The resulting entity.
Entity *Entity `protobuf:"bytes,1,opt,name=entity,proto3" json:"entity,omitempty"`
// The version of the entity, a strictly positive number that monotonically
// increases with changes to the entity.
//
// This field is set for
// [`FULL`][google.datastore.v1.EntityResult.ResultType.FULL] entity results.
//
// For [missing][google.datastore.v1.LookupResponse.missing] entities in
// `LookupResponse`, this is the version of the snapshot that was used to look
// up the entity, and it is always set except for eventually consistent reads.
Version int64 `protobuf:"varint,4,opt,name=version,proto3" json:"version,omitempty"`
// The time at which the entity was created.
// This field is set for
// [`FULL`][google.datastore.v1.EntityResult.ResultType.FULL] entity results.
// If this entity is missing, this field will not be set.
CreateTime *timestamppb.Timestamp `protobuf:"bytes,6,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
// The time at which the entity was last changed.
// This field is set for
// [`FULL`][google.datastore.v1.EntityResult.ResultType.FULL] entity results.
// If this entity is missing, this field will not be set.
UpdateTime *timestamppb.Timestamp `protobuf:"bytes,5,opt,name=update_time,json=updateTime,proto3" json:"update_time,omitempty"`
// A cursor that points to the position after the result entity.
// Set only when the `EntityResult` is part of a `QueryResultBatch` message.
Cursor []byte `protobuf:"bytes,3,opt,name=cursor,proto3" json:"cursor,omitempty"`
// contains filtered or unexported fields
}
The result of fetching an entity from Datastore.
func (*EntityResult) ClearCreateTime ¶
func (x *EntityResult) ClearCreateTime()
func (*EntityResult) ClearEntity ¶
func (x *EntityResult) ClearEntity()
func (*EntityResult) ClearUpdateTime ¶
func (x *EntityResult) ClearUpdateTime()
func (*EntityResult) GetCreateTime ¶
func (x *EntityResult) GetCreateTime() *timestamppb.Timestamp
func (*EntityResult) GetCursor ¶
func (x *EntityResult) GetCursor() []byte
func (*EntityResult) GetEntity ¶
func (x *EntityResult) GetEntity() *Entity
func (*EntityResult) GetUpdateTime ¶
func (x *EntityResult) GetUpdateTime() *timestamppb.Timestamp
func (*EntityResult) GetVersion ¶
func (x *EntityResult) GetVersion() int64
func (*EntityResult) HasCreateTime ¶
func (x *EntityResult) HasCreateTime() bool
func (*EntityResult) HasEntity ¶
func (x *EntityResult) HasEntity() bool
func (*EntityResult) HasUpdateTime ¶
func (x *EntityResult) HasUpdateTime() bool
func (*EntityResult) ProtoMessage ¶
func (*EntityResult) ProtoMessage()
func (*EntityResult) ProtoReflect ¶
func (x *EntityResult) ProtoReflect() protoreflect.Message
func (*EntityResult) Reset ¶
func (x *EntityResult) Reset()
func (*EntityResult) SetCreateTime ¶
func (x *EntityResult) SetCreateTime(v *timestamppb.Timestamp)
func (*EntityResult) SetCursor ¶
func (x *EntityResult) SetCursor(v []byte)
func (*EntityResult) SetEntity ¶
func (x *EntityResult) SetEntity(v *Entity)
func (*EntityResult) SetUpdateTime ¶
func (x *EntityResult) SetUpdateTime(v *timestamppb.Timestamp)
func (*EntityResult) SetVersion ¶
func (x *EntityResult) SetVersion(v int64)
func (*EntityResult) String ¶
func (x *EntityResult) String() string
type EntityResult_ResultType ¶
type EntityResult_ResultType int32
Specifies what data the 'entity' field contains. A `ResultType` is either implied (for example, in `LookupResponse.missing` from `datastore.proto`, it is always `KEY_ONLY`) or specified by context (for example, in message `QueryResultBatch`, field `entity_result_type` specifies a `ResultType` for all the values in field `entity_results`).
const ( // Unspecified. This value is never used. EntityResult_RESULT_TYPE_UNSPECIFIED EntityResult_ResultType = 0 // The key and properties. EntityResult_FULL EntityResult_ResultType = 1 // A projected subset of properties. The entity may have no key. EntityResult_PROJECTION EntityResult_ResultType = 2 // Only the key. EntityResult_KEY_ONLY EntityResult_ResultType = 3 )
func (EntityResult_ResultType) Descriptor ¶
func (EntityResult_ResultType) Descriptor() protoreflect.EnumDescriptor
func (EntityResult_ResultType) Enum ¶
func (x EntityResult_ResultType) Enum() *EntityResult_ResultType
func (EntityResult_ResultType) Number ¶
func (x EntityResult_ResultType) Number() protoreflect.EnumNumber
func (EntityResult_ResultType) String ¶
func (x EntityResult_ResultType) String() string
func (EntityResult_ResultType) Type ¶
func (EntityResult_ResultType) Type() protoreflect.EnumType
type EntityResult_builder ¶
type EntityResult_builder struct {
// The resulting entity.
Entity *Entity
// The version of the entity, a strictly positive number that monotonically
// increases with changes to the entity.
//
// This field is set for
// [`FULL`][google.datastore.v1.EntityResult.ResultType.FULL] entity results.
//
// For [missing][google.datastore.v1.LookupResponse.missing] entities in
// `LookupResponse`, this is the version of the snapshot that was used to look
// up the entity, and it is always set except for eventually consistent reads.
Version int64
// The time at which the entity was created.
// This field is set for
// [`FULL`][google.datastore.v1.EntityResult.ResultType.FULL] entity results.
// If this entity is missing, this field will not be set.
CreateTime *timestamppb.Timestamp
// The time at which the entity was last changed.
// This field is set for
// [`FULL`][google.datastore.v1.EntityResult.ResultType.FULL] entity results.
// If this entity is missing, this field will not be set.
UpdateTime *timestamppb.Timestamp
// A cursor that points to the position after the result entity.
// Set only when the `EntityResult` is part of a `QueryResultBatch` message.
Cursor []byte
// contains filtered or unexported fields
}
func (EntityResult_builder) Build ¶
func (b0 EntityResult_builder) Build() *EntityResult
type EntityUpdatedEvent ¶
type EntityUpdatedEvent struct {
// The data associated with the event.
Data *EntityEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
// contains filtered or unexported fields
}
The CloudEvent is raised when a Firestore entity is updated.
func (*EntityUpdatedEvent) ClearData ¶
func (x *EntityUpdatedEvent) ClearData()
func (*EntityUpdatedEvent) GetData ¶
func (x *EntityUpdatedEvent) GetData() *EntityEventData
func (*EntityUpdatedEvent) HasData ¶
func (x *EntityUpdatedEvent) HasData() bool
func (*EntityUpdatedEvent) ProtoMessage ¶
func (*EntityUpdatedEvent) ProtoMessage()
func (*EntityUpdatedEvent) ProtoReflect ¶
func (x *EntityUpdatedEvent) ProtoReflect() protoreflect.Message
func (*EntityUpdatedEvent) Reset ¶
func (x *EntityUpdatedEvent) Reset()
func (*EntityUpdatedEvent) SetData ¶
func (x *EntityUpdatedEvent) SetData(v *EntityEventData)
func (*EntityUpdatedEvent) String ¶
func (x *EntityUpdatedEvent) String() string
type EntityUpdatedEventWithAuthContext ¶
type EntityUpdatedEventWithAuthContext struct {
// The data associated with the event.
Data *EntityEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
// contains filtered or unexported fields
}
The CloudEvent with Auth Context is raised when a Firestore entity is updated.
func (*EntityUpdatedEventWithAuthContext) ClearData ¶
func (x *EntityUpdatedEventWithAuthContext) ClearData()
func (*EntityUpdatedEventWithAuthContext) GetData ¶
func (x *EntityUpdatedEventWithAuthContext) GetData() *EntityEventData
func (*EntityUpdatedEventWithAuthContext) HasData ¶
func (x *EntityUpdatedEventWithAuthContext) HasData() bool
func (*EntityUpdatedEventWithAuthContext) ProtoMessage ¶
func (*EntityUpdatedEventWithAuthContext) ProtoMessage()
func (*EntityUpdatedEventWithAuthContext) ProtoReflect ¶
func (x *EntityUpdatedEventWithAuthContext) ProtoReflect() protoreflect.Message
func (*EntityUpdatedEventWithAuthContext) Reset ¶
func (x *EntityUpdatedEventWithAuthContext) Reset()
func (*EntityUpdatedEventWithAuthContext) SetData ¶
func (x *EntityUpdatedEventWithAuthContext) SetData(v *EntityEventData)
func (*EntityUpdatedEventWithAuthContext) String ¶
func (x *EntityUpdatedEventWithAuthContext) String() string
type EntityUpdatedEventWithAuthContext_builder ¶
type EntityUpdatedEventWithAuthContext_builder struct {
// The data associated with the event.
Data *EntityEventData
// contains filtered or unexported fields
}
func (EntityUpdatedEventWithAuthContext_builder) Build ¶
func (b0 EntityUpdatedEventWithAuthContext_builder) Build() *EntityUpdatedEventWithAuthContext
type EntityUpdatedEvent_builder ¶
type EntityUpdatedEvent_builder struct {
// The data associated with the event.
Data *EntityEventData
// contains filtered or unexported fields
}
func (EntityUpdatedEvent_builder) Build ¶
func (b0 EntityUpdatedEvent_builder) Build() *EntityUpdatedEvent
type EntityWrittenEvent ¶
type EntityWrittenEvent struct {
// The data associated with the event.
Data *EntityEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
// contains filtered or unexported fields
}
The CloudEvent is raised when a Firestore entity is created, updated or deleted.
func (*EntityWrittenEvent) ClearData ¶
func (x *EntityWrittenEvent) ClearData()
func (*EntityWrittenEvent) GetData ¶
func (x *EntityWrittenEvent) GetData() *EntityEventData
func (*EntityWrittenEvent) HasData ¶
func (x *EntityWrittenEvent) HasData() bool
func (*EntityWrittenEvent) ProtoMessage ¶
func (*EntityWrittenEvent) ProtoMessage()
func (*EntityWrittenEvent) ProtoReflect ¶
func (x *EntityWrittenEvent) ProtoReflect() protoreflect.Message
func (*EntityWrittenEvent) Reset ¶
func (x *EntityWrittenEvent) Reset()
func (*EntityWrittenEvent) SetData ¶
func (x *EntityWrittenEvent) SetData(v *EntityEventData)
func (*EntityWrittenEvent) String ¶
func (x *EntityWrittenEvent) String() string
type EntityWrittenEventWithAuthContext ¶
type EntityWrittenEventWithAuthContext struct {
// The data associated with the event.
Data *EntityEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
// contains filtered or unexported fields
}
The CloudEvent with Auth Context is raised when a Firestore entity is created, updated or deleted.
func (*EntityWrittenEventWithAuthContext) ClearData ¶
func (x *EntityWrittenEventWithAuthContext) ClearData()
func (*EntityWrittenEventWithAuthContext) GetData ¶
func (x *EntityWrittenEventWithAuthContext) GetData() *EntityEventData
func (*EntityWrittenEventWithAuthContext) HasData ¶
func (x *EntityWrittenEventWithAuthContext) HasData() bool
func (*EntityWrittenEventWithAuthContext) ProtoMessage ¶
func (*EntityWrittenEventWithAuthContext) ProtoMessage()
func (*EntityWrittenEventWithAuthContext) ProtoReflect ¶
func (x *EntityWrittenEventWithAuthContext) ProtoReflect() protoreflect.Message
func (*EntityWrittenEventWithAuthContext) Reset ¶
func (x *EntityWrittenEventWithAuthContext) Reset()
func (*EntityWrittenEventWithAuthContext) SetData ¶
func (x *EntityWrittenEventWithAuthContext) SetData(v *EntityEventData)
func (*EntityWrittenEventWithAuthContext) String ¶
func (x *EntityWrittenEventWithAuthContext) String() string
type EntityWrittenEventWithAuthContext_builder ¶
type EntityWrittenEventWithAuthContext_builder struct {
// The data associated with the event.
Data *EntityEventData
// contains filtered or unexported fields
}
func (EntityWrittenEventWithAuthContext_builder) Build ¶
func (b0 EntityWrittenEventWithAuthContext_builder) Build() *EntityWrittenEventWithAuthContext
type EntityWrittenEvent_builder ¶
type EntityWrittenEvent_builder struct {
// The data associated with the event.
Data *EntityEventData
// contains filtered or unexported fields
}
func (EntityWrittenEvent_builder) Build ¶
func (b0 EntityWrittenEvent_builder) Build() *EntityWrittenEvent
type Entity_builder ¶
type Entity_builder struct {
// The entity's key.
//
// An entity must have a key, unless otherwise documented (for example,
// an entity in `Value.entity_value` may have no key).
// An entity's kind is its key path's last element's kind,
// or null if it has no key.
Key *Key
// The entity's properties.
// The map's keys are property names.
// A property name matching regex `__.*__` is reserved.
// A reserved property name is forbidden in certain documented contexts.
// The map keys, represented as UTF-8, must not exceed 1,500 bytes and cannot
// be empty.
Properties map[string]*Value
// contains filtered or unexported fields
}
func (Entity_builder) Build ¶
func (b0 Entity_builder) Build() *Entity
type Key ¶
type Key struct {
// Entities are partitioned into subsets, currently identified by a project
// ID and namespace ID.
// Queries are scoped to a single partition.
PartitionId *PartitionId `protobuf:"bytes,1,opt,name=partition_id,json=partitionId,proto3" json:"partition_id,omitempty"`
// The entity path.
// An entity path consists of one or more elements composed of a kind and a
// string or numerical identifier, which identify entities. The first
// element identifies a _root entity_, the second element identifies
// a _child_ of the root entity, the third element identifies a child of the
// second entity, and so forth. The entities identified by all prefixes of
// the path are called the element's _ancestors_.
//
// An entity path is always fully complete: *all* of the entity's ancestors
// are required to be in the path along with the entity identifier itself.
// The only exception is that in some documented cases, the identifier in the
// last path element (for the entity) itself may be omitted. For example,
// the last path element of the key of `Mutation.insert` may have no
// identifier.
//
// A path can never be empty, and a path can have at most 100 elements.
Path []*Key_PathElement `protobuf:"bytes,2,rep,name=path,proto3" json:"path,omitempty"`
// contains filtered or unexported fields
}
A unique identifier for an entity. If a key's partition ID or any of its path kinds or names are reserved/read-only, the key is reserved/read-only. A reserved/read-only key is forbidden in certain documented contexts.
func (*Key) GetPartitionId ¶
func (x *Key) GetPartitionId() *PartitionId
func (*Key) GetPath ¶
func (x *Key) GetPath() []*Key_PathElement
func (*Key) ProtoReflect ¶
func (x *Key) ProtoReflect() protoreflect.Message
func (*Key) SetPartitionId ¶
func (x *Key) SetPartitionId(v *PartitionId)
func (*Key) SetPath ¶
func (x *Key) SetPath(v []*Key_PathElement)
type Key_PathElement ¶
type Key_PathElement struct {
// The kind of the entity.
//
// A kind matching regex `__.*__` is reserved/read-only.
// A kind must not contain more than 1500 bytes when UTF-8 encoded.
// Cannot be `""`.
//
// Must be valid UTF-8 bytes. Legacy values that are not valid UTF-8 are
// encoded as `__bytes<X>__` where `<X>` is the base-64 encoding of the
// bytes.
Kind string `protobuf:"bytes,1,opt,name=kind,proto3" json:"kind,omitempty"`
// The type of ID.
//
// Types that are valid to be assigned to IdType:
//
// *Key_PathElement_Id
// *Key_PathElement_Name
IdType isKey_PathElement_IdType `protobuf_oneof:"id_type"`
// contains filtered or unexported fields
}
A (kind, ID/name) pair used to construct a key path.
If either name or ID is set, the element is complete. If neither is set, the element is incomplete.
func (*Key_PathElement) ClearId ¶
func (x *Key_PathElement) ClearId()
func (*Key_PathElement) ClearIdType ¶
func (x *Key_PathElement) ClearIdType()
func (*Key_PathElement) ClearName ¶
func (x *Key_PathElement) ClearName()
func (*Key_PathElement) GetId ¶
func (x *Key_PathElement) GetId() int64
func (*Key_PathElement) GetIdType ¶
func (x *Key_PathElement) GetIdType() isKey_PathElement_IdType
func (*Key_PathElement) GetKind ¶
func (x *Key_PathElement) GetKind() string
func (*Key_PathElement) GetName ¶
func (x *Key_PathElement) GetName() string
func (*Key_PathElement) HasId ¶
func (x *Key_PathElement) HasId() bool
func (*Key_PathElement) HasIdType ¶
func (x *Key_PathElement) HasIdType() bool
func (*Key_PathElement) HasName ¶
func (x *Key_PathElement) HasName() bool
func (*Key_PathElement) ProtoMessage ¶
func (*Key_PathElement) ProtoMessage()
func (*Key_PathElement) ProtoReflect ¶
func (x *Key_PathElement) ProtoReflect() protoreflect.Message
func (*Key_PathElement) Reset ¶
func (x *Key_PathElement) Reset()
func (*Key_PathElement) SetId ¶
func (x *Key_PathElement) SetId(v int64)
func (*Key_PathElement) SetKind ¶
func (x *Key_PathElement) SetKind(v string)
func (*Key_PathElement) SetName ¶
func (x *Key_PathElement) SetName(v string)
func (*Key_PathElement) String ¶
func (x *Key_PathElement) String() string
func (*Key_PathElement) WhichIdType ¶
func (x *Key_PathElement) WhichIdType() case_Key_PathElement_IdType
type Key_PathElement_Id ¶
type Key_PathElement_Id struct {
// The auto-allocated ID of the entity.
//
// Never equal to zero. Values less than zero are discouraged and may not
// be supported in the future.
Id int64 `protobuf:"varint,2,opt,name=id,proto3,oneof"`
}
type Key_PathElement_Name ¶
type Key_PathElement_Name struct {
// The name of the entity.
//
// A name matching regex `__.*__` is reserved/read-only.
// A name must not be more than 1500 bytes when UTF-8 encoded.
// Cannot be `""`.
//
// Must be valid UTF-8 bytes. Legacy values that are not valid UTF-8 are
// encoded as `__bytes<X>__` where `<X>` is the base-64 encoding of the
// bytes.
Name string `protobuf:"bytes,3,opt,name=name,proto3,oneof"`
}
type Key_PathElement_builder ¶
type Key_PathElement_builder struct {
// The kind of the entity.
//
// A kind matching regex `__.*__` is reserved/read-only.
// A kind must not contain more than 1500 bytes when UTF-8 encoded.
// Cannot be `""`.
//
// Must be valid UTF-8 bytes. Legacy values that are not valid UTF-8 are
// encoded as `__bytes<X>__` where `<X>` is the base-64 encoding of the
// bytes.
Kind string
// Fields of oneof IdType:
// The auto-allocated ID of the entity.
//
// Never equal to zero. Values less than zero are discouraged and may not
// be supported in the future.
Id *int64
// The name of the entity.
//
// A name matching regex `__.*__` is reserved/read-only.
// A name must not be more than 1500 bytes when UTF-8 encoded.
// Cannot be `""`.
//
// Must be valid UTF-8 bytes. Legacy values that are not valid UTF-8 are
// encoded as `__bytes<X>__` where `<X>` is the base-64 encoding of the
// bytes.
Name *string
// contains filtered or unexported fields
}
func (Key_PathElement_builder) Build ¶
func (b0 Key_PathElement_builder) Build() *Key_PathElement
type Key_builder ¶
type Key_builder struct {
// Entities are partitioned into subsets, currently identified by a project
// ID and namespace ID.
// Queries are scoped to a single partition.
PartitionId *PartitionId
// The entity path.
// An entity path consists of one or more elements composed of a kind and a
// string or numerical identifier, which identify entities. The first
// element identifies a _root entity_, the second element identifies
// a _child_ of the root entity, the third element identifies a child of the
// second entity, and so forth. The entities identified by all prefixes of
// the path are called the element's _ancestors_.
//
// An entity path is always fully complete: *all* of the entity's ancestors
// are required to be in the path along with the entity identifier itself.
// The only exception is that in some documented cases, the identifier in the
// last path element (for the entity) itself may be omitted. For example,
// the last path element of the key of `Mutation.insert` may have no
// identifier.
//
// A path can never be empty, and a path can have at most 100 elements.
Path []*Key_PathElement
// contains filtered or unexported fields
}
func (Key_builder) Build ¶
func (b0 Key_builder) Build() *Key
type PartitionId ¶
type PartitionId struct {
// The ID of the project to which the entities belong.
ProjectId string `protobuf:"bytes,2,opt,name=project_id,json=projectId,proto3" json:"project_id,omitempty"`
// If not empty, the ID of the database to which the entities
// belong.
DatabaseId string `protobuf:"bytes,3,opt,name=database_id,json=databaseId,proto3" json:"database_id,omitempty"`
// If not empty, the ID of the namespace to which the entities belong.
NamespaceId string `protobuf:"bytes,4,opt,name=namespace_id,json=namespaceId,proto3" json:"namespace_id,omitempty"`
// contains filtered or unexported fields
}
A partition ID identifies a grouping of entities. The grouping is always by project and namespace, however the namespace ID may be empty.
A partition ID contains several dimensions: project ID and namespace ID.
Partition dimensions:
- May be `""`. - Must be valid UTF-8 bytes. - Must have values that match regex `[A-Za-z\d\.\-_]{1,100}` If the value of any dimension matches regex `__.*__`, the partition is reserved/read-only. A reserved/read-only partition ID is forbidden in certain documented contexts.
Foreign partition IDs (in which the project ID does not match the context project ID ) are discouraged. Reads and writes of foreign partition IDs may fail if the project is not in an active state.
func (*PartitionId) GetDatabaseId ¶
func (x *PartitionId) GetDatabaseId() string
func (*PartitionId) GetNamespaceId ¶
func (x *PartitionId) GetNamespaceId() string
func (*PartitionId) GetProjectId ¶
func (x *PartitionId) GetProjectId() string
func (*PartitionId) ProtoMessage ¶
func (*PartitionId) ProtoMessage()
func (*PartitionId) ProtoReflect ¶
func (x *PartitionId) ProtoReflect() protoreflect.Message
func (*PartitionId) Reset ¶
func (x *PartitionId) Reset()
func (*PartitionId) SetDatabaseId ¶
func (x *PartitionId) SetDatabaseId(v string)
func (*PartitionId) SetNamespaceId ¶
func (x *PartitionId) SetNamespaceId(v string)
func (*PartitionId) SetProjectId ¶
func (x *PartitionId) SetProjectId(v string)
func (*PartitionId) String ¶
func (x *PartitionId) String() string
type PartitionId_builder ¶
type PartitionId_builder struct {
// The ID of the project to which the entities belong.
ProjectId string
// If not empty, the ID of the database to which the entities
// belong.
DatabaseId string
// If not empty, the ID of the namespace to which the entities belong.
NamespaceId string
// contains filtered or unexported fields
}
func (PartitionId_builder) Build ¶
func (b0 PartitionId_builder) Build() *PartitionId
type PropertyMask ¶
type PropertyMask struct {
// The list of property paths in the mask.
// This is not populated for delete events.
PropertyPaths []string `protobuf:"bytes,1,rep,name=property_paths,json=propertyPaths,proto3" json:"property_paths,omitempty"`
// contains filtered or unexported fields
}
A set of property paths on an entity.
func (*PropertyMask) GetPropertyPaths ¶
func (x *PropertyMask) GetPropertyPaths() []string
func (*PropertyMask) ProtoMessage ¶
func (*PropertyMask) ProtoMessage()
func (*PropertyMask) ProtoReflect ¶
func (x *PropertyMask) ProtoReflect() protoreflect.Message
func (*PropertyMask) Reset ¶
func (x *PropertyMask) Reset()
func (*PropertyMask) SetPropertyPaths ¶
func (x *PropertyMask) SetPropertyPaths(v []string)
func (*PropertyMask) String ¶
func (x *PropertyMask) String() string
type PropertyMask_builder ¶
type PropertyMask_builder struct {
// The list of property paths in the mask.
// This is not populated for delete events.
PropertyPaths []string
// contains filtered or unexported fields
}
func (PropertyMask_builder) Build ¶
func (b0 PropertyMask_builder) Build() *PropertyMask
type Value ¶
type Value struct {
// Must have a value set.
//
// Types that are valid to be assigned to ValueType:
//
// *Value_NullValue
// *Value_BooleanValue
// *Value_IntegerValue
// *Value_DoubleValue
// *Value_TimestampValue
// *Value_KeyValue
// *Value_StringValue
// *Value_BlobValue
// *Value_GeoPointValue
// *Value_EntityValue
// *Value_ArrayValue
ValueType isValue_ValueType `protobuf_oneof:"value_type"`
// The `meaning` field should only be populated for backwards compatibility.
Meaning int32 `protobuf:"varint,14,opt,name=meaning,proto3" json:"meaning,omitempty"`
// If the value should be excluded from all indexes including those defined
// explicitly.
ExcludeFromIndexes bool `protobuf:"varint,19,opt,name=exclude_from_indexes,json=excludeFromIndexes,proto3" json:"exclude_from_indexes,omitempty"`
// contains filtered or unexported fields
}
A message that can hold any of the supported value types and associated metadata.
func (*Value) GetArrayValue ¶
func (x *Value) GetArrayValue() *ArrayValue
func (*Value) GetTimestampValue ¶
func (x *Value) GetTimestampValue() *timestamppb.Timestamp
func (*Value) ProtoReflect ¶
func (x *Value) ProtoReflect() protoreflect.Message
func (*Value) SetArrayValue ¶
func (x *Value) SetArrayValue(v *ArrayValue)
func (*Value) SetTimestampValue ¶
func (x *Value) SetTimestampValue(v *timestamppb.Timestamp)
type Value_ArrayValue ¶
type Value_ArrayValue struct {
// An array value.
// Cannot contain another array value.
// A `Value` instance that sets field `array_value` must not set fields
// `meaning` or `exclude_from_indexes`.
ArrayValue *ArrayValue `protobuf:"bytes,9,opt,name=array_value,json=arrayValue,proto3,oneof"`
}
type Value_BlobValue ¶
type Value_BlobValue struct {
// A blob value.
// May have at most 1,000,000 bytes.
// When `exclude_from_indexes` is false, may have at most 1500 bytes.
// In JSON requests, must be base64-encoded.
BlobValue []byte `protobuf:"bytes,18,opt,name=blob_value,json=blobValue,proto3,oneof"`
}
type Value_BooleanValue ¶
type Value_BooleanValue struct {
// A boolean value.
BooleanValue bool `protobuf:"varint,1,opt,name=boolean_value,json=booleanValue,proto3,oneof"`
}
type Value_DoubleValue ¶
type Value_DoubleValue struct {
// A double value.
DoubleValue float64 `protobuf:"fixed64,3,opt,name=double_value,json=doubleValue,proto3,oneof"`
}
type Value_EntityValue ¶
type Value_EntityValue struct {
// An entity value.
//
// - May have no key.
// - May have a key with an incomplete key path.
// - May have a reserved/read-only key.
EntityValue *Entity `protobuf:"bytes,6,opt,name=entity_value,json=entityValue,proto3,oneof"`
}
type Value_GeoPointValue ¶
type Value_IntegerValue ¶
type Value_IntegerValue struct {
// An integer value.
IntegerValue int64 `protobuf:"varint,2,opt,name=integer_value,json=integerValue,proto3,oneof"`
}
type Value_KeyValue ¶
type Value_KeyValue struct {
// A key value.
KeyValue *Key `protobuf:"bytes,5,opt,name=key_value,json=keyValue,proto3,oneof"`
}
type Value_NullValue ¶
type Value_StringValue ¶
type Value_StringValue struct {
// A UTF-8 encoded string value.
// When `exclude_from_indexes` is false (it is indexed) , may have at most
// 1500 bytes. Otherwise, may be set to at most 1,000,000 bytes.
StringValue string `protobuf:"bytes,17,opt,name=string_value,json=stringValue,proto3,oneof"`
}
type Value_TimestampValue ¶
type Value_TimestampValue struct {
// A timestamp value.
// When stored in the Datastore, precise only to microseconds;
// any additional precision is rounded down.
TimestampValue *timestamppb.Timestamp `protobuf:"bytes,10,opt,name=timestamp_value,json=timestampValue,proto3,oneof"`
}
type Value_builder ¶
type Value_builder struct {
// Fields of oneof ValueType:
// A null value.
NullValue *structpb.NullValue
// A boolean value.
BooleanValue *bool
// An integer value.
IntegerValue *int64
// A double value.
DoubleValue *float64
// A timestamp value.
// When stored in the Datastore, precise only to microseconds;
// any additional precision is rounded down.
TimestampValue *timestamppb.Timestamp
// A key value.
KeyValue *Key
// A UTF-8 encoded string value.
// When `exclude_from_indexes` is false (it is indexed) , may have at most
// 1500 bytes. Otherwise, may be set to at most 1,000,000 bytes.
StringValue *string
// A blob value.
// May have at most 1,000,000 bytes.
// When `exclude_from_indexes` is false, may have at most 1500 bytes.
// In JSON requests, must be base64-encoded.
BlobValue []byte
// A geo point value representing a point on the surface of Earth.
GeoPointValue *latlng.LatLng
// An entity value.
//
// - May have no key.
// - May have a key with an incomplete key path.
// - May have a reserved/read-only key.
EntityValue *Entity
// An array value.
// Cannot contain another array value.
// A `Value` instance that sets field `array_value` must not set fields
// `meaning` or `exclude_from_indexes`.
ArrayValue *ArrayValue
// -- end of ValueType
// The `meaning` field should only be populated for backwards compatibility.
Meaning int32
// If the value should be excluded from all indexes including those defined
// explicitly.
ExcludeFromIndexes bool
// contains filtered or unexported fields
}
func (Value_builder) Build ¶
func (b0 Value_builder) Build() *Value
Source Files
¶
- data.pb.go
- events.pb.go