Documentation
¶
Index ¶
- Variables
- type CustomClass
- func (x *CustomClass) ClearDeleteTime()
- func (x *CustomClass) ClearExpireTime()
- func (x *CustomClass) GetAnnotations() map[string]string
- func (x *CustomClass) GetCustomClassId() string
- func (x *CustomClass) GetDeleteTime() *timestamppb.Timestamp
- func (x *CustomClass) GetDisplayName() string
- func (x *CustomClass) GetEtag() string
- func (x *CustomClass) GetExpireTime() *timestamppb.Timestamp
- func (x *CustomClass) GetItems() []*CustomClass_ClassItem
- func (x *CustomClass) GetKmsKeyName() string
- func (x *CustomClass) GetKmsKeyVersionName() string
- func (x *CustomClass) GetName() string
- func (x *CustomClass) GetReconciling() bool
- func (x *CustomClass) GetState() CustomClass_State
- func (x *CustomClass) GetUid() string
- func (x *CustomClass) HasDeleteTime() bool
- func (x *CustomClass) HasExpireTime() bool
- func (*CustomClass) ProtoMessage()
- func (x *CustomClass) ProtoReflect() protoreflect.Message
- func (x *CustomClass) Reset()
- func (x *CustomClass) SetAnnotations(v map[string]string)
- func (x *CustomClass) SetCustomClassId(v string)
- func (x *CustomClass) SetDeleteTime(v *timestamppb.Timestamp)
- func (x *CustomClass) SetDisplayName(v string)
- func (x *CustomClass) SetEtag(v string)
- func (x *CustomClass) SetExpireTime(v *timestamppb.Timestamp)
- func (x *CustomClass) SetItems(v []*CustomClass_ClassItem)
- func (x *CustomClass) SetKmsKeyName(v string)
- func (x *CustomClass) SetKmsKeyVersionName(v string)
- func (x *CustomClass) SetName(v string)
- func (x *CustomClass) SetReconciling(v bool)
- func (x *CustomClass) SetState(v CustomClass_State)
- func (x *CustomClass) SetUid(v string)
- func (x *CustomClass) String() string
- type CustomClassCreatedEvent
- func (x *CustomClassCreatedEvent) ClearData()
- func (x *CustomClassCreatedEvent) GetData() *CustomClassEventData
- func (x *CustomClassCreatedEvent) HasData() bool
- func (*CustomClassCreatedEvent) ProtoMessage()
- func (x *CustomClassCreatedEvent) ProtoReflect() protoreflect.Message
- func (x *CustomClassCreatedEvent) Reset()
- func (x *CustomClassCreatedEvent) SetData(v *CustomClassEventData)
- func (x *CustomClassCreatedEvent) String() string
- type CustomClassCreatedEvent_builder
- type CustomClassDeletedEvent
- func (x *CustomClassDeletedEvent) ClearData()
- func (x *CustomClassDeletedEvent) GetData() *CustomClassEventData
- func (x *CustomClassDeletedEvent) HasData() bool
- func (*CustomClassDeletedEvent) ProtoMessage()
- func (x *CustomClassDeletedEvent) ProtoReflect() protoreflect.Message
- func (x *CustomClassDeletedEvent) Reset()
- func (x *CustomClassDeletedEvent) SetData(v *CustomClassEventData)
- func (x *CustomClassDeletedEvent) String() string
- type CustomClassDeletedEvent_builder
- type CustomClassEventData
- func (x *CustomClassEventData) ClearPayload()
- func (x *CustomClassEventData) GetPayload() *CustomClass
- func (x *CustomClassEventData) HasPayload() bool
- func (*CustomClassEventData) ProtoMessage()
- func (x *CustomClassEventData) ProtoReflect() protoreflect.Message
- func (x *CustomClassEventData) Reset()
- func (x *CustomClassEventData) SetPayload(v *CustomClass)
- func (x *CustomClassEventData) String() string
- type CustomClassEventData_builder
- type CustomClassUpdatedEvent
- func (x *CustomClassUpdatedEvent) ClearData()
- func (x *CustomClassUpdatedEvent) GetData() *CustomClassEventData
- func (x *CustomClassUpdatedEvent) HasData() bool
- func (*CustomClassUpdatedEvent) ProtoMessage()
- func (x *CustomClassUpdatedEvent) ProtoReflect() protoreflect.Message
- func (x *CustomClassUpdatedEvent) Reset()
- func (x *CustomClassUpdatedEvent) SetData(v *CustomClassEventData)
- func (x *CustomClassUpdatedEvent) String() string
- type CustomClassUpdatedEvent_builder
- type CustomClass_ClassItem
- func (x *CustomClass_ClassItem) GetValue() string
- func (*CustomClass_ClassItem) ProtoMessage()
- func (x *CustomClass_ClassItem) ProtoReflect() protoreflect.Message
- func (x *CustomClass_ClassItem) Reset()
- func (x *CustomClass_ClassItem) SetValue(v string)
- func (x *CustomClass_ClassItem) String() string
- type CustomClass_ClassItem_builder
- type CustomClass_State
- type CustomClass_builder
- type PhraseSet
- func (x *PhraseSet) ClearDeleteTime()
- func (x *PhraseSet) ClearExpireTime()
- func (x *PhraseSet) GetAnnotations() map[string]string
- func (x *PhraseSet) GetBoost() float32
- func (x *PhraseSet) GetDeleteTime() *timestamppb.Timestamp
- func (x *PhraseSet) GetDisplayName() string
- func (x *PhraseSet) GetEtag() string
- func (x *PhraseSet) GetExpireTime() *timestamppb.Timestamp
- func (x *PhraseSet) GetKmsKeyName() string
- func (x *PhraseSet) GetKmsKeyVersionName() string
- func (x *PhraseSet) GetName() string
- func (x *PhraseSet) GetPhrases() []*PhraseSet_Phrase
- func (x *PhraseSet) GetReconciling() bool
- func (x *PhraseSet) GetState() PhraseSet_State
- func (x *PhraseSet) GetUid() string
- func (x *PhraseSet) HasDeleteTime() bool
- func (x *PhraseSet) HasExpireTime() bool
- func (*PhraseSet) ProtoMessage()
- func (x *PhraseSet) ProtoReflect() protoreflect.Message
- func (x *PhraseSet) Reset()
- func (x *PhraseSet) SetAnnotations(v map[string]string)
- func (x *PhraseSet) SetBoost(v float32)
- func (x *PhraseSet) SetDeleteTime(v *timestamppb.Timestamp)
- func (x *PhraseSet) SetDisplayName(v string)
- func (x *PhraseSet) SetEtag(v string)
- func (x *PhraseSet) SetExpireTime(v *timestamppb.Timestamp)
- func (x *PhraseSet) SetKmsKeyName(v string)
- func (x *PhraseSet) SetKmsKeyVersionName(v string)
- func (x *PhraseSet) SetName(v string)
- func (x *PhraseSet) SetPhrases(v []*PhraseSet_Phrase)
- func (x *PhraseSet) SetReconciling(v bool)
- func (x *PhraseSet) SetState(v PhraseSet_State)
- func (x *PhraseSet) SetUid(v string)
- func (x *PhraseSet) String() string
- type PhraseSetCreatedEvent
- func (x *PhraseSetCreatedEvent) ClearData()
- func (x *PhraseSetCreatedEvent) GetData() *PhraseSetEventData
- func (x *PhraseSetCreatedEvent) HasData() bool
- func (*PhraseSetCreatedEvent) ProtoMessage()
- func (x *PhraseSetCreatedEvent) ProtoReflect() protoreflect.Message
- func (x *PhraseSetCreatedEvent) Reset()
- func (x *PhraseSetCreatedEvent) SetData(v *PhraseSetEventData)
- func (x *PhraseSetCreatedEvent) String() string
- type PhraseSetCreatedEvent_builder
- type PhraseSetDeletedEvent
- func (x *PhraseSetDeletedEvent) ClearData()
- func (x *PhraseSetDeletedEvent) GetData() *PhraseSetEventData
- func (x *PhraseSetDeletedEvent) HasData() bool
- func (*PhraseSetDeletedEvent) ProtoMessage()
- func (x *PhraseSetDeletedEvent) ProtoReflect() protoreflect.Message
- func (x *PhraseSetDeletedEvent) Reset()
- func (x *PhraseSetDeletedEvent) SetData(v *PhraseSetEventData)
- func (x *PhraseSetDeletedEvent) String() string
- type PhraseSetDeletedEvent_builder
- type PhraseSetEventData
- func (x *PhraseSetEventData) ClearPayload()
- func (x *PhraseSetEventData) GetPayload() *PhraseSet
- func (x *PhraseSetEventData) HasPayload() bool
- func (*PhraseSetEventData) ProtoMessage()
- func (x *PhraseSetEventData) ProtoReflect() protoreflect.Message
- func (x *PhraseSetEventData) Reset()
- func (x *PhraseSetEventData) SetPayload(v *PhraseSet)
- func (x *PhraseSetEventData) String() string
- type PhraseSetEventData_builder
- type PhraseSetUpdatedEvent
- func (x *PhraseSetUpdatedEvent) ClearData()
- func (x *PhraseSetUpdatedEvent) GetData() *PhraseSetEventData
- func (x *PhraseSetUpdatedEvent) HasData() bool
- func (*PhraseSetUpdatedEvent) ProtoMessage()
- func (x *PhraseSetUpdatedEvent) ProtoReflect() protoreflect.Message
- func (x *PhraseSetUpdatedEvent) Reset()
- func (x *PhraseSetUpdatedEvent) SetData(v *PhraseSetEventData)
- func (x *PhraseSetUpdatedEvent) String() string
- type PhraseSetUpdatedEvent_builder
- type PhraseSet_Phrase
- func (x *PhraseSet_Phrase) GetBoost() float32
- func (x *PhraseSet_Phrase) GetValue() string
- func (*PhraseSet_Phrase) ProtoMessage()
- func (x *PhraseSet_Phrase) ProtoReflect() protoreflect.Message
- func (x *PhraseSet_Phrase) Reset()
- func (x *PhraseSet_Phrase) SetBoost(v float32)
- func (x *PhraseSet_Phrase) SetValue(v string)
- func (x *PhraseSet_Phrase) String() string
- type PhraseSet_Phrase_builder
- type PhraseSet_State
- type PhraseSet_builder
Constants ¶
This section is empty.
Variables ¶
var ( CustomClass_State_name = map[int32]string{ 0: "STATE_UNSPECIFIED", 2: "ACTIVE", 4: "DELETED", } CustomClass_State_value = map[string]int32{ "STATE_UNSPECIFIED": 0, "ACTIVE": 2, "DELETED": 4, } )
Enum value maps for CustomClass_State.
var ( PhraseSet_State_name = map[int32]string{ 0: "STATE_UNSPECIFIED", 2: "ACTIVE", 4: "DELETED", } PhraseSet_State_value = map[string]int32{ "STATE_UNSPECIFIED": 0, "ACTIVE": 2, "DELETED": 4, } )
Enum value maps for PhraseSet_State.
var File_google_events_cloud_speech_v1_data_proto protoreflect.FileDescriptor
var File_google_events_cloud_speech_v1_events_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type CustomClass ¶
type CustomClass struct {
// The resource name of the custom class.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// If this custom class is a resource, the custom_class_id is the resource id
// of the CustomClass. Case sensitive.
CustomClassId string `protobuf:"bytes,2,opt,name=custom_class_id,json=customClassId,proto3" json:"custom_class_id,omitempty"`
// A collection of class items.
Items []*CustomClass_ClassItem `protobuf:"bytes,3,rep,name=items,proto3" json:"items,omitempty"`
// Output only. The [KMS key
// name](https://cloud.google.com/kms/docs/resource-hierarchy#keys) with which
// the content of the ClassItem is encrypted. The expected format is
// `projects/{project}/locations/{location}/keyRings/{key_ring}/cryptoKeys/{crypto_key}`.
KmsKeyName string `protobuf:"bytes,6,opt,name=kms_key_name,json=kmsKeyName,proto3" json:"kms_key_name,omitempty"`
// Output only. The [KMS key version
// name](https://cloud.google.com/kms/docs/resource-hierarchy#key_versions)
// with which content of the ClassItem is encrypted. The expected format is
// `projects/{project}/locations/{location}/keyRings/{key_ring}/cryptoKeys/{crypto_key}/cryptoKeyVersions/{crypto_key_version}`.
KmsKeyVersionName string `protobuf:"bytes,7,opt,name=kms_key_version_name,json=kmsKeyVersionName,proto3" json:"kms_key_version_name,omitempty"`
// Output only. System-assigned unique identifier for the CustomClass.
// This field is not used.
Uid string `protobuf:"bytes,8,opt,name=uid,proto3" json:"uid,omitempty"`
// Output only. User-settable, human-readable name for the CustomClass. Must
// be 63 characters or less. This field is not used.
DisplayName string `protobuf:"bytes,9,opt,name=display_name,json=displayName,proto3" json:"display_name,omitempty"`
// Output only. The CustomClass lifecycle state.
// This field is not used.
State CustomClass_State `protobuf:"varint,10,opt,name=state,proto3,enum=google.events.cloud.speech.v1.CustomClass_State" json:"state,omitempty"`
// Output only. The time at which this resource was requested for deletion.
// This field is not used.
DeleteTime *timestamppb.Timestamp `protobuf:"bytes,11,opt,name=delete_time,json=deleteTime,proto3" json:"delete_time,omitempty"`
// Output only. The time at which this resource will be purged.
// This field is not used.
ExpireTime *timestamppb.Timestamp `protobuf:"bytes,12,opt,name=expire_time,json=expireTime,proto3" json:"expire_time,omitempty"`
// Output only. Allows users to store small amounts of arbitrary data.
// Both the key and the value must be 63 characters or less each.
// At most 100 annotations.
// This field is not used.
Annotations map[string]string `` /* 150-byte string literal not displayed */
// Output only. This checksum is computed by the server based on the value of
// other fields. This may be sent on update, undelete, and delete requests to
// ensure the client has an up-to-date value before proceeding. This field is
// not used.
Etag string `protobuf:"bytes,14,opt,name=etag,proto3" json:"etag,omitempty"`
// Output only. Whether or not this CustomClass is in the process of being
// updated. This field is not used.
Reconciling bool `protobuf:"varint,15,opt,name=reconciling,proto3" json:"reconciling,omitempty"`
// contains filtered or unexported fields
}
A set of words or phrases that represents a common concept likely to appear in your audio, for example a list of passenger ship names. CustomClass items can be substituted into placeholders that you set in PhraseSet phrases.
func (*CustomClass) ClearDeleteTime ¶
func (x *CustomClass) ClearDeleteTime()
func (*CustomClass) ClearExpireTime ¶
func (x *CustomClass) ClearExpireTime()
func (*CustomClass) GetAnnotations ¶
func (x *CustomClass) GetAnnotations() map[string]string
func (*CustomClass) GetCustomClassId ¶
func (x *CustomClass) GetCustomClassId() string
func (*CustomClass) GetDeleteTime ¶
func (x *CustomClass) GetDeleteTime() *timestamppb.Timestamp
func (*CustomClass) GetDisplayName ¶
func (x *CustomClass) GetDisplayName() string
func (*CustomClass) GetEtag ¶
func (x *CustomClass) GetEtag() string
func (*CustomClass) GetExpireTime ¶
func (x *CustomClass) GetExpireTime() *timestamppb.Timestamp
func (*CustomClass) GetItems ¶
func (x *CustomClass) GetItems() []*CustomClass_ClassItem
func (*CustomClass) GetKmsKeyName ¶
func (x *CustomClass) GetKmsKeyName() string
func (*CustomClass) GetKmsKeyVersionName ¶
func (x *CustomClass) GetKmsKeyVersionName() string
func (*CustomClass) GetName ¶
func (x *CustomClass) GetName() string
func (*CustomClass) GetReconciling ¶
func (x *CustomClass) GetReconciling() bool
func (*CustomClass) GetState ¶
func (x *CustomClass) GetState() CustomClass_State
func (*CustomClass) GetUid ¶
func (x *CustomClass) GetUid() string
func (*CustomClass) HasDeleteTime ¶
func (x *CustomClass) HasDeleteTime() bool
func (*CustomClass) HasExpireTime ¶
func (x *CustomClass) HasExpireTime() bool
func (*CustomClass) ProtoMessage ¶
func (*CustomClass) ProtoMessage()
func (*CustomClass) ProtoReflect ¶
func (x *CustomClass) ProtoReflect() protoreflect.Message
func (*CustomClass) Reset ¶
func (x *CustomClass) Reset()
func (*CustomClass) SetAnnotations ¶
func (x *CustomClass) SetAnnotations(v map[string]string)
func (*CustomClass) SetCustomClassId ¶
func (x *CustomClass) SetCustomClassId(v string)
func (*CustomClass) SetDeleteTime ¶
func (x *CustomClass) SetDeleteTime(v *timestamppb.Timestamp)
func (*CustomClass) SetDisplayName ¶
func (x *CustomClass) SetDisplayName(v string)
func (*CustomClass) SetEtag ¶
func (x *CustomClass) SetEtag(v string)
func (*CustomClass) SetExpireTime ¶
func (x *CustomClass) SetExpireTime(v *timestamppb.Timestamp)
func (*CustomClass) SetItems ¶
func (x *CustomClass) SetItems(v []*CustomClass_ClassItem)
func (*CustomClass) SetKmsKeyName ¶
func (x *CustomClass) SetKmsKeyName(v string)
func (*CustomClass) SetKmsKeyVersionName ¶
func (x *CustomClass) SetKmsKeyVersionName(v string)
func (*CustomClass) SetName ¶
func (x *CustomClass) SetName(v string)
func (*CustomClass) SetReconciling ¶
func (x *CustomClass) SetReconciling(v bool)
func (*CustomClass) SetState ¶
func (x *CustomClass) SetState(v CustomClass_State)
func (*CustomClass) SetUid ¶
func (x *CustomClass) SetUid(v string)
func (*CustomClass) String ¶
func (x *CustomClass) String() string
type CustomClassCreatedEvent ¶
type CustomClassCreatedEvent struct {
// The data associated with the event.
Data *CustomClassEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
// contains filtered or unexported fields
}
The CloudEvent raised when a CustomClass is created.
func (*CustomClassCreatedEvent) ClearData ¶
func (x *CustomClassCreatedEvent) ClearData()
func (*CustomClassCreatedEvent) GetData ¶
func (x *CustomClassCreatedEvent) GetData() *CustomClassEventData
func (*CustomClassCreatedEvent) HasData ¶
func (x *CustomClassCreatedEvent) HasData() bool
func (*CustomClassCreatedEvent) ProtoMessage ¶
func (*CustomClassCreatedEvent) ProtoMessage()
func (*CustomClassCreatedEvent) ProtoReflect ¶
func (x *CustomClassCreatedEvent) ProtoReflect() protoreflect.Message
func (*CustomClassCreatedEvent) Reset ¶
func (x *CustomClassCreatedEvent) Reset()
func (*CustomClassCreatedEvent) SetData ¶
func (x *CustomClassCreatedEvent) SetData(v *CustomClassEventData)
func (*CustomClassCreatedEvent) String ¶
func (x *CustomClassCreatedEvent) String() string
type CustomClassCreatedEvent_builder ¶
type CustomClassCreatedEvent_builder struct {
// The data associated with the event.
Data *CustomClassEventData
// contains filtered or unexported fields
}
func (CustomClassCreatedEvent_builder) Build ¶
func (b0 CustomClassCreatedEvent_builder) Build() *CustomClassCreatedEvent
type CustomClassDeletedEvent ¶
type CustomClassDeletedEvent struct {
// The data associated with the event.
Data *CustomClassEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
// contains filtered or unexported fields
}
The CloudEvent raised when a CustomClass is deleted.
func (*CustomClassDeletedEvent) ClearData ¶
func (x *CustomClassDeletedEvent) ClearData()
func (*CustomClassDeletedEvent) GetData ¶
func (x *CustomClassDeletedEvent) GetData() *CustomClassEventData
func (*CustomClassDeletedEvent) HasData ¶
func (x *CustomClassDeletedEvent) HasData() bool
func (*CustomClassDeletedEvent) ProtoMessage ¶
func (*CustomClassDeletedEvent) ProtoMessage()
func (*CustomClassDeletedEvent) ProtoReflect ¶
func (x *CustomClassDeletedEvent) ProtoReflect() protoreflect.Message
func (*CustomClassDeletedEvent) Reset ¶
func (x *CustomClassDeletedEvent) Reset()
func (*CustomClassDeletedEvent) SetData ¶
func (x *CustomClassDeletedEvent) SetData(v *CustomClassEventData)
func (*CustomClassDeletedEvent) String ¶
func (x *CustomClassDeletedEvent) String() string
type CustomClassDeletedEvent_builder ¶
type CustomClassDeletedEvent_builder struct {
// The data associated with the event.
Data *CustomClassEventData
// contains filtered or unexported fields
}
func (CustomClassDeletedEvent_builder) Build ¶
func (b0 CustomClassDeletedEvent_builder) Build() *CustomClassDeletedEvent
type CustomClassEventData ¶
type CustomClassEventData struct {
// Optional. The CustomClass event payload. Unset for deletion events.
Payload *CustomClass `protobuf:"bytes,1,opt,name=payload,proto3" json:"payload,omitempty"`
// contains filtered or unexported fields
}
The data within all CustomClass events.
func (*CustomClassEventData) ClearPayload ¶
func (x *CustomClassEventData) ClearPayload()
func (*CustomClassEventData) GetPayload ¶
func (x *CustomClassEventData) GetPayload() *CustomClass
func (*CustomClassEventData) HasPayload ¶
func (x *CustomClassEventData) HasPayload() bool
func (*CustomClassEventData) ProtoMessage ¶
func (*CustomClassEventData) ProtoMessage()
func (*CustomClassEventData) ProtoReflect ¶
func (x *CustomClassEventData) ProtoReflect() protoreflect.Message
func (*CustomClassEventData) Reset ¶
func (x *CustomClassEventData) Reset()
func (*CustomClassEventData) SetPayload ¶
func (x *CustomClassEventData) SetPayload(v *CustomClass)
func (*CustomClassEventData) String ¶
func (x *CustomClassEventData) String() string
type CustomClassEventData_builder ¶
type CustomClassEventData_builder struct {
// Optional. The CustomClass event payload. Unset for deletion events.
Payload *CustomClass
// contains filtered or unexported fields
}
func (CustomClassEventData_builder) Build ¶
func (b0 CustomClassEventData_builder) Build() *CustomClassEventData
type CustomClassUpdatedEvent ¶
type CustomClassUpdatedEvent struct {
// The data associated with the event.
Data *CustomClassEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
// contains filtered or unexported fields
}
The CloudEvent raised when a CustomClass is updated.
func (*CustomClassUpdatedEvent) ClearData ¶
func (x *CustomClassUpdatedEvent) ClearData()
func (*CustomClassUpdatedEvent) GetData ¶
func (x *CustomClassUpdatedEvent) GetData() *CustomClassEventData
func (*CustomClassUpdatedEvent) HasData ¶
func (x *CustomClassUpdatedEvent) HasData() bool
func (*CustomClassUpdatedEvent) ProtoMessage ¶
func (*CustomClassUpdatedEvent) ProtoMessage()
func (*CustomClassUpdatedEvent) ProtoReflect ¶
func (x *CustomClassUpdatedEvent) ProtoReflect() protoreflect.Message
func (*CustomClassUpdatedEvent) Reset ¶
func (x *CustomClassUpdatedEvent) Reset()
func (*CustomClassUpdatedEvent) SetData ¶
func (x *CustomClassUpdatedEvent) SetData(v *CustomClassEventData)
func (*CustomClassUpdatedEvent) String ¶
func (x *CustomClassUpdatedEvent) String() string
type CustomClassUpdatedEvent_builder ¶
type CustomClassUpdatedEvent_builder struct {
// The data associated with the event.
Data *CustomClassEventData
// contains filtered or unexported fields
}
func (CustomClassUpdatedEvent_builder) Build ¶
func (b0 CustomClassUpdatedEvent_builder) Build() *CustomClassUpdatedEvent
type CustomClass_ClassItem ¶
type CustomClass_ClassItem struct {
// The class item's value.
Value string `protobuf:"bytes,1,opt,name=value,proto3" json:"value,omitempty"`
// contains filtered or unexported fields
}
An item of the class.
func (*CustomClass_ClassItem) GetValue ¶
func (x *CustomClass_ClassItem) GetValue() string
func (*CustomClass_ClassItem) ProtoMessage ¶
func (*CustomClass_ClassItem) ProtoMessage()
func (*CustomClass_ClassItem) ProtoReflect ¶
func (x *CustomClass_ClassItem) ProtoReflect() protoreflect.Message
func (*CustomClass_ClassItem) Reset ¶
func (x *CustomClass_ClassItem) Reset()
func (*CustomClass_ClassItem) SetValue ¶
func (x *CustomClass_ClassItem) SetValue(v string)
func (*CustomClass_ClassItem) String ¶
func (x *CustomClass_ClassItem) String() string
type CustomClass_ClassItem_builder ¶
type CustomClass_ClassItem_builder struct {
// The class item's value.
Value string
// contains filtered or unexported fields
}
func (CustomClass_ClassItem_builder) Build ¶
func (b0 CustomClass_ClassItem_builder) Build() *CustomClass_ClassItem
type CustomClass_State ¶
type CustomClass_State int32
Set of states that define the lifecycle of a CustomClass.
const ( // Unspecified state. This is only used/useful for distinguishing // unset values. CustomClass_STATE_UNSPECIFIED CustomClass_State = 0 // The normal and active state. CustomClass_ACTIVE CustomClass_State = 2 // This CustomClass has been deleted. CustomClass_DELETED CustomClass_State = 4 )
func (CustomClass_State) Descriptor ¶
func (CustomClass_State) Descriptor() protoreflect.EnumDescriptor
func (CustomClass_State) Enum ¶
func (x CustomClass_State) Enum() *CustomClass_State
func (CustomClass_State) Number ¶
func (x CustomClass_State) Number() protoreflect.EnumNumber
func (CustomClass_State) String ¶
func (x CustomClass_State) String() string
func (CustomClass_State) Type ¶
func (CustomClass_State) Type() protoreflect.EnumType
type CustomClass_builder ¶
type CustomClass_builder struct {
// The resource name of the custom class.
Name string
// If this custom class is a resource, the custom_class_id is the resource id
// of the CustomClass. Case sensitive.
CustomClassId string
// A collection of class items.
Items []*CustomClass_ClassItem
// Output only. The [KMS key
// name](https://cloud.google.com/kms/docs/resource-hierarchy#keys) with which
// the content of the ClassItem is encrypted. The expected format is
// `projects/{project}/locations/{location}/keyRings/{key_ring}/cryptoKeys/{crypto_key}`.
KmsKeyName string
// Output only. The [KMS key version
// name](https://cloud.google.com/kms/docs/resource-hierarchy#key_versions)
// with which content of the ClassItem is encrypted. The expected format is
// `projects/{project}/locations/{location}/keyRings/{key_ring}/cryptoKeys/{crypto_key}/cryptoKeyVersions/{crypto_key_version}`.
KmsKeyVersionName string
// Output only. System-assigned unique identifier for the CustomClass.
// This field is not used.
Uid string
// Output only. User-settable, human-readable name for the CustomClass. Must
// be 63 characters or less. This field is not used.
DisplayName string
// Output only. The CustomClass lifecycle state.
// This field is not used.
State CustomClass_State
// Output only. The time at which this resource was requested for deletion.
// This field is not used.
DeleteTime *timestamppb.Timestamp
// Output only. The time at which this resource will be purged.
// This field is not used.
ExpireTime *timestamppb.Timestamp
// Output only. Allows users to store small amounts of arbitrary data.
// Both the key and the value must be 63 characters or less each.
// At most 100 annotations.
// This field is not used.
Annotations map[string]string
// Output only. This checksum is computed by the server based on the value of
// other fields. This may be sent on update, undelete, and delete requests to
// ensure the client has an up-to-date value before proceeding. This field is
// not used.
Etag string
// Output only. Whether or not this CustomClass is in the process of being
// updated. This field is not used.
Reconciling bool
// contains filtered or unexported fields
}
func (CustomClass_builder) Build ¶
func (b0 CustomClass_builder) Build() *CustomClass
type PhraseSet ¶
type PhraseSet struct {
// The resource name of the phrase set.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// A list of word and phrases.
Phrases []*PhraseSet_Phrase `protobuf:"bytes,2,rep,name=phrases,proto3" json:"phrases,omitempty"`
// Hint Boost. Positive value will increase the probability that a specific
// phrase will be recognized over other similar sounding phrases. The higher
// the boost, the higher the chance of false positive recognition as well.
// Negative boost values would correspond to anti-biasing. Anti-biasing is not
// enabled, so negative boost will simply be ignored. Though `boost` can
// accept a wide range of positive values, most use cases are best served with
// values between 0 (exclusive) and 20. We recommend using a binary search
// approach to finding the optimal value for your use case as well as adding
// phrases both with and without boost to your requests.
Boost float32 `protobuf:"fixed32,4,opt,name=boost,proto3" json:"boost,omitempty"`
// Output only. The [KMS key
// name](https://cloud.google.com/kms/docs/resource-hierarchy#keys) with which
// the content of the PhraseSet is encrypted. The expected format is
// `projects/{project}/locations/{location}/keyRings/{key_ring}/cryptoKeys/{crypto_key}`.
KmsKeyName string `protobuf:"bytes,7,opt,name=kms_key_name,json=kmsKeyName,proto3" json:"kms_key_name,omitempty"`
// Output only. The [KMS key version
// name](https://cloud.google.com/kms/docs/resource-hierarchy#key_versions)
// with which content of the PhraseSet is encrypted. The expected format is
// `projects/{project}/locations/{location}/keyRings/{key_ring}/cryptoKeys/{crypto_key}/cryptoKeyVersions/{crypto_key_version}`.
KmsKeyVersionName string `protobuf:"bytes,8,opt,name=kms_key_version_name,json=kmsKeyVersionName,proto3" json:"kms_key_version_name,omitempty"`
// Output only. System-assigned unique identifier for the PhraseSet.
// This field is not used.
Uid string `protobuf:"bytes,9,opt,name=uid,proto3" json:"uid,omitempty"`
// Output only. User-settable, human-readable name for the PhraseSet. Must be
// 63 characters or less. This field is not used.
DisplayName string `protobuf:"bytes,10,opt,name=display_name,json=displayName,proto3" json:"display_name,omitempty"`
// Output only. The CustomClass lifecycle state.
// This field is not used.
State PhraseSet_State `protobuf:"varint,11,opt,name=state,proto3,enum=google.events.cloud.speech.v1.PhraseSet_State" json:"state,omitempty"`
// Output only. The time at which this resource was requested for deletion.
// This field is not used.
DeleteTime *timestamppb.Timestamp `protobuf:"bytes,12,opt,name=delete_time,json=deleteTime,proto3" json:"delete_time,omitempty"`
// Output only. The time at which this resource will be purged.
// This field is not used.
ExpireTime *timestamppb.Timestamp `protobuf:"bytes,13,opt,name=expire_time,json=expireTime,proto3" json:"expire_time,omitempty"`
// Output only. Allows users to store small amounts of arbitrary data.
// Both the key and the value must be 63 characters or less each.
// At most 100 annotations.
// This field is not used.
Annotations map[string]string `` /* 150-byte string literal not displayed */
// Output only. This checksum is computed by the server based on the value of
// other fields. This may be sent on update, undelete, and delete requests to
// ensure the client has an up-to-date value before proceeding. This field is
// not used.
Etag string `protobuf:"bytes,15,opt,name=etag,proto3" json:"etag,omitempty"`
// Output only. Whether or not this PhraseSet is in the process of being
// updated. This field is not used.
Reconciling bool `protobuf:"varint,16,opt,name=reconciling,proto3" json:"reconciling,omitempty"`
// contains filtered or unexported fields
}
Provides "hints" to the speech recognizer to favor specific words and phrases in the results.
func (*PhraseSet) GetDeleteTime ¶
func (x *PhraseSet) GetDeleteTime() *timestamppb.Timestamp
func (*PhraseSet) GetExpireTime ¶
func (x *PhraseSet) GetExpireTime() *timestamppb.Timestamp
func (*PhraseSet) GetPhrases ¶
func (x *PhraseSet) GetPhrases() []*PhraseSet_Phrase
func (*PhraseSet) GetState ¶
func (x *PhraseSet) GetState() PhraseSet_State
func (*PhraseSet) ProtoReflect ¶
func (x *PhraseSet) ProtoReflect() protoreflect.Message
func (*PhraseSet) SetDeleteTime ¶
func (x *PhraseSet) SetDeleteTime(v *timestamppb.Timestamp)
func (*PhraseSet) SetExpireTime ¶
func (x *PhraseSet) SetExpireTime(v *timestamppb.Timestamp)
func (*PhraseSet) SetPhrases ¶
func (x *PhraseSet) SetPhrases(v []*PhraseSet_Phrase)
func (*PhraseSet) SetState ¶
func (x *PhraseSet) SetState(v PhraseSet_State)
type PhraseSetCreatedEvent ¶
type PhraseSetCreatedEvent struct {
// The data associated with the event.
Data *PhraseSetEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
// contains filtered or unexported fields
}
The CloudEvent raised when a PhraseSet is created.
func (*PhraseSetCreatedEvent) ClearData ¶
func (x *PhraseSetCreatedEvent) ClearData()
func (*PhraseSetCreatedEvent) GetData ¶
func (x *PhraseSetCreatedEvent) GetData() *PhraseSetEventData
func (*PhraseSetCreatedEvent) HasData ¶
func (x *PhraseSetCreatedEvent) HasData() bool
func (*PhraseSetCreatedEvent) ProtoMessage ¶
func (*PhraseSetCreatedEvent) ProtoMessage()
func (*PhraseSetCreatedEvent) ProtoReflect ¶
func (x *PhraseSetCreatedEvent) ProtoReflect() protoreflect.Message
func (*PhraseSetCreatedEvent) Reset ¶
func (x *PhraseSetCreatedEvent) Reset()
func (*PhraseSetCreatedEvent) SetData ¶
func (x *PhraseSetCreatedEvent) SetData(v *PhraseSetEventData)
func (*PhraseSetCreatedEvent) String ¶
func (x *PhraseSetCreatedEvent) String() string
type PhraseSetCreatedEvent_builder ¶
type PhraseSetCreatedEvent_builder struct {
// The data associated with the event.
Data *PhraseSetEventData
// contains filtered or unexported fields
}
func (PhraseSetCreatedEvent_builder) Build ¶
func (b0 PhraseSetCreatedEvent_builder) Build() *PhraseSetCreatedEvent
type PhraseSetDeletedEvent ¶
type PhraseSetDeletedEvent struct {
// The data associated with the event.
Data *PhraseSetEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
// contains filtered or unexported fields
}
The CloudEvent raised when a PhraseSet is deleted.
func (*PhraseSetDeletedEvent) ClearData ¶
func (x *PhraseSetDeletedEvent) ClearData()
func (*PhraseSetDeletedEvent) GetData ¶
func (x *PhraseSetDeletedEvent) GetData() *PhraseSetEventData
func (*PhraseSetDeletedEvent) HasData ¶
func (x *PhraseSetDeletedEvent) HasData() bool
func (*PhraseSetDeletedEvent) ProtoMessage ¶
func (*PhraseSetDeletedEvent) ProtoMessage()
func (*PhraseSetDeletedEvent) ProtoReflect ¶
func (x *PhraseSetDeletedEvent) ProtoReflect() protoreflect.Message
func (*PhraseSetDeletedEvent) Reset ¶
func (x *PhraseSetDeletedEvent) Reset()
func (*PhraseSetDeletedEvent) SetData ¶
func (x *PhraseSetDeletedEvent) SetData(v *PhraseSetEventData)
func (*PhraseSetDeletedEvent) String ¶
func (x *PhraseSetDeletedEvent) String() string
type PhraseSetDeletedEvent_builder ¶
type PhraseSetDeletedEvent_builder struct {
// The data associated with the event.
Data *PhraseSetEventData
// contains filtered or unexported fields
}
func (PhraseSetDeletedEvent_builder) Build ¶
func (b0 PhraseSetDeletedEvent_builder) Build() *PhraseSetDeletedEvent
type PhraseSetEventData ¶
type PhraseSetEventData struct {
// Optional. The PhraseSet event payload. Unset for deletion events.
Payload *PhraseSet `protobuf:"bytes,1,opt,name=payload,proto3" json:"payload,omitempty"`
// contains filtered or unexported fields
}
The data within all PhraseSet events.
func (*PhraseSetEventData) ClearPayload ¶
func (x *PhraseSetEventData) ClearPayload()
func (*PhraseSetEventData) GetPayload ¶
func (x *PhraseSetEventData) GetPayload() *PhraseSet
func (*PhraseSetEventData) HasPayload ¶
func (x *PhraseSetEventData) HasPayload() bool
func (*PhraseSetEventData) ProtoMessage ¶
func (*PhraseSetEventData) ProtoMessage()
func (*PhraseSetEventData) ProtoReflect ¶
func (x *PhraseSetEventData) ProtoReflect() protoreflect.Message
func (*PhraseSetEventData) Reset ¶
func (x *PhraseSetEventData) Reset()
func (*PhraseSetEventData) SetPayload ¶
func (x *PhraseSetEventData) SetPayload(v *PhraseSet)
func (*PhraseSetEventData) String ¶
func (x *PhraseSetEventData) String() string
type PhraseSetEventData_builder ¶
type PhraseSetEventData_builder struct {
// Optional. The PhraseSet event payload. Unset for deletion events.
Payload *PhraseSet
// contains filtered or unexported fields
}
func (PhraseSetEventData_builder) Build ¶
func (b0 PhraseSetEventData_builder) Build() *PhraseSetEventData
type PhraseSetUpdatedEvent ¶
type PhraseSetUpdatedEvent struct {
// The data associated with the event.
Data *PhraseSetEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
// contains filtered or unexported fields
}
The CloudEvent raised when a PhraseSet is updated.
func (*PhraseSetUpdatedEvent) ClearData ¶
func (x *PhraseSetUpdatedEvent) ClearData()
func (*PhraseSetUpdatedEvent) GetData ¶
func (x *PhraseSetUpdatedEvent) GetData() *PhraseSetEventData
func (*PhraseSetUpdatedEvent) HasData ¶
func (x *PhraseSetUpdatedEvent) HasData() bool
func (*PhraseSetUpdatedEvent) ProtoMessage ¶
func (*PhraseSetUpdatedEvent) ProtoMessage()
func (*PhraseSetUpdatedEvent) ProtoReflect ¶
func (x *PhraseSetUpdatedEvent) ProtoReflect() protoreflect.Message
func (*PhraseSetUpdatedEvent) Reset ¶
func (x *PhraseSetUpdatedEvent) Reset()
func (*PhraseSetUpdatedEvent) SetData ¶
func (x *PhraseSetUpdatedEvent) SetData(v *PhraseSetEventData)
func (*PhraseSetUpdatedEvent) String ¶
func (x *PhraseSetUpdatedEvent) String() string
type PhraseSetUpdatedEvent_builder ¶
type PhraseSetUpdatedEvent_builder struct {
// The data associated with the event.
Data *PhraseSetEventData
// contains filtered or unexported fields
}
func (PhraseSetUpdatedEvent_builder) Build ¶
func (b0 PhraseSetUpdatedEvent_builder) Build() *PhraseSetUpdatedEvent
type PhraseSet_Phrase ¶
type PhraseSet_Phrase struct {
// The phrase itself.
Value string `protobuf:"bytes,1,opt,name=value,proto3" json:"value,omitempty"`
// Hint Boost. Overrides the boost set at the phrase set level.
// Positive value will increase the probability that a specific phrase will
// be recognized over other similar sounding phrases. The higher the boost,
// the higher the chance of false positive recognition as well. Negative
// boost will simply be ignored. Though `boost` can accept a wide range of
// positive values, most use cases are best served
// with values between 0 and 20. We recommend using a binary search approach
// to finding the optimal value for your use case as well as adding
// phrases both with and without boost to your requests.
Boost float32 `protobuf:"fixed32,2,opt,name=boost,proto3" json:"boost,omitempty"`
// contains filtered or unexported fields
}
A phrases containing words and phrase "hints" so that the speech recognition is more likely to recognize them. This can be used to improve the accuracy for specific words and phrases, for example, if specific commands are typically spoken by the user. This can also be used to add additional words to the vocabulary of the recognizer. See [usage limits](https://cloud.google.com/speech-to-text/quotas#content).
List items can also include pre-built or custom classes containing groups of words that represent common concepts that occur in natural language. For example, rather than providing a phrase hint for every month of the year (e.g. "i was born in january", "i was born in febuary", ...), use the pre-built `$MONTH` class improves the likelihood of correctly transcribing audio that includes months (e.g. "i was born in $month"). To refer to pre-built classes, use the class' symbol prepended with `$` e.g. `$MONTH`. To refer to custom classes that were defined inline in the request, set the class's `custom_class_id` to a string unique to all class resources and inline classes. Then use the class' id wrapped in $`{...}` e.g. "${my-months}". To refer to custom classes resources, use the class' id wrapped in `${}` (e.g. `${my-months}`).
Speech-to-Text supports three locations: `global`, `us` (US North America), and `eu` (Europe). If you are calling the `speech.googleapis.com` endpoint, use the `global` location. To specify a region, use a [regional endpoint](https://cloud.google.com/speech-to-text/docs/endpoints) with matching `us` or `eu` location value.
func (*PhraseSet_Phrase) GetBoost ¶
func (x *PhraseSet_Phrase) GetBoost() float32
func (*PhraseSet_Phrase) GetValue ¶
func (x *PhraseSet_Phrase) GetValue() string
func (*PhraseSet_Phrase) ProtoMessage ¶
func (*PhraseSet_Phrase) ProtoMessage()
func (*PhraseSet_Phrase) ProtoReflect ¶
func (x *PhraseSet_Phrase) ProtoReflect() protoreflect.Message
func (*PhraseSet_Phrase) Reset ¶
func (x *PhraseSet_Phrase) Reset()
func (*PhraseSet_Phrase) SetBoost ¶
func (x *PhraseSet_Phrase) SetBoost(v float32)
func (*PhraseSet_Phrase) SetValue ¶
func (x *PhraseSet_Phrase) SetValue(v string)
func (*PhraseSet_Phrase) String ¶
func (x *PhraseSet_Phrase) String() string
type PhraseSet_Phrase_builder ¶
type PhraseSet_Phrase_builder struct {
// The phrase itself.
Value string
// Hint Boost. Overrides the boost set at the phrase set level.
// Positive value will increase the probability that a specific phrase will
// be recognized over other similar sounding phrases. The higher the boost,
// the higher the chance of false positive recognition as well. Negative
// boost will simply be ignored. Though `boost` can accept a wide range of
// positive values, most use cases are best served
// with values between 0 and 20. We recommend using a binary search approach
// to finding the optimal value for your use case as well as adding
// phrases both with and without boost to your requests.
Boost float32
// contains filtered or unexported fields
}
func (PhraseSet_Phrase_builder) Build ¶
func (b0 PhraseSet_Phrase_builder) Build() *PhraseSet_Phrase
type PhraseSet_State ¶
type PhraseSet_State int32
Set of states that define the lifecycle of a CustomClass.
const ( // Unspecified state. This is only used/useful for distinguishing // unset values. PhraseSet_STATE_UNSPECIFIED PhraseSet_State = 0 // The normal and active state. PhraseSet_ACTIVE PhraseSet_State = 2 // This CustomClass has been deleted. PhraseSet_DELETED PhraseSet_State = 4 )
func (PhraseSet_State) Descriptor ¶
func (PhraseSet_State) Descriptor() protoreflect.EnumDescriptor
func (PhraseSet_State) Enum ¶
func (x PhraseSet_State) Enum() *PhraseSet_State
func (PhraseSet_State) Number ¶
func (x PhraseSet_State) Number() protoreflect.EnumNumber
func (PhraseSet_State) String ¶
func (x PhraseSet_State) String() string
func (PhraseSet_State) Type ¶
func (PhraseSet_State) Type() protoreflect.EnumType
type PhraseSet_builder ¶
type PhraseSet_builder struct {
// The resource name of the phrase set.
Name string
// A list of word and phrases.
Phrases []*PhraseSet_Phrase
// Hint Boost. Positive value will increase the probability that a specific
// phrase will be recognized over other similar sounding phrases. The higher
// the boost, the higher the chance of false positive recognition as well.
// Negative boost values would correspond to anti-biasing. Anti-biasing is not
// enabled, so negative boost will simply be ignored. Though `boost` can
// accept a wide range of positive values, most use cases are best served with
// values between 0 (exclusive) and 20. We recommend using a binary search
// approach to finding the optimal value for your use case as well as adding
// phrases both with and without boost to your requests.
Boost float32
// Output only. The [KMS key
// name](https://cloud.google.com/kms/docs/resource-hierarchy#keys) with which
// the content of the PhraseSet is encrypted. The expected format is
// `projects/{project}/locations/{location}/keyRings/{key_ring}/cryptoKeys/{crypto_key}`.
KmsKeyName string
// Output only. The [KMS key version
// name](https://cloud.google.com/kms/docs/resource-hierarchy#key_versions)
// with which content of the PhraseSet is encrypted. The expected format is
// `projects/{project}/locations/{location}/keyRings/{key_ring}/cryptoKeys/{crypto_key}/cryptoKeyVersions/{crypto_key_version}`.
KmsKeyVersionName string
// Output only. System-assigned unique identifier for the PhraseSet.
// This field is not used.
Uid string
// Output only. User-settable, human-readable name for the PhraseSet. Must be
// 63 characters or less. This field is not used.
DisplayName string
// Output only. The CustomClass lifecycle state.
// This field is not used.
State PhraseSet_State
// Output only. The time at which this resource was requested for deletion.
// This field is not used.
DeleteTime *timestamppb.Timestamp
// Output only. The time at which this resource will be purged.
// This field is not used.
ExpireTime *timestamppb.Timestamp
// Output only. Allows users to store small amounts of arbitrary data.
// Both the key and the value must be 63 characters or less each.
// At most 100 annotations.
// This field is not used.
Annotations map[string]string
// Output only. This checksum is computed by the server based on the value of
// other fields. This may be sent on update, undelete, and delete requests to
// ensure the client has an up-to-date value before proceeding. This field is
// not used.
Etag string
// Output only. Whether or not this PhraseSet is in the process of being
// updated. This field is not used.
Reconciling bool
// contains filtered or unexported fields
}
func (PhraseSet_builder) Build ¶
func (b0 PhraseSet_builder) Build() *PhraseSet
Source Files
¶
- data.pb.go
- events.pb.go