Documentation
¶
Index ¶
- Constants
- Variables
- type Workflow
- func (x *Workflow) ClearCreateTime()
- func (x *Workflow) ClearRevisionCreateTime()
- func (x *Workflow) ClearSourceCode()
- func (x *Workflow) ClearSourceContents()
- func (x *Workflow) ClearUpdateTime()
- func (x *Workflow) GetCreateTime() *timestamppb.Timestamp
- func (x *Workflow) GetDescription() string
- func (x *Workflow) GetLabels() map[string]string
- func (x *Workflow) GetName() string
- func (x *Workflow) GetRevisionCreateTime() *timestamppb.Timestamp
- func (x *Workflow) GetRevisionId() string
- func (x *Workflow) GetServiceAccount() string
- func (x *Workflow) GetSourceCode() isWorkflow_SourceCode
- func (x *Workflow) GetSourceContents() string
- func (x *Workflow) GetState() Workflow_State
- func (x *Workflow) GetUpdateTime() *timestamppb.Timestamp
- func (x *Workflow) HasCreateTime() bool
- func (x *Workflow) HasRevisionCreateTime() bool
- func (x *Workflow) HasSourceCode() bool
- func (x *Workflow) HasSourceContents() bool
- func (x *Workflow) HasUpdateTime() bool
- func (*Workflow) ProtoMessage()
- func (x *Workflow) ProtoReflect() protoreflect.Message
- func (x *Workflow) Reset()
- func (x *Workflow) SetCreateTime(v *timestamppb.Timestamp)
- func (x *Workflow) SetDescription(v string)
- func (x *Workflow) SetLabels(v map[string]string)
- func (x *Workflow) SetName(v string)
- func (x *Workflow) SetRevisionCreateTime(v *timestamppb.Timestamp)
- func (x *Workflow) SetRevisionId(v string)
- func (x *Workflow) SetServiceAccount(v string)
- func (x *Workflow) SetSourceContents(v string)
- func (x *Workflow) SetState(v Workflow_State)
- func (x *Workflow) SetUpdateTime(v *timestamppb.Timestamp)
- func (x *Workflow) String() string
- func (x *Workflow) WhichSourceCode() case_Workflow_SourceCode
- type WorkflowCreatedEvent
- func (x *WorkflowCreatedEvent) ClearData()
- func (x *WorkflowCreatedEvent) GetData() *WorkflowEventData
- func (x *WorkflowCreatedEvent) HasData() bool
- func (*WorkflowCreatedEvent) ProtoMessage()
- func (x *WorkflowCreatedEvent) ProtoReflect() protoreflect.Message
- func (x *WorkflowCreatedEvent) Reset()
- func (x *WorkflowCreatedEvent) SetData(v *WorkflowEventData)
- func (x *WorkflowCreatedEvent) String() string
- type WorkflowCreatedEvent_builder
- type WorkflowDeletedEvent
- func (x *WorkflowDeletedEvent) ClearData()
- func (x *WorkflowDeletedEvent) GetData() *WorkflowEventData
- func (x *WorkflowDeletedEvent) HasData() bool
- func (*WorkflowDeletedEvent) ProtoMessage()
- func (x *WorkflowDeletedEvent) ProtoReflect() protoreflect.Message
- func (x *WorkflowDeletedEvent) Reset()
- func (x *WorkflowDeletedEvent) SetData(v *WorkflowEventData)
- func (x *WorkflowDeletedEvent) String() string
- type WorkflowDeletedEvent_builder
- type WorkflowEventData
- func (x *WorkflowEventData) ClearPayload()
- func (x *WorkflowEventData) GetPayload() *Workflow
- func (x *WorkflowEventData) HasPayload() bool
- func (*WorkflowEventData) ProtoMessage()
- func (x *WorkflowEventData) ProtoReflect() protoreflect.Message
- func (x *WorkflowEventData) Reset()
- func (x *WorkflowEventData) SetPayload(v *Workflow)
- func (x *WorkflowEventData) String() string
- type WorkflowEventData_builder
- type WorkflowUpdatedEvent
- func (x *WorkflowUpdatedEvent) ClearData()
- func (x *WorkflowUpdatedEvent) GetData() *WorkflowEventData
- func (x *WorkflowUpdatedEvent) HasData() bool
- func (*WorkflowUpdatedEvent) ProtoMessage()
- func (x *WorkflowUpdatedEvent) ProtoReflect() protoreflect.Message
- func (x *WorkflowUpdatedEvent) Reset()
- func (x *WorkflowUpdatedEvent) SetData(v *WorkflowEventData)
- func (x *WorkflowUpdatedEvent) String() string
- type WorkflowUpdatedEvent_builder
- type Workflow_SourceContents
- type Workflow_State
- type Workflow_builder
Constants ¶
const Workflow_SourceCode_not_set_case case_Workflow_SourceCode = 0
const Workflow_SourceContents_case case_Workflow_SourceCode = 10
Variables ¶
var ( Workflow_State_name = map[int32]string{ 0: "STATE_UNSPECIFIED", 1: "ACTIVE", } Workflow_State_value = map[string]int32{ "STATE_UNSPECIFIED": 0, "ACTIVE": 1, } )
Enum value maps for Workflow_State.
var File_google_events_cloud_workflows_v1_data_proto protoreflect.FileDescriptor
var File_google_events_cloud_workflows_v1_events_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Workflow ¶
type Workflow struct {
// The resource name of the workflow.
// Format: projects/{project}/locations/{location}/workflows/{workflow}
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// Description of the workflow provided by the user.
// Must be at most 1000 unicode characters long.
Description string `protobuf:"bytes,2,opt,name=description,proto3" json:"description,omitempty"`
// Output only. State of the workflow deployment.
State Workflow_State `protobuf:"varint,3,opt,name=state,proto3,enum=google.events.cloud.workflows.v1.Workflow_State" json:"state,omitempty"`
// Output only. The revision of the workflow.
// A new revision of a workflow is created as a result of updating the
// following properties of a workflow:
//
// - [Service account][google.cloud.workflows.v1.Workflow.service_account]
// - [Workflow code to be
// executed][google.cloud.workflows.v1.Workflow.source_contents]
//
// The format is "000001-a4d", where the first 6 characters define
// the zero-padded revision ordinal number. They are followed by a hyphen and
// 3 hexadecimal random characters.
RevisionId string `protobuf:"bytes,4,opt,name=revision_id,json=revisionId,proto3" json:"revision_id,omitempty"`
// Output only. The timestamp of when the workflow was created.
CreateTime *timestamppb.Timestamp `protobuf:"bytes,5,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
// Output only. The last update timestamp of the workflow.
UpdateTime *timestamppb.Timestamp `protobuf:"bytes,6,opt,name=update_time,json=updateTime,proto3" json:"update_time,omitempty"`
// Output only. The timestamp that the latest revision of the workflow
// was created.
RevisionCreateTime *timestamppb.Timestamp `protobuf:"bytes,7,opt,name=revision_create_time,json=revisionCreateTime,proto3" json:"revision_create_time,omitempty"`
// Labels associated with this workflow.
// Labels can contain at most 64 entries. Keys and values can be no longer
// than 63 characters and can only contain lowercase letters, numeric
// characters, underscores and dashes. Label keys must start with a letter.
// International characters are allowed.
Labels map[string]string `` /* 139-byte string literal not displayed */
// The service account associated with the latest workflow version.
// This service account represents the identity of the workflow and determines
// what permissions the workflow has.
// Format: projects/{project}/serviceAccounts/{account} or {account}
//
// Using `-` as a wildcard for the `{project}` or not providing one at all
// will infer the project from the account. The `{account}` value can be the
// `email` address or the `unique_id` of the service account.
//
// If not provided, workflow will use the project's default service account.
// Modifying this field for an existing workflow results in a new workflow
// revision.
ServiceAccount string `protobuf:"bytes,9,opt,name=service_account,json=serviceAccount,proto3" json:"service_account,omitempty"`
// Required. Location of the workflow source code.
// Modifying this field for an existing workflow results in a new workflow
// revision.
//
// Types that are valid to be assigned to SourceCode:
//
// *Workflow_SourceContents
SourceCode isWorkflow_SourceCode `protobuf_oneof:"source_code"`
// contains filtered or unexported fields
}
Workflow program to be executed by Workflows.
func (*Workflow) GetCreateTime ¶
func (x *Workflow) GetCreateTime() *timestamppb.Timestamp
func (*Workflow) GetRevisionCreateTime ¶
func (x *Workflow) GetRevisionCreateTime() *timestamppb.Timestamp
func (*Workflow) GetState ¶
func (x *Workflow) GetState() Workflow_State
func (*Workflow) GetUpdateTime ¶
func (x *Workflow) GetUpdateTime() *timestamppb.Timestamp
func (*Workflow) ProtoReflect ¶
func (x *Workflow) ProtoReflect() protoreflect.Message
func (*Workflow) SetCreateTime ¶
func (x *Workflow) SetCreateTime(v *timestamppb.Timestamp)
func (*Workflow) SetRevisionCreateTime ¶
func (x *Workflow) SetRevisionCreateTime(v *timestamppb.Timestamp)
func (*Workflow) SetState ¶
func (x *Workflow) SetState(v Workflow_State)
func (*Workflow) SetUpdateTime ¶
func (x *Workflow) SetUpdateTime(v *timestamppb.Timestamp)
type WorkflowCreatedEvent ¶
type WorkflowCreatedEvent struct {
// The data associated with the event.
Data *WorkflowEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
// contains filtered or unexported fields
}
The CloudEvent raised when a Workflow is created.
func (*WorkflowCreatedEvent) ClearData ¶
func (x *WorkflowCreatedEvent) ClearData()
func (*WorkflowCreatedEvent) GetData ¶
func (x *WorkflowCreatedEvent) GetData() *WorkflowEventData
func (*WorkflowCreatedEvent) HasData ¶
func (x *WorkflowCreatedEvent) HasData() bool
func (*WorkflowCreatedEvent) ProtoMessage ¶
func (*WorkflowCreatedEvent) ProtoMessage()
func (*WorkflowCreatedEvent) ProtoReflect ¶
func (x *WorkflowCreatedEvent) ProtoReflect() protoreflect.Message
func (*WorkflowCreatedEvent) Reset ¶
func (x *WorkflowCreatedEvent) Reset()
func (*WorkflowCreatedEvent) SetData ¶
func (x *WorkflowCreatedEvent) SetData(v *WorkflowEventData)
func (*WorkflowCreatedEvent) String ¶
func (x *WorkflowCreatedEvent) String() string
type WorkflowCreatedEvent_builder ¶
type WorkflowCreatedEvent_builder struct {
// The data associated with the event.
Data *WorkflowEventData
// contains filtered or unexported fields
}
func (WorkflowCreatedEvent_builder) Build ¶
func (b0 WorkflowCreatedEvent_builder) Build() *WorkflowCreatedEvent
type WorkflowDeletedEvent ¶
type WorkflowDeletedEvent struct {
// The data associated with the event.
Data *WorkflowEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
// contains filtered or unexported fields
}
The CloudEvent raised when a Workflow is deleted.
func (*WorkflowDeletedEvent) ClearData ¶
func (x *WorkflowDeletedEvent) ClearData()
func (*WorkflowDeletedEvent) GetData ¶
func (x *WorkflowDeletedEvent) GetData() *WorkflowEventData
func (*WorkflowDeletedEvent) HasData ¶
func (x *WorkflowDeletedEvent) HasData() bool
func (*WorkflowDeletedEvent) ProtoMessage ¶
func (*WorkflowDeletedEvent) ProtoMessage()
func (*WorkflowDeletedEvent) ProtoReflect ¶
func (x *WorkflowDeletedEvent) ProtoReflect() protoreflect.Message
func (*WorkflowDeletedEvent) Reset ¶
func (x *WorkflowDeletedEvent) Reset()
func (*WorkflowDeletedEvent) SetData ¶
func (x *WorkflowDeletedEvent) SetData(v *WorkflowEventData)
func (*WorkflowDeletedEvent) String ¶
func (x *WorkflowDeletedEvent) String() string
type WorkflowDeletedEvent_builder ¶
type WorkflowDeletedEvent_builder struct {
// The data associated with the event.
Data *WorkflowEventData
// contains filtered or unexported fields
}
func (WorkflowDeletedEvent_builder) Build ¶
func (b0 WorkflowDeletedEvent_builder) Build() *WorkflowDeletedEvent
type WorkflowEventData ¶
type WorkflowEventData struct {
// Optional. The Workflow event payload. Unset for deletion events.
Payload *Workflow `protobuf:"bytes,1,opt,name=payload,proto3,oneof" json:"payload,omitempty"`
// contains filtered or unexported fields
}
The data within all Workflow events.
func (*WorkflowEventData) ClearPayload ¶
func (x *WorkflowEventData) ClearPayload()
func (*WorkflowEventData) GetPayload ¶
func (x *WorkflowEventData) GetPayload() *Workflow
func (*WorkflowEventData) HasPayload ¶
func (x *WorkflowEventData) HasPayload() bool
func (*WorkflowEventData) ProtoMessage ¶
func (*WorkflowEventData) ProtoMessage()
func (*WorkflowEventData) ProtoReflect ¶
func (x *WorkflowEventData) ProtoReflect() protoreflect.Message
func (*WorkflowEventData) Reset ¶
func (x *WorkflowEventData) Reset()
func (*WorkflowEventData) SetPayload ¶
func (x *WorkflowEventData) SetPayload(v *Workflow)
func (*WorkflowEventData) String ¶
func (x *WorkflowEventData) String() string
type WorkflowEventData_builder ¶
type WorkflowEventData_builder struct {
// Optional. The Workflow event payload. Unset for deletion events.
Payload *Workflow
// contains filtered or unexported fields
}
func (WorkflowEventData_builder) Build ¶
func (b0 WorkflowEventData_builder) Build() *WorkflowEventData
type WorkflowUpdatedEvent ¶
type WorkflowUpdatedEvent struct {
// The data associated with the event.
Data *WorkflowEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
// contains filtered or unexported fields
}
The CloudEvent raised when a Workflow is updated.
func (*WorkflowUpdatedEvent) ClearData ¶
func (x *WorkflowUpdatedEvent) ClearData()
func (*WorkflowUpdatedEvent) GetData ¶
func (x *WorkflowUpdatedEvent) GetData() *WorkflowEventData
func (*WorkflowUpdatedEvent) HasData ¶
func (x *WorkflowUpdatedEvent) HasData() bool
func (*WorkflowUpdatedEvent) ProtoMessage ¶
func (*WorkflowUpdatedEvent) ProtoMessage()
func (*WorkflowUpdatedEvent) ProtoReflect ¶
func (x *WorkflowUpdatedEvent) ProtoReflect() protoreflect.Message
func (*WorkflowUpdatedEvent) Reset ¶
func (x *WorkflowUpdatedEvent) Reset()
func (*WorkflowUpdatedEvent) SetData ¶
func (x *WorkflowUpdatedEvent) SetData(v *WorkflowEventData)
func (*WorkflowUpdatedEvent) String ¶
func (x *WorkflowUpdatedEvent) String() string
type WorkflowUpdatedEvent_builder ¶
type WorkflowUpdatedEvent_builder struct {
// The data associated with the event.
Data *WorkflowEventData
// contains filtered or unexported fields
}
func (WorkflowUpdatedEvent_builder) Build ¶
func (b0 WorkflowUpdatedEvent_builder) Build() *WorkflowUpdatedEvent
type Workflow_SourceContents ¶
type Workflow_SourceContents struct {
// Workflow code to be executed. The size limit is 128KB.
SourceContents string `protobuf:"bytes,10,opt,name=source_contents,json=sourceContents,proto3,oneof"`
}
type Workflow_State ¶
type Workflow_State int32
Describes the current state of workflow deployment. More states may be added in the future.
const ( // Invalid state. Workflow_STATE_UNSPECIFIED Workflow_State = 0 // The workflow has been deployed successfully and is serving. Workflow_ACTIVE Workflow_State = 1 )
func (Workflow_State) Descriptor ¶
func (Workflow_State) Descriptor() protoreflect.EnumDescriptor
func (Workflow_State) Enum ¶
func (x Workflow_State) Enum() *Workflow_State
func (Workflow_State) Number ¶
func (x Workflow_State) Number() protoreflect.EnumNumber
func (Workflow_State) String ¶
func (x Workflow_State) String() string
func (Workflow_State) Type ¶
func (Workflow_State) Type() protoreflect.EnumType
type Workflow_builder ¶
type Workflow_builder struct {
// The resource name of the workflow.
// Format: projects/{project}/locations/{location}/workflows/{workflow}
Name string
// Description of the workflow provided by the user.
// Must be at most 1000 unicode characters long.
Description string
// Output only. State of the workflow deployment.
State Workflow_State
// Output only. The revision of the workflow.
// A new revision of a workflow is created as a result of updating the
// following properties of a workflow:
//
// - [Service account][google.cloud.workflows.v1.Workflow.service_account]
// - [Workflow code to be
// executed][google.cloud.workflows.v1.Workflow.source_contents]
//
// The format is "000001-a4d", where the first 6 characters define
// the zero-padded revision ordinal number. They are followed by a hyphen and
// 3 hexadecimal random characters.
RevisionId string
// Output only. The timestamp of when the workflow was created.
CreateTime *timestamppb.Timestamp
// Output only. The last update timestamp of the workflow.
UpdateTime *timestamppb.Timestamp
// Output only. The timestamp that the latest revision of the workflow
// was created.
RevisionCreateTime *timestamppb.Timestamp
// Labels associated with this workflow.
// Labels can contain at most 64 entries. Keys and values can be no longer
// than 63 characters and can only contain lowercase letters, numeric
// characters, underscores and dashes. Label keys must start with a letter.
// International characters are allowed.
Labels map[string]string
// The service account associated with the latest workflow version.
// This service account represents the identity of the workflow and determines
// what permissions the workflow has.
// Format: projects/{project}/serviceAccounts/{account} or {account}
//
// Using `-` as a wildcard for the `{project}` or not providing one at all
// will infer the project from the account. The `{account}` value can be the
// `email` address or the `unique_id` of the service account.
//
// If not provided, workflow will use the project's default service account.
// Modifying this field for an existing workflow results in a new workflow
// revision.
ServiceAccount string
// Fields of oneof SourceCode:
// Workflow code to be executed. The size limit is 128KB.
SourceContents *string
// contains filtered or unexported fields
}
func (Workflow_builder) Build ¶
func (b0 Workflow_builder) Build() *Workflow
Source Files
¶
- data.pb.go
- events.pb.go
Click to show internal directories.
Click to hide internal directories.