Documentation
¶
Index ¶
- Constants
- Variables
- type AnalyticsLogData
- func (x *AnalyticsLogData) ClearUserDim()
- func (x *AnalyticsLogData) GetEventDim() []*EventDimensions
- func (x *AnalyticsLogData) GetUserDim() *UserDimensions
- func (x *AnalyticsLogData) HasUserDim() bool
- func (*AnalyticsLogData) ProtoMessage()
- func (x *AnalyticsLogData) ProtoReflect() protoreflect.Message
- func (x *AnalyticsLogData) Reset()
- func (x *AnalyticsLogData) SetEventDim(v []*EventDimensions)
- func (x *AnalyticsLogData) SetUserDim(v *UserDimensions)
- func (x *AnalyticsLogData) String() string
- type AnalyticsLogData_builder
- type AnalyticsLogWrittenEvent
- func (x *AnalyticsLogWrittenEvent) ClearData()
- func (x *AnalyticsLogWrittenEvent) GetData() *AnalyticsLogData
- func (x *AnalyticsLogWrittenEvent) HasData() bool
- func (*AnalyticsLogWrittenEvent) ProtoMessage()
- func (x *AnalyticsLogWrittenEvent) ProtoReflect() protoreflect.Message
- func (x *AnalyticsLogWrittenEvent) Reset()
- func (x *AnalyticsLogWrittenEvent) SetData(v *AnalyticsLogData)
- func (x *AnalyticsLogWrittenEvent) String() string
- type AnalyticsLogWrittenEvent_builder
- type AnalyticsValue
- func (x *AnalyticsValue) ClearDoubleValue()
- func (x *AnalyticsValue) ClearFloatValue()
- func (x *AnalyticsValue) ClearIntValue()
- func (x *AnalyticsValue) ClearParamValue()
- func (x *AnalyticsValue) ClearStringValue()
- func (x *AnalyticsValue) GetDoubleValue() float64
- func (x *AnalyticsValue) GetFloatValue() float32
- func (x *AnalyticsValue) GetIntValue() int64
- func (x *AnalyticsValue) GetParamValue() isAnalyticsValue_ParamValue
- func (x *AnalyticsValue) GetStringValue() string
- func (x *AnalyticsValue) HasDoubleValue() bool
- func (x *AnalyticsValue) HasFloatValue() bool
- func (x *AnalyticsValue) HasIntValue() bool
- func (x *AnalyticsValue) HasParamValue() bool
- func (x *AnalyticsValue) HasStringValue() bool
- func (*AnalyticsValue) ProtoMessage()
- func (x *AnalyticsValue) ProtoReflect() protoreflect.Message
- func (x *AnalyticsValue) Reset()
- func (x *AnalyticsValue) SetDoubleValue(v float64)
- func (x *AnalyticsValue) SetFloatValue(v float32)
- func (x *AnalyticsValue) SetIntValue(v int64)
- func (x *AnalyticsValue) SetStringValue(v string)
- func (x *AnalyticsValue) String() string
- func (x *AnalyticsValue) WhichParamValue() case_AnalyticsValue_ParamValue
- type AnalyticsValue_DoubleValue
- type AnalyticsValue_FloatValue
- type AnalyticsValue_IntValue
- type AnalyticsValue_StringValue
- type AnalyticsValue_builder
- type AppInfo
- func (x *AppInfo) GetAppId() string
- func (x *AppInfo) GetAppInstanceId() string
- func (x *AppInfo) GetAppPlatform() string
- func (x *AppInfo) GetAppStore() string
- func (x *AppInfo) GetAppVersion() string
- func (*AppInfo) ProtoMessage()
- func (x *AppInfo) ProtoReflect() protoreflect.Message
- func (x *AppInfo) Reset()
- func (x *AppInfo) SetAppId(v string)
- func (x *AppInfo) SetAppInstanceId(v string)
- func (x *AppInfo) SetAppPlatform(v string)
- func (x *AppInfo) SetAppStore(v string)
- func (x *AppInfo) SetAppVersion(v string)
- func (x *AppInfo) String() string
- type AppInfo_builder
- type DeviceInfo
- func (x *DeviceInfo) GetDeviceCategory() string
- func (x *DeviceInfo) GetDeviceId() string
- func (x *DeviceInfo) GetDeviceModel() string
- func (x *DeviceInfo) GetDeviceTimeZoneOffsetSeconds() int32
- func (x *DeviceInfo) GetLimitedAdTracking() bool
- func (x *DeviceInfo) GetMobileBrandName() string
- func (x *DeviceInfo) GetMobileMarketingName() string
- func (x *DeviceInfo) GetMobileModelName() string
- func (x *DeviceInfo) GetPlatformVersion() string
- func (x *DeviceInfo) GetResettableDeviceId() string
- func (x *DeviceInfo) GetUserDefaultLanguage() string
- func (*DeviceInfo) ProtoMessage()
- func (x *DeviceInfo) ProtoReflect() protoreflect.Message
- func (x *DeviceInfo) Reset()
- func (x *DeviceInfo) SetDeviceCategory(v string)
- func (x *DeviceInfo) SetDeviceId(v string)
- func (x *DeviceInfo) SetDeviceModel(v string)
- func (x *DeviceInfo) SetDeviceTimeZoneOffsetSeconds(v int32)
- func (x *DeviceInfo) SetLimitedAdTracking(v bool)
- func (x *DeviceInfo) SetMobileBrandName(v string)
- func (x *DeviceInfo) SetMobileMarketingName(v string)
- func (x *DeviceInfo) SetMobileModelName(v string)
- func (x *DeviceInfo) SetPlatformVersion(v string)
- func (x *DeviceInfo) SetResettableDeviceId(v string)
- func (x *DeviceInfo) SetUserDefaultLanguage(v string)
- func (x *DeviceInfo) String() string
- type DeviceInfo_builder
- type EventDimensions
- func (x *EventDimensions) GetDate() string
- func (x *EventDimensions) GetName() string
- func (x *EventDimensions) GetParams() map[string]*AnalyticsValue
- func (x *EventDimensions) GetPreviousTimestampMicros() int64
- func (x *EventDimensions) GetTimestampMicros() int64
- func (x *EventDimensions) GetValueInUsd() float64
- func (*EventDimensions) ProtoMessage()
- func (x *EventDimensions) ProtoReflect() protoreflect.Message
- func (x *EventDimensions) Reset()
- func (x *EventDimensions) SetDate(v string)
- func (x *EventDimensions) SetName(v string)
- func (x *EventDimensions) SetParams(v map[string]*AnalyticsValue)
- func (x *EventDimensions) SetPreviousTimestampMicros(v int64)
- func (x *EventDimensions) SetTimestampMicros(v int64)
- func (x *EventDimensions) SetValueInUsd(v float64)
- func (x *EventDimensions) String() string
- type EventDimensions_builder
- type ExportBundleInfo
- func (x *ExportBundleInfo) GetBundleSequenceId() int32
- func (x *ExportBundleInfo) GetServerTimestampOffsetMicros() int64
- func (*ExportBundleInfo) ProtoMessage()
- func (x *ExportBundleInfo) ProtoReflect() protoreflect.Message
- func (x *ExportBundleInfo) Reset()
- func (x *ExportBundleInfo) SetBundleSequenceId(v int32)
- func (x *ExportBundleInfo) SetServerTimestampOffsetMicros(v int64)
- func (x *ExportBundleInfo) String() string
- type ExportBundleInfo_builder
- type GeoInfo
- func (x *GeoInfo) GetCity() string
- func (x *GeoInfo) GetContinent() string
- func (x *GeoInfo) GetCountry() string
- func (x *GeoInfo) GetRegion() string
- func (*GeoInfo) ProtoMessage()
- func (x *GeoInfo) ProtoReflect() protoreflect.Message
- func (x *GeoInfo) Reset()
- func (x *GeoInfo) SetCity(v string)
- func (x *GeoInfo) SetContinent(v string)
- func (x *GeoInfo) SetCountry(v string)
- func (x *GeoInfo) SetRegion(v string)
- func (x *GeoInfo) String() string
- type GeoInfo_builder
- type LtvInfo
- func (x *LtvInfo) GetCurrency() string
- func (x *LtvInfo) GetRevenue() float64
- func (*LtvInfo) ProtoMessage()
- func (x *LtvInfo) ProtoReflect() protoreflect.Message
- func (x *LtvInfo) Reset()
- func (x *LtvInfo) SetCurrency(v string)
- func (x *LtvInfo) SetRevenue(v float64)
- func (x *LtvInfo) String() string
- type LtvInfo_builder
- type TrafficSource
- func (x *TrafficSource) GetUserAcquiredCampaign() string
- func (x *TrafficSource) GetUserAcquiredMedium() string
- func (x *TrafficSource) GetUserAcquiredSource() string
- func (*TrafficSource) ProtoMessage()
- func (x *TrafficSource) ProtoReflect() protoreflect.Message
- func (x *TrafficSource) Reset()
- func (x *TrafficSource) SetUserAcquiredCampaign(v string)
- func (x *TrafficSource) SetUserAcquiredMedium(v string)
- func (x *TrafficSource) SetUserAcquiredSource(v string)
- func (x *TrafficSource) String() string
- type TrafficSource_builder
- type UserDimensions
- func (x *UserDimensions) ClearAppInfo()
- func (x *UserDimensions) ClearBundleInfo()
- func (x *UserDimensions) ClearDeviceInfo()
- func (x *UserDimensions) ClearGeoInfo()
- func (x *UserDimensions) ClearLtvInfo()
- func (x *UserDimensions) ClearTrafficSource()
- func (x *UserDimensions) GetAppInfo() *AppInfo
- func (x *UserDimensions) GetBundleInfo() *ExportBundleInfo
- func (x *UserDimensions) GetDeviceInfo() *DeviceInfo
- func (x *UserDimensions) GetFirstOpenTimestampMicros() int64
- func (x *UserDimensions) GetGeoInfo() *GeoInfo
- func (x *UserDimensions) GetLtvInfo() *LtvInfo
- func (x *UserDimensions) GetTrafficSource() *TrafficSource
- func (x *UserDimensions) GetUserId() string
- func (x *UserDimensions) GetUserProperties() map[string]*UserPropertyValue
- func (x *UserDimensions) HasAppInfo() bool
- func (x *UserDimensions) HasBundleInfo() bool
- func (x *UserDimensions) HasDeviceInfo() bool
- func (x *UserDimensions) HasGeoInfo() bool
- func (x *UserDimensions) HasLtvInfo() bool
- func (x *UserDimensions) HasTrafficSource() bool
- func (*UserDimensions) ProtoMessage()
- func (x *UserDimensions) ProtoReflect() protoreflect.Message
- func (x *UserDimensions) Reset()
- func (x *UserDimensions) SetAppInfo(v *AppInfo)
- func (x *UserDimensions) SetBundleInfo(v *ExportBundleInfo)
- func (x *UserDimensions) SetDeviceInfo(v *DeviceInfo)
- func (x *UserDimensions) SetFirstOpenTimestampMicros(v int64)
- func (x *UserDimensions) SetGeoInfo(v *GeoInfo)
- func (x *UserDimensions) SetLtvInfo(v *LtvInfo)
- func (x *UserDimensions) SetTrafficSource(v *TrafficSource)
- func (x *UserDimensions) SetUserId(v string)
- func (x *UserDimensions) SetUserProperties(v map[string]*UserPropertyValue)
- func (x *UserDimensions) String() string
- type UserDimensions_builder
- type UserPropertyValue
- func (x *UserPropertyValue) ClearValue()
- func (x *UserPropertyValue) GetIndex() int32
- func (x *UserPropertyValue) GetSetTimestampUsec() int64
- func (x *UserPropertyValue) GetValue() *AnalyticsValue
- func (x *UserPropertyValue) HasValue() bool
- func (*UserPropertyValue) ProtoMessage()
- func (x *UserPropertyValue) ProtoReflect() protoreflect.Message
- func (x *UserPropertyValue) Reset()
- func (x *UserPropertyValue) SetIndex(v int32)
- func (x *UserPropertyValue) SetSetTimestampUsec(v int64)
- func (x *UserPropertyValue) SetValue(v *AnalyticsValue)
- func (x *UserPropertyValue) String() string
- type UserPropertyValue_builder
Constants ¶
const AnalyticsValue_DoubleValue_case case_AnalyticsValue_ParamValue = 4
const AnalyticsValue_FloatValue_case case_AnalyticsValue_ParamValue = 3
const AnalyticsValue_IntValue_case case_AnalyticsValue_ParamValue = 2
const AnalyticsValue_ParamValue_not_set_case case_AnalyticsValue_ParamValue = 0
const AnalyticsValue_StringValue_case case_AnalyticsValue_ParamValue = 1
Variables ¶
var File_google_events_firebase_analytics_v1_data_proto protoreflect.FileDescriptor
var File_google_events_firebase_analytics_v1_events_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type AnalyticsLogData ¶
type AnalyticsLogData struct {
// User related dimensions.
UserDim *UserDimensions `protobuf:"bytes,1,opt,name=user_dim,json=userDim,proto3" json:"user_dim,omitempty"`
// A repeated record of event related dimensions.
EventDim []*EventDimensions `protobuf:"bytes,2,rep,name=event_dim,json=eventDim,proto3" json:"event_dim,omitempty"`
// contains filtered or unexported fields
}
The data within Firebase Analytics log events.
func (*AnalyticsLogData) ClearUserDim ¶
func (x *AnalyticsLogData) ClearUserDim()
func (*AnalyticsLogData) GetEventDim ¶
func (x *AnalyticsLogData) GetEventDim() []*EventDimensions
func (*AnalyticsLogData) GetUserDim ¶
func (x *AnalyticsLogData) GetUserDim() *UserDimensions
func (*AnalyticsLogData) HasUserDim ¶
func (x *AnalyticsLogData) HasUserDim() bool
func (*AnalyticsLogData) ProtoMessage ¶
func (*AnalyticsLogData) ProtoMessage()
func (*AnalyticsLogData) ProtoReflect ¶
func (x *AnalyticsLogData) ProtoReflect() protoreflect.Message
func (*AnalyticsLogData) Reset ¶
func (x *AnalyticsLogData) Reset()
func (*AnalyticsLogData) SetEventDim ¶
func (x *AnalyticsLogData) SetEventDim(v []*EventDimensions)
func (*AnalyticsLogData) SetUserDim ¶
func (x *AnalyticsLogData) SetUserDim(v *UserDimensions)
func (*AnalyticsLogData) String ¶
func (x *AnalyticsLogData) String() string
type AnalyticsLogData_builder ¶
type AnalyticsLogData_builder struct {
// User related dimensions.
UserDim *UserDimensions
// A repeated record of event related dimensions.
EventDim []*EventDimensions
// contains filtered or unexported fields
}
func (AnalyticsLogData_builder) Build ¶
func (b0 AnalyticsLogData_builder) Build() *AnalyticsLogData
type AnalyticsLogWrittenEvent ¶
type AnalyticsLogWrittenEvent struct {
// The data associated with the event.
Data *AnalyticsLogData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
// contains filtered or unexported fields
}
The CloudEvent raised when a Firebase Analytics log is written.
func (*AnalyticsLogWrittenEvent) ClearData ¶
func (x *AnalyticsLogWrittenEvent) ClearData()
func (*AnalyticsLogWrittenEvent) GetData ¶
func (x *AnalyticsLogWrittenEvent) GetData() *AnalyticsLogData
func (*AnalyticsLogWrittenEvent) HasData ¶
func (x *AnalyticsLogWrittenEvent) HasData() bool
func (*AnalyticsLogWrittenEvent) ProtoMessage ¶
func (*AnalyticsLogWrittenEvent) ProtoMessage()
func (*AnalyticsLogWrittenEvent) ProtoReflect ¶
func (x *AnalyticsLogWrittenEvent) ProtoReflect() protoreflect.Message
func (*AnalyticsLogWrittenEvent) Reset ¶
func (x *AnalyticsLogWrittenEvent) Reset()
func (*AnalyticsLogWrittenEvent) SetData ¶
func (x *AnalyticsLogWrittenEvent) SetData(v *AnalyticsLogData)
func (*AnalyticsLogWrittenEvent) String ¶
func (x *AnalyticsLogWrittenEvent) String() string
type AnalyticsLogWrittenEvent_builder ¶
type AnalyticsLogWrittenEvent_builder struct {
// The data associated with the event.
Data *AnalyticsLogData
// contains filtered or unexported fields
}
func (AnalyticsLogWrittenEvent_builder) Build ¶
func (b0 AnalyticsLogWrittenEvent_builder) Build() *AnalyticsLogWrittenEvent
type AnalyticsValue ¶
type AnalyticsValue struct {
// Types that are valid to be assigned to ParamValue:
//
// *AnalyticsValue_StringValue
// *AnalyticsValue_IntValue
// *AnalyticsValue_FloatValue
// *AnalyticsValue_DoubleValue
ParamValue isAnalyticsValue_ParamValue `protobuf_oneof:"param_value"`
// contains filtered or unexported fields
}
Value for Event Params and UserProperty can be of type string or int or float or double.
func (*AnalyticsValue) ClearDoubleValue ¶
func (x *AnalyticsValue) ClearDoubleValue()
func (*AnalyticsValue) ClearFloatValue ¶
func (x *AnalyticsValue) ClearFloatValue()
func (*AnalyticsValue) ClearIntValue ¶
func (x *AnalyticsValue) ClearIntValue()
func (*AnalyticsValue) ClearParamValue ¶
func (x *AnalyticsValue) ClearParamValue()
func (*AnalyticsValue) ClearStringValue ¶
func (x *AnalyticsValue) ClearStringValue()
func (*AnalyticsValue) GetDoubleValue ¶
func (x *AnalyticsValue) GetDoubleValue() float64
func (*AnalyticsValue) GetFloatValue ¶
func (x *AnalyticsValue) GetFloatValue() float32
func (*AnalyticsValue) GetIntValue ¶
func (x *AnalyticsValue) GetIntValue() int64
func (*AnalyticsValue) GetParamValue ¶
func (x *AnalyticsValue) GetParamValue() isAnalyticsValue_ParamValue
func (*AnalyticsValue) GetStringValue ¶
func (x *AnalyticsValue) GetStringValue() string
func (*AnalyticsValue) HasDoubleValue ¶
func (x *AnalyticsValue) HasDoubleValue() bool
func (*AnalyticsValue) HasFloatValue ¶
func (x *AnalyticsValue) HasFloatValue() bool
func (*AnalyticsValue) HasIntValue ¶
func (x *AnalyticsValue) HasIntValue() bool
func (*AnalyticsValue) HasParamValue ¶
func (x *AnalyticsValue) HasParamValue() bool
func (*AnalyticsValue) HasStringValue ¶
func (x *AnalyticsValue) HasStringValue() bool
func (*AnalyticsValue) ProtoMessage ¶
func (*AnalyticsValue) ProtoMessage()
func (*AnalyticsValue) ProtoReflect ¶
func (x *AnalyticsValue) ProtoReflect() protoreflect.Message
func (*AnalyticsValue) Reset ¶
func (x *AnalyticsValue) Reset()
func (*AnalyticsValue) SetDoubleValue ¶
func (x *AnalyticsValue) SetDoubleValue(v float64)
func (*AnalyticsValue) SetFloatValue ¶
func (x *AnalyticsValue) SetFloatValue(v float32)
func (*AnalyticsValue) SetIntValue ¶
func (x *AnalyticsValue) SetIntValue(v int64)
func (*AnalyticsValue) SetStringValue ¶
func (x *AnalyticsValue) SetStringValue(v string)
func (*AnalyticsValue) String ¶
func (x *AnalyticsValue) String() string
func (*AnalyticsValue) WhichParamValue ¶
func (x *AnalyticsValue) WhichParamValue() case_AnalyticsValue_ParamValue
type AnalyticsValue_DoubleValue ¶
type AnalyticsValue_DoubleValue struct {
DoubleValue float64 `protobuf:"fixed64,4,opt,name=double_value,json=doubleValue,proto3,oneof"`
}
type AnalyticsValue_FloatValue ¶
type AnalyticsValue_FloatValue struct {
FloatValue float32 `protobuf:"fixed32,3,opt,name=float_value,json=floatValue,proto3,oneof"`
}
type AnalyticsValue_IntValue ¶
type AnalyticsValue_IntValue struct {
IntValue int64 `protobuf:"varint,2,opt,name=int_value,json=intValue,proto3,oneof"`
}
type AnalyticsValue_StringValue ¶
type AnalyticsValue_StringValue struct {
StringValue string `protobuf:"bytes,1,opt,name=string_value,json=stringValue,proto3,oneof"`
}
type AnalyticsValue_builder ¶
type AnalyticsValue_builder struct {
// Fields of oneof ParamValue:
StringValue *string
IntValue *int64
FloatValue *float32
DoubleValue *float64
// contains filtered or unexported fields
}
func (AnalyticsValue_builder) Build ¶
func (b0 AnalyticsValue_builder) Build() *AnalyticsValue
type AppInfo ¶
type AppInfo struct {
// The app's version name
// Examples: "1.0", "4.3.1.1.213361", "2.3 (1824253)", "v1.8b22p6"
AppVersion string `protobuf:"bytes,1,opt,name=app_version,json=appVersion,proto3" json:"app_version,omitempty"`
// Unique id for this instance of the app.
// Example: "71683BF9FA3B4B0D9535A1F05188BAF3"
AppInstanceId string `protobuf:"bytes,2,opt,name=app_instance_id,json=appInstanceId,proto3" json:"app_instance_id,omitempty"`
// The identifier of the store that installed the app.
// Eg. "com.sec.android.app.samsungapps", "com.amazon.venezia",
// "com.nokia.nstore"
AppStore string `protobuf:"bytes,3,opt,name=app_store,json=appStore,proto3" json:"app_store,omitempty"`
// The app platform.
// Eg "ANDROID", "IOS".
AppPlatform string `protobuf:"bytes,4,opt,name=app_platform,json=appPlatform,proto3" json:"app_platform,omitempty"`
// Unique application identifier within an app store.
AppId string `protobuf:"bytes,5,opt,name=app_id,json=appId,proto3" json:"app_id,omitempty"`
// contains filtered or unexported fields
}
Message which contains App Information.
func (*AppInfo) ProtoReflect ¶
func (x *AppInfo) ProtoReflect() protoreflect.Message
type AppInfo_builder ¶
type AppInfo_builder struct {
// The app's version name
// Examples: "1.0", "4.3.1.1.213361", "2.3 (1824253)", "v1.8b22p6"
AppVersion string
// Unique id for this instance of the app.
// Example: "71683BF9FA3B4B0D9535A1F05188BAF3"
AppInstanceId string
// The identifier of the store that installed the app.
// Eg. "com.sec.android.app.samsungapps", "com.amazon.venezia",
// "com.nokia.nstore"
AppStore string
// The app platform.
// Eg "ANDROID", "IOS".
AppPlatform string
// Unique application identifier within an app store.
AppId string
// contains filtered or unexported fields
}
func (AppInfo_builder) Build ¶
func (b0 AppInfo_builder) Build() *AppInfo
type DeviceInfo ¶
type DeviceInfo struct {
// Device category.
// Eg. tablet or mobile.
DeviceCategory string `protobuf:"bytes,1,opt,name=device_category,json=deviceCategory,proto3" json:"device_category,omitempty"`
// Device brand name.
// Eg. Samsung, HTC, etc.
MobileBrandName string `protobuf:"bytes,2,opt,name=mobile_brand_name,json=mobileBrandName,proto3" json:"mobile_brand_name,omitempty"`
// Device model name.
// Eg. GT-I9192
MobileModelName string `protobuf:"bytes,3,opt,name=mobile_model_name,json=mobileModelName,proto3" json:"mobile_model_name,omitempty"`
// Device marketing name.
// Eg. Galaxy S4 Mini
MobileMarketingName string `protobuf:"bytes,4,opt,name=mobile_marketing_name,json=mobileMarketingName,proto3" json:"mobile_marketing_name,omitempty"`
// Device model.
// Eg. GT-I9192
DeviceModel string `protobuf:"bytes,12,opt,name=device_model,json=deviceModel,proto3" json:"device_model,omitempty"`
// Device OS version when data capture ended.
// Eg. 4.4.2
PlatformVersion string `protobuf:"bytes,6,opt,name=platform_version,json=platformVersion,proto3" json:"platform_version,omitempty"`
// Vendor specific device identifier. This is IDFV on iOS. Not used for
// Android.
// Example: "599F9C00-92DC-4B5C-9464-7971F01F8370"
DeviceId string `protobuf:"bytes,7,opt,name=device_id,json=deviceId,proto3" json:"device_id,omitempty"`
// The type of the resettable_device_id is always IDFA on iOS and AdId
// on Android.
// Example: "71683BF9-FA3B-4B0D-9535-A1F05188BAF3"
ResettableDeviceId string `protobuf:"bytes,8,opt,name=resettable_device_id,json=resettableDeviceId,proto3" json:"resettable_device_id,omitempty"`
// The user language.
// Eg. "en-us", "en-za", "zh-tw", "jp"
UserDefaultLanguage string `protobuf:"bytes,9,opt,name=user_default_language,json=userDefaultLanguage,proto3" json:"user_default_language,omitempty"`
// The timezone of the device when data was uploaded as seconds skew from UTC.
DeviceTimeZoneOffsetSeconds int32 `` /* 150-byte string literal not displayed */
// The device's Limit Ad Tracking setting.
// When true, we cannot use device_id for remarketing, demographics or
// influencing ads serving behaviour. However, we can use device_id for
// conversion tracking and campaign attribution.
LimitedAdTracking bool `protobuf:"varint,11,opt,name=limited_ad_tracking,json=limitedAdTracking,proto3" json:"limited_ad_tracking,omitempty"`
// contains filtered or unexported fields
}
Message containing device informations.
func (*DeviceInfo) GetDeviceCategory ¶
func (x *DeviceInfo) GetDeviceCategory() string
func (*DeviceInfo) GetDeviceId ¶
func (x *DeviceInfo) GetDeviceId() string
func (*DeviceInfo) GetDeviceModel ¶
func (x *DeviceInfo) GetDeviceModel() string
func (*DeviceInfo) GetDeviceTimeZoneOffsetSeconds ¶
func (x *DeviceInfo) GetDeviceTimeZoneOffsetSeconds() int32
func (*DeviceInfo) GetLimitedAdTracking ¶
func (x *DeviceInfo) GetLimitedAdTracking() bool
func (*DeviceInfo) GetMobileBrandName ¶
func (x *DeviceInfo) GetMobileBrandName() string
func (*DeviceInfo) GetMobileMarketingName ¶
func (x *DeviceInfo) GetMobileMarketingName() string
func (*DeviceInfo) GetMobileModelName ¶
func (x *DeviceInfo) GetMobileModelName() string
func (*DeviceInfo) GetPlatformVersion ¶
func (x *DeviceInfo) GetPlatformVersion() string
func (*DeviceInfo) GetResettableDeviceId ¶
func (x *DeviceInfo) GetResettableDeviceId() string
func (*DeviceInfo) GetUserDefaultLanguage ¶
func (x *DeviceInfo) GetUserDefaultLanguage() string
func (*DeviceInfo) ProtoMessage ¶
func (*DeviceInfo) ProtoMessage()
func (*DeviceInfo) ProtoReflect ¶
func (x *DeviceInfo) ProtoReflect() protoreflect.Message
func (*DeviceInfo) Reset ¶
func (x *DeviceInfo) Reset()
func (*DeviceInfo) SetDeviceCategory ¶
func (x *DeviceInfo) SetDeviceCategory(v string)
func (*DeviceInfo) SetDeviceId ¶
func (x *DeviceInfo) SetDeviceId(v string)
func (*DeviceInfo) SetDeviceModel ¶
func (x *DeviceInfo) SetDeviceModel(v string)
func (*DeviceInfo) SetDeviceTimeZoneOffsetSeconds ¶
func (x *DeviceInfo) SetDeviceTimeZoneOffsetSeconds(v int32)
func (*DeviceInfo) SetLimitedAdTracking ¶
func (x *DeviceInfo) SetLimitedAdTracking(v bool)
func (*DeviceInfo) SetMobileBrandName ¶
func (x *DeviceInfo) SetMobileBrandName(v string)
func (*DeviceInfo) SetMobileMarketingName ¶
func (x *DeviceInfo) SetMobileMarketingName(v string)
func (*DeviceInfo) SetMobileModelName ¶
func (x *DeviceInfo) SetMobileModelName(v string)
func (*DeviceInfo) SetPlatformVersion ¶
func (x *DeviceInfo) SetPlatformVersion(v string)
func (*DeviceInfo) SetResettableDeviceId ¶
func (x *DeviceInfo) SetResettableDeviceId(v string)
func (*DeviceInfo) SetUserDefaultLanguage ¶
func (x *DeviceInfo) SetUserDefaultLanguage(v string)
func (*DeviceInfo) String ¶
func (x *DeviceInfo) String() string
type DeviceInfo_builder ¶
type DeviceInfo_builder struct {
// Device category.
// Eg. tablet or mobile.
DeviceCategory string
// Device brand name.
// Eg. Samsung, HTC, etc.
MobileBrandName string
// Device model name.
// Eg. GT-I9192
MobileModelName string
// Device marketing name.
// Eg. Galaxy S4 Mini
MobileMarketingName string
// Device model.
// Eg. GT-I9192
DeviceModel string
// Device OS version when data capture ended.
// Eg. 4.4.2
PlatformVersion string
// Vendor specific device identifier. This is IDFV on iOS. Not used for
// Android.
// Example: "599F9C00-92DC-4B5C-9464-7971F01F8370"
DeviceId string
// The type of the resettable_device_id is always IDFA on iOS and AdId
// on Android.
// Example: "71683BF9-FA3B-4B0D-9535-A1F05188BAF3"
ResettableDeviceId string
// The user language.
// Eg. "en-us", "en-za", "zh-tw", "jp"
UserDefaultLanguage string
// The timezone of the device when data was uploaded as seconds skew from UTC.
DeviceTimeZoneOffsetSeconds int32
// The device's Limit Ad Tracking setting.
// When true, we cannot use device_id for remarketing, demographics or
// influencing ads serving behaviour. However, we can use device_id for
// conversion tracking and campaign attribution.
LimitedAdTracking bool
// contains filtered or unexported fields
}
func (DeviceInfo_builder) Build ¶
func (b0 DeviceInfo_builder) Build() *DeviceInfo
type EventDimensions ¶
type EventDimensions struct {
// The date on which this event was logged.
// (YYYYMMDD format in the registered timezone of your app.)
Date string `protobuf:"bytes,6,opt,name=date,proto3" json:"date,omitempty"`
// The name of this event.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// A repeated record of the parameters associated with this event.
Params map[string]*AnalyticsValue `` /* 139-byte string literal not displayed */
// UTC client time when the event happened.
TimestampMicros int64 `protobuf:"varint,4,opt,name=timestamp_micros,json=timestampMicros,proto3" json:"timestamp_micros,omitempty"`
// UTC client time when the previous event happened.
PreviousTimestampMicros int64 `` /* 133-byte string literal not displayed */
// Value param in USD.
ValueInUsd float64 `protobuf:"fixed64,7,opt,name=value_in_usd,json=valueInUsd,proto3" json:"value_in_usd,omitempty"`
// contains filtered or unexported fields
}
Message containing information pertaining to the event.
func (*EventDimensions) GetDate ¶
func (x *EventDimensions) GetDate() string
func (*EventDimensions) GetName ¶
func (x *EventDimensions) GetName() string
func (*EventDimensions) GetParams ¶
func (x *EventDimensions) GetParams() map[string]*AnalyticsValue
func (*EventDimensions) GetPreviousTimestampMicros ¶
func (x *EventDimensions) GetPreviousTimestampMicros() int64
func (*EventDimensions) GetTimestampMicros ¶
func (x *EventDimensions) GetTimestampMicros() int64
func (*EventDimensions) GetValueInUsd ¶
func (x *EventDimensions) GetValueInUsd() float64
func (*EventDimensions) ProtoMessage ¶
func (*EventDimensions) ProtoMessage()
func (*EventDimensions) ProtoReflect ¶
func (x *EventDimensions) ProtoReflect() protoreflect.Message
func (*EventDimensions) Reset ¶
func (x *EventDimensions) Reset()
func (*EventDimensions) SetDate ¶
func (x *EventDimensions) SetDate(v string)
func (*EventDimensions) SetName ¶
func (x *EventDimensions) SetName(v string)
func (*EventDimensions) SetParams ¶
func (x *EventDimensions) SetParams(v map[string]*AnalyticsValue)
func (*EventDimensions) SetPreviousTimestampMicros ¶
func (x *EventDimensions) SetPreviousTimestampMicros(v int64)
func (*EventDimensions) SetTimestampMicros ¶
func (x *EventDimensions) SetTimestampMicros(v int64)
func (*EventDimensions) SetValueInUsd ¶
func (x *EventDimensions) SetValueInUsd(v float64)
func (*EventDimensions) String ¶
func (x *EventDimensions) String() string
type EventDimensions_builder ¶
type EventDimensions_builder struct {
// The date on which this event was logged.
// (YYYYMMDD format in the registered timezone of your app.)
Date string
// The name of this event.
Name string
// A repeated record of the parameters associated with this event.
Params map[string]*AnalyticsValue
// UTC client time when the event happened.
TimestampMicros int64
// UTC client time when the previous event happened.
PreviousTimestampMicros int64
// Value param in USD.
ValueInUsd float64
// contains filtered or unexported fields
}
func (EventDimensions_builder) Build ¶
func (b0 EventDimensions_builder) Build() *EventDimensions
type ExportBundleInfo ¶
type ExportBundleInfo struct {
// Monotonically increasing index for each bundle set by SDK.
BundleSequenceId int32 `protobuf:"varint,1,opt,name=bundle_sequence_id,json=bundleSequenceId,proto3" json:"bundle_sequence_id,omitempty"`
// Timestamp offset between collection time and upload time.
ServerTimestampOffsetMicros int64 `` /* 147-byte string literal not displayed */
// contains filtered or unexported fields
}
Message containing information regarding the bundle in which these events were uploaded.
func (*ExportBundleInfo) GetBundleSequenceId ¶
func (x *ExportBundleInfo) GetBundleSequenceId() int32
func (*ExportBundleInfo) GetServerTimestampOffsetMicros ¶
func (x *ExportBundleInfo) GetServerTimestampOffsetMicros() int64
func (*ExportBundleInfo) ProtoMessage ¶
func (*ExportBundleInfo) ProtoMessage()
func (*ExportBundleInfo) ProtoReflect ¶
func (x *ExportBundleInfo) ProtoReflect() protoreflect.Message
func (*ExportBundleInfo) Reset ¶
func (x *ExportBundleInfo) Reset()
func (*ExportBundleInfo) SetBundleSequenceId ¶
func (x *ExportBundleInfo) SetBundleSequenceId(v int32)
func (*ExportBundleInfo) SetServerTimestampOffsetMicros ¶
func (x *ExportBundleInfo) SetServerTimestampOffsetMicros(v int64)
func (*ExportBundleInfo) String ¶
func (x *ExportBundleInfo) String() string
type ExportBundleInfo_builder ¶
type ExportBundleInfo_builder struct {
// Monotonically increasing index for each bundle set by SDK.
BundleSequenceId int32
// Timestamp offset between collection time and upload time.
ServerTimestampOffsetMicros int64
// contains filtered or unexported fields
}
func (ExportBundleInfo_builder) Build ¶
func (b0 ExportBundleInfo_builder) Build() *ExportBundleInfo
type GeoInfo ¶
type GeoInfo struct {
// The geographic continent.
// Eg. Americas
Continent string `protobuf:"bytes,1,opt,name=continent,proto3" json:"continent,omitempty"`
// The geographic country.
// Eg. Brazil
Country string `protobuf:"bytes,2,opt,name=country,proto3" json:"country,omitempty"`
// The geographic region.
// Eg. State of Sao Paulo
Region string `protobuf:"bytes,3,opt,name=region,proto3" json:"region,omitempty"`
// The geographic city.
// Eg. Sao Paulo
City string `protobuf:"bytes,4,opt,name=city,proto3" json:"city,omitempty"`
// contains filtered or unexported fields
}
User's geographic informaiton.
func (*GeoInfo) ProtoReflect ¶
func (x *GeoInfo) ProtoReflect() protoreflect.Message
type GeoInfo_builder ¶
type GeoInfo_builder struct {
// The geographic continent.
// Eg. Americas
Continent string
// The geographic country.
// Eg. Brazil
Country string
// The geographic region.
// Eg. State of Sao Paulo
Region string
// The geographic city.
// Eg. Sao Paulo
City string
// contains filtered or unexported fields
}
func (GeoInfo_builder) Build ¶
func (b0 GeoInfo_builder) Build() *GeoInfo
type LtvInfo ¶
type LtvInfo struct {
// The Lifetime Value revenue of this user.
Revenue float64 `protobuf:"fixed64,1,opt,name=revenue,proto3" json:"revenue,omitempty"`
// The currency corresponding to the revenue.
Currency string `protobuf:"bytes,2,opt,name=currency,proto3" json:"currency,omitempty"`
// contains filtered or unexported fields
}
Lifetime Value information about this user.
func (*LtvInfo) ProtoReflect ¶
func (x *LtvInfo) ProtoReflect() protoreflect.Message
type LtvInfo_builder ¶
type LtvInfo_builder struct {
// The Lifetime Value revenue of this user.
Revenue float64
// The currency corresponding to the revenue.
Currency string
// contains filtered or unexported fields
}
func (LtvInfo_builder) Build ¶
func (b0 LtvInfo_builder) Build() *LtvInfo
type TrafficSource ¶
type TrafficSource struct {
// The name of the campaign which acquired the user.
UserAcquiredCampaign string `protobuf:"bytes,2,opt,name=user_acquired_campaign,json=userAcquiredCampaign,proto3" json:"user_acquired_campaign,omitempty"`
// The name of the network which acquired the user.
UserAcquiredSource string `protobuf:"bytes,3,opt,name=user_acquired_source,json=userAcquiredSource,proto3" json:"user_acquired_source,omitempty"`
// The name of the medium which acquired the user.
UserAcquiredMedium string `protobuf:"bytes,4,opt,name=user_acquired_medium,json=userAcquiredMedium,proto3" json:"user_acquired_medium,omitempty"`
// contains filtered or unexported fields
}
Mesage containing marketing campaign information which acquired the user.
func (*TrafficSource) GetUserAcquiredCampaign ¶
func (x *TrafficSource) GetUserAcquiredCampaign() string
func (*TrafficSource) GetUserAcquiredMedium ¶
func (x *TrafficSource) GetUserAcquiredMedium() string
func (*TrafficSource) GetUserAcquiredSource ¶
func (x *TrafficSource) GetUserAcquiredSource() string
func (*TrafficSource) ProtoMessage ¶
func (*TrafficSource) ProtoMessage()
func (*TrafficSource) ProtoReflect ¶
func (x *TrafficSource) ProtoReflect() protoreflect.Message
func (*TrafficSource) Reset ¶
func (x *TrafficSource) Reset()
func (*TrafficSource) SetUserAcquiredCampaign ¶
func (x *TrafficSource) SetUserAcquiredCampaign(v string)
func (*TrafficSource) SetUserAcquiredMedium ¶
func (x *TrafficSource) SetUserAcquiredMedium(v string)
func (*TrafficSource) SetUserAcquiredSource ¶
func (x *TrafficSource) SetUserAcquiredSource(v string)
func (*TrafficSource) String ¶
func (x *TrafficSource) String() string
type TrafficSource_builder ¶
type TrafficSource_builder struct {
// The name of the campaign which acquired the user.
UserAcquiredCampaign string
// The name of the network which acquired the user.
UserAcquiredSource string
// The name of the medium which acquired the user.
UserAcquiredMedium string
// contains filtered or unexported fields
}
func (TrafficSource_builder) Build ¶
func (b0 TrafficSource_builder) Build() *TrafficSource
type UserDimensions ¶
type UserDimensions struct {
// The user ID set via the setUserId API.
UserId string `protobuf:"bytes,1,opt,name=user_id,json=userId,proto3" json:"user_id,omitempty"`
// The time (in microseconds) at which the user first opened the app.
FirstOpenTimestampMicros int64 `` /* 138-byte string literal not displayed */
// A repeated record of user properties set with the setUserProperty API.
// https://firebase.google.com/docs/analytics/android/properties
UserProperties map[string]*UserPropertyValue `` /* 177-byte string literal not displayed */
// Device information.
DeviceInfo *DeviceInfo `protobuf:"bytes,4,opt,name=device_info,json=deviceInfo,proto3" json:"device_info,omitempty"`
// User's geographic information.
GeoInfo *GeoInfo `protobuf:"bytes,5,opt,name=geo_info,json=geoInfo,proto3" json:"geo_info,omitempty"`
// App information.
AppInfo *AppInfo `protobuf:"bytes,6,opt,name=app_info,json=appInfo,proto3" json:"app_info,omitempty"`
// Information about marketing campaign which acquired the user.
TrafficSource *TrafficSource `protobuf:"bytes,7,opt,name=traffic_source,json=trafficSource,proto3" json:"traffic_source,omitempty"`
// Information regarding the bundle in which these events were uploaded.
BundleInfo *ExportBundleInfo `protobuf:"bytes,8,opt,name=bundle_info,json=bundleInfo,proto3" json:"bundle_info,omitempty"`
// Lifetime Value information about this user.
LtvInfo *LtvInfo `protobuf:"bytes,9,opt,name=ltv_info,json=ltvInfo,proto3" json:"ltv_info,omitempty"`
// contains filtered or unexported fields
}
Message containing information about the user associated with the event.
func (*UserDimensions) ClearAppInfo ¶
func (x *UserDimensions) ClearAppInfo()
func (*UserDimensions) ClearBundleInfo ¶
func (x *UserDimensions) ClearBundleInfo()
func (*UserDimensions) ClearDeviceInfo ¶
func (x *UserDimensions) ClearDeviceInfo()
func (*UserDimensions) ClearGeoInfo ¶
func (x *UserDimensions) ClearGeoInfo()
func (*UserDimensions) ClearLtvInfo ¶
func (x *UserDimensions) ClearLtvInfo()
func (*UserDimensions) ClearTrafficSource ¶
func (x *UserDimensions) ClearTrafficSource()
func (*UserDimensions) GetAppInfo ¶
func (x *UserDimensions) GetAppInfo() *AppInfo
func (*UserDimensions) GetBundleInfo ¶
func (x *UserDimensions) GetBundleInfo() *ExportBundleInfo
func (*UserDimensions) GetDeviceInfo ¶
func (x *UserDimensions) GetDeviceInfo() *DeviceInfo
func (*UserDimensions) GetFirstOpenTimestampMicros ¶
func (x *UserDimensions) GetFirstOpenTimestampMicros() int64
func (*UserDimensions) GetGeoInfo ¶
func (x *UserDimensions) GetGeoInfo() *GeoInfo
func (*UserDimensions) GetLtvInfo ¶
func (x *UserDimensions) GetLtvInfo() *LtvInfo
func (*UserDimensions) GetTrafficSource ¶
func (x *UserDimensions) GetTrafficSource() *TrafficSource
func (*UserDimensions) GetUserId ¶
func (x *UserDimensions) GetUserId() string
func (*UserDimensions) GetUserProperties ¶
func (x *UserDimensions) GetUserProperties() map[string]*UserPropertyValue
func (*UserDimensions) HasAppInfo ¶
func (x *UserDimensions) HasAppInfo() bool
func (*UserDimensions) HasBundleInfo ¶
func (x *UserDimensions) HasBundleInfo() bool
func (*UserDimensions) HasDeviceInfo ¶
func (x *UserDimensions) HasDeviceInfo() bool
func (*UserDimensions) HasGeoInfo ¶
func (x *UserDimensions) HasGeoInfo() bool
func (*UserDimensions) HasLtvInfo ¶
func (x *UserDimensions) HasLtvInfo() bool
func (*UserDimensions) HasTrafficSource ¶
func (x *UserDimensions) HasTrafficSource() bool
func (*UserDimensions) ProtoMessage ¶
func (*UserDimensions) ProtoMessage()
func (*UserDimensions) ProtoReflect ¶
func (x *UserDimensions) ProtoReflect() protoreflect.Message
func (*UserDimensions) Reset ¶
func (x *UserDimensions) Reset()
func (*UserDimensions) SetAppInfo ¶
func (x *UserDimensions) SetAppInfo(v *AppInfo)
func (*UserDimensions) SetBundleInfo ¶
func (x *UserDimensions) SetBundleInfo(v *ExportBundleInfo)
func (*UserDimensions) SetDeviceInfo ¶
func (x *UserDimensions) SetDeviceInfo(v *DeviceInfo)
func (*UserDimensions) SetFirstOpenTimestampMicros ¶
func (x *UserDimensions) SetFirstOpenTimestampMicros(v int64)
func (*UserDimensions) SetGeoInfo ¶
func (x *UserDimensions) SetGeoInfo(v *GeoInfo)
func (*UserDimensions) SetLtvInfo ¶
func (x *UserDimensions) SetLtvInfo(v *LtvInfo)
func (*UserDimensions) SetTrafficSource ¶
func (x *UserDimensions) SetTrafficSource(v *TrafficSource)
func (*UserDimensions) SetUserId ¶
func (x *UserDimensions) SetUserId(v string)
func (*UserDimensions) SetUserProperties ¶
func (x *UserDimensions) SetUserProperties(v map[string]*UserPropertyValue)
func (*UserDimensions) String ¶
func (x *UserDimensions) String() string
type UserDimensions_builder ¶
type UserDimensions_builder struct {
// The user ID set via the setUserId API.
UserId string
// The time (in microseconds) at which the user first opened the app.
FirstOpenTimestampMicros int64
// A repeated record of user properties set with the setUserProperty API.
// https://firebase.google.com/docs/analytics/android/properties
UserProperties map[string]*UserPropertyValue
// Device information.
DeviceInfo *DeviceInfo
// User's geographic information.
GeoInfo *GeoInfo
// App information.
AppInfo *AppInfo
// Information about marketing campaign which acquired the user.
TrafficSource *TrafficSource
// Information regarding the bundle in which these events were uploaded.
BundleInfo *ExportBundleInfo
// Lifetime Value information about this user.
LtvInfo *LtvInfo
// contains filtered or unexported fields
}
func (UserDimensions_builder) Build ¶
func (b0 UserDimensions_builder) Build() *UserDimensions
type UserPropertyValue ¶
type UserPropertyValue struct {
// Last set value of user property.
Value *AnalyticsValue `protobuf:"bytes,1,opt,name=value,proto3" json:"value,omitempty"`
// UTC client time when user property was last set.
SetTimestampUsec int64 `protobuf:"varint,2,opt,name=set_timestamp_usec,json=setTimestampUsec,proto3" json:"set_timestamp_usec,omitempty"`
// Index for user property (one-based).
Index int32 `protobuf:"varint,3,opt,name=index,proto3" json:"index,omitempty"`
// contains filtered or unexported fields
}
Predefined (eg: LTV) or custom properties (eg: birthday) stored on client side and associated with subsequent HitBundles.
func (*UserPropertyValue) ClearValue ¶
func (x *UserPropertyValue) ClearValue()
func (*UserPropertyValue) GetIndex ¶
func (x *UserPropertyValue) GetIndex() int32
func (*UserPropertyValue) GetSetTimestampUsec ¶
func (x *UserPropertyValue) GetSetTimestampUsec() int64
func (*UserPropertyValue) GetValue ¶
func (x *UserPropertyValue) GetValue() *AnalyticsValue
func (*UserPropertyValue) HasValue ¶
func (x *UserPropertyValue) HasValue() bool
func (*UserPropertyValue) ProtoMessage ¶
func (*UserPropertyValue) ProtoMessage()
func (*UserPropertyValue) ProtoReflect ¶
func (x *UserPropertyValue) ProtoReflect() protoreflect.Message
func (*UserPropertyValue) Reset ¶
func (x *UserPropertyValue) Reset()
func (*UserPropertyValue) SetIndex ¶
func (x *UserPropertyValue) SetIndex(v int32)
func (*UserPropertyValue) SetSetTimestampUsec ¶
func (x *UserPropertyValue) SetSetTimestampUsec(v int64)
func (*UserPropertyValue) SetValue ¶
func (x *UserPropertyValue) SetValue(v *AnalyticsValue)
func (*UserPropertyValue) String ¶
func (x *UserPropertyValue) String() string
type UserPropertyValue_builder ¶
type UserPropertyValue_builder struct {
// Last set value of user property.
Value *AnalyticsValue
// UTC client time when user property was last set.
SetTimestampUsec int64
// Index for user property (one-based).
Index int32
// contains filtered or unexported fields
}
func (UserPropertyValue_builder) Build ¶
func (b0 UserPropertyValue_builder) Build() *UserPropertyValue
Source Files
¶
- data.pb.go
- events.pb.go