Documentation
¶
Index ¶
- Variables
- type ClientInfo
- func (x *ClientInfo) GetClient() string
- func (x *ClientInfo) GetDetails() map[string]string
- func (*ClientInfo) ProtoMessage()
- func (x *ClientInfo) ProtoReflect() protoreflect.Message
- func (x *ClientInfo) Reset()
- func (x *ClientInfo) SetClient(v string)
- func (x *ClientInfo) SetDetails(v map[string]string)
- func (x *ClientInfo) String() string
- type ClientInfo_builder
- type OutcomeSummary
- type ResultStorage
- func (x *ResultStorage) GetGcsPath() string
- func (x *ResultStorage) GetResultsUri() string
- func (x *ResultStorage) GetToolResultsExecution() string
- func (x *ResultStorage) GetToolResultsHistory() string
- func (*ResultStorage) ProtoMessage()
- func (x *ResultStorage) ProtoReflect() protoreflect.Message
- func (x *ResultStorage) Reset()
- func (x *ResultStorage) SetGcsPath(v string)
- func (x *ResultStorage) SetResultsUri(v string)
- func (x *ResultStorage) SetToolResultsExecution(v string)
- func (x *ResultStorage) SetToolResultsHistory(v string)
- func (x *ResultStorage) String() string
- type ResultStorage_builder
- type TestMatrixCompletedEvent
- func (x *TestMatrixCompletedEvent) ClearData()
- func (x *TestMatrixCompletedEvent) GetData() *TestMatrixEventData
- func (x *TestMatrixCompletedEvent) HasData() bool
- func (*TestMatrixCompletedEvent) ProtoMessage()
- func (x *TestMatrixCompletedEvent) ProtoReflect() protoreflect.Message
- func (x *TestMatrixCompletedEvent) Reset()
- func (x *TestMatrixCompletedEvent) SetData(v *TestMatrixEventData)
- func (x *TestMatrixCompletedEvent) String() string
- type TestMatrixCompletedEvent_builder
- type TestMatrixEventData
- func (x *TestMatrixEventData) ClearClientInfo()
- func (x *TestMatrixEventData) ClearCreateTime()
- func (x *TestMatrixEventData) ClearResultStorage()
- func (x *TestMatrixEventData) GetClientInfo() *ClientInfo
- func (x *TestMatrixEventData) GetCreateTime() *timestamppb.Timestamp
- func (x *TestMatrixEventData) GetInvalidMatrixDetails() string
- func (x *TestMatrixEventData) GetOutcomeSummary() OutcomeSummary
- func (x *TestMatrixEventData) GetResultStorage() *ResultStorage
- func (x *TestMatrixEventData) GetState() TestState
- func (x *TestMatrixEventData) GetTestMatrixId() string
- func (x *TestMatrixEventData) HasClientInfo() bool
- func (x *TestMatrixEventData) HasCreateTime() bool
- func (x *TestMatrixEventData) HasResultStorage() bool
- func (*TestMatrixEventData) ProtoMessage()
- func (x *TestMatrixEventData) ProtoReflect() protoreflect.Message
- func (x *TestMatrixEventData) Reset()
- func (x *TestMatrixEventData) SetClientInfo(v *ClientInfo)
- func (x *TestMatrixEventData) SetCreateTime(v *timestamppb.Timestamp)
- func (x *TestMatrixEventData) SetInvalidMatrixDetails(v string)
- func (x *TestMatrixEventData) SetOutcomeSummary(v OutcomeSummary)
- func (x *TestMatrixEventData) SetResultStorage(v *ResultStorage)
- func (x *TestMatrixEventData) SetState(v TestState)
- func (x *TestMatrixEventData) SetTestMatrixId(v string)
- func (x *TestMatrixEventData) String() string
- type TestMatrixEventData_builder
- type TestState
Constants ¶
This section is empty.
Variables ¶
var ( TestState_name = map[int32]string{ 0: "TEST_STATE_UNSPECIFIED", 1: "VALIDATING", 2: "PENDING", 3: "FINISHED", 4: "ERROR", 5: "INVALID", } TestState_value = map[string]int32{ "TEST_STATE_UNSPECIFIED": 0, "VALIDATING": 1, "PENDING": 2, "FINISHED": 3, "ERROR": 4, "INVALID": 5, } )
Enum value maps for TestState.
var ( OutcomeSummary_name = map[int32]string{ 0: "OUTCOME_SUMMARY_UNSPECIFIED", 1: "SUCCESS", 2: "FAILURE", 3: "INCONCLUSIVE", 4: "SKIPPED", } OutcomeSummary_value = map[string]int32{ "OUTCOME_SUMMARY_UNSPECIFIED": 0, "SUCCESS": 1, "FAILURE": 2, "INCONCLUSIVE": 3, "SKIPPED": 4, } )
Enum value maps for OutcomeSummary.
var File_google_events_firebase_testlab_v1_data_proto protoreflect.FileDescriptor
var File_google_events_firebase_testlab_v1_events_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type ClientInfo ¶
type ClientInfo struct {
// Client name, such as "gcloud".
Client string `protobuf:"bytes,1,opt,name=client,proto3" json:"client,omitempty"`
// Map of detailed information about the client.
Details map[string]string `` /* 141-byte string literal not displayed */
// contains filtered or unexported fields
}
Information about the client which invoked the test.
func (*ClientInfo) GetClient ¶
func (x *ClientInfo) GetClient() string
func (*ClientInfo) GetDetails ¶
func (x *ClientInfo) GetDetails() map[string]string
func (*ClientInfo) ProtoMessage ¶
func (*ClientInfo) ProtoMessage()
func (*ClientInfo) ProtoReflect ¶
func (x *ClientInfo) ProtoReflect() protoreflect.Message
func (*ClientInfo) Reset ¶
func (x *ClientInfo) Reset()
func (*ClientInfo) SetClient ¶
func (x *ClientInfo) SetClient(v string)
func (*ClientInfo) SetDetails ¶
func (x *ClientInfo) SetDetails(v map[string]string)
func (*ClientInfo) String ¶
func (x *ClientInfo) String() string
type ClientInfo_builder ¶
type ClientInfo_builder struct {
// Client name, such as "gcloud".
Client string
// Map of detailed information about the client.
Details map[string]string
// contains filtered or unexported fields
}
func (ClientInfo_builder) Build ¶
func (b0 ClientInfo_builder) Build() *ClientInfo
type OutcomeSummary ¶
type OutcomeSummary int32
Outcome summary for a finished test matrix.
const ( // The default value. This value is used if the state is omitted. OutcomeSummary_OUTCOME_SUMMARY_UNSPECIFIED OutcomeSummary = 0 // The test matrix run was successful, for instance: // - All test cases passed. // - No crash of the application under test was detected. OutcomeSummary_SUCCESS OutcomeSummary = 1 // A run failed, for instance: // - One or more test case failed. // - A test timed out. // - The application under test crashed. OutcomeSummary_FAILURE OutcomeSummary = 2 // Something unexpected happened. The test run should still be considered // unsuccessful but this is likely a transient problem and re-running the // test might be successful. OutcomeSummary_INCONCLUSIVE OutcomeSummary = 3 // All tests were skipped. OutcomeSummary_SKIPPED OutcomeSummary = 4 )
func (OutcomeSummary) Descriptor ¶
func (OutcomeSummary) Descriptor() protoreflect.EnumDescriptor
func (OutcomeSummary) Enum ¶
func (x OutcomeSummary) Enum() *OutcomeSummary
func (OutcomeSummary) Number ¶
func (x OutcomeSummary) Number() protoreflect.EnumNumber
func (OutcomeSummary) String ¶
func (x OutcomeSummary) String() string
func (OutcomeSummary) Type ¶
func (OutcomeSummary) Type() protoreflect.EnumType
type ResultStorage ¶
type ResultStorage struct {
// Tool Results history resource containing test results. Format is
// `projects/{project_id}/histories/{history_id}`.
// See https://firebase.google.com/docs/test-lab/reference/toolresults/rest
// for more information.
ToolResultsHistory string `protobuf:"bytes,1,opt,name=tool_results_history,json=toolResultsHistory,proto3" json:"tool_results_history,omitempty"`
// Tool Results execution resource containing test results. Format is
// `projects/{project_id}/histories/{history_id}/executions/{execution_id}`.
// Optional, can be omitted in erroneous test states.
// See https://firebase.google.com/docs/test-lab/reference/toolresults/rest
// for more information.
ToolResultsExecution string `protobuf:"bytes,2,opt,name=tool_results_execution,json=toolResultsExecution,proto3" json:"tool_results_execution,omitempty"`
// URI to the test results in the Firebase Web Console.
ResultsUri string `protobuf:"bytes,3,opt,name=results_uri,json=resultsUri,proto3" json:"results_uri,omitempty"`
// Location in Google Cloud Storage where test results are written to.
// In the form "gs://bucket/path/to/somewhere".
GcsPath string `protobuf:"bytes,4,opt,name=gcs_path,json=gcsPath,proto3" json:"gcs_path,omitempty"`
// contains filtered or unexported fields
}
Locations where test results are stored.
func (*ResultStorage) GetGcsPath ¶
func (x *ResultStorage) GetGcsPath() string
func (*ResultStorage) GetResultsUri ¶
func (x *ResultStorage) GetResultsUri() string
func (*ResultStorage) GetToolResultsExecution ¶
func (x *ResultStorage) GetToolResultsExecution() string
func (*ResultStorage) GetToolResultsHistory ¶
func (x *ResultStorage) GetToolResultsHistory() string
func (*ResultStorage) ProtoMessage ¶
func (*ResultStorage) ProtoMessage()
func (*ResultStorage) ProtoReflect ¶
func (x *ResultStorage) ProtoReflect() protoreflect.Message
func (*ResultStorage) Reset ¶
func (x *ResultStorage) Reset()
func (*ResultStorage) SetGcsPath ¶
func (x *ResultStorage) SetGcsPath(v string)
func (*ResultStorage) SetResultsUri ¶
func (x *ResultStorage) SetResultsUri(v string)
func (*ResultStorage) SetToolResultsExecution ¶
func (x *ResultStorage) SetToolResultsExecution(v string)
func (*ResultStorage) SetToolResultsHistory ¶
func (x *ResultStorage) SetToolResultsHistory(v string)
func (*ResultStorage) String ¶
func (x *ResultStorage) String() string
type ResultStorage_builder ¶
type ResultStorage_builder struct {
// Tool Results history resource containing test results. Format is
// `projects/{project_id}/histories/{history_id}`.
// See https://firebase.google.com/docs/test-lab/reference/toolresults/rest
// for more information.
ToolResultsHistory string
// Tool Results execution resource containing test results. Format is
// `projects/{project_id}/histories/{history_id}/executions/{execution_id}`.
// Optional, can be omitted in erroneous test states.
// See https://firebase.google.com/docs/test-lab/reference/toolresults/rest
// for more information.
ToolResultsExecution string
// URI to the test results in the Firebase Web Console.
ResultsUri string
// Location in Google Cloud Storage where test results are written to.
// In the form "gs://bucket/path/to/somewhere".
GcsPath string
// contains filtered or unexported fields
}
func (ResultStorage_builder) Build ¶
func (b0 ResultStorage_builder) Build() *ResultStorage
type TestMatrixCompletedEvent ¶
type TestMatrixCompletedEvent struct {
// The data associated with the event.
Data *TestMatrixEventData `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
// contains filtered or unexported fields
}
The CloudEvent raised when a TestMatrix is completed
func (*TestMatrixCompletedEvent) ClearData ¶
func (x *TestMatrixCompletedEvent) ClearData()
func (*TestMatrixCompletedEvent) GetData ¶
func (x *TestMatrixCompletedEvent) GetData() *TestMatrixEventData
func (*TestMatrixCompletedEvent) HasData ¶
func (x *TestMatrixCompletedEvent) HasData() bool
func (*TestMatrixCompletedEvent) ProtoMessage ¶
func (*TestMatrixCompletedEvent) ProtoMessage()
func (*TestMatrixCompletedEvent) ProtoReflect ¶
func (x *TestMatrixCompletedEvent) ProtoReflect() protoreflect.Message
func (*TestMatrixCompletedEvent) Reset ¶
func (x *TestMatrixCompletedEvent) Reset()
func (*TestMatrixCompletedEvent) SetData ¶
func (x *TestMatrixCompletedEvent) SetData(v *TestMatrixEventData)
func (*TestMatrixCompletedEvent) String ¶
func (x *TestMatrixCompletedEvent) String() string
type TestMatrixCompletedEvent_builder ¶
type TestMatrixCompletedEvent_builder struct {
// The data associated with the event.
Data *TestMatrixEventData
// contains filtered or unexported fields
}
func (TestMatrixCompletedEvent_builder) Build ¶
func (b0 TestMatrixCompletedEvent_builder) Build() *TestMatrixCompletedEvent
type TestMatrixEventData ¶
type TestMatrixEventData struct {
// Time the test matrix was created.
CreateTime *timestamppb.Timestamp `protobuf:"bytes,1,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
// State of the test matrix.
State TestState `protobuf:"varint,2,opt,name=state,proto3,enum=google.events.firebase.testlab.v1.TestState" json:"state,omitempty"`
// Code that describes why the test matrix is considered invalid. Only set for
// matrices in the INVALID state.
InvalidMatrixDetails string `protobuf:"bytes,3,opt,name=invalid_matrix_details,json=invalidMatrixDetails,proto3" json:"invalid_matrix_details,omitempty"`
// Outcome summary of the test matrix.
OutcomeSummary OutcomeSummary `` /* 158-byte string literal not displayed */
// Locations where test results are stored.
ResultStorage *ResultStorage `protobuf:"bytes,5,opt,name=result_storage,json=resultStorage,proto3" json:"result_storage,omitempty"`
// Information provided by the client that created the test matrix.
ClientInfo *ClientInfo `protobuf:"bytes,6,opt,name=client_info,json=clientInfo,proto3" json:"client_info,omitempty"`
// ID of the test matrix this event belongs to.
TestMatrixId string `protobuf:"bytes,7,opt,name=test_matrix_id,json=testMatrixId,proto3" json:"test_matrix_id,omitempty"`
// contains filtered or unexported fields
}
The data within all Firebase test matrix events.
func (*TestMatrixEventData) ClearClientInfo ¶
func (x *TestMatrixEventData) ClearClientInfo()
func (*TestMatrixEventData) ClearCreateTime ¶
func (x *TestMatrixEventData) ClearCreateTime()
func (*TestMatrixEventData) ClearResultStorage ¶
func (x *TestMatrixEventData) ClearResultStorage()
func (*TestMatrixEventData) GetClientInfo ¶
func (x *TestMatrixEventData) GetClientInfo() *ClientInfo
func (*TestMatrixEventData) GetCreateTime ¶
func (x *TestMatrixEventData) GetCreateTime() *timestamppb.Timestamp
func (*TestMatrixEventData) GetInvalidMatrixDetails ¶
func (x *TestMatrixEventData) GetInvalidMatrixDetails() string
func (*TestMatrixEventData) GetOutcomeSummary ¶
func (x *TestMatrixEventData) GetOutcomeSummary() OutcomeSummary
func (*TestMatrixEventData) GetResultStorage ¶
func (x *TestMatrixEventData) GetResultStorage() *ResultStorage
func (*TestMatrixEventData) GetState ¶
func (x *TestMatrixEventData) GetState() TestState
func (*TestMatrixEventData) GetTestMatrixId ¶
func (x *TestMatrixEventData) GetTestMatrixId() string
func (*TestMatrixEventData) HasClientInfo ¶
func (x *TestMatrixEventData) HasClientInfo() bool
func (*TestMatrixEventData) HasCreateTime ¶
func (x *TestMatrixEventData) HasCreateTime() bool
func (*TestMatrixEventData) HasResultStorage ¶
func (x *TestMatrixEventData) HasResultStorage() bool
func (*TestMatrixEventData) ProtoMessage ¶
func (*TestMatrixEventData) ProtoMessage()
func (*TestMatrixEventData) ProtoReflect ¶
func (x *TestMatrixEventData) ProtoReflect() protoreflect.Message
func (*TestMatrixEventData) Reset ¶
func (x *TestMatrixEventData) Reset()
func (*TestMatrixEventData) SetClientInfo ¶
func (x *TestMatrixEventData) SetClientInfo(v *ClientInfo)
func (*TestMatrixEventData) SetCreateTime ¶
func (x *TestMatrixEventData) SetCreateTime(v *timestamppb.Timestamp)
func (*TestMatrixEventData) SetInvalidMatrixDetails ¶
func (x *TestMatrixEventData) SetInvalidMatrixDetails(v string)
func (*TestMatrixEventData) SetOutcomeSummary ¶
func (x *TestMatrixEventData) SetOutcomeSummary(v OutcomeSummary)
func (*TestMatrixEventData) SetResultStorage ¶
func (x *TestMatrixEventData) SetResultStorage(v *ResultStorage)
func (*TestMatrixEventData) SetState ¶
func (x *TestMatrixEventData) SetState(v TestState)
func (*TestMatrixEventData) SetTestMatrixId ¶
func (x *TestMatrixEventData) SetTestMatrixId(v string)
func (*TestMatrixEventData) String ¶
func (x *TestMatrixEventData) String() string
type TestMatrixEventData_builder ¶
type TestMatrixEventData_builder struct {
// Time the test matrix was created.
CreateTime *timestamppb.Timestamp
// State of the test matrix.
State TestState
// Code that describes why the test matrix is considered invalid. Only set for
// matrices in the INVALID state.
InvalidMatrixDetails string
// Outcome summary of the test matrix.
OutcomeSummary OutcomeSummary
// Locations where test results are stored.
ResultStorage *ResultStorage
// Information provided by the client that created the test matrix.
ClientInfo *ClientInfo
// ID of the test matrix this event belongs to.
TestMatrixId string
// contains filtered or unexported fields
}
func (TestMatrixEventData_builder) Build ¶
func (b0 TestMatrixEventData_builder) Build() *TestMatrixEventData
type TestState ¶
type TestState int32
Possible test states for a test matrix.
const ( // The default value. This value is used if the state is omitted. TestState_TEST_STATE_UNSPECIFIED TestState = 0 // The test matrix is being validated. TestState_VALIDATING TestState = 1 // The test matrix is waiting for resources to become available. TestState_PENDING TestState = 2 // The test matrix has completed normally. TestState_FINISHED TestState = 3 // The test matrix has completed because of an infrastructure failure. TestState_ERROR TestState = 4 // The test matrix was not run because the provided inputs are not valid. TestState_INVALID TestState = 5 )
func (TestState) Descriptor ¶
func (TestState) Descriptor() protoreflect.EnumDescriptor
func (TestState) Number ¶
func (x TestState) Number() protoreflect.EnumNumber
func (TestState) Type ¶
func (TestState) Type() protoreflect.EnumType
Source Files
¶
- data.pb.go
- events.pb.go
Click to show internal directories.
Click to hide internal directories.